#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Cordics (COordinate Rotation DIgital Computers) are used to calculate
#    trigonometric functions and complex plane phase rotations.
#    This rotation mode cordic rotates a complex vector by the initial angle.
#    If the rotation will transition through +-PI/2 then the "flip_i" control
#    input must be set.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      enable_i : Synchronous enable.
#      reset_i  : Synchronous reset.
#  
#    Inputs:
#      flip_i   : Set to perform initial rotation if rotation will transition through +-PI/2
#      real_i   : Initial real component (signed).
#      imag_i   : Initial imaginary component (signed).
#      angle_i  : Initial angle (modulo 2PI).
#  
#    Outputs:
#      real_o   : Resulting real component (signed).
#      imag_o   : Resulting imaginary component (signed).
#      angle_o  : Resulting angle (modulo 2PI).
#  
#  Built In Parameters:
#  
#    Cordic Mode    = Rotation
#    Vector Width   = 16
#    Angle Width    = 16
#    Cordic Stages  = 16
#  
#  Resulting Pipeline Latency is 18 clock cycles.
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:44:22 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_cordic_r_16_16_16
#    Clock Domains : clock_c  
#    Vector Input  : enable_i(1)
#    Vector Input  : reset_i(1)
#    Vector Input  : flip_i(1)
#    Vector Input  : real_i(16)
#    Vector Input  : imag_i(16)
#    Vector Input  : ang_i(16)
#    Vector Output : real_o(16)
#    Vector Output : imag_o(16)
#    Vector Output : ang_o(16)
#  
#  
#  

import sys
import time

class cf_cordic_r_16_16_16:

  def init(self):
    self.n1291 = 0L
    self.n1289 = 0L
    self.n1287 = 0L
    self.n1285 = 0L
    self.n1283 = 0L
    self.n1281 = 0L
    self.n1279 = 0L
    self.n1277 = 0L
    self.n1275 = 0L
    self.n1273 = 0L
    self.n1271 = 0L
    self.n1269 = 0L
    self.n1267 = 0L
    self.n1265 = 0L
    self.n1263 = 0L
    self.n1261 = 0L
    self.n1194 = 0L
    self.n1191 = 0L
    self.n1190 = 0L
    self.n1189 = 0L
    self.n1178 = 0L
    self.n1166 = 0L
    self.n1149 = 0L
    self.n1136 = 0L
    self.n1119 = 0L
    self.n1113 = 0L
    self.n1107 = 0L
    self.n1105 = 0L
    self.n1093 = 0L
    self.n1081 = 0L
    self.n1065 = 0L
    self.n1052 = 0L
    self.n1036 = 0L
    self.n1030 = 0L
    self.n1024 = 0L
    self.n1022 = 0L
    self.n1010 = 0L
    self.n998 = 0L
    self.n983 = 0L
    self.n970 = 0L
    self.n955 = 0L
    self.n949 = 0L
    self.n943 = 0L
    self.n941 = 0L
    self.n929 = 0L
    self.n917 = 0L
    self.n903 = 0L
    self.n890 = 0L
    self.n876 = 0L
    self.n870 = 0L
    self.n864 = 0L
    self.n862 = 0L
    self.n850 = 0L
    self.n838 = 0L
    self.n825 = 0L
    self.n812 = 0L
    self.n799 = 0L
    self.n793 = 0L
    self.n787 = 0L
    self.n785 = 0L
    self.n773 = 0L
    self.n761 = 0L
    self.n749 = 0L
    self.n736 = 0L
    self.n724 = 0L
    self.n718 = 0L
    self.n712 = 0L
    self.n710 = 0L
    self.n698 = 0L
    self.n686 = 0L
    self.n675 = 0L
    self.n662 = 0L
    self.n651 = 0L
    self.n645 = 0L
    self.n639 = 0L
    self.n637 = 0L
    self.n625 = 0L
    self.n613 = 0L
    self.n603 = 0L
    self.n590 = 0L
    self.n580 = 0L
    self.n574 = 0L
    self.n568 = 0L
    self.n566 = 0L
    self.n554 = 0L
    self.n542 = 0L
    self.n533 = 0L
    self.n520 = 0L
    self.n511 = 0L
    self.n505 = 0L
    self.n499 = 0L
    self.n497 = 0L
    self.n485 = 0L
    self.n473 = 0L
    self.n465 = 0L
    self.n452 = 0L
    self.n444 = 0L
    self.n438 = 0L
    self.n432 = 0L
    self.n430 = 0L
    self.n418 = 0L
    self.n406 = 0L
    self.n399 = 0L
    self.n386 = 0L
    self.n379 = 0L
    self.n373 = 0L
    self.n367 = 0L
    self.n365 = 0L
    self.n353 = 0L
    self.n341 = 0L
    self.n335 = 0L
    self.n322 = 0L
    self.n316 = 0L
    self.n310 = 0L
    self.n304 = 0L
    self.n302 = 0L
    self.n290 = 0L
    self.n278 = 0L
    self.n273 = 0L
    self.n260 = 0L
    self.n255 = 0L
    self.n249 = 0L
    self.n243 = 0L
    self.n241 = 0L
    self.n229 = 0L
    self.n217 = 0L
    self.n213 = 0L
    self.n200 = 0L
    self.n196 = 0L
    self.n190 = 0L
    self.n184 = 0L
    self.n182 = 0L
    self.n170 = 0L
    self.n158 = 0L
    self.n155 = 0L
    self.n142 = 0L
    self.n139 = 0L
    self.n133 = 0L
    self.n127 = 0L
    self.n125 = 0L
    self.n113 = 0L
    self.n101 = 0L
    self.n86 = 0L
    self.n78 = 0L
    self.n72 = 0L
    self.n70 = 0L
    self.n39 = 0L
    self.n37 = 0L
    self.n8 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n1180 = 0L
    self.n1179 = 0L
    self.n1152 = 0L
    self.n1122 = 0L
    self.n1106 = 0L
    self.n1095 = 0L
    self.n1094 = 0L
    self.n1068 = 0L
    self.n1039 = 0L
    self.n1023 = 0L
    self.n1012 = 0L
    self.n1011 = 0L
    self.n986 = 0L
    self.n958 = 0L
    self.n942 = 0L
    self.n931 = 0L
    self.n930 = 0L
    self.n906 = 0L
    self.n879 = 0L
    self.n863 = 0L
    self.n852 = 0L
    self.n851 = 0L
    self.n828 = 0L
    self.n802 = 0L
    self.n786 = 0L
    self.n775 = 0L
    self.n774 = 0L
    self.n752 = 0L
    self.n727 = 0L
    self.n711 = 0L
    self.n700 = 0L
    self.n699 = 0L
    self.n678 = 0L
    self.n654 = 0L
    self.n638 = 0L
    self.n627 = 0L
    self.n626 = 0L
    self.n606 = 0L
    self.n583 = 0L
    self.n567 = 0L
    self.n556 = 0L
    self.n555 = 0L
    self.n536 = 0L
    self.n514 = 0L
    self.n498 = 0L
    self.n487 = 0L
    self.n486 = 0L
    self.n468 = 0L
    self.n447 = 0L
    self.n431 = 0L
    self.n420 = 0L
    self.n419 = 0L
    self.n402 = 0L
    self.n382 = 0L
    self.n366 = 0L
    self.n355 = 0L
    self.n354 = 0L
    self.n338 = 0L
    self.n319 = 0L
    self.n303 = 0L
    self.n292 = 0L
    self.n291 = 0L
    self.n276 = 0L
    self.n258 = 0L
    self.n242 = 0L
    self.n231 = 0L
    self.n230 = 0L
    self.n216 = 0L
    self.n199 = 0L
    self.n183 = 0L
    self.n172 = 0L
    self.n171 = 0L
    self.n159 = 0L
    self.n143 = 0L
    self.n126 = 0L
    self.n115 = 0L
    self.n114 = 0L
    self.n104 = 0L
    self.n103 = 0L
    self.n89 = 0L
    self.n88 = 0L
    self.n71 = 0L
    self.n44 = 0L
    self.n40 = 0L
    self.n38 = 0L
    self.n36 = 0L
    self.n36r = 0L
    self.n36e = 0L
    self.n36d = 0L
    self.n29 = 0L
    self.n29r = 0L
    self.n29e = 0L
    self.n29d = 0L
    self.n22 = 0L
    self.n22r = 0L
    self.n22e = 0L
    self.n22d = 0L
    self.n15 = 0L
    self.n15r = 0L
    self.n15e = 0L
    self.n15d = 0L
    self.n1153 = 0L
    self.n1123 = 0L
    self.n1108 = 0L
    self.n1069 = 0L
    self.n1040 = 0L
    self.n1025 = 0L
    self.n987 = 0L
    self.n959 = 0L
    self.n944 = 0L
    self.n907 = 0L
    self.n880 = 0L
    self.n865 = 0L
    self.n829 = 0L
    self.n803 = 0L
    self.n788 = 0L
    self.n753 = 0L
    self.n728 = 0L
    self.n713 = 0L
    self.n679 = 0L
    self.n655 = 0L
    self.n640 = 0L
    self.n607 = 0L
    self.n584 = 0L
    self.n569 = 0L
    self.n537 = 0L
    self.n515 = 0L
    self.n500 = 0L
    self.n469 = 0L
    self.n448 = 0L
    self.n433 = 0L
    self.n403 = 0L
    self.n383 = 0L
    self.n368 = 0L
    self.n339 = 0L
    self.n320 = 0L
    self.n305 = 0L
    self.n277 = 0L
    self.n259 = 0L
    self.n244 = 0L
    self.n218 = 0L
    self.n201 = 0L
    self.n185 = 0L
    self.n161 = 0L
    self.n160 = 0L
    self.n145 = 0L
    self.n144 = 0L
    self.n128 = 0L
    self.n73 = 0L
    self.n61 = 0L
    self.n53 = 0L
    self.n45 = 0L
    self.n1154 = 0L
    self.n1124 = 0L
    self.n1114 = 0L
    self.n1070 = 0L
    self.n1041 = 0L
    self.n1031 = 0L
    self.n988 = 0L
    self.n960 = 0L
    self.n950 = 0L
    self.n908 = 0L
    self.n881 = 0L
    self.n871 = 0L
    self.n830 = 0L
    self.n804 = 0L
    self.n794 = 0L
    self.n754 = 0L
    self.n729 = 0L
    self.n719 = 0L
    self.n680 = 0L
    self.n656 = 0L
    self.n646 = 0L
    self.n608 = 0L
    self.n585 = 0L
    self.n575 = 0L
    self.n538 = 0L
    self.n516 = 0L
    self.n506 = 0L
    self.n470 = 0L
    self.n449 = 0L
    self.n439 = 0L
    self.n404 = 0L
    self.n384 = 0L
    self.n374 = 0L
    self.n340 = 0L
    self.n321 = 0L
    self.n311 = 0L
    self.n279 = 0L
    self.n261 = 0L
    self.n250 = 0L
    self.n220 = 0L
    self.n219 = 0L
    self.n203 = 0L
    self.n202 = 0L
    self.n191 = 0L
    self.n134 = 0L
    self.n79 = 0L
    self.n68 = 0L
    self.n68r = 0L
    self.n68e = 0L
    self.n68d = 0L
    self.n60 = 0L
    self.n60r = 0L
    self.n60e = 0L
    self.n60d = 0L
    self.n52 = 0L
    self.n52r = 0L
    self.n52e = 0L
    self.n52d = 0L
    self.n1155 = 0L
    self.n1125 = 0L
    self.n1117 = 0L
    self.n1071 = 0L
    self.n1042 = 0L
    self.n1034 = 0L
    self.n989 = 0L
    self.n961 = 0L
    self.n953 = 0L
    self.n909 = 0L
    self.n882 = 0L
    self.n874 = 0L
    self.n831 = 0L
    self.n805 = 0L
    self.n797 = 0L
    self.n755 = 0L
    self.n730 = 0L
    self.n722 = 0L
    self.n681 = 0L
    self.n657 = 0L
    self.n649 = 0L
    self.n609 = 0L
    self.n586 = 0L
    self.n578 = 0L
    self.n539 = 0L
    self.n517 = 0L
    self.n509 = 0L
    self.n471 = 0L
    self.n450 = 0L
    self.n442 = 0L
    self.n405 = 0L
    self.n385 = 0L
    self.n377 = 0L
    self.n342 = 0L
    self.n323 = 0L
    self.n314 = 0L
    self.n281 = 0L
    self.n280 = 0L
    self.n263 = 0L
    self.n262 = 0L
    self.n253 = 0L
    self.n194 = 0L
    self.n137 = 0L
    self.n82 = 0L
    self.n1156 = 0L
    self.n1126 = 0L
    self.n1118 = 0L
    self.n1072 = 0L
    self.n1043 = 0L
    self.n1035 = 0L
    self.n990 = 0L
    self.n962 = 0L
    self.n954 = 0L
    self.n910 = 0L
    self.n883 = 0L
    self.n875 = 0L
    self.n832 = 0L
    self.n806 = 0L
    self.n798 = 0L
    self.n756 = 0L
    self.n731 = 0L
    self.n723 = 0L
    self.n682 = 0L
    self.n658 = 0L
    self.n650 = 0L
    self.n610 = 0L
    self.n587 = 0L
    self.n579 = 0L
    self.n540 = 0L
    self.n518 = 0L
    self.n510 = 0L
    self.n472 = 0L
    self.n451 = 0L
    self.n443 = 0L
    self.n407 = 0L
    self.n387 = 0L
    self.n378 = 0L
    self.n344 = 0L
    self.n343 = 0L
    self.n325 = 0L
    self.n324 = 0L
    self.n315 = 0L
    self.n254 = 0L
    self.n195 = 0L
    self.n138 = 0L
    self.n83 = 0L
    self.n1181 = 0L
    self.n1157 = 0L
    self.n1148 = 0L
    self.n1127 = 0L
    self.n1096 = 0L
    self.n1073 = 0L
    self.n1064 = 0L
    self.n1044 = 0L
    self.n1013 = 0L
    self.n991 = 0L
    self.n982 = 0L
    self.n963 = 0L
    self.n932 = 0L
    self.n911 = 0L
    self.n902 = 0L
    self.n884 = 0L
    self.n853 = 0L
    self.n833 = 0L
    self.n824 = 0L
    self.n807 = 0L
    self.n776 = 0L
    self.n757 = 0L
    self.n748 = 0L
    self.n732 = 0L
    self.n701 = 0L
    self.n683 = 0L
    self.n674 = 0L
    self.n659 = 0L
    self.n628 = 0L
    self.n611 = 0L
    self.n602 = 0L
    self.n588 = 0L
    self.n557 = 0L
    self.n541 = 0L
    self.n532 = 0L
    self.n519 = 0L
    self.n488 = 0L
    self.n474 = 0L
    self.n464 = 0L
    self.n453 = 0L
    self.n421 = 0L
    self.n409 = 0L
    self.n408 = 0L
    self.n398 = 0L
    self.n389 = 0L
    self.n388 = 0L
    self.n356 = 0L
    self.n334 = 0L
    self.n326 = 0L
    self.n293 = 0L
    self.n272 = 0L
    self.n264 = 0L
    self.n232 = 0L
    self.n212 = 0L
    self.n204 = 0L
    self.n173 = 0L
    self.n154 = 0L
    self.n146 = 0L
    self.n116 = 0L
    self.n98 = 0L
    self.n90 = 0L
    self.n1188 = 0L
    self.n1188r = 0L
    self.n1188e = 0L
    self.n1188d = 0L
    self.n1158 = 0L
    self.n1128 = 0L
    self.n1103 = 0L
    self.n1103r = 0L
    self.n1103e = 0L
    self.n1103d = 0L
    self.n1074 = 0L
    self.n1045 = 0L
    self.n1020 = 0L
    self.n1020r = 0L
    self.n1020e = 0L
    self.n1020d = 0L
    self.n992 = 0L
    self.n964 = 0L
    self.n939 = 0L
    self.n939r = 0L
    self.n939e = 0L
    self.n939d = 0L
    self.n912 = 0L
    self.n885 = 0L
    self.n860 = 0L
    self.n860r = 0L
    self.n860e = 0L
    self.n860d = 0L
    self.n834 = 0L
    self.n808 = 0L
    self.n783 = 0L
    self.n783r = 0L
    self.n783e = 0L
    self.n783d = 0L
    self.n758 = 0L
    self.n733 = 0L
    self.n708 = 0L
    self.n708r = 0L
    self.n708e = 0L
    self.n708d = 0L
    self.n684 = 0L
    self.n660 = 0L
    self.n635 = 0L
    self.n635r = 0L
    self.n635e = 0L
    self.n635d = 0L
    self.n612 = 0L
    self.n589 = 0L
    self.n564 = 0L
    self.n564r = 0L
    self.n564e = 0L
    self.n564d = 0L
    self.n543 = 0L
    self.n521 = 0L
    self.n495 = 0L
    self.n495r = 0L
    self.n495e = 0L
    self.n495d = 0L
    self.n476 = 0L
    self.n475 = 0L
    self.n455 = 0L
    self.n454 = 0L
    self.n428 = 0L
    self.n428r = 0L
    self.n428e = 0L
    self.n428d = 0L
    self.n410 = 0L
    self.n390 = 0L
    self.n363 = 0L
    self.n363r = 0L
    self.n363e = 0L
    self.n363d = 0L
    self.n345 = 0L
    self.n333 = 0L
    self.n333r = 0L
    self.n333e = 0L
    self.n333d = 0L
    self.n300 = 0L
    self.n300r = 0L
    self.n300e = 0L
    self.n300d = 0L
    self.n282 = 0L
    self.n271 = 0L
    self.n271r = 0L
    self.n271e = 0L
    self.n271d = 0L
    self.n239 = 0L
    self.n239r = 0L
    self.n239e = 0L
    self.n239d = 0L
    self.n221 = 0L
    self.n211 = 0L
    self.n211r = 0L
    self.n211e = 0L
    self.n211d = 0L
    self.n180 = 0L
    self.n180r = 0L
    self.n180e = 0L
    self.n180d = 0L
    self.n162 = 0L
    self.n153 = 0L
    self.n153r = 0L
    self.n153e = 0L
    self.n153d = 0L
    self.n123 = 0L
    self.n123r = 0L
    self.n123e = 0L
    self.n123d = 0L
    self.n105 = 0L
    self.n97 = 0L
    self.n97r = 0L
    self.n97e = 0L
    self.n97d = 0L
    self.n1159 = 0L
    self.n1129 = 0L
    self.n1075 = 0L
    self.n1046 = 0L
    self.n993 = 0L
    self.n965 = 0L
    self.n913 = 0L
    self.n886 = 0L
    self.n835 = 0L
    self.n809 = 0L
    self.n759 = 0L
    self.n734 = 0L
    self.n685 = 0L
    self.n661 = 0L
    self.n614 = 0L
    self.n591 = 0L
    self.n545 = 0L
    self.n544 = 0L
    self.n523 = 0L
    self.n522 = 0L
    self.n477 = 0L
    self.n456 = 0L
    self.n417 = 0L
    self.n417r = 0L
    self.n417e = 0L
    self.n417d = 0L
    self.n397 = 0L
    self.n397r = 0L
    self.n397e = 0L
    self.n397d = 0L
    self.n352 = 0L
    self.n352r = 0L
    self.n352e = 0L
    self.n352d = 0L
    self.n289 = 0L
    self.n289r = 0L
    self.n289e = 0L
    self.n289d = 0L
    self.n228 = 0L
    self.n228r = 0L
    self.n228e = 0L
    self.n228d = 0L
    self.n169 = 0L
    self.n169r = 0L
    self.n169e = 0L
    self.n169d = 0L
    self.n112 = 0L
    self.n112r = 0L
    self.n112e = 0L
    self.n112d = 0L
    self.n1160 = 0L
    self.n1130 = 0L
    self.n1076 = 0L
    self.n1047 = 0L
    self.n994 = 0L
    self.n966 = 0L
    self.n914 = 0L
    self.n887 = 0L
    self.n836 = 0L
    self.n810 = 0L
    self.n760 = 0L
    self.n735 = 0L
    self.n687 = 0L
    self.n663 = 0L
    self.n616 = 0L
    self.n615 = 0L
    self.n593 = 0L
    self.n592 = 0L
    self.n546 = 0L
    self.n524 = 0L
    self.n484 = 0L
    self.n484r = 0L
    self.n484e = 0L
    self.n484d = 0L
    self.n463 = 0L
    self.n463r = 0L
    self.n463e = 0L
    self.n463d = 0L
    self.n1161 = 0L
    self.n1131 = 0L
    self.n1077 = 0L
    self.n1048 = 0L
    self.n995 = 0L
    self.n967 = 0L
    self.n915 = 0L
    self.n888 = 0L
    self.n837 = 0L
    self.n811 = 0L
    self.n762 = 0L
    self.n737 = 0L
    self.n689 = 0L
    self.n688 = 0L
    self.n665 = 0L
    self.n664 = 0L
    self.n617 = 0L
    self.n594 = 0L
    self.n553 = 0L
    self.n553r = 0L
    self.n553e = 0L
    self.n553d = 0L
    self.n531 = 0L
    self.n531r = 0L
    self.n531e = 0L
    self.n531d = 0L
    self.n1162 = 0L
    self.n1132 = 0L
    self.n1078 = 0L
    self.n1049 = 0L
    self.n996 = 0L
    self.n968 = 0L
    self.n916 = 0L
    self.n889 = 0L
    self.n839 = 0L
    self.n813 = 0L
    self.n764 = 0L
    self.n763 = 0L
    self.n739 = 0L
    self.n738 = 0L
    self.n690 = 0L
    self.n666 = 0L
    self.n624 = 0L
    self.n624r = 0L
    self.n624e = 0L
    self.n624d = 0L
    self.n601 = 0L
    self.n601r = 0L
    self.n601e = 0L
    self.n601d = 0L
    self.n1163 = 0L
    self.n1133 = 0L
    self.n1079 = 0L
    self.n1050 = 0L
    self.n997 = 0L
    self.n969 = 0L
    self.n918 = 0L
    self.n891 = 0L
    self.n841 = 0L
    self.n840 = 0L
    self.n815 = 0L
    self.n814 = 0L
    self.n765 = 0L
    self.n740 = 0L
    self.n697 = 0L
    self.n697r = 0L
    self.n697e = 0L
    self.n697d = 0L
    self.n673 = 0L
    self.n673r = 0L
    self.n673e = 0L
    self.n673d = 0L
    self.n1164 = 0L
    self.n1134 = 0L
    self.n1080 = 0L
    self.n1051 = 0L
    self.n999 = 0L
    self.n971 = 0L
    self.n920 = 0L
    self.n919 = 0L
    self.n893 = 0L
    self.n892 = 0L
    self.n842 = 0L
    self.n816 = 0L
    self.n772 = 0L
    self.n772r = 0L
    self.n772e = 0L
    self.n772d = 0L
    self.n747 = 0L
    self.n747r = 0L
    self.n747e = 0L
    self.n747d = 0L
    self.n1165 = 0L
    self.n1135 = 0L
    self.n1082 = 0L
    self.n1053 = 0L
    self.n1001 = 0L
    self.n1000 = 0L
    self.n973 = 0L
    self.n972 = 0L
    self.n921 = 0L
    self.n894 = 0L
    self.n849 = 0L
    self.n849r = 0L
    self.n849e = 0L
    self.n849d = 0L
    self.n823 = 0L
    self.n823r = 0L
    self.n823e = 0L
    self.n823d = 0L
    self.n1167 = 0L
    self.n1137 = 0L
    self.n1084 = 0L
    self.n1083 = 0L
    self.n1055 = 0L
    self.n1054 = 0L
    self.n1002 = 0L
    self.n974 = 0L
    self.n928 = 0L
    self.n928r = 0L
    self.n928e = 0L
    self.n928d = 0L
    self.n901 = 0L
    self.n901r = 0L
    self.n901e = 0L
    self.n901d = 0L
    self.n1169 = 0L
    self.n1168 = 0L
    self.n1139 = 0L
    self.n1138 = 0L
    self.n1085 = 0L
    self.n1056 = 0L
    self.n1009 = 0L
    self.n1009r = 0L
    self.n1009e = 0L
    self.n1009d = 0L
    self.n981 = 0L
    self.n981r = 0L
    self.n981e = 0L
    self.n981d = 0L
    self.n1170 = 0L
    self.n1140 = 0L
    self.n1092 = 0L
    self.n1092r = 0L
    self.n1092e = 0L
    self.n1092d = 0L
    self.n1063 = 0L
    self.n1063r = 0L
    self.n1063e = 0L
    self.n1063d = 0L
    self.n1177 = 0L
    self.n1177r = 0L
    self.n1177e = 0L
    self.n1177d = 0L
    self.n1147 = 0L
    self.n1147r = 0L
    self.n1147e = 0L
    self.n1147d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, 0L, )

  def calc(self, enable_i, reset_i, flip_i, real_i, imag_i, ang_i, ):
    self.n1291 = 0x08000L
    self.n1289 = 0x08000L
    self.n1287 = 0x08000L
    self.n1285 = 0x08000L
    self.n1283 = 0x08000L
    self.n1281 = 0x08000L
    self.n1279 = 0x08000L
    self.n1277 = 0x08000L
    self.n1275 = 0x08000L
    self.n1273 = 0x08000L
    self.n1271 = 0x08000L
    self.n1269 = 0x08000L
    self.n1267 = 0x08000L
    self.n1265 = 0x08000L
    self.n1263 = 0x08000L
    self.n1261 = 0x08000L
    self.n1194 = 0x8000L
    ang_o = self.n1188
    self.n1191 = self.n1188
    imag_o = self.n1177
    self.n1190 = self.n1177
    real_o = self.n1147
    self.n1189 = self.n1147
    self.n1178 = 0x0000L
    self.n1166 = ((self.n1063 & 0x8000L) >> 15)
    self.n1149 = ((self.n1063 & 0x8000L) >> 15)
    self.n1136 = ((self.n1092 & 0x8000L) >> 15)
    self.n1119 = ((self.n1092 & 0x8000L) >> 15)
    self.n1113 = 0x0L
    self.n1107 = (self.n1103 & 0x4000L) | (self.n1103 & 0x2000L) | (self.n1103 & 0x1000L) | (self.n1103 & 0x800L) | (self.n1103 & 0x400L) | (self.n1103 & 0x200L) | (self.n1103 & 0x100L) | (self.n1103 & 0x80L) | (self.n1103 & 0x40L) | (self.n1103 & 0x20L) | (self.n1103 & 0x10L) | (self.n1103 & 0x8L) | (self.n1103 & 0x4L) | (self.n1103 & 0x2L) | (self.n1103 & 0x1L)
    self.n1105 = ((self.n1103 & 0x8000L) >> 15)
    self.n1093 = 0x0001L
    self.n1081 = ((self.n981 & 0x8000L) >> 14) | ((self.n981 & 0x4000L) >> 14)
    self.n1065 = ((self.n981 & 0x8000L) >> 15)
    self.n1052 = ((self.n1009 & 0x8000L) >> 14) | ((self.n1009 & 0x4000L) >> 14)
    self.n1036 = ((self.n1009 & 0x8000L) >> 15)
    self.n1030 = 0x0L
    self.n1024 = (self.n1020 & 0x4000L) | (self.n1020 & 0x2000L) | (self.n1020 & 0x1000L) | (self.n1020 & 0x800L) | (self.n1020 & 0x400L) | (self.n1020 & 0x200L) | (self.n1020 & 0x100L) | (self.n1020 & 0x80L) | (self.n1020 & 0x40L) | (self.n1020 & 0x20L) | (self.n1020 & 0x10L) | (self.n1020 & 0x8L) | (self.n1020 & 0x4L) | (self.n1020 & 0x2L) | (self.n1020 & 0x1L)
    self.n1022 = ((self.n1020 & 0x8000L) >> 15)
    self.n1010 = 0x0001L
    self.n998 = ((self.n901 & 0x8000L) >> 13) | ((self.n901 & 0x4000L) >> 13) | ((self.n901 & 0x2000L) >> 13)
    self.n983 = ((self.n901 & 0x8000L) >> 15)
    self.n970 = ((self.n928 & 0x8000L) >> 13) | ((self.n928 & 0x4000L) >> 13) | ((self.n928 & 0x2000L) >> 13)
    self.n955 = ((self.n928 & 0x8000L) >> 15)
    self.n949 = 0x0L
    self.n943 = (self.n939 & 0x4000L) | (self.n939 & 0x2000L) | (self.n939 & 0x1000L) | (self.n939 & 0x800L) | (self.n939 & 0x400L) | (self.n939 & 0x200L) | (self.n939 & 0x100L) | (self.n939 & 0x80L) | (self.n939 & 0x40L) | (self.n939 & 0x20L) | (self.n939 & 0x10L) | (self.n939 & 0x8L) | (self.n939 & 0x4L) | (self.n939 & 0x2L) | (self.n939 & 0x1L)
    self.n941 = ((self.n939 & 0x8000L) >> 15)
    self.n929 = 0x0003L
    self.n917 = ((self.n823 & 0x8000L) >> 12) | ((self.n823 & 0x4000L) >> 12) | ((self.n823 & 0x2000L) >> 12) | ((self.n823 & 0x1000L) >> 12)
    self.n903 = ((self.n823 & 0x8000L) >> 15)
    self.n890 = ((self.n849 & 0x8000L) >> 12) | ((self.n849 & 0x4000L) >> 12) | ((self.n849 & 0x2000L) >> 12) | ((self.n849 & 0x1000L) >> 12)
    self.n876 = ((self.n849 & 0x8000L) >> 15)
    self.n870 = 0x0L
    self.n864 = (self.n860 & 0x4000L) | (self.n860 & 0x2000L) | (self.n860 & 0x1000L) | (self.n860 & 0x800L) | (self.n860 & 0x400L) | (self.n860 & 0x200L) | (self.n860 & 0x100L) | (self.n860 & 0x80L) | (self.n860 & 0x40L) | (self.n860 & 0x20L) | (self.n860 & 0x10L) | (self.n860 & 0x8L) | (self.n860 & 0x4L) | (self.n860 & 0x2L) | (self.n860 & 0x1L)
    self.n862 = ((self.n860 & 0x8000L) >> 15)
    self.n850 = 0x0005L
    self.n838 = ((self.n747 & 0x8000L) >> 11) | ((self.n747 & 0x4000L) >> 11) | ((self.n747 & 0x2000L) >> 11) | ((self.n747 & 0x1000L) >> 11) | ((self.n747 & 0x800L) >> 11)
    self.n825 = ((self.n747 & 0x8000L) >> 15)
    self.n812 = ((self.n772 & 0x8000L) >> 11) | ((self.n772 & 0x4000L) >> 11) | ((self.n772 & 0x2000L) >> 11) | ((self.n772 & 0x1000L) >> 11) | ((self.n772 & 0x800L) >> 11)
    self.n799 = ((self.n772 & 0x8000L) >> 15)
    self.n793 = 0x0L
    self.n787 = (self.n783 & 0x4000L) | (self.n783 & 0x2000L) | (self.n783 & 0x1000L) | (self.n783 & 0x800L) | (self.n783 & 0x400L) | (self.n783 & 0x200L) | (self.n783 & 0x100L) | (self.n783 & 0x80L) | (self.n783 & 0x40L) | (self.n783 & 0x20L) | (self.n783 & 0x10L) | (self.n783 & 0x8L) | (self.n783 & 0x4L) | (self.n783 & 0x2L) | (self.n783 & 0x1L)
    self.n785 = ((self.n783 & 0x8000L) >> 15)
    self.n773 = 0x000AL
    self.n761 = ((self.n673 & 0x8000L) >> 10) | ((self.n673 & 0x4000L) >> 10) | ((self.n673 & 0x2000L) >> 10) | ((self.n673 & 0x1000L) >> 10) | ((self.n673 & 0x800L) >> 10) | ((self.n673 & 0x400L) >> 10)
    self.n749 = ((self.n673 & 0x8000L) >> 15)
    self.n736 = ((self.n697 & 0x8000L) >> 10) | ((self.n697 & 0x4000L) >> 10) | ((self.n697 & 0x2000L) >> 10) | ((self.n697 & 0x1000L) >> 10) | ((self.n697 & 0x800L) >> 10) | ((self.n697 & 0x400L) >> 10)
    self.n724 = ((self.n697 & 0x8000L) >> 15)
    self.n718 = 0x0L
    self.n712 = (self.n708 & 0x4000L) | (self.n708 & 0x2000L) | (self.n708 & 0x1000L) | (self.n708 & 0x800L) | (self.n708 & 0x400L) | (self.n708 & 0x200L) | (self.n708 & 0x100L) | (self.n708 & 0x80L) | (self.n708 & 0x40L) | (self.n708 & 0x20L) | (self.n708 & 0x10L) | (self.n708 & 0x8L) | (self.n708 & 0x4L) | (self.n708 & 0x2L) | (self.n708 & 0x1L)
    self.n710 = ((self.n708 & 0x8000L) >> 15)
    self.n698 = 0x0014L
    self.n686 = ((self.n601 & 0x8000L) >> 9) | ((self.n601 & 0x4000L) >> 9) | ((self.n601 & 0x2000L) >> 9) | ((self.n601 & 0x1000L) >> 9) | ((self.n601 & 0x800L) >> 9) | ((self.n601 & 0x400L) >> 9) | ((self.n601 & 0x200L) >> 9)
    self.n675 = ((self.n601 & 0x8000L) >> 15)
    self.n662 = ((self.n624 & 0x8000L) >> 9) | ((self.n624 & 0x4000L) >> 9) | ((self.n624 & 0x2000L) >> 9) | ((self.n624 & 0x1000L) >> 9) | ((self.n624 & 0x800L) >> 9) | ((self.n624 & 0x400L) >> 9) | ((self.n624 & 0x200L) >> 9)
    self.n651 = ((self.n624 & 0x8000L) >> 15)
    self.n645 = 0x0L
    self.n639 = (self.n635 & 0x4000L) | (self.n635 & 0x2000L) | (self.n635 & 0x1000L) | (self.n635 & 0x800L) | (self.n635 & 0x400L) | (self.n635 & 0x200L) | (self.n635 & 0x100L) | (self.n635 & 0x80L) | (self.n635 & 0x40L) | (self.n635 & 0x20L) | (self.n635 & 0x10L) | (self.n635 & 0x8L) | (self.n635 & 0x4L) | (self.n635 & 0x2L) | (self.n635 & 0x1L)
    self.n637 = ((self.n635 & 0x8000L) >> 15)
    self.n625 = 0x0029L
    self.n613 = ((self.n531 & 0x8000L) >> 8) | ((self.n531 & 0x4000L) >> 8) | ((self.n531 & 0x2000L) >> 8) | ((self.n531 & 0x1000L) >> 8) | ((self.n531 & 0x800L) >> 8) | ((self.n531 & 0x400L) >> 8) | ((self.n531 & 0x200L) >> 8) | ((self.n531 & 0x100L) >> 8)
    self.n603 = ((self.n531 & 0x8000L) >> 15)
    self.n590 = ((self.n553 & 0x8000L) >> 8) | ((self.n553 & 0x4000L) >> 8) | ((self.n553 & 0x2000L) >> 8) | ((self.n553 & 0x1000L) >> 8) | ((self.n553 & 0x800L) >> 8) | ((self.n553 & 0x400L) >> 8) | ((self.n553 & 0x200L) >> 8) | ((self.n553 & 0x100L) >> 8)
    self.n580 = ((self.n553 & 0x8000L) >> 15)
    self.n574 = 0x0L
    self.n568 = (self.n564 & 0x4000L) | (self.n564 & 0x2000L) | (self.n564 & 0x1000L) | (self.n564 & 0x800L) | (self.n564 & 0x400L) | (self.n564 & 0x200L) | (self.n564 & 0x100L) | (self.n564 & 0x80L) | (self.n564 & 0x40L) | (self.n564 & 0x20L) | (self.n564 & 0x10L) | (self.n564 & 0x8L) | (self.n564 & 0x4L) | (self.n564 & 0x2L) | (self.n564 & 0x1L)
    self.n566 = ((self.n564 & 0x8000L) >> 15)
    self.n554 = 0x0051L
    self.n542 = ((self.n463 & 0x8000L) >> 7) | ((self.n463 & 0x4000L) >> 7) | ((self.n463 & 0x2000L) >> 7) | ((self.n463 & 0x1000L) >> 7) | ((self.n463 & 0x800L) >> 7) | ((self.n463 & 0x400L) >> 7) | ((self.n463 & 0x200L) >> 7) | ((self.n463 & 0x100L) >> 7) | ((self.n463 & 0x80L) >> 7)
    self.n533 = ((self.n463 & 0x8000L) >> 15)
    self.n520 = ((self.n484 & 0x8000L) >> 7) | ((self.n484 & 0x4000L) >> 7) | ((self.n484 & 0x2000L) >> 7) | ((self.n484 & 0x1000L) >> 7) | ((self.n484 & 0x800L) >> 7) | ((self.n484 & 0x400L) >> 7) | ((self.n484 & 0x200L) >> 7) | ((self.n484 & 0x100L) >> 7) | ((self.n484 & 0x80L) >> 7)
    self.n511 = ((self.n484 & 0x8000L) >> 15)
    self.n505 = 0x0L
    self.n499 = (self.n495 & 0x4000L) | (self.n495 & 0x2000L) | (self.n495 & 0x1000L) | (self.n495 & 0x800L) | (self.n495 & 0x400L) | (self.n495 & 0x200L) | (self.n495 & 0x100L) | (self.n495 & 0x80L) | (self.n495 & 0x40L) | (self.n495 & 0x20L) | (self.n495 & 0x10L) | (self.n495 & 0x8L) | (self.n495 & 0x4L) | (self.n495 & 0x2L) | (self.n495 & 0x1L)
    self.n497 = ((self.n495 & 0x8000L) >> 15)
    self.n485 = 0x00A3L
    self.n473 = ((self.n397 & 0x8000L) >> 6) | ((self.n397 & 0x4000L) >> 6) | ((self.n397 & 0x2000L) >> 6) | ((self.n397 & 0x1000L) >> 6) | ((self.n397 & 0x800L) >> 6) | ((self.n397 & 0x400L) >> 6) | ((self.n397 & 0x200L) >> 6) | ((self.n397 & 0x100L) >> 6) | ((self.n397 & 0x80L) >> 6) | ((self.n397 & 0x40L) >> 6)
    self.n465 = ((self.n397 & 0x8000L) >> 15)
    self.n452 = ((self.n417 & 0x8000L) >> 6) | ((self.n417 & 0x4000L) >> 6) | ((self.n417 & 0x2000L) >> 6) | ((self.n417 & 0x1000L) >> 6) | ((self.n417 & 0x800L) >> 6) | ((self.n417 & 0x400L) >> 6) | ((self.n417 & 0x200L) >> 6) | ((self.n417 & 0x100L) >> 6) | ((self.n417 & 0x80L) >> 6) | ((self.n417 & 0x40L) >> 6)
    self.n444 = ((self.n417 & 0x8000L) >> 15)
    self.n438 = 0x0L
    self.n432 = (self.n428 & 0x4000L) | (self.n428 & 0x2000L) | (self.n428 & 0x1000L) | (self.n428 & 0x800L) | (self.n428 & 0x400L) | (self.n428 & 0x200L) | (self.n428 & 0x100L) | (self.n428 & 0x80L) | (self.n428 & 0x40L) | (self.n428 & 0x20L) | (self.n428 & 0x10L) | (self.n428 & 0x8L) | (self.n428 & 0x4L) | (self.n428 & 0x2L) | (self.n428 & 0x1L)
    self.n430 = ((self.n428 & 0x8000L) >> 15)
    self.n418 = 0x0146L
    self.n406 = ((self.n333 & 0x8000L) >> 5) | ((self.n333 & 0x4000L) >> 5) | ((self.n333 & 0x2000L) >> 5) | ((self.n333 & 0x1000L) >> 5) | ((self.n333 & 0x800L) >> 5) | ((self.n333 & 0x400L) >> 5) | ((self.n333 & 0x200L) >> 5) | ((self.n333 & 0x100L) >> 5) | ((self.n333 & 0x80L) >> 5) | ((self.n333 & 0x40L) >> 5) | ((self.n333 & 0x20L) >> 5)
    self.n399 = ((self.n333 & 0x8000L) >> 15)
    self.n386 = ((self.n352 & 0x8000L) >> 5) | ((self.n352 & 0x4000L) >> 5) | ((self.n352 & 0x2000L) >> 5) | ((self.n352 & 0x1000L) >> 5) | ((self.n352 & 0x800L) >> 5) | ((self.n352 & 0x400L) >> 5) | ((self.n352 & 0x200L) >> 5) | ((self.n352 & 0x100L) >> 5) | ((self.n352 & 0x80L) >> 5) | ((self.n352 & 0x40L) >> 5) | ((self.n352 & 0x20L) >> 5)
    self.n379 = ((self.n352 & 0x8000L) >> 15)
    self.n373 = 0x0L
    self.n367 = (self.n363 & 0x4000L) | (self.n363 & 0x2000L) | (self.n363 & 0x1000L) | (self.n363 & 0x800L) | (self.n363 & 0x400L) | (self.n363 & 0x200L) | (self.n363 & 0x100L) | (self.n363 & 0x80L) | (self.n363 & 0x40L) | (self.n363 & 0x20L) | (self.n363 & 0x10L) | (self.n363 & 0x8L) | (self.n363 & 0x4L) | (self.n363 & 0x2L) | (self.n363 & 0x1L)
    self.n365 = ((self.n363 & 0x8000L) >> 15)
    self.n353 = 0x028BL
    self.n341 = ((self.n271 & 0x8000L) >> 4) | ((self.n271 & 0x4000L) >> 4) | ((self.n271 & 0x2000L) >> 4) | ((self.n271 & 0x1000L) >> 4) | ((self.n271 & 0x800L) >> 4) | ((self.n271 & 0x400L) >> 4) | ((self.n271 & 0x200L) >> 4) | ((self.n271 & 0x100L) >> 4) | ((self.n271 & 0x80L) >> 4) | ((self.n271 & 0x40L) >> 4) | ((self.n271 & 0x20L) >> 4) | ((self.n271 & 0x10L) >> 4)
    self.n335 = ((self.n271 & 0x8000L) >> 15)
    self.n322 = ((self.n289 & 0x8000L) >> 4) | ((self.n289 & 0x4000L) >> 4) | ((self.n289 & 0x2000L) >> 4) | ((self.n289 & 0x1000L) >> 4) | ((self.n289 & 0x800L) >> 4) | ((self.n289 & 0x400L) >> 4) | ((self.n289 & 0x200L) >> 4) | ((self.n289 & 0x100L) >> 4) | ((self.n289 & 0x80L) >> 4) | ((self.n289 & 0x40L) >> 4) | ((self.n289 & 0x20L) >> 4) | ((self.n289 & 0x10L) >> 4)
    self.n316 = ((self.n289 & 0x8000L) >> 15)
    self.n310 = 0x0L
    self.n304 = (self.n300 & 0x4000L) | (self.n300 & 0x2000L) | (self.n300 & 0x1000L) | (self.n300 & 0x800L) | (self.n300 & 0x400L) | (self.n300 & 0x200L) | (self.n300 & 0x100L) | (self.n300 & 0x80L) | (self.n300 & 0x40L) | (self.n300 & 0x20L) | (self.n300 & 0x10L) | (self.n300 & 0x8L) | (self.n300 & 0x4L) | (self.n300 & 0x2L) | (self.n300 & 0x1L)
    self.n302 = ((self.n300 & 0x8000L) >> 15)
    self.n290 = 0x0511L
    self.n278 = ((self.n211 & 0x8000L) >> 3) | ((self.n211 & 0x4000L) >> 3) | ((self.n211 & 0x2000L) >> 3) | ((self.n211 & 0x1000L) >> 3) | ((self.n211 & 0x800L) >> 3) | ((self.n211 & 0x400L) >> 3) | ((self.n211 & 0x200L) >> 3) | ((self.n211 & 0x100L) >> 3) | ((self.n211 & 0x80L) >> 3) | ((self.n211 & 0x40L) >> 3) | ((self.n211 & 0x20L) >> 3) | ((self.n211 & 0x10L) >> 3) | ((self.n211 & 0x8L) >> 3)
    self.n273 = ((self.n211 & 0x8000L) >> 15)
    self.n260 = ((self.n228 & 0x8000L) >> 3) | ((self.n228 & 0x4000L) >> 3) | ((self.n228 & 0x2000L) >> 3) | ((self.n228 & 0x1000L) >> 3) | ((self.n228 & 0x800L) >> 3) | ((self.n228 & 0x400L) >> 3) | ((self.n228 & 0x200L) >> 3) | ((self.n228 & 0x100L) >> 3) | ((self.n228 & 0x80L) >> 3) | ((self.n228 & 0x40L) >> 3) | ((self.n228 & 0x20L) >> 3) | ((self.n228 & 0x10L) >> 3) | ((self.n228 & 0x8L) >> 3)
    self.n255 = ((self.n228 & 0x8000L) >> 15)
    self.n249 = 0x0L
    self.n243 = (self.n239 & 0x4000L) | (self.n239 & 0x2000L) | (self.n239 & 0x1000L) | (self.n239 & 0x800L) | (self.n239 & 0x400L) | (self.n239 & 0x200L) | (self.n239 & 0x100L) | (self.n239 & 0x80L) | (self.n239 & 0x40L) | (self.n239 & 0x20L) | (self.n239 & 0x10L) | (self.n239 & 0x8L) | (self.n239 & 0x4L) | (self.n239 & 0x2L) | (self.n239 & 0x1L)
    self.n241 = ((self.n239 & 0x8000L) >> 15)
    self.n229 = 0x09FBL
    self.n217 = ((self.n153 & 0x8000L) >> 2) | ((self.n153 & 0x4000L) >> 2) | ((self.n153 & 0x2000L) >> 2) | ((self.n153 & 0x1000L) >> 2) | ((self.n153 & 0x800L) >> 2) | ((self.n153 & 0x400L) >> 2) | ((self.n153 & 0x200L) >> 2) | ((self.n153 & 0x100L) >> 2) | ((self.n153 & 0x80L) >> 2) | ((self.n153 & 0x40L) >> 2) | ((self.n153 & 0x20L) >> 2) | ((self.n153 & 0x10L) >> 2) | ((self.n153 & 0x8L) >> 2) | ((self.n153 & 0x4L) >> 2)
    self.n213 = ((self.n153 & 0x8000L) >> 15)
    self.n200 = ((self.n169 & 0x8000L) >> 2) | ((self.n169 & 0x4000L) >> 2) | ((self.n169 & 0x2000L) >> 2) | ((self.n169 & 0x1000L) >> 2) | ((self.n169 & 0x800L) >> 2) | ((self.n169 & 0x400L) >> 2) | ((self.n169 & 0x200L) >> 2) | ((self.n169 & 0x100L) >> 2) | ((self.n169 & 0x80L) >> 2) | ((self.n169 & 0x40L) >> 2) | ((self.n169 & 0x20L) >> 2) | ((self.n169 & 0x10L) >> 2) | ((self.n169 & 0x8L) >> 2) | ((self.n169 & 0x4L) >> 2)
    self.n196 = ((self.n169 & 0x8000L) >> 15)
    self.n190 = 0x0L
    self.n184 = (self.n180 & 0x4000L) | (self.n180 & 0x2000L) | (self.n180 & 0x1000L) | (self.n180 & 0x800L) | (self.n180 & 0x400L) | (self.n180 & 0x200L) | (self.n180 & 0x100L) | (self.n180 & 0x80L) | (self.n180 & 0x40L) | (self.n180 & 0x20L) | (self.n180 & 0x10L) | (self.n180 & 0x8L) | (self.n180 & 0x4L) | (self.n180 & 0x2L) | (self.n180 & 0x1L)
    self.n182 = ((self.n180 & 0x8000L) >> 15)
    self.n170 = 0x12E4L
    self.n158 = ((self.n97 & 0x8000L) >> 1) | ((self.n97 & 0x4000L) >> 1) | ((self.n97 & 0x2000L) >> 1) | ((self.n97 & 0x1000L) >> 1) | ((self.n97 & 0x800L) >> 1) | ((self.n97 & 0x400L) >> 1) | ((self.n97 & 0x200L) >> 1) | ((self.n97 & 0x100L) >> 1) | ((self.n97 & 0x80L) >> 1) | ((self.n97 & 0x40L) >> 1) | ((self.n97 & 0x20L) >> 1) | ((self.n97 & 0x10L) >> 1) | ((self.n97 & 0x8L) >> 1) | ((self.n97 & 0x4L) >> 1) | ((self.n97 & 0x2L) >> 1)
    self.n155 = ((self.n97 & 0x8000L) >> 15)
    self.n142 = ((self.n112 & 0x8000L) >> 1) | ((self.n112 & 0x4000L) >> 1) | ((self.n112 & 0x2000L) >> 1) | ((self.n112 & 0x1000L) >> 1) | ((self.n112 & 0x800L) >> 1) | ((self.n112 & 0x400L) >> 1) | ((self.n112 & 0x200L) >> 1) | ((self.n112 & 0x100L) >> 1) | ((self.n112 & 0x80L) >> 1) | ((self.n112 & 0x40L) >> 1) | ((self.n112 & 0x20L) >> 1) | ((self.n112 & 0x10L) >> 1) | ((self.n112 & 0x8L) >> 1) | ((self.n112 & 0x4L) >> 1) | ((self.n112 & 0x2L) >> 1)
    self.n139 = ((self.n112 & 0x8000L) >> 15)
    self.n133 = 0x0L
    self.n127 = (self.n123 & 0x4000L) | (self.n123 & 0x2000L) | (self.n123 & 0x1000L) | (self.n123 & 0x800L) | (self.n123 & 0x400L) | (self.n123 & 0x200L) | (self.n123 & 0x100L) | (self.n123 & 0x80L) | (self.n123 & 0x40L) | (self.n123 & 0x20L) | (self.n123 & 0x10L) | (self.n123 & 0x8L) | (self.n123 & 0x4L) | (self.n123 & 0x2L) | (self.n123 & 0x1L)
    self.n125 = ((self.n123 & 0x8000L) >> 15)
    self.n113 = 0x2000L
    self.n101 = (self.n52 & 0x8000L) | (self.n52 & 0x4000L) | (self.n52 & 0x2000L) | (self.n52 & 0x1000L) | (self.n52 & 0x800L) | (self.n52 & 0x400L) | (self.n52 & 0x200L) | (self.n52 & 0x100L) | (self.n52 & 0x80L) | (self.n52 & 0x40L) | (self.n52 & 0x20L) | (self.n52 & 0x10L) | (self.n52 & 0x8L) | (self.n52 & 0x4L) | (self.n52 & 0x2L) | (self.n52 & 0x1L)
    self.n86 = (self.n60 & 0x8000L) | (self.n60 & 0x4000L) | (self.n60 & 0x2000L) | (self.n60 & 0x1000L) | (self.n60 & 0x800L) | (self.n60 & 0x400L) | (self.n60 & 0x200L) | (self.n60 & 0x100L) | (self.n60 & 0x80L) | (self.n60 & 0x40L) | (self.n60 & 0x20L) | (self.n60 & 0x10L) | (self.n60 & 0x8L) | (self.n60 & 0x4L) | (self.n60 & 0x2L) | (self.n60 & 0x1L)
    self.n78 = 0x0L
    self.n72 = (self.n68 & 0x4000L) | (self.n68 & 0x2000L) | (self.n68 & 0x1000L) | (self.n68 & 0x800L) | (self.n68 & 0x400L) | (self.n68 & 0x200L) | (self.n68 & 0x100L) | (self.n68 & 0x80L) | (self.n68 & 0x40L) | (self.n68 & 0x20L) | (self.n68 & 0x10L) | (self.n68 & 0x8L) | (self.n68 & 0x4L) | (self.n68 & 0x2L) | (self.n68 & 0x1L)
    self.n70 = ((self.n68 & 0x8000L) >> 15)
    self.n39 = 0x0000L
    self.n37 = 0x0000L
    self.n8 = ang_i
    self.n7 = imag_i
    self.n6 = real_i
    self.n5 = flip_i
    self.n4 = reset_i
    self.n3 = enable_i
    self.n1180 = (self.n1103 - self.n1178) & 0xFFFFL
    self.n1179 = (self.n1103 + self.n1178) & 0xFFFFL
    self.n1152 = self.n1149 << 1 | self.n1149
    self.n1122 = self.n1119 << 1 | self.n1119
    self.n1106 = ~self.n1105 & 0x1L
    self.n1095 = (self.n1020 - self.n1093) & 0xFFFFL
    self.n1094 = (self.n1020 + self.n1093) & 0xFFFFL
    self.n1068 = self.n1065 << 1 | self.n1065
    self.n1039 = self.n1036 << 1 | self.n1036
    self.n1023 = ~self.n1022 & 0x1L
    self.n1012 = (self.n939 - self.n1010) & 0xFFFFL
    self.n1011 = (self.n939 + self.n1010) & 0xFFFFL
    self.n986 = self.n983 << 1 | self.n983
    self.n958 = self.n955 << 1 | self.n955
    self.n942 = ~self.n941 & 0x1L
    self.n931 = (self.n860 - self.n929) & 0xFFFFL
    self.n930 = (self.n860 + self.n929) & 0xFFFFL
    self.n906 = self.n903 << 1 | self.n903
    self.n879 = self.n876 << 1 | self.n876
    self.n863 = ~self.n862 & 0x1L
    self.n852 = (self.n783 - self.n850) & 0xFFFFL
    self.n851 = (self.n783 + self.n850) & 0xFFFFL
    self.n828 = self.n825 << 1 | self.n825
    self.n802 = self.n799 << 1 | self.n799
    self.n786 = ~self.n785 & 0x1L
    self.n775 = (self.n708 - self.n773) & 0xFFFFL
    self.n774 = (self.n708 + self.n773) & 0xFFFFL
    self.n752 = self.n749 << 1 | self.n749
    self.n727 = self.n724 << 1 | self.n724
    self.n711 = ~self.n710 & 0x1L
    self.n700 = (self.n635 - self.n698) & 0xFFFFL
    self.n699 = (self.n635 + self.n698) & 0xFFFFL
    self.n678 = self.n675 << 1 | self.n675
    self.n654 = self.n651 << 1 | self.n651
    self.n638 = ~self.n637 & 0x1L
    self.n627 = (self.n564 - self.n625) & 0xFFFFL
    self.n626 = (self.n564 + self.n625) & 0xFFFFL
    self.n606 = self.n603 << 1 | self.n603
    self.n583 = self.n580 << 1 | self.n580
    self.n567 = ~self.n566 & 0x1L
    self.n556 = (self.n495 - self.n554) & 0xFFFFL
    self.n555 = (self.n495 + self.n554) & 0xFFFFL
    self.n536 = self.n533 << 1 | self.n533
    self.n514 = self.n511 << 1 | self.n511
    self.n498 = ~self.n497 & 0x1L
    self.n487 = (self.n428 - self.n485) & 0xFFFFL
    self.n486 = (self.n428 + self.n485) & 0xFFFFL
    self.n468 = self.n465 << 1 | self.n465
    self.n447 = self.n444 << 1 | self.n444
    self.n431 = ~self.n430 & 0x1L
    self.n420 = (self.n363 - self.n418) & 0xFFFFL
    self.n419 = (self.n363 + self.n418) & 0xFFFFL
    self.n402 = self.n399 << 1 | self.n399
    self.n382 = self.n379 << 1 | self.n379
    self.n366 = ~self.n365 & 0x1L
    self.n355 = (self.n300 - self.n353) & 0xFFFFL
    self.n354 = (self.n300 + self.n353) & 0xFFFFL
    self.n338 = self.n335 << 1 | self.n335
    self.n319 = self.n316 << 1 | self.n316
    self.n303 = ~self.n302 & 0x1L
    self.n292 = (self.n239 - self.n290) & 0xFFFFL
    self.n291 = (self.n239 + self.n290) & 0xFFFFL
    self.n276 = self.n273 << 1 | self.n273
    self.n258 = self.n255 << 1 | self.n255
    self.n242 = ~self.n241 & 0x1L
    self.n231 = (self.n180 - self.n229) & 0xFFFFL
    self.n230 = (self.n180 + self.n229) & 0xFFFFL
    self.n216 = self.n213 << 1 | self.n213
    self.n199 = self.n196 << 1 | self.n196
    self.n183 = ~self.n182 & 0x1L
    self.n172 = (self.n123 - self.n170) & 0xFFFFL
    self.n171 = (self.n123 + self.n170) & 0xFFFFL
    self.n159 = self.n155 << 15 | self.n158
    self.n143 = self.n139 << 15 | self.n142
    self.n126 = ~self.n125 & 0x1L
    self.n115 = (self.n68 - self.n113) & 0xFFFFL
    self.n114 = (self.n68 + self.n113) & 0xFFFFL
    self.n104 = (self.n60 - self.n101) & 0xFFFFL
    self.n103 = (self.n60 + self.n101) & 0xFFFFL
    self.n89 = (self.n52 - self.n86) & 0xFFFFL
    self.n88 = (self.n52 + self.n86) & 0xFFFFL
    self.n71 = ~self.n70 & 0x1L
    self.n44 = (self.n36 - self.n1194) & 0xFFFFL
    self.n40 = (self.n39 - self.n29) & 0xFFFFL
    self.n38 = (self.n37 - self.n22) & 0xFFFFL
    self.n36r = self.n4
    self.n36e = self.n3
    self.n36d = self.n8
    self.n29r = self.n4
    self.n29e = self.n3
    self.n29d = self.n7
    self.n22r = self.n4
    self.n22e = self.n3
    self.n22d = self.n6
    self.n15r = self.n4
    self.n15e = self.n3
    self.n15d = self.n5
    self.n1153 = self.n1149 << 2 | self.n1152
    self.n1123 = self.n1119 << 2 | self.n1122
    self.n1108 = self.n1106 << 15 | self.n1107
    self.n1069 = self.n1065 << 2 | self.n1068
    self.n1040 = self.n1036 << 2 | self.n1039
    self.n1025 = self.n1023 << 15 | self.n1024
    self.n987 = self.n983 << 2 | self.n986
    self.n959 = self.n955 << 2 | self.n958
    self.n944 = self.n942 << 15 | self.n943
    self.n907 = self.n903 << 2 | self.n906
    self.n880 = self.n876 << 2 | self.n879
    self.n865 = self.n863 << 15 | self.n864
    self.n829 = self.n825 << 2 | self.n828
    self.n803 = self.n799 << 2 | self.n802
    self.n788 = self.n786 << 15 | self.n787
    self.n753 = self.n749 << 2 | self.n752
    self.n728 = self.n724 << 2 | self.n727
    self.n713 = self.n711 << 15 | self.n712
    self.n679 = self.n675 << 2 | self.n678
    self.n655 = self.n651 << 2 | self.n654
    self.n640 = self.n638 << 15 | self.n639
    self.n607 = self.n603 << 2 | self.n606
    self.n584 = self.n580 << 2 | self.n583
    self.n569 = self.n567 << 15 | self.n568
    self.n537 = self.n533 << 2 | self.n536
    self.n515 = self.n511 << 2 | self.n514
    self.n500 = self.n498 << 15 | self.n499
    self.n469 = self.n465 << 2 | self.n468
    self.n448 = self.n444 << 2 | self.n447
    self.n433 = self.n431 << 15 | self.n432
    self.n403 = self.n399 << 2 | self.n402
    self.n383 = self.n379 << 2 | self.n382
    self.n368 = self.n366 << 15 | self.n367
    self.n339 = self.n335 << 2 | self.n338
    self.n320 = self.n316 << 2 | self.n319
    self.n305 = self.n303 << 15 | self.n304
    self.n277 = self.n273 << 2 | self.n276
    self.n259 = self.n255 << 2 | self.n258
    self.n244 = self.n242 << 15 | self.n243
    self.n218 = self.n216 << 14 | self.n217
    self.n201 = self.n199 << 14 | self.n200
    self.n185 = self.n183 << 15 | self.n184
    self.n161 = (self.n112 - self.n159) & 0xFFFFL
    self.n160 = (self.n112 + self.n159) & 0xFFFFL
    self.n145 = (self.n97 - self.n143) & 0xFFFFL
    self.n144 = (self.n97 + self.n143) & 0xFFFFL
    self.n128 = self.n126 << 15 | self.n127
    self.n73 = self.n71 << 15 | self.n72
    if self.n15:
      self.n61 = self.n44
    else:
      self.n61 = self.n36
    if self.n15:
      self.n53 = self.n40
    else:
      self.n53 = self.n29
    if self.n15:
      self.n45 = self.n38
    else:
      self.n45 = self.n22
    self.n1154 = self.n1149 << 3 | self.n1153
    self.n1124 = self.n1119 << 3 | self.n1123
    self.n1114 = self.n1113 << 16 | self.n1108
    self.n1070 = self.n1065 << 3 | self.n1069
    self.n1041 = self.n1036 << 3 | self.n1040
    self.n1031 = self.n1030 << 16 | self.n1025
    self.n988 = self.n983 << 3 | self.n987
    self.n960 = self.n955 << 3 | self.n959
    self.n950 = self.n949 << 16 | self.n944
    self.n908 = self.n903 << 3 | self.n907
    self.n881 = self.n876 << 3 | self.n880
    self.n871 = self.n870 << 16 | self.n865
    self.n830 = self.n825 << 3 | self.n829
    self.n804 = self.n799 << 3 | self.n803
    self.n794 = self.n793 << 16 | self.n788
    self.n754 = self.n749 << 3 | self.n753
    self.n729 = self.n724 << 3 | self.n728
    self.n719 = self.n718 << 16 | self.n713
    self.n680 = self.n675 << 3 | self.n679
    self.n656 = self.n651 << 3 | self.n655
    self.n646 = self.n645 << 16 | self.n640
    self.n608 = self.n603 << 3 | self.n607
    self.n585 = self.n580 << 3 | self.n584
    self.n575 = self.n574 << 16 | self.n569
    self.n538 = self.n533 << 3 | self.n537
    self.n516 = self.n511 << 3 | self.n515
    self.n506 = self.n505 << 16 | self.n500
    self.n470 = self.n465 << 3 | self.n469
    self.n449 = self.n444 << 3 | self.n448
    self.n439 = self.n438 << 16 | self.n433
    self.n404 = self.n399 << 3 | self.n403
    self.n384 = self.n379 << 3 | self.n383
    self.n374 = self.n373 << 16 | self.n368
    self.n340 = self.n335 << 3 | self.n339
    self.n321 = self.n316 << 3 | self.n320
    self.n311 = self.n310 << 16 | self.n305
    self.n279 = self.n277 << 13 | self.n278
    self.n261 = self.n259 << 13 | self.n260
    self.n250 = self.n249 << 16 | self.n244
    self.n220 = (self.n169 - self.n218) & 0xFFFFL
    self.n219 = (self.n169 + self.n218) & 0xFFFFL
    self.n203 = (self.n153 - self.n201) & 0xFFFFL
    self.n202 = (self.n153 + self.n201) & 0xFFFFL
    self.n191 = self.n190 << 16 | self.n185
    self.n134 = self.n133 << 16 | self.n128
    self.n79 = self.n78 << 16 | self.n73
    self.n68r = self.n4
    self.n68e = self.n3
    self.n68d = self.n61
    self.n60r = self.n4
    self.n60e = self.n3
    self.n60d = self.n53
    self.n52r = self.n4
    self.n52e = self.n3
    self.n52d = self.n45
    self.n1155 = self.n1149 << 4 | self.n1154
    self.n1125 = self.n1119 << 4 | self.n1124
    self.n1117 = (self.n1114 - self.n1291) & 0x1FFFFL
    self.n1071 = self.n1065 << 4 | self.n1070
    self.n1042 = self.n1036 << 4 | self.n1041
    self.n1034 = (self.n1031 - self.n1289) & 0x1FFFFL
    self.n989 = self.n983 << 4 | self.n988
    self.n961 = self.n955 << 4 | self.n960
    self.n953 = (self.n950 - self.n1287) & 0x1FFFFL
    self.n909 = self.n903 << 4 | self.n908
    self.n882 = self.n876 << 4 | self.n881
    self.n874 = (self.n871 - self.n1285) & 0x1FFFFL
    self.n831 = self.n825 << 4 | self.n830
    self.n805 = self.n799 << 4 | self.n804
    self.n797 = (self.n794 - self.n1283) & 0x1FFFFL
    self.n755 = self.n749 << 4 | self.n754
    self.n730 = self.n724 << 4 | self.n729
    self.n722 = (self.n719 - self.n1281) & 0x1FFFFL
    self.n681 = self.n675 << 4 | self.n680
    self.n657 = self.n651 << 4 | self.n656
    self.n649 = (self.n646 - self.n1279) & 0x1FFFFL
    self.n609 = self.n603 << 4 | self.n608
    self.n586 = self.n580 << 4 | self.n585
    self.n578 = (self.n575 - self.n1277) & 0x1FFFFL
    self.n539 = self.n533 << 4 | self.n538
    self.n517 = self.n511 << 4 | self.n516
    self.n509 = (self.n506 - self.n1275) & 0x1FFFFL
    self.n471 = self.n465 << 4 | self.n470
    self.n450 = self.n444 << 4 | self.n449
    self.n442 = (self.n439 - self.n1273) & 0x1FFFFL
    self.n405 = self.n399 << 4 | self.n404
    self.n385 = self.n379 << 4 | self.n384
    self.n377 = (self.n374 - self.n1271) & 0x1FFFFL
    self.n342 = self.n340 << 12 | self.n341
    self.n323 = self.n321 << 12 | self.n322
    self.n314 = (self.n311 - self.n1269) & 0x1FFFFL
    self.n281 = (self.n228 - self.n279) & 0xFFFFL
    self.n280 = (self.n228 + self.n279) & 0xFFFFL
    self.n263 = (self.n211 - self.n261) & 0xFFFFL
    self.n262 = (self.n211 + self.n261) & 0xFFFFL
    self.n253 = (self.n250 - self.n1267) & 0x1FFFFL
    self.n194 = (self.n191 - self.n1265) & 0x1FFFFL
    self.n137 = (self.n134 - self.n1263) & 0x1FFFFL
    self.n82 = (self.n79 - self.n1261) & 0x1FFFFL
    self.n1156 = self.n1149 << 5 | self.n1155
    self.n1126 = self.n1119 << 5 | self.n1125
    self.n1118 = ((self.n1117 & 0x10000L) >> 16)
    self.n1072 = self.n1065 << 5 | self.n1071
    self.n1043 = self.n1036 << 5 | self.n1042
    self.n1035 = ((self.n1034 & 0x10000L) >> 16)
    self.n990 = self.n983 << 5 | self.n989
    self.n962 = self.n955 << 5 | self.n961
    self.n954 = ((self.n953 & 0x10000L) >> 16)
    self.n910 = self.n903 << 5 | self.n909
    self.n883 = self.n876 << 5 | self.n882
    self.n875 = ((self.n874 & 0x10000L) >> 16)
    self.n832 = self.n825 << 5 | self.n831
    self.n806 = self.n799 << 5 | self.n805
    self.n798 = ((self.n797 & 0x10000L) >> 16)
    self.n756 = self.n749 << 5 | self.n755
    self.n731 = self.n724 << 5 | self.n730
    self.n723 = ((self.n722 & 0x10000L) >> 16)
    self.n682 = self.n675 << 5 | self.n681
    self.n658 = self.n651 << 5 | self.n657
    self.n650 = ((self.n649 & 0x10000L) >> 16)
    self.n610 = self.n603 << 5 | self.n609
    self.n587 = self.n580 << 5 | self.n586
    self.n579 = ((self.n578 & 0x10000L) >> 16)
    self.n540 = self.n533 << 5 | self.n539
    self.n518 = self.n511 << 5 | self.n517
    self.n510 = ((self.n509 & 0x10000L) >> 16)
    self.n472 = self.n465 << 5 | self.n471
    self.n451 = self.n444 << 5 | self.n450
    self.n443 = ((self.n442 & 0x10000L) >> 16)
    self.n407 = self.n405 << 11 | self.n406
    self.n387 = self.n385 << 11 | self.n386
    self.n378 = ((self.n377 & 0x10000L) >> 16)
    self.n344 = (self.n289 - self.n342) & 0xFFFFL
    self.n343 = (self.n289 + self.n342) & 0xFFFFL
    self.n325 = (self.n271 - self.n323) & 0xFFFFL
    self.n324 = (self.n271 + self.n323) & 0xFFFFL
    self.n315 = ((self.n314 & 0x10000L) >> 16)
    self.n254 = ((self.n253 & 0x10000L) >> 16)
    self.n195 = ((self.n194 & 0x10000L) >> 16)
    self.n138 = ((self.n137 & 0x10000L) >> 16)
    self.n83 = ((self.n82 & 0x10000L) >> 16)
    if self.n1118:
      self.n1181 = self.n1179
    else:
      self.n1181 = self.n1180
    self.n1157 = self.n1149 << 6 | self.n1156
    self.n1148 = ~self.n1118 & 0x1L
    self.n1127 = self.n1119 << 6 | self.n1126
    if self.n1035:
      self.n1096 = self.n1094
    else:
      self.n1096 = self.n1095
    self.n1073 = self.n1065 << 6 | self.n1072
    self.n1064 = ~self.n1035 & 0x1L
    self.n1044 = self.n1036 << 6 | self.n1043
    if self.n954:
      self.n1013 = self.n1011
    else:
      self.n1013 = self.n1012
    self.n991 = self.n983 << 6 | self.n990
    self.n982 = ~self.n954 & 0x1L
    self.n963 = self.n955 << 6 | self.n962
    if self.n875:
      self.n932 = self.n930
    else:
      self.n932 = self.n931
    self.n911 = self.n903 << 6 | self.n910
    self.n902 = ~self.n875 & 0x1L
    self.n884 = self.n876 << 6 | self.n883
    if self.n798:
      self.n853 = self.n851
    else:
      self.n853 = self.n852
    self.n833 = self.n825 << 6 | self.n832
    self.n824 = ~self.n798 & 0x1L
    self.n807 = self.n799 << 6 | self.n806
    if self.n723:
      self.n776 = self.n774
    else:
      self.n776 = self.n775
    self.n757 = self.n749 << 6 | self.n756
    self.n748 = ~self.n723 & 0x1L
    self.n732 = self.n724 << 6 | self.n731
    if self.n650:
      self.n701 = self.n699
    else:
      self.n701 = self.n700
    self.n683 = self.n675 << 6 | self.n682
    self.n674 = ~self.n650 & 0x1L
    self.n659 = self.n651 << 6 | self.n658
    if self.n579:
      self.n628 = self.n626
    else:
      self.n628 = self.n627
    self.n611 = self.n603 << 6 | self.n610
    self.n602 = ~self.n579 & 0x1L
    self.n588 = self.n580 << 6 | self.n587
    if self.n510:
      self.n557 = self.n555
    else:
      self.n557 = self.n556
    self.n541 = self.n533 << 6 | self.n540
    self.n532 = ~self.n510 & 0x1L
    self.n519 = self.n511 << 6 | self.n518
    if self.n443:
      self.n488 = self.n486
    else:
      self.n488 = self.n487
    self.n474 = self.n472 << 10 | self.n473
    self.n464 = ~self.n443 & 0x1L
    self.n453 = self.n451 << 10 | self.n452
    if self.n378:
      self.n421 = self.n419
    else:
      self.n421 = self.n420
    self.n409 = (self.n352 - self.n407) & 0xFFFFL
    self.n408 = (self.n352 + self.n407) & 0xFFFFL
    self.n398 = ~self.n378 & 0x1L
    self.n389 = (self.n333 - self.n387) & 0xFFFFL
    self.n388 = (self.n333 + self.n387) & 0xFFFFL
    if self.n315:
      self.n356 = self.n354
    else:
      self.n356 = self.n355
    self.n334 = ~self.n315 & 0x1L
    if self.n315:
      self.n326 = self.n324
    else:
      self.n326 = self.n325
    if self.n254:
      self.n293 = self.n291
    else:
      self.n293 = self.n292
    self.n272 = ~self.n254 & 0x1L
    if self.n254:
      self.n264 = self.n262
    else:
      self.n264 = self.n263
    if self.n195:
      self.n232 = self.n230
    else:
      self.n232 = self.n231
    self.n212 = ~self.n195 & 0x1L
    if self.n195:
      self.n204 = self.n202
    else:
      self.n204 = self.n203
    if self.n138:
      self.n173 = self.n171
    else:
      self.n173 = self.n172
    self.n154 = ~self.n138 & 0x1L
    if self.n138:
      self.n146 = self.n144
    else:
      self.n146 = self.n145
    if self.n83:
      self.n116 = self.n114
    else:
      self.n116 = self.n115
    self.n98 = ~self.n83 & 0x1L
    if self.n83:
      self.n90 = self.n88
    else:
      self.n90 = self.n89
    self.n1188r = self.n4
    self.n1188e = self.n3
    self.n1188d = self.n1181
    self.n1158 = self.n1149 << 7 | self.n1157
    self.n1128 = self.n1119 << 7 | self.n1127
    self.n1103r = self.n4
    self.n1103e = self.n3
    self.n1103d = self.n1096
    self.n1074 = self.n1065 << 7 | self.n1073
    self.n1045 = self.n1036 << 7 | self.n1044
    self.n1020r = self.n4
    self.n1020e = self.n3
    self.n1020d = self.n1013
    self.n992 = self.n983 << 7 | self.n991
    self.n964 = self.n955 << 7 | self.n963
    self.n939r = self.n4
    self.n939e = self.n3
    self.n939d = self.n932
    self.n912 = self.n903 << 7 | self.n911
    self.n885 = self.n876 << 7 | self.n884
    self.n860r = self.n4
    self.n860e = self.n3
    self.n860d = self.n853
    self.n834 = self.n825 << 7 | self.n833
    self.n808 = self.n799 << 7 | self.n807
    self.n783r = self.n4
    self.n783e = self.n3
    self.n783d = self.n776
    self.n758 = self.n749 << 7 | self.n757
    self.n733 = self.n724 << 7 | self.n732
    self.n708r = self.n4
    self.n708e = self.n3
    self.n708d = self.n701
    self.n684 = self.n675 << 7 | self.n683
    self.n660 = self.n651 << 7 | self.n659
    self.n635r = self.n4
    self.n635e = self.n3
    self.n635d = self.n628
    self.n612 = self.n603 << 7 | self.n611
    self.n589 = self.n580 << 7 | self.n588
    self.n564r = self.n4
    self.n564e = self.n3
    self.n564d = self.n557
    self.n543 = self.n541 << 9 | self.n542
    self.n521 = self.n519 << 9 | self.n520
    self.n495r = self.n4
    self.n495e = self.n3
    self.n495d = self.n488
    self.n476 = (self.n417 - self.n474) & 0xFFFFL
    self.n475 = (self.n417 + self.n474) & 0xFFFFL
    self.n455 = (self.n397 - self.n453) & 0xFFFFL
    self.n454 = (self.n397 + self.n453) & 0xFFFFL
    self.n428r = self.n4
    self.n428e = self.n3
    self.n428d = self.n421
    if self.n398:
      self.n410 = self.n408
    else:
      self.n410 = self.n409
    if self.n378:
      self.n390 = self.n388
    else:
      self.n390 = self.n389
    self.n363r = self.n4
    self.n363e = self.n3
    self.n363d = self.n356
    if self.n334:
      self.n345 = self.n343
    else:
      self.n345 = self.n344
    self.n333r = self.n4
    self.n333e = self.n3
    self.n333d = self.n326
    self.n300r = self.n4
    self.n300e = self.n3
    self.n300d = self.n293
    if self.n272:
      self.n282 = self.n280
    else:
      self.n282 = self.n281
    self.n271r = self.n4
    self.n271e = self.n3
    self.n271d = self.n264
    self.n239r = self.n4
    self.n239e = self.n3
    self.n239d = self.n232
    if self.n212:
      self.n221 = self.n219
    else:
      self.n221 = self.n220
    self.n211r = self.n4
    self.n211e = self.n3
    self.n211d = self.n204
    self.n180r = self.n4
    self.n180e = self.n3
    self.n180d = self.n173
    if self.n154:
      self.n162 = self.n160
    else:
      self.n162 = self.n161
    self.n153r = self.n4
    self.n153e = self.n3
    self.n153d = self.n146
    self.n123r = self.n4
    self.n123e = self.n3
    self.n123d = self.n116
    if self.n98:
      self.n105 = self.n103
    else:
      self.n105 = self.n104
    self.n97r = self.n4
    self.n97e = self.n3
    self.n97d = self.n90
    self.n1159 = self.n1149 << 8 | self.n1158
    self.n1129 = self.n1119 << 8 | self.n1128
    self.n1075 = self.n1065 << 8 | self.n1074
    self.n1046 = self.n1036 << 8 | self.n1045
    self.n993 = self.n983 << 8 | self.n992
    self.n965 = self.n955 << 8 | self.n964
    self.n913 = self.n903 << 8 | self.n912
    self.n886 = self.n876 << 8 | self.n885
    self.n835 = self.n825 << 8 | self.n834
    self.n809 = self.n799 << 8 | self.n808
    self.n759 = self.n749 << 8 | self.n758
    self.n734 = self.n724 << 8 | self.n733
    self.n685 = self.n675 << 8 | self.n684
    self.n661 = self.n651 << 8 | self.n660
    self.n614 = self.n612 << 8 | self.n613
    self.n591 = self.n589 << 8 | self.n590
    self.n545 = (self.n484 - self.n543) & 0xFFFFL
    self.n544 = (self.n484 + self.n543) & 0xFFFFL
    self.n523 = (self.n463 - self.n521) & 0xFFFFL
    self.n522 = (self.n463 + self.n521) & 0xFFFFL
    if self.n464:
      self.n477 = self.n475
    else:
      self.n477 = self.n476
    if self.n443:
      self.n456 = self.n454
    else:
      self.n456 = self.n455
    self.n417r = self.n4
    self.n417e = self.n3
    self.n417d = self.n410
    self.n397r = self.n4
    self.n397e = self.n3
    self.n397d = self.n390
    self.n352r = self.n4
    self.n352e = self.n3
    self.n352d = self.n345
    self.n289r = self.n4
    self.n289e = self.n3
    self.n289d = self.n282
    self.n228r = self.n4
    self.n228e = self.n3
    self.n228d = self.n221
    self.n169r = self.n4
    self.n169e = self.n3
    self.n169d = self.n162
    self.n112r = self.n4
    self.n112e = self.n3
    self.n112d = self.n105
    self.n1160 = self.n1149 << 9 | self.n1159
    self.n1130 = self.n1119 << 9 | self.n1129
    self.n1076 = self.n1065 << 9 | self.n1075
    self.n1047 = self.n1036 << 9 | self.n1046
    self.n994 = self.n983 << 9 | self.n993
    self.n966 = self.n955 << 9 | self.n965
    self.n914 = self.n903 << 9 | self.n913
    self.n887 = self.n876 << 9 | self.n886
    self.n836 = self.n825 << 9 | self.n835
    self.n810 = self.n799 << 9 | self.n809
    self.n760 = self.n749 << 9 | self.n759
    self.n735 = self.n724 << 9 | self.n734
    self.n687 = self.n685 << 7 | self.n686
    self.n663 = self.n661 << 7 | self.n662
    self.n616 = (self.n553 - self.n614) & 0xFFFFL
    self.n615 = (self.n553 + self.n614) & 0xFFFFL
    self.n593 = (self.n531 - self.n591) & 0xFFFFL
    self.n592 = (self.n531 + self.n591) & 0xFFFFL
    if self.n532:
      self.n546 = self.n544
    else:
      self.n546 = self.n545
    if self.n510:
      self.n524 = self.n522
    else:
      self.n524 = self.n523
    self.n484r = self.n4
    self.n484e = self.n3
    self.n484d = self.n477
    self.n463r = self.n4
    self.n463e = self.n3
    self.n463d = self.n456
    self.n1161 = self.n1149 << 10 | self.n1160
    self.n1131 = self.n1119 << 10 | self.n1130
    self.n1077 = self.n1065 << 10 | self.n1076
    self.n1048 = self.n1036 << 10 | self.n1047
    self.n995 = self.n983 << 10 | self.n994
    self.n967 = self.n955 << 10 | self.n966
    self.n915 = self.n903 << 10 | self.n914
    self.n888 = self.n876 << 10 | self.n887
    self.n837 = self.n825 << 10 | self.n836
    self.n811 = self.n799 << 10 | self.n810
    self.n762 = self.n760 << 6 | self.n761
    self.n737 = self.n735 << 6 | self.n736
    self.n689 = (self.n624 - self.n687) & 0xFFFFL
    self.n688 = (self.n624 + self.n687) & 0xFFFFL
    self.n665 = (self.n601 - self.n663) & 0xFFFFL
    self.n664 = (self.n601 + self.n663) & 0xFFFFL
    if self.n602:
      self.n617 = self.n615
    else:
      self.n617 = self.n616
    if self.n579:
      self.n594 = self.n592
    else:
      self.n594 = self.n593
    self.n553r = self.n4
    self.n553e = self.n3
    self.n553d = self.n546
    self.n531r = self.n4
    self.n531e = self.n3
    self.n531d = self.n524
    self.n1162 = self.n1149 << 11 | self.n1161
    self.n1132 = self.n1119 << 11 | self.n1131
    self.n1078 = self.n1065 << 11 | self.n1077
    self.n1049 = self.n1036 << 11 | self.n1048
    self.n996 = self.n983 << 11 | self.n995
    self.n968 = self.n955 << 11 | self.n967
    self.n916 = self.n903 << 11 | self.n915
    self.n889 = self.n876 << 11 | self.n888
    self.n839 = self.n837 << 5 | self.n838
    self.n813 = self.n811 << 5 | self.n812
    self.n764 = (self.n697 - self.n762) & 0xFFFFL
    self.n763 = (self.n697 + self.n762) & 0xFFFFL
    self.n739 = (self.n673 - self.n737) & 0xFFFFL
    self.n738 = (self.n673 + self.n737) & 0xFFFFL
    if self.n674:
      self.n690 = self.n688
    else:
      self.n690 = self.n689
    if self.n650:
      self.n666 = self.n664
    else:
      self.n666 = self.n665
    self.n624r = self.n4
    self.n624e = self.n3
    self.n624d = self.n617
    self.n601r = self.n4
    self.n601e = self.n3
    self.n601d = self.n594
    self.n1163 = self.n1149 << 12 | self.n1162
    self.n1133 = self.n1119 << 12 | self.n1132
    self.n1079 = self.n1065 << 12 | self.n1078
    self.n1050 = self.n1036 << 12 | self.n1049
    self.n997 = self.n983 << 12 | self.n996
    self.n969 = self.n955 << 12 | self.n968
    self.n918 = self.n916 << 4 | self.n917
    self.n891 = self.n889 << 4 | self.n890
    self.n841 = (self.n772 - self.n839) & 0xFFFFL
    self.n840 = (self.n772 + self.n839) & 0xFFFFL
    self.n815 = (self.n747 - self.n813) & 0xFFFFL
    self.n814 = (self.n747 + self.n813) & 0xFFFFL
    if self.n748:
      self.n765 = self.n763
    else:
      self.n765 = self.n764
    if self.n723:
      self.n740 = self.n738
    else:
      self.n740 = self.n739
    self.n697r = self.n4
    self.n697e = self.n3
    self.n697d = self.n690
    self.n673r = self.n4
    self.n673e = self.n3
    self.n673d = self.n666
    self.n1164 = self.n1149 << 13 | self.n1163
    self.n1134 = self.n1119 << 13 | self.n1133
    self.n1080 = self.n1065 << 13 | self.n1079
    self.n1051 = self.n1036 << 13 | self.n1050
    self.n999 = self.n997 << 3 | self.n998
    self.n971 = self.n969 << 3 | self.n970
    self.n920 = (self.n849 - self.n918) & 0xFFFFL
    self.n919 = (self.n849 + self.n918) & 0xFFFFL
    self.n893 = (self.n823 - self.n891) & 0xFFFFL
    self.n892 = (self.n823 + self.n891) & 0xFFFFL
    if self.n824:
      self.n842 = self.n840
    else:
      self.n842 = self.n841
    if self.n798:
      self.n816 = self.n814
    else:
      self.n816 = self.n815
    self.n772r = self.n4
    self.n772e = self.n3
    self.n772d = self.n765
    self.n747r = self.n4
    self.n747e = self.n3
    self.n747d = self.n740
    self.n1165 = self.n1149 << 14 | self.n1164
    self.n1135 = self.n1119 << 14 | self.n1134
    self.n1082 = self.n1080 << 2 | self.n1081
    self.n1053 = self.n1051 << 2 | self.n1052
    self.n1001 = (self.n928 - self.n999) & 0xFFFFL
    self.n1000 = (self.n928 + self.n999) & 0xFFFFL
    self.n973 = (self.n901 - self.n971) & 0xFFFFL
    self.n972 = (self.n901 + self.n971) & 0xFFFFL
    if self.n902:
      self.n921 = self.n919
    else:
      self.n921 = self.n920
    if self.n875:
      self.n894 = self.n892
    else:
      self.n894 = self.n893
    self.n849r = self.n4
    self.n849e = self.n3
    self.n849d = self.n842
    self.n823r = self.n4
    self.n823e = self.n3
    self.n823d = self.n816
    self.n1167 = self.n1165 << 1 | self.n1166
    self.n1137 = self.n1135 << 1 | self.n1136
    self.n1084 = (self.n1009 - self.n1082) & 0xFFFFL
    self.n1083 = (self.n1009 + self.n1082) & 0xFFFFL
    self.n1055 = (self.n981 - self.n1053) & 0xFFFFL
    self.n1054 = (self.n981 + self.n1053) & 0xFFFFL
    if self.n982:
      self.n1002 = self.n1000
    else:
      self.n1002 = self.n1001
    if self.n954:
      self.n974 = self.n972
    else:
      self.n974 = self.n973
    self.n928r = self.n4
    self.n928e = self.n3
    self.n928d = self.n921
    self.n901r = self.n4
    self.n901e = self.n3
    self.n901d = self.n894
    self.n1169 = (self.n1092 - self.n1167) & 0xFFFFL
    self.n1168 = (self.n1092 + self.n1167) & 0xFFFFL
    self.n1139 = (self.n1063 - self.n1137) & 0xFFFFL
    self.n1138 = (self.n1063 + self.n1137) & 0xFFFFL
    if self.n1064:
      self.n1085 = self.n1083
    else:
      self.n1085 = self.n1084
    if self.n1035:
      self.n1056 = self.n1054
    else:
      self.n1056 = self.n1055
    self.n1009r = self.n4
    self.n1009e = self.n3
    self.n1009d = self.n1002
    self.n981r = self.n4
    self.n981e = self.n3
    self.n981d = self.n974
    if self.n1148:
      self.n1170 = self.n1168
    else:
      self.n1170 = self.n1169
    if self.n1118:
      self.n1140 = self.n1138
    else:
      self.n1140 = self.n1139
    self.n1092r = self.n4
    self.n1092e = self.n3
    self.n1092d = self.n1085
    self.n1063r = self.n4
    self.n1063e = self.n3
    self.n1063d = self.n1056
    self.n1177r = self.n4
    self.n1177e = self.n3
    self.n1177d = self.n1170
    self.n1147r = self.n4
    self.n1147e = self.n3
    self.n1147d = self.n1140
    return (real_o, imag_o, ang_o, )

  def cycle_clock(self):
    if self.n15r:
      self.n15 = 0L
    elif self.n15e:
        self.n15 = self.n15d
    if self.n22r:
      self.n22 = 0L
    elif self.n22e:
        self.n22 = self.n22d
    if self.n29r:
      self.n29 = 0L
    elif self.n29e:
        self.n29 = self.n29d
    if self.n36r:
      self.n36 = 0L
    elif self.n36e:
        self.n36 = self.n36d
    if self.n52r:
      self.n52 = 0L
    elif self.n52e:
        self.n52 = self.n52d
    if self.n60r:
      self.n60 = 0L
    elif self.n60e:
        self.n60 = self.n60d
    if self.n68r:
      self.n68 = 0L
    elif self.n68e:
        self.n68 = self.n68d
    if self.n97r:
      self.n97 = 0L
    elif self.n97e:
        self.n97 = self.n97d
    if self.n112r:
      self.n112 = 0L
    elif self.n112e:
        self.n112 = self.n112d
    if self.n123r:
      self.n123 = 0L
    elif self.n123e:
        self.n123 = self.n123d
    if self.n153r:
      self.n153 = 0L
    elif self.n153e:
        self.n153 = self.n153d
    if self.n169r:
      self.n169 = 0L
    elif self.n169e:
        self.n169 = self.n169d
    if self.n180r:
      self.n180 = 0L
    elif self.n180e:
        self.n180 = self.n180d
    if self.n211r:
      self.n211 = 0L
    elif self.n211e:
        self.n211 = self.n211d
    if self.n228r:
      self.n228 = 0L
    elif self.n228e:
        self.n228 = self.n228d
    if self.n239r:
      self.n239 = 0L
    elif self.n239e:
        self.n239 = self.n239d
    if self.n271r:
      self.n271 = 0L
    elif self.n271e:
        self.n271 = self.n271d
    if self.n289r:
      self.n289 = 0L
    elif self.n289e:
        self.n289 = self.n289d
    if self.n300r:
      self.n300 = 0L
    elif self.n300e:
        self.n300 = self.n300d
    if self.n333r:
      self.n333 = 0L
    elif self.n333e:
        self.n333 = self.n333d
    if self.n352r:
      self.n352 = 0L
    elif self.n352e:
        self.n352 = self.n352d
    if self.n363r:
      self.n363 = 0L
    elif self.n363e:
        self.n363 = self.n363d
    if self.n397r:
      self.n397 = 0L
    elif self.n397e:
        self.n397 = self.n397d
    if self.n417r:
      self.n417 = 0L
    elif self.n417e:
        self.n417 = self.n417d
    if self.n428r:
      self.n428 = 0L
    elif self.n428e:
        self.n428 = self.n428d
    if self.n463r:
      self.n463 = 0L
    elif self.n463e:
        self.n463 = self.n463d
    if self.n484r:
      self.n484 = 0L
    elif self.n484e:
        self.n484 = self.n484d
    if self.n495r:
      self.n495 = 0L
    elif self.n495e:
        self.n495 = self.n495d
    if self.n531r:
      self.n531 = 0L
    elif self.n531e:
        self.n531 = self.n531d
    if self.n553r:
      self.n553 = 0L
    elif self.n553e:
        self.n553 = self.n553d
    if self.n564r:
      self.n564 = 0L
    elif self.n564e:
        self.n564 = self.n564d
    if self.n601r:
      self.n601 = 0L
    elif self.n601e:
        self.n601 = self.n601d
    if self.n624r:
      self.n624 = 0L
    elif self.n624e:
        self.n624 = self.n624d
    if self.n635r:
      self.n635 = 0L
    elif self.n635e:
        self.n635 = self.n635d
    if self.n673r:
      self.n673 = 0L
    elif self.n673e:
        self.n673 = self.n673d
    if self.n697r:
      self.n697 = 0L
    elif self.n697e:
        self.n697 = self.n697d
    if self.n708r:
      self.n708 = 0L
    elif self.n708e:
        self.n708 = self.n708d
    if self.n747r:
      self.n747 = 0L
    elif self.n747e:
        self.n747 = self.n747d
    if self.n772r:
      self.n772 = 0L
    elif self.n772e:
        self.n772 = self.n772d
    if self.n783r:
      self.n783 = 0L
    elif self.n783e:
        self.n783 = self.n783d
    if self.n823r:
      self.n823 = 0L
    elif self.n823e:
        self.n823 = self.n823d
    if self.n849r:
      self.n849 = 0L
    elif self.n849e:
        self.n849 = self.n849d
    if self.n860r:
      self.n860 = 0L
    elif self.n860e:
        self.n860 = self.n860d
    if self.n901r:
      self.n901 = 0L
    elif self.n901e:
        self.n901 = self.n901d
    if self.n928r:
      self.n928 = 0L
    elif self.n928e:
        self.n928 = self.n928d
    if self.n939r:
      self.n939 = 0L
    elif self.n939e:
        self.n939 = self.n939d
    if self.n981r:
      self.n981 = 0L
    elif self.n981e:
        self.n981 = self.n981d
    if self.n1009r:
      self.n1009 = 0L
    elif self.n1009e:
        self.n1009 = self.n1009d
    if self.n1020r:
      self.n1020 = 0L
    elif self.n1020e:
        self.n1020 = self.n1020d
    if self.n1063r:
      self.n1063 = 0L
    elif self.n1063e:
        self.n1063 = self.n1063d
    if self.n1092r:
      self.n1092 = 0L
    elif self.n1092e:
        self.n1092 = self.n1092d
    if self.n1103r:
      self.n1103 = 0L
    elif self.n1103e:
        self.n1103 = self.n1103d
    if self.n1147r:
      self.n1147 = 0L
    elif self.n1147e:
        self.n1147 = self.n1147d
    if self.n1177r:
      self.n1177 = 0L
    elif self.n1177e:
        self.n1177 = self.n1177d
    if self.n1188r:
      self.n1188 = 0L
    elif self.n1188e:
        self.n1188 = self.n1188d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n3 = self.n3
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n8 = self.n8
    self.sim_n1189 = self.n1189
    self.sim_n1190 = self.n1190
    self.sim_n1191 = self.n1191
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_cordic_r_16_16_16 $end\n")
    self.sim_file.write("$var wire 1 ! enable_i $end\n")
    self.sim_file.write("$var wire 1 \" reset_i $end\n")
    self.sim_file.write("$var wire 1 # flip_i $end\n")
    self.sim_file.write("$var wire 16 $ real_i $end\n")
    self.sim_file.write("$var wire 16 % imag_i $end\n")
    self.sim_file.write("$var wire 16 & ang_i $end\n")
    self.sim_file.write("$var wire 16 ' real_o $end\n")
    self.sim_file.write("$var wire 16 ( imag_o $end\n")
    self.sim_file.write("$var wire 16 ) ang_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n3:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    if self.n4:
      self.sim_file.write("1\"\n")
    else:
      self.sim_file.write("0\"\n")
    if self.n5:
      self.sim_file.write("1#\n")
    else:
      self.sim_file.write("0#\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n7 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n7 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n8 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n8 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n1189 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n1189 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n1190 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n1190 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" (\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n1191 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n1191 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" )\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n3 = self.n3
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n4:
        self.sim_file.write("1\"\n")
      else:
        self.sim_file.write("0\"\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n5:
        self.sim_file.write("1#\n")
      else:
        self.sim_file.write("0#\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n7 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n7 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n7 = self.n7
    if self.sim_n8 != self.n8:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n8 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n8 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n8 = self.n8
    if self.sim_n1189 != self.n1189:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n1189 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n1189 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n1189 = self.n1189
    if self.sim_n1190 != self.n1190:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n1190 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n1190 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" (\n")
      self.sim_n1190 = self.n1190
    if self.sim_n1191 != self.n1191:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n1191 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n1191 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" )\n")
      self.sim_n1191 = self.n1191
    self.sim_count = self.sim_count + 1

