//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Cordics (COordinate Rotation DIgital Computers) are used to calculate
//    trigonometric functions and complex plane phase rotations.
//    This rotation mode cordic rotates a complex vector by the initial angle.
//    If the rotation will transition through +-PI/2 then the "flip_i" control
//    input must be set.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      enable_i : Synchronous enable.
//      reset_i  : Synchronous reset.
//  
//    Inputs:
//      flip_i   : Set to perform initial rotation if rotation will transition through +-PI/2
//      real_i   : Initial real component (signed).
//      imag_i   : Initial imaginary component (signed).
//      angle_i  : Initial angle (modulo 2PI).
//  
//    Outputs:
//      real_o   : Resulting real component (signed).
//      imag_o   : Resulting imaginary component (signed).
//      angle_o  : Resulting angle (modulo 2PI).
//  
//  Built In Parameters:
//  
//    Cordic Mode    = Rotation
//    Vector Width   = 8
//    Angle Width    = 8
//    Cordic Stages  = 8
//  
//  Resulting Pipeline Latency is 10 clock cycles.
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:44:17 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_cordic_r_8_8_8
//    Clock Domains : clock_c  
//    Vector Input  : enable_i(1)
//    Vector Input  : reset_i(1)
//    Vector Input  : flip_i(1)
//    Vector Input  : real_i(8)
//    Vector Input  : imag_i(8)
//    Vector Input  : ang_i(8)
//    Vector Output : real_o(8)
//    Vector Output : imag_o(8)
//    Vector Output : ang_o(8)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_cordic_r_8_8_8.h"

static unsigned char n619[2];
static unsigned char n617[2];
static unsigned char n615[2];
static unsigned char n613[2];
static unsigned char n611[2];
static unsigned char n609[2];
static unsigned char n607[2];
static unsigned char n605[2];
static unsigned char n570[1];
static unsigned char *ang_o;
static unsigned char *imag_o;
static unsigned char *real_o;
static unsigned char n554[1];
static unsigned char n542[1];
static unsigned char n533[1];
static unsigned char n520[1];
static unsigned char n511[1];
static unsigned char n505[1];
static unsigned char n499[1];
static unsigned char n497[1];
static unsigned char n485[1];
static unsigned char n473[1];
static unsigned char n465[1];
static unsigned char n452[1];
static unsigned char n444[1];
static unsigned char n438[1];
static unsigned char n432[1];
static unsigned char n430[1];
static unsigned char n418[1];
static unsigned char n406[1];
static unsigned char n399[1];
static unsigned char n386[1];
static unsigned char n379[1];
static unsigned char n373[1];
static unsigned char n367[1];
static unsigned char n365[1];
static unsigned char n353[1];
static unsigned char n341[1];
static unsigned char n335[1];
static unsigned char n322[1];
static unsigned char n316[1];
static unsigned char n310[1];
static unsigned char n304[1];
static unsigned char n302[1];
static unsigned char n290[1];
static unsigned char n278[1];
static unsigned char n273[1];
static unsigned char n260[1];
static unsigned char n255[1];
static unsigned char n249[1];
static unsigned char n243[1];
static unsigned char n241[1];
static unsigned char n229[1];
static unsigned char n217[1];
static unsigned char n213[1];
static unsigned char n200[1];
static unsigned char n196[1];
static unsigned char n190[1];
static unsigned char n184[1];
static unsigned char n182[1];
static unsigned char n170[1];
static unsigned char n158[1];
static unsigned char n155[1];
static unsigned char n142[1];
static unsigned char n139[1];
static unsigned char n133[1];
static unsigned char n127[1];
static unsigned char n125[1];
static unsigned char n113[1];
static unsigned char n101[1];
static unsigned char n86[1];
static unsigned char n78[1];
static unsigned char n72[1];
static unsigned char n70[1];
static unsigned char n39[1];
static unsigned char n37[1];
static unsigned char *ang_i;
static unsigned char *imag_i;
static unsigned char *real_i;
static unsigned char *flip_i;
static unsigned char *reset_i;
static unsigned char *enable_i;
static unsigned char n556[1];
static unsigned char n555[1];
static unsigned char n536[1];
static unsigned char n514[1];
static unsigned char n498[1];
static unsigned char n487[1];
static unsigned char n486[1];
static unsigned char n468[1];
static unsigned char n447[1];
static unsigned char n431[1];
static unsigned char n420[1];
static unsigned char n419[1];
static unsigned char n402[1];
static unsigned char n382[1];
static unsigned char n366[1];
static unsigned char n355[1];
static unsigned char n354[1];
static unsigned char n338[1];
static unsigned char n319[1];
static unsigned char n303[1];
static unsigned char n292[1];
static unsigned char n291[1];
static unsigned char n276[1];
static unsigned char n258[1];
static unsigned char n242[1];
static unsigned char n231[1];
static unsigned char n230[1];
static unsigned char n216[1];
static unsigned char n199[1];
static unsigned char n183[1];
static unsigned char n172[1];
static unsigned char n171[1];
static unsigned char n159[1];
static unsigned char n143[1];
static unsigned char n126[1];
static unsigned char n115[1];
static unsigned char n114[1];
static unsigned char n104[1];
static unsigned char n103[1];
static unsigned char n89[1];
static unsigned char n88[1];
static unsigned char n71[1];
static unsigned char n44[1];
static unsigned char n40[1];
static unsigned char n38[1];
static unsigned char n36[1];
static unsigned char n36r[1];
static unsigned char n36e[1];
static unsigned char n36d[1];
static unsigned char n29[1];
static unsigned char n29r[1];
static unsigned char n29e[1];
static unsigned char n29d[1];
static unsigned char n22[1];
static unsigned char n22r[1];
static unsigned char n22e[1];
static unsigned char n22d[1];
static unsigned char n15[1];
static unsigned char n15r[1];
static unsigned char n15e[1];
static unsigned char n15d[1];
static unsigned char n537[1];
static unsigned char n515[1];
static unsigned char n500[1];
static unsigned char n469[1];
static unsigned char n448[1];
static unsigned char n433[1];
static unsigned char n403[1];
static unsigned char n383[1];
static unsigned char n368[1];
static unsigned char n339[1];
static unsigned char n320[1];
static unsigned char n305[1];
static unsigned char n277[1];
static unsigned char n259[1];
static unsigned char n244[1];
static unsigned char n218[1];
static unsigned char n201[1];
static unsigned char n185[1];
static unsigned char n161[1];
static unsigned char n160[1];
static unsigned char n145[1];
static unsigned char n144[1];
static unsigned char n128[1];
static unsigned char n73[1];
static unsigned char n61[1];
static unsigned char n53[1];
static unsigned char n45[1];
static unsigned char n538[1];
static unsigned char n516[1];
static unsigned char n506[2];
static unsigned char n470[1];
static unsigned char n449[1];
static unsigned char n439[2];
static unsigned char n404[1];
static unsigned char n384[1];
static unsigned char n374[2];
static unsigned char n340[1];
static unsigned char n321[1];
static unsigned char n311[2];
static unsigned char n279[1];
static unsigned char n261[1];
static unsigned char n250[2];
static unsigned char n220[1];
static unsigned char n219[1];
static unsigned char n203[1];
static unsigned char n202[1];
static unsigned char n191[2];
static unsigned char n134[2];
static unsigned char n79[2];
static unsigned char n68[1];
static unsigned char n68r[1];
static unsigned char n68e[1];
static unsigned char n68d[1];
static unsigned char n60[1];
static unsigned char n60r[1];
static unsigned char n60e[1];
static unsigned char n60d[1];
static unsigned char n52[1];
static unsigned char n52r[1];
static unsigned char n52e[1];
static unsigned char n52d[1];
static unsigned char n539[1];
static unsigned char n517[1];
static unsigned char n509[2];
static unsigned char n471[1];
static unsigned char n450[1];
static unsigned char n442[2];
static unsigned char n405[1];
static unsigned char n385[1];
static unsigned char n377[2];
static unsigned char n342[1];
static unsigned char n323[1];
static unsigned char n314[2];
static unsigned char n281[1];
static unsigned char n280[1];
static unsigned char n263[1];
static unsigned char n262[1];
static unsigned char n253[2];
static unsigned char n194[2];
static unsigned char n137[2];
static unsigned char n82[2];
static unsigned char n540[1];
static unsigned char n518[1];
static unsigned char n510[1];
static unsigned char n472[1];
static unsigned char n451[1];
static unsigned char n443[1];
static unsigned char n407[1];
static unsigned char n387[1];
static unsigned char n378[1];
static unsigned char n344[1];
static unsigned char n343[1];
static unsigned char n325[1];
static unsigned char n324[1];
static unsigned char n315[1];
static unsigned char n254[1];
static unsigned char n195[1];
static unsigned char n138[1];
static unsigned char n83[1];
static unsigned char n557[1];
static unsigned char n541[1];
static unsigned char n532[1];
static unsigned char n519[1];
static unsigned char n488[1];
static unsigned char n474[1];
static unsigned char n464[1];
static unsigned char n453[1];
static unsigned char n421[1];
static unsigned char n409[1];
static unsigned char n408[1];
static unsigned char n398[1];
static unsigned char n389[1];
static unsigned char n388[1];
static unsigned char n356[1];
static unsigned char n334[1];
static unsigned char n326[1];
static unsigned char n293[1];
static unsigned char n272[1];
static unsigned char n264[1];
static unsigned char n232[1];
static unsigned char n212[1];
static unsigned char n204[1];
static unsigned char n173[1];
static unsigned char n154[1];
static unsigned char n146[1];
static unsigned char n116[1];
static unsigned char n98[1];
static unsigned char n90[1];
static unsigned char n564[1];
static unsigned char n564r[1];
static unsigned char n564e[1];
static unsigned char n564d[1];
static unsigned char n543[1];
static unsigned char n521[1];
static unsigned char n495[1];
static unsigned char n495r[1];
static unsigned char n495e[1];
static unsigned char n495d[1];
static unsigned char n476[1];
static unsigned char n475[1];
static unsigned char n455[1];
static unsigned char n454[1];
static unsigned char n428[1];
static unsigned char n428r[1];
static unsigned char n428e[1];
static unsigned char n428d[1];
static unsigned char n410[1];
static unsigned char n390[1];
static unsigned char n363[1];
static unsigned char n363r[1];
static unsigned char n363e[1];
static unsigned char n363d[1];
static unsigned char n345[1];
static unsigned char n333[1];
static unsigned char n333r[1];
static unsigned char n333e[1];
static unsigned char n333d[1];
static unsigned char n300[1];
static unsigned char n300r[1];
static unsigned char n300e[1];
static unsigned char n300d[1];
static unsigned char n282[1];
static unsigned char n271[1];
static unsigned char n271r[1];
static unsigned char n271e[1];
static unsigned char n271d[1];
static unsigned char n239[1];
static unsigned char n239r[1];
static unsigned char n239e[1];
static unsigned char n239d[1];
static unsigned char n221[1];
static unsigned char n211[1];
static unsigned char n211r[1];
static unsigned char n211e[1];
static unsigned char n211d[1];
static unsigned char n180[1];
static unsigned char n180r[1];
static unsigned char n180e[1];
static unsigned char n180d[1];
static unsigned char n162[1];
static unsigned char n153[1];
static unsigned char n153r[1];
static unsigned char n153e[1];
static unsigned char n153d[1];
static unsigned char n123[1];
static unsigned char n123r[1];
static unsigned char n123e[1];
static unsigned char n123d[1];
static unsigned char n105[1];
static unsigned char n97[1];
static unsigned char n97r[1];
static unsigned char n97e[1];
static unsigned char n97d[1];
static unsigned char n545[1];
static unsigned char n544[1];
static unsigned char n523[1];
static unsigned char n522[1];
static unsigned char n477[1];
static unsigned char n456[1];
static unsigned char n417[1];
static unsigned char n417r[1];
static unsigned char n417e[1];
static unsigned char n417d[1];
static unsigned char n397[1];
static unsigned char n397r[1];
static unsigned char n397e[1];
static unsigned char n397d[1];
static unsigned char n352[1];
static unsigned char n352r[1];
static unsigned char n352e[1];
static unsigned char n352d[1];
static unsigned char n289[1];
static unsigned char n289r[1];
static unsigned char n289e[1];
static unsigned char n289d[1];
static unsigned char n228[1];
static unsigned char n228r[1];
static unsigned char n228e[1];
static unsigned char n228d[1];
static unsigned char n169[1];
static unsigned char n169r[1];
static unsigned char n169e[1];
static unsigned char n169d[1];
static unsigned char n112[1];
static unsigned char n112r[1];
static unsigned char n112e[1];
static unsigned char n112d[1];
static unsigned char n546[1];
static unsigned char n524[1];
static unsigned char n484[1];
static unsigned char n484r[1];
static unsigned char n484e[1];
static unsigned char n484d[1];
static unsigned char n463[1];
static unsigned char n463r[1];
static unsigned char n463e[1];
static unsigned char n463d[1];
static unsigned char n553[1];
static unsigned char n553r[1];
static unsigned char n553e[1];
static unsigned char n553d[1];
static unsigned char n531[1];
static unsigned char n531r[1];
static unsigned char n531e[1];
static unsigned char n531d[1];

void cf_cordic_r_8_8_8_ports(unsigned char* port_enable_i, unsigned char* port_reset_i, unsigned char* port_flip_i, unsigned char* port_real_i, unsigned char* port_imag_i, unsigned char* port_ang_i, unsigned char* port_real_o, unsigned char* port_imag_o, unsigned char* port_ang_o) {
  enable_i = port_enable_i;
  reset_i = port_reset_i;
  flip_i = port_flip_i;
  real_i = port_real_i;
  imag_i = port_imag_i;
  ang_i = port_ang_i;
  real_o = port_real_o;
  imag_o = port_imag_o;
  ang_o = port_ang_o;
}

void cf_cordic_r_8_8_8_calc() {
  n619[0] = 128;
  n619[1] = 0;
  n617[0] = 128;
  n617[1] = 0;
  n615[0] = 128;
  n615[1] = 0;
  n613[0] = 128;
  n613[1] = 0;
  n611[0] = 128;
  n611[1] = 0;
  n609[0] = 128;
  n609[1] = 0;
  n607[0] = 128;
  n607[1] = 0;
  n605[0] = 128;
  n605[1] = 0;
  n570[0] = 128;
  ang_o[0] = n564[0];
  imag_o[0] = n553[0];
  real_o[0] = n531[0];
  n554[0] = 0;
  n542[0] = (1 & (n463[0] >> 7));
  n533[0] = (1 & (n463[0] >> 7));
  n520[0] = (1 & (n484[0] >> 7));
  n511[0] = (1 & (n484[0] >> 7));
  n505[0] = 0;
  n499[0] = (1 & (n495[0])) | (2 & (n495[0])) | (4 & (n495[0])) | (8 & (n495[0])) | (16 & (n495[0])) | (32 & (n495[0])) | (64 & (n495[0]));
  n497[0] = (1 & (n495[0] >> 7));
  n485[0] = 1;
  n473[0] = (1 & (n397[0] >> 6)) | (2 & (n397[0] >> 6));
  n465[0] = (1 & (n397[0] >> 7));
  n452[0] = (1 & (n417[0] >> 6)) | (2 & (n417[0] >> 6));
  n444[0] = (1 & (n417[0] >> 7));
  n438[0] = 0;
  n432[0] = (1 & (n428[0])) | (2 & (n428[0])) | (4 & (n428[0])) | (8 & (n428[0])) | (16 & (n428[0])) | (32 & (n428[0])) | (64 & (n428[0]));
  n430[0] = (1 & (n428[0] >> 7));
  n418[0] = 1;
  n406[0] = (1 & (n333[0] >> 5)) | (2 & (n333[0] >> 5)) | (4 & (n333[0] >> 5));
  n399[0] = (1 & (n333[0] >> 7));
  n386[0] = (1 & (n352[0] >> 5)) | (2 & (n352[0] >> 5)) | (4 & (n352[0] >> 5));
  n379[0] = (1 & (n352[0] >> 7));
  n373[0] = 0;
  n367[0] = (1 & (n363[0])) | (2 & (n363[0])) | (4 & (n363[0])) | (8 & (n363[0])) | (16 & (n363[0])) | (32 & (n363[0])) | (64 & (n363[0]));
  n365[0] = (1 & (n363[0] >> 7));
  n353[0] = 3;
  n341[0] = (1 & (n271[0] >> 4)) | (2 & (n271[0] >> 4)) | (4 & (n271[0] >> 4)) | (8 & (n271[0] >> 4));
  n335[0] = (1 & (n271[0] >> 7));
  n322[0] = (1 & (n289[0] >> 4)) | (2 & (n289[0] >> 4)) | (4 & (n289[0] >> 4)) | (8 & (n289[0] >> 4));
  n316[0] = (1 & (n289[0] >> 7));
  n310[0] = 0;
  n304[0] = (1 & (n300[0])) | (2 & (n300[0])) | (4 & (n300[0])) | (8 & (n300[0])) | (16 & (n300[0])) | (32 & (n300[0])) | (64 & (n300[0]));
  n302[0] = (1 & (n300[0] >> 7));
  n290[0] = 5;
  n278[0] = (1 & (n211[0] >> 3)) | (2 & (n211[0] >> 3)) | (4 & (n211[0] >> 3)) | (8 & (n211[0] >> 3)) | (16 & (n211[0] >> 3));
  n273[0] = (1 & (n211[0] >> 7));
  n260[0] = (1 & (n228[0] >> 3)) | (2 & (n228[0] >> 3)) | (4 & (n228[0] >> 3)) | (8 & (n228[0] >> 3)) | (16 & (n228[0] >> 3));
  n255[0] = (1 & (n228[0] >> 7));
  n249[0] = 0;
  n243[0] = (1 & (n239[0])) | (2 & (n239[0])) | (4 & (n239[0])) | (8 & (n239[0])) | (16 & (n239[0])) | (32 & (n239[0])) | (64 & (n239[0]));
  n241[0] = (1 & (n239[0] >> 7));
  n229[0] = 10;
  n217[0] = (1 & (n153[0] >> 2)) | (2 & (n153[0] >> 2)) | (4 & (n153[0] >> 2)) | (8 & (n153[0] >> 2)) | (16 & (n153[0] >> 2)) | (32 & (n153[0] >> 2));
  n213[0] = (1 & (n153[0] >> 7));
  n200[0] = (1 & (n169[0] >> 2)) | (2 & (n169[0] >> 2)) | (4 & (n169[0] >> 2)) | (8 & (n169[0] >> 2)) | (16 & (n169[0] >> 2)) | (32 & (n169[0] >> 2));
  n196[0] = (1 & (n169[0] >> 7));
  n190[0] = 0;
  n184[0] = (1 & (n180[0])) | (2 & (n180[0])) | (4 & (n180[0])) | (8 & (n180[0])) | (16 & (n180[0])) | (32 & (n180[0])) | (64 & (n180[0]));
  n182[0] = (1 & (n180[0] >> 7));
  n170[0] = 19;
  n158[0] = (1 & (n97[0] >> 1)) | (2 & (n97[0] >> 1)) | (4 & (n97[0] >> 1)) | (8 & (n97[0] >> 1)) | (16 & (n97[0] >> 1)) | (32 & (n97[0] >> 1)) | (64 & (n97[0] >> 1));
  n155[0] = (1 & (n97[0] >> 7));
  n142[0] = (1 & (n112[0] >> 1)) | (2 & (n112[0] >> 1)) | (4 & (n112[0] >> 1)) | (8 & (n112[0] >> 1)) | (16 & (n112[0] >> 1)) | (32 & (n112[0] >> 1)) | (64 & (n112[0] >> 1));
  n139[0] = (1 & (n112[0] >> 7));
  n133[0] = 0;
  n127[0] = (1 & (n123[0])) | (2 & (n123[0])) | (4 & (n123[0])) | (8 & (n123[0])) | (16 & (n123[0])) | (32 & (n123[0])) | (64 & (n123[0]));
  n125[0] = (1 & (n123[0] >> 7));
  n113[0] = 32;
  n101[0] = (1 & (n52[0])) | (2 & (n52[0])) | (4 & (n52[0])) | (8 & (n52[0])) | (16 & (n52[0])) | (32 & (n52[0])) | (64 & (n52[0])) | (128 & (n52[0]));
  n86[0] = (1 & (n60[0])) | (2 & (n60[0])) | (4 & (n60[0])) | (8 & (n60[0])) | (16 & (n60[0])) | (32 & (n60[0])) | (64 & (n60[0])) | (128 & (n60[0]));
  n78[0] = 0;
  n72[0] = (1 & (n68[0])) | (2 & (n68[0])) | (4 & (n68[0])) | (8 & (n68[0])) | (16 & (n68[0])) | (32 & (n68[0])) | (64 & (n68[0]));
  n70[0] = (1 & (n68[0] >> 7));
  n39[0] = 0;
  n37[0] = 0;
  { unsigned int tmp; (tmp = (unsigned int) n495[0] - (unsigned int) n554[0], n556[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n495[0] + (unsigned int) n554[0], n555[0] = 255 & (unsigned char) tmp); }
  n536[0] = 255 & (n533[0] << 1 | n533[0]);
  n514[0] = 255 & (n511[0] << 1 | n511[0]);
  n498[0] = 1 & ~n497[0];
  { unsigned int tmp; (tmp = (unsigned int) n428[0] - (unsigned int) n485[0], n487[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n428[0] + (unsigned int) n485[0], n486[0] = 255 & (unsigned char) tmp); }
  n468[0] = 255 & (n465[0] << 1 | n465[0]);
  n447[0] = 255 & (n444[0] << 1 | n444[0]);
  n431[0] = 1 & ~n430[0];
  { unsigned int tmp; (tmp = (unsigned int) n363[0] - (unsigned int) n418[0], n420[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n363[0] + (unsigned int) n418[0], n419[0] = 255 & (unsigned char) tmp); }
  n402[0] = 255 & (n399[0] << 1 | n399[0]);
  n382[0] = 255 & (n379[0] << 1 | n379[0]);
  n366[0] = 1 & ~n365[0];
  { unsigned int tmp; (tmp = (unsigned int) n300[0] - (unsigned int) n353[0], n355[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n300[0] + (unsigned int) n353[0], n354[0] = 255 & (unsigned char) tmp); }
  n338[0] = 255 & (n335[0] << 1 | n335[0]);
  n319[0] = 255 & (n316[0] << 1 | n316[0]);
  n303[0] = 1 & ~n302[0];
  { unsigned int tmp; (tmp = (unsigned int) n239[0] - (unsigned int) n290[0], n292[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n239[0] + (unsigned int) n290[0], n291[0] = 255 & (unsigned char) tmp); }
  n276[0] = 255 & (n273[0] << 1 | n273[0]);
  n258[0] = 255 & (n255[0] << 1 | n255[0]);
  n242[0] = 1 & ~n241[0];
  { unsigned int tmp; (tmp = (unsigned int) n180[0] - (unsigned int) n229[0], n231[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n180[0] + (unsigned int) n229[0], n230[0] = 255 & (unsigned char) tmp); }
  n216[0] = 255 & (n213[0] << 1 | n213[0]);
  n199[0] = 255 & (n196[0] << 1 | n196[0]);
  n183[0] = 1 & ~n182[0];
  { unsigned int tmp; (tmp = (unsigned int) n123[0] - (unsigned int) n170[0], n172[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n123[0] + (unsigned int) n170[0], n171[0] = 255 & (unsigned char) tmp); }
  n159[0] = 255 & (n155[0] << 7 | n158[0]);
  n143[0] = 255 & (n139[0] << 7 | n142[0]);
  n126[0] = 1 & ~n125[0];
  { unsigned int tmp; (tmp = (unsigned int) n68[0] - (unsigned int) n113[0], n115[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n68[0] + (unsigned int) n113[0], n114[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n60[0] - (unsigned int) n101[0], n104[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n60[0] + (unsigned int) n101[0], n103[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n52[0] - (unsigned int) n86[0], n89[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n52[0] + (unsigned int) n86[0], n88[0] = 255 & (unsigned char) tmp); }
  n71[0] = 1 & ~n70[0];
  { unsigned int tmp; (tmp = (unsigned int) n36[0] - (unsigned int) n570[0], n44[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n39[0] - (unsigned int) n29[0], n40[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n37[0] - (unsigned int) n22[0], n38[0] = 255 & (unsigned char) tmp); }
  n36r[0] = reset_i[0];
  n36e[0] = enable_i[0];
  n36d[0] = ang_i[0];
  n29r[0] = reset_i[0];
  n29e[0] = enable_i[0];
  n29d[0] = imag_i[0];
  n22r[0] = reset_i[0];
  n22e[0] = enable_i[0];
  n22d[0] = real_i[0];
  n15r[0] = reset_i[0];
  n15e[0] = enable_i[0];
  n15d[0] = flip_i[0];
  n537[0] = 255 & (n533[0] << 2 | n536[0]);
  n515[0] = 255 & (n511[0] << 2 | n514[0]);
  n500[0] = 255 & (n498[0] << 7 | n499[0]);
  n469[0] = 255 & (n465[0] << 2 | n468[0]);
  n448[0] = 255 & (n444[0] << 2 | n447[0]);
  n433[0] = 255 & (n431[0] << 7 | n432[0]);
  n403[0] = 255 & (n399[0] << 2 | n402[0]);
  n383[0] = 255 & (n379[0] << 2 | n382[0]);
  n368[0] = 255 & (n366[0] << 7 | n367[0]);
  n339[0] = 255 & (n335[0] << 2 | n338[0]);
  n320[0] = 255 & (n316[0] << 2 | n319[0]);
  n305[0] = 255 & (n303[0] << 7 | n304[0]);
  n277[0] = 255 & (n273[0] << 2 | n276[0]);
  n259[0] = 255 & (n255[0] << 2 | n258[0]);
  n244[0] = 255 & (n242[0] << 7 | n243[0]);
  n218[0] = 255 & (n216[0] << 6 | n217[0]);
  n201[0] = 255 & (n199[0] << 6 | n200[0]);
  n185[0] = 255 & (n183[0] << 7 | n184[0]);
  { unsigned int tmp; (tmp = (unsigned int) n112[0] - (unsigned int) n159[0], n161[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n112[0] + (unsigned int) n159[0], n160[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n97[0] - (unsigned int) n143[0], n145[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n97[0] + (unsigned int) n143[0], n144[0] = 255 & (unsigned char) tmp); }
  n128[0] = 255 & (n126[0] << 7 | n127[0]);
  n73[0] = 255 & (n71[0] << 7 | n72[0]);
  if (n15[0]) {
    n61[0] = n44[0];
  }
  else {
    n61[0] = n36[0];
  }
  if (n15[0]) {
    n53[0] = n40[0];
  }
  else {
    n53[0] = n29[0];
  }
  if (n15[0]) {
    n45[0] = n38[0];
  }
  else {
    n45[0] = n22[0];
  }
  n538[0] = 255 & (n533[0] << 3 | n537[0]);
  n516[0] = 255 & (n511[0] << 3 | n515[0]);
  n506[0] = n500[0];
  n506[1] = n505[0];
  n470[0] = 255 & (n465[0] << 3 | n469[0]);
  n449[0] = 255 & (n444[0] << 3 | n448[0]);
  n439[0] = n433[0];
  n439[1] = n438[0];
  n404[0] = 255 & (n399[0] << 3 | n403[0]);
  n384[0] = 255 & (n379[0] << 3 | n383[0]);
  n374[0] = n368[0];
  n374[1] = n373[0];
  n340[0] = 255 & (n335[0] << 3 | n339[0]);
  n321[0] = 255 & (n316[0] << 3 | n320[0]);
  n311[0] = n305[0];
  n311[1] = n310[0];
  n279[0] = 255 & (n277[0] << 5 | n278[0]);
  n261[0] = 255 & (n259[0] << 5 | n260[0]);
  n250[0] = n244[0];
  n250[1] = n249[0];
  { unsigned int tmp; (tmp = (unsigned int) n169[0] - (unsigned int) n218[0], n220[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n169[0] + (unsigned int) n218[0], n219[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n153[0] - (unsigned int) n201[0], n203[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n153[0] + (unsigned int) n201[0], n202[0] = 255 & (unsigned char) tmp); }
  n191[0] = n185[0];
  n191[1] = n190[0];
  n134[0] = n128[0];
  n134[1] = n133[0];
  n79[0] = n73[0];
  n79[1] = n78[0];
  n68r[0] = reset_i[0];
  n68e[0] = enable_i[0];
  n68d[0] = n61[0];
  n60r[0] = reset_i[0];
  n60e[0] = enable_i[0];
  n60d[0] = n53[0];
  n52r[0] = reset_i[0];
  n52e[0] = enable_i[0];
  n52d[0] = n45[0];
  n539[0] = 255 & (n533[0] << 4 | n538[0]);
  n517[0] = 255 & (n511[0] << 4 | n516[0]);
  { unsigned int tmp; (tmp = (unsigned int) n506[1] - (unsigned int) n619[1] - (tmp = (unsigned int) n506[0] - (unsigned int) n619[0], n509[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n509[1] = 1 & (unsigned char) tmp); }
  n471[0] = 255 & (n465[0] << 4 | n470[0]);
  n450[0] = 255 & (n444[0] << 4 | n449[0]);
  { unsigned int tmp; (tmp = (unsigned int) n439[1] - (unsigned int) n617[1] - (tmp = (unsigned int) n439[0] - (unsigned int) n617[0], n442[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n442[1] = 1 & (unsigned char) tmp); }
  n405[0] = 255 & (n399[0] << 4 | n404[0]);
  n385[0] = 255 & (n379[0] << 4 | n384[0]);
  { unsigned int tmp; (tmp = (unsigned int) n374[1] - (unsigned int) n615[1] - (tmp = (unsigned int) n374[0] - (unsigned int) n615[0], n377[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n377[1] = 1 & (unsigned char) tmp); }
  n342[0] = 255 & (n340[0] << 4 | n341[0]);
  n323[0] = 255 & (n321[0] << 4 | n322[0]);
  { unsigned int tmp; (tmp = (unsigned int) n311[1] - (unsigned int) n613[1] - (tmp = (unsigned int) n311[0] - (unsigned int) n613[0], n314[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n314[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n228[0] - (unsigned int) n279[0], n281[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n228[0] + (unsigned int) n279[0], n280[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n211[0] - (unsigned int) n261[0], n263[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n211[0] + (unsigned int) n261[0], n262[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n250[1] - (unsigned int) n611[1] - (tmp = (unsigned int) n250[0] - (unsigned int) n611[0], n253[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n253[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n191[1] - (unsigned int) n609[1] - (tmp = (unsigned int) n191[0] - (unsigned int) n609[0], n194[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n194[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n134[1] - (unsigned int) n607[1] - (tmp = (unsigned int) n134[0] - (unsigned int) n607[0], n137[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n137[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n79[1] - (unsigned int) n605[1] - (tmp = (unsigned int) n79[0] - (unsigned int) n605[0], n82[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n82[1] = 1 & (unsigned char) tmp); }
  n540[0] = 255 & (n533[0] << 5 | n539[0]);
  n518[0] = 255 & (n511[0] << 5 | n517[0]);
  n510[0] = (1 & (n509[1]));
  n472[0] = 255 & (n465[0] << 5 | n471[0]);
  n451[0] = 255 & (n444[0] << 5 | n450[0]);
  n443[0] = (1 & (n442[1]));
  n407[0] = 255 & (n405[0] << 3 | n406[0]);
  n387[0] = 255 & (n385[0] << 3 | n386[0]);
  n378[0] = (1 & (n377[1]));
  { unsigned int tmp; (tmp = (unsigned int) n289[0] - (unsigned int) n342[0], n344[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n289[0] + (unsigned int) n342[0], n343[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n271[0] - (unsigned int) n323[0], n325[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n271[0] + (unsigned int) n323[0], n324[0] = 255 & (unsigned char) tmp); }
  n315[0] = (1 & (n314[1]));
  n254[0] = (1 & (n253[1]));
  n195[0] = (1 & (n194[1]));
  n138[0] = (1 & (n137[1]));
  n83[0] = (1 & (n82[1]));
  if (n510[0]) {
    n557[0] = n555[0];
  }
  else {
    n557[0] = n556[0];
  }
  n541[0] = 255 & (n533[0] << 6 | n540[0]);
  n532[0] = 1 & ~n510[0];
  n519[0] = 255 & (n511[0] << 6 | n518[0]);
  if (n443[0]) {
    n488[0] = n486[0];
  }
  else {
    n488[0] = n487[0];
  }
  n474[0] = 255 & (n472[0] << 2 | n473[0]);
  n464[0] = 1 & ~n443[0];
  n453[0] = 255 & (n451[0] << 2 | n452[0]);
  if (n378[0]) {
    n421[0] = n419[0];
  }
  else {
    n421[0] = n420[0];
  }
  { unsigned int tmp; (tmp = (unsigned int) n352[0] - (unsigned int) n407[0], n409[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n352[0] + (unsigned int) n407[0], n408[0] = 255 & (unsigned char) tmp); }
  n398[0] = 1 & ~n378[0];
  { unsigned int tmp; (tmp = (unsigned int) n333[0] - (unsigned int) n387[0], n389[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n333[0] + (unsigned int) n387[0], n388[0] = 255 & (unsigned char) tmp); }
  if (n315[0]) {
    n356[0] = n354[0];
  }
  else {
    n356[0] = n355[0];
  }
  n334[0] = 1 & ~n315[0];
  if (n315[0]) {
    n326[0] = n324[0];
  }
  else {
    n326[0] = n325[0];
  }
  if (n254[0]) {
    n293[0] = n291[0];
  }
  else {
    n293[0] = n292[0];
  }
  n272[0] = 1 & ~n254[0];
  if (n254[0]) {
    n264[0] = n262[0];
  }
  else {
    n264[0] = n263[0];
  }
  if (n195[0]) {
    n232[0] = n230[0];
  }
  else {
    n232[0] = n231[0];
  }
  n212[0] = 1 & ~n195[0];
  if (n195[0]) {
    n204[0] = n202[0];
  }
  else {
    n204[0] = n203[0];
  }
  if (n138[0]) {
    n173[0] = n171[0];
  }
  else {
    n173[0] = n172[0];
  }
  n154[0] = 1 & ~n138[0];
  if (n138[0]) {
    n146[0] = n144[0];
  }
  else {
    n146[0] = n145[0];
  }
  if (n83[0]) {
    n116[0] = n114[0];
  }
  else {
    n116[0] = n115[0];
  }
  n98[0] = 1 & ~n83[0];
  if (n83[0]) {
    n90[0] = n88[0];
  }
  else {
    n90[0] = n89[0];
  }
  n564r[0] = reset_i[0];
  n564e[0] = enable_i[0];
  n564d[0] = n557[0];
  n543[0] = 255 & (n541[0] << 1 | n542[0]);
  n521[0] = 255 & (n519[0] << 1 | n520[0]);
  n495r[0] = reset_i[0];
  n495e[0] = enable_i[0];
  n495d[0] = n488[0];
  { unsigned int tmp; (tmp = (unsigned int) n417[0] - (unsigned int) n474[0], n476[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n417[0] + (unsigned int) n474[0], n475[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n397[0] - (unsigned int) n453[0], n455[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n397[0] + (unsigned int) n453[0], n454[0] = 255 & (unsigned char) tmp); }
  n428r[0] = reset_i[0];
  n428e[0] = enable_i[0];
  n428d[0] = n421[0];
  if (n398[0]) {
    n410[0] = n408[0];
  }
  else {
    n410[0] = n409[0];
  }
  if (n378[0]) {
    n390[0] = n388[0];
  }
  else {
    n390[0] = n389[0];
  }
  n363r[0] = reset_i[0];
  n363e[0] = enable_i[0];
  n363d[0] = n356[0];
  if (n334[0]) {
    n345[0] = n343[0];
  }
  else {
    n345[0] = n344[0];
  }
  n333r[0] = reset_i[0];
  n333e[0] = enable_i[0];
  n333d[0] = n326[0];
  n300r[0] = reset_i[0];
  n300e[0] = enable_i[0];
  n300d[0] = n293[0];
  if (n272[0]) {
    n282[0] = n280[0];
  }
  else {
    n282[0] = n281[0];
  }
  n271r[0] = reset_i[0];
  n271e[0] = enable_i[0];
  n271d[0] = n264[0];
  n239r[0] = reset_i[0];
  n239e[0] = enable_i[0];
  n239d[0] = n232[0];
  if (n212[0]) {
    n221[0] = n219[0];
  }
  else {
    n221[0] = n220[0];
  }
  n211r[0] = reset_i[0];
  n211e[0] = enable_i[0];
  n211d[0] = n204[0];
  n180r[0] = reset_i[0];
  n180e[0] = enable_i[0];
  n180d[0] = n173[0];
  if (n154[0]) {
    n162[0] = n160[0];
  }
  else {
    n162[0] = n161[0];
  }
  n153r[0] = reset_i[0];
  n153e[0] = enable_i[0];
  n153d[0] = n146[0];
  n123r[0] = reset_i[0];
  n123e[0] = enable_i[0];
  n123d[0] = n116[0];
  if (n98[0]) {
    n105[0] = n103[0];
  }
  else {
    n105[0] = n104[0];
  }
  n97r[0] = reset_i[0];
  n97e[0] = enable_i[0];
  n97d[0] = n90[0];
  { unsigned int tmp; (tmp = (unsigned int) n484[0] - (unsigned int) n543[0], n545[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n484[0] + (unsigned int) n543[0], n544[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n463[0] - (unsigned int) n521[0], n523[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n463[0] + (unsigned int) n521[0], n522[0] = 255 & (unsigned char) tmp); }
  if (n464[0]) {
    n477[0] = n475[0];
  }
  else {
    n477[0] = n476[0];
  }
  if (n443[0]) {
    n456[0] = n454[0];
  }
  else {
    n456[0] = n455[0];
  }
  n417r[0] = reset_i[0];
  n417e[0] = enable_i[0];
  n417d[0] = n410[0];
  n397r[0] = reset_i[0];
  n397e[0] = enable_i[0];
  n397d[0] = n390[0];
  n352r[0] = reset_i[0];
  n352e[0] = enable_i[0];
  n352d[0] = n345[0];
  n289r[0] = reset_i[0];
  n289e[0] = enable_i[0];
  n289d[0] = n282[0];
  n228r[0] = reset_i[0];
  n228e[0] = enable_i[0];
  n228d[0] = n221[0];
  n169r[0] = reset_i[0];
  n169e[0] = enable_i[0];
  n169d[0] = n162[0];
  n112r[0] = reset_i[0];
  n112e[0] = enable_i[0];
  n112d[0] = n105[0];
  if (n532[0]) {
    n546[0] = n544[0];
  }
  else {
    n546[0] = n545[0];
  }
  if (n510[0]) {
    n524[0] = n522[0];
  }
  else {
    n524[0] = n523[0];
  }
  n484r[0] = reset_i[0];
  n484e[0] = enable_i[0];
  n484d[0] = n477[0];
  n463r[0] = reset_i[0];
  n463e[0] = enable_i[0];
  n463d[0] = n456[0];
  n553r[0] = reset_i[0];
  n553e[0] = enable_i[0];
  n553d[0] = n546[0];
  n531r[0] = reset_i[0];
  n531e[0] = enable_i[0];
  n531d[0] = n524[0];
}

void cf_cordic_r_8_8_8_init() {
  { int index; for (index = 2; index > 0;) n619[--index] = 0; }
  { int index; for (index = 2; index > 0;) n617[--index] = 0; }
  { int index; for (index = 2; index > 0;) n615[--index] = 0; }
  { int index; for (index = 2; index > 0;) n613[--index] = 0; }
  { int index; for (index = 2; index > 0;) n611[--index] = 0; }
  { int index; for (index = 2; index > 0;) n609[--index] = 0; }
  { int index; for (index = 2; index > 0;) n607[--index] = 0; }
  { int index; for (index = 2; index > 0;) n605[--index] = 0; }
  n570[0] = 0;
  n554[0] = 0;
  n542[0] = 0;
  n533[0] = 0;
  n520[0] = 0;
  n511[0] = 0;
  n505[0] = 0;
  n499[0] = 0;
  n497[0] = 0;
  n485[0] = 0;
  n473[0] = 0;
  n465[0] = 0;
  n452[0] = 0;
  n444[0] = 0;
  n438[0] = 0;
  n432[0] = 0;
  n430[0] = 0;
  n418[0] = 0;
  n406[0] = 0;
  n399[0] = 0;
  n386[0] = 0;
  n379[0] = 0;
  n373[0] = 0;
  n367[0] = 0;
  n365[0] = 0;
  n353[0] = 0;
  n341[0] = 0;
  n335[0] = 0;
  n322[0] = 0;
  n316[0] = 0;
  n310[0] = 0;
  n304[0] = 0;
  n302[0] = 0;
  n290[0] = 0;
  n278[0] = 0;
  n273[0] = 0;
  n260[0] = 0;
  n255[0] = 0;
  n249[0] = 0;
  n243[0] = 0;
  n241[0] = 0;
  n229[0] = 0;
  n217[0] = 0;
  n213[0] = 0;
  n200[0] = 0;
  n196[0] = 0;
  n190[0] = 0;
  n184[0] = 0;
  n182[0] = 0;
  n170[0] = 0;
  n158[0] = 0;
  n155[0] = 0;
  n142[0] = 0;
  n139[0] = 0;
  n133[0] = 0;
  n127[0] = 0;
  n125[0] = 0;
  n113[0] = 0;
  n101[0] = 0;
  n86[0] = 0;
  n78[0] = 0;
  n72[0] = 0;
  n70[0] = 0;
  n39[0] = 0;
  n37[0] = 0;
  n556[0] = 0;
  n555[0] = 0;
  n536[0] = 0;
  n514[0] = 0;
  n498[0] = 0;
  n487[0] = 0;
  n486[0] = 0;
  n468[0] = 0;
  n447[0] = 0;
  n431[0] = 0;
  n420[0] = 0;
  n419[0] = 0;
  n402[0] = 0;
  n382[0] = 0;
  n366[0] = 0;
  n355[0] = 0;
  n354[0] = 0;
  n338[0] = 0;
  n319[0] = 0;
  n303[0] = 0;
  n292[0] = 0;
  n291[0] = 0;
  n276[0] = 0;
  n258[0] = 0;
  n242[0] = 0;
  n231[0] = 0;
  n230[0] = 0;
  n216[0] = 0;
  n199[0] = 0;
  n183[0] = 0;
  n172[0] = 0;
  n171[0] = 0;
  n159[0] = 0;
  n143[0] = 0;
  n126[0] = 0;
  n115[0] = 0;
  n114[0] = 0;
  n104[0] = 0;
  n103[0] = 0;
  n89[0] = 0;
  n88[0] = 0;
  n71[0] = 0;
  n44[0] = 0;
  n40[0] = 0;
  n38[0] = 0;
  n36[0] = 0;
  n36r[0] = 0;
  n36e[0] = 0;
  n36d[0] = 0;
  n29[0] = 0;
  n29r[0] = 0;
  n29e[0] = 0;
  n29d[0] = 0;
  n22[0] = 0;
  n22r[0] = 0;
  n22e[0] = 0;
  n22d[0] = 0;
  n15[0] = 0;
  n15r[0] = 0;
  n15e[0] = 0;
  n15d[0] = 0;
  n537[0] = 0;
  n515[0] = 0;
  n500[0] = 0;
  n469[0] = 0;
  n448[0] = 0;
  n433[0] = 0;
  n403[0] = 0;
  n383[0] = 0;
  n368[0] = 0;
  n339[0] = 0;
  n320[0] = 0;
  n305[0] = 0;
  n277[0] = 0;
  n259[0] = 0;
  n244[0] = 0;
  n218[0] = 0;
  n201[0] = 0;
  n185[0] = 0;
  n161[0] = 0;
  n160[0] = 0;
  n145[0] = 0;
  n144[0] = 0;
  n128[0] = 0;
  n73[0] = 0;
  n61[0] = 0;
  n53[0] = 0;
  n45[0] = 0;
  n538[0] = 0;
  n516[0] = 0;
  { int index; for (index = 2; index > 0;) n506[--index] = 0; }
  n470[0] = 0;
  n449[0] = 0;
  { int index; for (index = 2; index > 0;) n439[--index] = 0; }
  n404[0] = 0;
  n384[0] = 0;
  { int index; for (index = 2; index > 0;) n374[--index] = 0; }
  n340[0] = 0;
  n321[0] = 0;
  { int index; for (index = 2; index > 0;) n311[--index] = 0; }
  n279[0] = 0;
  n261[0] = 0;
  { int index; for (index = 2; index > 0;) n250[--index] = 0; }
  n220[0] = 0;
  n219[0] = 0;
  n203[0] = 0;
  n202[0] = 0;
  { int index; for (index = 2; index > 0;) n191[--index] = 0; }
  { int index; for (index = 2; index > 0;) n134[--index] = 0; }
  { int index; for (index = 2; index > 0;) n79[--index] = 0; }
  n68[0] = 0;
  n68r[0] = 0;
  n68e[0] = 0;
  n68d[0] = 0;
  n60[0] = 0;
  n60r[0] = 0;
  n60e[0] = 0;
  n60d[0] = 0;
  n52[0] = 0;
  n52r[0] = 0;
  n52e[0] = 0;
  n52d[0] = 0;
  n539[0] = 0;
  n517[0] = 0;
  { int index; for (index = 2; index > 0;) n509[--index] = 0; }
  n471[0] = 0;
  n450[0] = 0;
  { int index; for (index = 2; index > 0;) n442[--index] = 0; }
  n405[0] = 0;
  n385[0] = 0;
  { int index; for (index = 2; index > 0;) n377[--index] = 0; }
  n342[0] = 0;
  n323[0] = 0;
  { int index; for (index = 2; index > 0;) n314[--index] = 0; }
  n281[0] = 0;
  n280[0] = 0;
  n263[0] = 0;
  n262[0] = 0;
  { int index; for (index = 2; index > 0;) n253[--index] = 0; }
  { int index; for (index = 2; index > 0;) n194[--index] = 0; }
  { int index; for (index = 2; index > 0;) n137[--index] = 0; }
  { int index; for (index = 2; index > 0;) n82[--index] = 0; }
  n540[0] = 0;
  n518[0] = 0;
  n510[0] = 0;
  n472[0] = 0;
  n451[0] = 0;
  n443[0] = 0;
  n407[0] = 0;
  n387[0] = 0;
  n378[0] = 0;
  n344[0] = 0;
  n343[0] = 0;
  n325[0] = 0;
  n324[0] = 0;
  n315[0] = 0;
  n254[0] = 0;
  n195[0] = 0;
  n138[0] = 0;
  n83[0] = 0;
  n557[0] = 0;
  n541[0] = 0;
  n532[0] = 0;
  n519[0] = 0;
  n488[0] = 0;
  n474[0] = 0;
  n464[0] = 0;
  n453[0] = 0;
  n421[0] = 0;
  n409[0] = 0;
  n408[0] = 0;
  n398[0] = 0;
  n389[0] = 0;
  n388[0] = 0;
  n356[0] = 0;
  n334[0] = 0;
  n326[0] = 0;
  n293[0] = 0;
  n272[0] = 0;
  n264[0] = 0;
  n232[0] = 0;
  n212[0] = 0;
  n204[0] = 0;
  n173[0] = 0;
  n154[0] = 0;
  n146[0] = 0;
  n116[0] = 0;
  n98[0] = 0;
  n90[0] = 0;
  n564[0] = 0;
  n564r[0] = 0;
  n564e[0] = 0;
  n564d[0] = 0;
  n543[0] = 0;
  n521[0] = 0;
  n495[0] = 0;
  n495r[0] = 0;
  n495e[0] = 0;
  n495d[0] = 0;
  n476[0] = 0;
  n475[0] = 0;
  n455[0] = 0;
  n454[0] = 0;
  n428[0] = 0;
  n428r[0] = 0;
  n428e[0] = 0;
  n428d[0] = 0;
  n410[0] = 0;
  n390[0] = 0;
  n363[0] = 0;
  n363r[0] = 0;
  n363e[0] = 0;
  n363d[0] = 0;
  n345[0] = 0;
  n333[0] = 0;
  n333r[0] = 0;
  n333e[0] = 0;
  n333d[0] = 0;
  n300[0] = 0;
  n300r[0] = 0;
  n300e[0] = 0;
  n300d[0] = 0;
  n282[0] = 0;
  n271[0] = 0;
  n271r[0] = 0;
  n271e[0] = 0;
  n271d[0] = 0;
  n239[0] = 0;
  n239r[0] = 0;
  n239e[0] = 0;
  n239d[0] = 0;
  n221[0] = 0;
  n211[0] = 0;
  n211r[0] = 0;
  n211e[0] = 0;
  n211d[0] = 0;
  n180[0] = 0;
  n180r[0] = 0;
  n180e[0] = 0;
  n180d[0] = 0;
  n162[0] = 0;
  n153[0] = 0;
  n153r[0] = 0;
  n153e[0] = 0;
  n153d[0] = 0;
  n123[0] = 0;
  n123r[0] = 0;
  n123e[0] = 0;
  n123d[0] = 0;
  n105[0] = 0;
  n97[0] = 0;
  n97r[0] = 0;
  n97e[0] = 0;
  n97d[0] = 0;
  n545[0] = 0;
  n544[0] = 0;
  n523[0] = 0;
  n522[0] = 0;
  n477[0] = 0;
  n456[0] = 0;
  n417[0] = 0;
  n417r[0] = 0;
  n417e[0] = 0;
  n417d[0] = 0;
  n397[0] = 0;
  n397r[0] = 0;
  n397e[0] = 0;
  n397d[0] = 0;
  n352[0] = 0;
  n352r[0] = 0;
  n352e[0] = 0;
  n352d[0] = 0;
  n289[0] = 0;
  n289r[0] = 0;
  n289e[0] = 0;
  n289d[0] = 0;
  n228[0] = 0;
  n228r[0] = 0;
  n228e[0] = 0;
  n228d[0] = 0;
  n169[0] = 0;
  n169r[0] = 0;
  n169e[0] = 0;
  n169d[0] = 0;
  n112[0] = 0;
  n112r[0] = 0;
  n112e[0] = 0;
  n112d[0] = 0;
  n546[0] = 0;
  n524[0] = 0;
  n484[0] = 0;
  n484r[0] = 0;
  n484e[0] = 0;
  n484d[0] = 0;
  n463[0] = 0;
  n463r[0] = 0;
  n463e[0] = 0;
  n463d[0] = 0;
  n553[0] = 0;
  n553r[0] = 0;
  n553e[0] = 0;
  n553d[0] = 0;
  n531[0] = 0;
  n531r[0] = 0;
  n531e[0] = 0;
  n531d[0] = 0;
  cf_cordic_r_8_8_8_calc();
}

void cf_cordic_r_8_8_8_cycle_clock()
{
  if (n15r[0]) {
    n15[0] = 0;
  }
  else if (n15e[0]) {
    n15[0] = n15d[0];
  }
  if (n22r[0]) {
    n22[0] = 0;
  }
  else if (n22e[0]) {
    n22[0] = n22d[0];
  }
  if (n29r[0]) {
    n29[0] = 0;
  }
  else if (n29e[0]) {
    n29[0] = n29d[0];
  }
  if (n36r[0]) {
    n36[0] = 0;
  }
  else if (n36e[0]) {
    n36[0] = n36d[0];
  }
  if (n52r[0]) {
    n52[0] = 0;
  }
  else if (n52e[0]) {
    n52[0] = n52d[0];
  }
  if (n60r[0]) {
    n60[0] = 0;
  }
  else if (n60e[0]) {
    n60[0] = n60d[0];
  }
  if (n68r[0]) {
    n68[0] = 0;
  }
  else if (n68e[0]) {
    n68[0] = n68d[0];
  }
  if (n97r[0]) {
    n97[0] = 0;
  }
  else if (n97e[0]) {
    n97[0] = n97d[0];
  }
  if (n112r[0]) {
    n112[0] = 0;
  }
  else if (n112e[0]) {
    n112[0] = n112d[0];
  }
  if (n123r[0]) {
    n123[0] = 0;
  }
  else if (n123e[0]) {
    n123[0] = n123d[0];
  }
  if (n153r[0]) {
    n153[0] = 0;
  }
  else if (n153e[0]) {
    n153[0] = n153d[0];
  }
  if (n169r[0]) {
    n169[0] = 0;
  }
  else if (n169e[0]) {
    n169[0] = n169d[0];
  }
  if (n180r[0]) {
    n180[0] = 0;
  }
  else if (n180e[0]) {
    n180[0] = n180d[0];
  }
  if (n211r[0]) {
    n211[0] = 0;
  }
  else if (n211e[0]) {
    n211[0] = n211d[0];
  }
  if (n228r[0]) {
    n228[0] = 0;
  }
  else if (n228e[0]) {
    n228[0] = n228d[0];
  }
  if (n239r[0]) {
    n239[0] = 0;
  }
  else if (n239e[0]) {
    n239[0] = n239d[0];
  }
  if (n271r[0]) {
    n271[0] = 0;
  }
  else if (n271e[0]) {
    n271[0] = n271d[0];
  }
  if (n289r[0]) {
    n289[0] = 0;
  }
  else if (n289e[0]) {
    n289[0] = n289d[0];
  }
  if (n300r[0]) {
    n300[0] = 0;
  }
  else if (n300e[0]) {
    n300[0] = n300d[0];
  }
  if (n333r[0]) {
    n333[0] = 0;
  }
  else if (n333e[0]) {
    n333[0] = n333d[0];
  }
  if (n352r[0]) {
    n352[0] = 0;
  }
  else if (n352e[0]) {
    n352[0] = n352d[0];
  }
  if (n363r[0]) {
    n363[0] = 0;
  }
  else if (n363e[0]) {
    n363[0] = n363d[0];
  }
  if (n397r[0]) {
    n397[0] = 0;
  }
  else if (n397e[0]) {
    n397[0] = n397d[0];
  }
  if (n417r[0]) {
    n417[0] = 0;
  }
  else if (n417e[0]) {
    n417[0] = n417d[0];
  }
  if (n428r[0]) {
    n428[0] = 0;
  }
  else if (n428e[0]) {
    n428[0] = n428d[0];
  }
  if (n463r[0]) {
    n463[0] = 0;
  }
  else if (n463e[0]) {
    n463[0] = n463d[0];
  }
  if (n484r[0]) {
    n484[0] = 0;
  }
  else if (n484e[0]) {
    n484[0] = n484d[0];
  }
  if (n495r[0]) {
    n495[0] = 0;
  }
  else if (n495e[0]) {
    n495[0] = n495d[0];
  }
  if (n531r[0]) {
    n531[0] = 0;
  }
  else if (n531e[0]) {
    n531[0] = n531d[0];
  }
  if (n553r[0]) {
    n553[0] = 0;
  }
  else if (n553e[0]) {
    n553[0] = n553d[0];
  }
  if (n564r[0]) {
    n564[0] = 0;
  }
  else if (n564e[0]) {
    n564[0] = n564d[0];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_enable_i[1];
static unsigned char sim_reset_i[1];
static unsigned char sim_flip_i[1];
static unsigned char sim_real_i[1];
static unsigned char sim_imag_i[1];
static unsigned char sim_ang_i[1];
static unsigned char sim_real_o[1];
static unsigned char sim_imag_o[1];
static unsigned char sim_ang_o[1];

void cf_cordic_r_8_8_8_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_cordic_r_8_8_8_init();
  sim_enable_i[0] = enable_i[0];
  sim_reset_i[0] = reset_i[0];
  sim_flip_i[0] = flip_i[0];
  sim_real_i[0] = real_i[0];
  sim_imag_i[0] = imag_i[0];
  sim_ang_i[0] = ang_i[0];
  sim_real_o[0] = real_o[0];
  sim_imag_o[0] = imag_o[0];
  sim_ang_o[0] = ang_o[0];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_cordic_r_8_8_8 $end\n"
    "$var wire 1 ! enable_i $end\n"
    "$var wire 1 \" reset_i $end\n"
    "$var wire 1 # flip_i $end\n"
    "$var wire 8 $ real_i $end\n"
    "$var wire 8 %% imag_i $end\n"
    "$var wire 8 & ang_i $end\n"
    "$var wire 8 ' real_o $end\n"
    "$var wire 8 ( imag_o $end\n"
    "$var wire 8 ) ang_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, enable_i[0] ? "1!\n" : "0!\n");
  fprintf(sim_file, reset_i[0] ? "1\"\n" : "0\"\n");
  fprintf(sim_file, flip_i[0] ? "1#\n" : "0#\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & real_i[byte]) ? "1" : "0");
        else if (bit & real_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & imag_i[byte]) ? "1" : "0");
        else if (bit & imag_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & ang_i[byte]) ? "1" : "0");
        else if (bit & ang_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & real_o[byte]) ? "1" : "0");
        else if (bit & real_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & imag_o[byte]) ? "1" : "0");
        else if (bit & imag_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & ang_o[byte]) ? "1" : "0");
        else if (bit & ang_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_cordic_r_8_8_8_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_cordic_r_8_8_8_sim_sample() {
  int changed = 0;
  if (sim_enable_i[0] != enable_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, enable_i[0] ? "1!\n" : "0!\n");
    sim_enable_i[0] = enable_i[0];
  }
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1\"\n" : "0\"\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_flip_i[0] != flip_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, flip_i[0] ? "1#\n" : "0#\n");
    sim_flip_i[0] = flip_i[0];
  }
  if (sim_real_i[0] != real_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & real_i[byte]) ? "1" : "0");
          else if (bit & real_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_real_i[0] = real_i[0];
  }
  if (sim_imag_i[0] != imag_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & imag_i[byte]) ? "1" : "0");
          else if (bit & imag_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_imag_i[0] = imag_i[0];
  }
  if (sim_ang_i[0] != ang_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & ang_i[byte]) ? "1" : "0");
          else if (bit & ang_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_ang_i[0] = ang_i[0];
  }
  if (sim_real_o[0] != real_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & real_o[byte]) ? "1" : "0");
          else if (bit & real_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_real_o[0] = real_o[0];
  }
  if (sim_imag_o[0] != imag_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & imag_o[byte]) ? "1" : "0");
          else if (bit & imag_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_imag_o[0] = imag_o[0];
  }
  if (sim_ang_o[0] != ang_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & ang_o[byte]) ? "1" : "0");
          else if (bit & ang_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_ang_o[0] = ang_o[0];
  }
  sim_count++;
}

