#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Cordics (COordinate Rotation DIgital Computers) are used to calculate
#    trigonometric functions and complex plane phase rotations.
#    This vector mode cordic rotates any complex vector to the positive real axis.
#    The resulting angle is the initial angle plus the angle of rotation.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      enable_i : Synchronous enable.
#      reset_i  : Synchronous reset.
#  
#    Inputs:
#      real_i   : Initial real component (signed).
#      imag_i   : Initial imaginary component (signed).
#      angle_i  : Initial angle (modulo 2PI).
#  
#    Outputs:
#      real_o   : Resulting real component (signed).
#      imag_o   : Resulting imaginary component (signed).
#      angle_o  : Resulting angle (modulo 2PI).
#  
#  Built In Parameters:
#  
#    Cordic Mode    = Vector
#    Vector Width   = 16
#    Angle Width    = 16
#    Cordic Stages  = 16
#  
#  Resulting Pipeline Latency is 18 clock cycles.
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 09:44:24 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_cordic_v_16_16_16
#    Clock Domains : clock_c  
#    Vector Input  : enable_i(1)
#    Vector Input  : reset_i(1)
#    Vector Input  : real_i(16)
#    Vector Input  : imag_i(16)
#    Vector Input  : ang_i(16)
#    Vector Output : real_o(16)
#    Vector Output : imag_o(16)
#    Vector Output : ang_o(16)
#  
#  
#  

import sys
import time

class cf_cordic_v_16_16_16:

  def init(self):
    self.n1304 = 0L
    self.n1302 = 0L
    self.n1300 = 0L
    self.n1298 = 0L
    self.n1296 = 0L
    self.n1294 = 0L
    self.n1292 = 0L
    self.n1290 = 0L
    self.n1288 = 0L
    self.n1286 = 0L
    self.n1284 = 0L
    self.n1282 = 0L
    self.n1280 = 0L
    self.n1278 = 0L
    self.n1276 = 0L
    self.n1274 = 0L
    self.n1272 = 0L
    self.n1203 = 0L
    self.n1198 = 0L
    self.n1197 = 0L
    self.n1196 = 0L
    self.n1185 = 0L
    self.n1173 = 0L
    self.n1156 = 0L
    self.n1143 = 0L
    self.n1126 = 0L
    self.n1122 = 0L
    self.n1114 = 0L
    self.n1112 = 0L
    self.n1100 = 0L
    self.n1088 = 0L
    self.n1072 = 0L
    self.n1059 = 0L
    self.n1043 = 0L
    self.n1039 = 0L
    self.n1031 = 0L
    self.n1029 = 0L
    self.n1017 = 0L
    self.n1005 = 0L
    self.n990 = 0L
    self.n977 = 0L
    self.n962 = 0L
    self.n958 = 0L
    self.n950 = 0L
    self.n948 = 0L
    self.n936 = 0L
    self.n924 = 0L
    self.n910 = 0L
    self.n897 = 0L
    self.n883 = 0L
    self.n879 = 0L
    self.n871 = 0L
    self.n869 = 0L
    self.n857 = 0L
    self.n845 = 0L
    self.n832 = 0L
    self.n819 = 0L
    self.n806 = 0L
    self.n802 = 0L
    self.n794 = 0L
    self.n792 = 0L
    self.n780 = 0L
    self.n768 = 0L
    self.n756 = 0L
    self.n743 = 0L
    self.n731 = 0L
    self.n727 = 0L
    self.n719 = 0L
    self.n717 = 0L
    self.n705 = 0L
    self.n693 = 0L
    self.n682 = 0L
    self.n669 = 0L
    self.n658 = 0L
    self.n654 = 0L
    self.n646 = 0L
    self.n644 = 0L
    self.n632 = 0L
    self.n620 = 0L
    self.n610 = 0L
    self.n597 = 0L
    self.n587 = 0L
    self.n583 = 0L
    self.n575 = 0L
    self.n573 = 0L
    self.n561 = 0L
    self.n549 = 0L
    self.n540 = 0L
    self.n527 = 0L
    self.n518 = 0L
    self.n514 = 0L
    self.n506 = 0L
    self.n504 = 0L
    self.n492 = 0L
    self.n480 = 0L
    self.n472 = 0L
    self.n459 = 0L
    self.n451 = 0L
    self.n447 = 0L
    self.n439 = 0L
    self.n437 = 0L
    self.n425 = 0L
    self.n413 = 0L
    self.n406 = 0L
    self.n393 = 0L
    self.n386 = 0L
    self.n382 = 0L
    self.n374 = 0L
    self.n372 = 0L
    self.n360 = 0L
    self.n348 = 0L
    self.n342 = 0L
    self.n329 = 0L
    self.n323 = 0L
    self.n319 = 0L
    self.n311 = 0L
    self.n309 = 0L
    self.n297 = 0L
    self.n285 = 0L
    self.n280 = 0L
    self.n267 = 0L
    self.n262 = 0L
    self.n258 = 0L
    self.n250 = 0L
    self.n248 = 0L
    self.n236 = 0L
    self.n224 = 0L
    self.n220 = 0L
    self.n207 = 0L
    self.n203 = 0L
    self.n199 = 0L
    self.n191 = 0L
    self.n189 = 0L
    self.n177 = 0L
    self.n165 = 0L
    self.n162 = 0L
    self.n149 = 0L
    self.n146 = 0L
    self.n142 = 0L
    self.n134 = 0L
    self.n132 = 0L
    self.n120 = 0L
    self.n108 = 0L
    self.n93 = 0L
    self.n87 = 0L
    self.n79 = 0L
    self.n77 = 0L
    self.n46 = 0L
    self.n44 = 0L
    self.n38 = 0L
    self.n32 = 0L
    self.n30 = 0L
    self.n7 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n1187 = 0L
    self.n1186 = 0L
    self.n1159 = 0L
    self.n1129 = 0L
    self.n1113 = 0L
    self.n1102 = 0L
    self.n1101 = 0L
    self.n1075 = 0L
    self.n1046 = 0L
    self.n1030 = 0L
    self.n1019 = 0L
    self.n1018 = 0L
    self.n993 = 0L
    self.n965 = 0L
    self.n949 = 0L
    self.n938 = 0L
    self.n937 = 0L
    self.n913 = 0L
    self.n886 = 0L
    self.n870 = 0L
    self.n859 = 0L
    self.n858 = 0L
    self.n835 = 0L
    self.n809 = 0L
    self.n793 = 0L
    self.n782 = 0L
    self.n781 = 0L
    self.n759 = 0L
    self.n734 = 0L
    self.n718 = 0L
    self.n707 = 0L
    self.n706 = 0L
    self.n685 = 0L
    self.n661 = 0L
    self.n645 = 0L
    self.n634 = 0L
    self.n633 = 0L
    self.n613 = 0L
    self.n590 = 0L
    self.n574 = 0L
    self.n563 = 0L
    self.n562 = 0L
    self.n543 = 0L
    self.n521 = 0L
    self.n505 = 0L
    self.n494 = 0L
    self.n493 = 0L
    self.n475 = 0L
    self.n454 = 0L
    self.n438 = 0L
    self.n427 = 0L
    self.n426 = 0L
    self.n409 = 0L
    self.n389 = 0L
    self.n373 = 0L
    self.n362 = 0L
    self.n361 = 0L
    self.n345 = 0L
    self.n326 = 0L
    self.n310 = 0L
    self.n299 = 0L
    self.n298 = 0L
    self.n283 = 0L
    self.n265 = 0L
    self.n249 = 0L
    self.n238 = 0L
    self.n237 = 0L
    self.n223 = 0L
    self.n206 = 0L
    self.n190 = 0L
    self.n179 = 0L
    self.n178 = 0L
    self.n166 = 0L
    self.n150 = 0L
    self.n133 = 0L
    self.n122 = 0L
    self.n121 = 0L
    self.n111 = 0L
    self.n110 = 0L
    self.n96 = 0L
    self.n95 = 0L
    self.n78 = 0L
    self.n51 = 0L
    self.n47 = 0L
    self.n45 = 0L
    self.n31 = 0L
    self.n28 = 0L
    self.n28r = 0L
    self.n28e = 0L
    self.n28d = 0L
    self.n21 = 0L
    self.n21r = 0L
    self.n21e = 0L
    self.n21d = 0L
    self.n14 = 0L
    self.n14r = 0L
    self.n14e = 0L
    self.n14d = 0L
    self.n1160 = 0L
    self.n1130 = 0L
    self.n1115 = 0L
    self.n1076 = 0L
    self.n1047 = 0L
    self.n1032 = 0L
    self.n994 = 0L
    self.n966 = 0L
    self.n951 = 0L
    self.n914 = 0L
    self.n887 = 0L
    self.n872 = 0L
    self.n836 = 0L
    self.n810 = 0L
    self.n795 = 0L
    self.n760 = 0L
    self.n735 = 0L
    self.n720 = 0L
    self.n686 = 0L
    self.n662 = 0L
    self.n647 = 0L
    self.n614 = 0L
    self.n591 = 0L
    self.n576 = 0L
    self.n544 = 0L
    self.n522 = 0L
    self.n507 = 0L
    self.n476 = 0L
    self.n455 = 0L
    self.n440 = 0L
    self.n410 = 0L
    self.n390 = 0L
    self.n375 = 0L
    self.n346 = 0L
    self.n327 = 0L
    self.n312 = 0L
    self.n284 = 0L
    self.n266 = 0L
    self.n251 = 0L
    self.n225 = 0L
    self.n208 = 0L
    self.n192 = 0L
    self.n168 = 0L
    self.n167 = 0L
    self.n152 = 0L
    self.n151 = 0L
    self.n135 = 0L
    self.n80 = 0L
    self.n33 = 0L
    self.n1161 = 0L
    self.n1131 = 0L
    self.n1123 = 0L
    self.n1077 = 0L
    self.n1048 = 0L
    self.n1040 = 0L
    self.n995 = 0L
    self.n967 = 0L
    self.n959 = 0L
    self.n915 = 0L
    self.n888 = 0L
    self.n880 = 0L
    self.n837 = 0L
    self.n811 = 0L
    self.n803 = 0L
    self.n761 = 0L
    self.n736 = 0L
    self.n728 = 0L
    self.n687 = 0L
    self.n663 = 0L
    self.n655 = 0L
    self.n615 = 0L
    self.n592 = 0L
    self.n584 = 0L
    self.n545 = 0L
    self.n523 = 0L
    self.n515 = 0L
    self.n477 = 0L
    self.n456 = 0L
    self.n448 = 0L
    self.n411 = 0L
    self.n391 = 0L
    self.n383 = 0L
    self.n347 = 0L
    self.n328 = 0L
    self.n320 = 0L
    self.n286 = 0L
    self.n268 = 0L
    self.n259 = 0L
    self.n227 = 0L
    self.n226 = 0L
    self.n210 = 0L
    self.n209 = 0L
    self.n200 = 0L
    self.n143 = 0L
    self.n88 = 0L
    self.n39 = 0L
    self.n1162 = 0L
    self.n1132 = 0L
    self.n1124 = 0L
    self.n1078 = 0L
    self.n1049 = 0L
    self.n1041 = 0L
    self.n996 = 0L
    self.n968 = 0L
    self.n960 = 0L
    self.n916 = 0L
    self.n889 = 0L
    self.n881 = 0L
    self.n838 = 0L
    self.n812 = 0L
    self.n804 = 0L
    self.n762 = 0L
    self.n737 = 0L
    self.n729 = 0L
    self.n688 = 0L
    self.n664 = 0L
    self.n656 = 0L
    self.n616 = 0L
    self.n593 = 0L
    self.n585 = 0L
    self.n546 = 0L
    self.n524 = 0L
    self.n516 = 0L
    self.n478 = 0L
    self.n457 = 0L
    self.n449 = 0L
    self.n412 = 0L
    self.n392 = 0L
    self.n384 = 0L
    self.n349 = 0L
    self.n330 = 0L
    self.n321 = 0L
    self.n288 = 0L
    self.n287 = 0L
    self.n270 = 0L
    self.n269 = 0L
    self.n260 = 0L
    self.n201 = 0L
    self.n144 = 0L
    self.n89 = 0L
    self.n42 = 0L
    self.n1163 = 0L
    self.n1133 = 0L
    self.n1125 = 0L
    self.n1079 = 0L
    self.n1050 = 0L
    self.n1042 = 0L
    self.n997 = 0L
    self.n969 = 0L
    self.n961 = 0L
    self.n917 = 0L
    self.n890 = 0L
    self.n882 = 0L
    self.n839 = 0L
    self.n813 = 0L
    self.n805 = 0L
    self.n763 = 0L
    self.n738 = 0L
    self.n730 = 0L
    self.n689 = 0L
    self.n665 = 0L
    self.n657 = 0L
    self.n617 = 0L
    self.n594 = 0L
    self.n586 = 0L
    self.n547 = 0L
    self.n525 = 0L
    self.n517 = 0L
    self.n479 = 0L
    self.n458 = 0L
    self.n450 = 0L
    self.n414 = 0L
    self.n394 = 0L
    self.n385 = 0L
    self.n351 = 0L
    self.n350 = 0L
    self.n332 = 0L
    self.n331 = 0L
    self.n322 = 0L
    self.n261 = 0L
    self.n202 = 0L
    self.n145 = 0L
    self.n90 = 0L
    self.n43 = 0L
    self.n1188 = 0L
    self.n1164 = 0L
    self.n1155 = 0L
    self.n1134 = 0L
    self.n1103 = 0L
    self.n1080 = 0L
    self.n1071 = 0L
    self.n1051 = 0L
    self.n1020 = 0L
    self.n998 = 0L
    self.n989 = 0L
    self.n970 = 0L
    self.n939 = 0L
    self.n918 = 0L
    self.n909 = 0L
    self.n891 = 0L
    self.n860 = 0L
    self.n840 = 0L
    self.n831 = 0L
    self.n814 = 0L
    self.n783 = 0L
    self.n764 = 0L
    self.n755 = 0L
    self.n739 = 0L
    self.n708 = 0L
    self.n690 = 0L
    self.n681 = 0L
    self.n666 = 0L
    self.n635 = 0L
    self.n618 = 0L
    self.n609 = 0L
    self.n595 = 0L
    self.n564 = 0L
    self.n548 = 0L
    self.n539 = 0L
    self.n526 = 0L
    self.n495 = 0L
    self.n481 = 0L
    self.n471 = 0L
    self.n460 = 0L
    self.n428 = 0L
    self.n416 = 0L
    self.n415 = 0L
    self.n405 = 0L
    self.n396 = 0L
    self.n395 = 0L
    self.n363 = 0L
    self.n341 = 0L
    self.n333 = 0L
    self.n300 = 0L
    self.n279 = 0L
    self.n271 = 0L
    self.n239 = 0L
    self.n219 = 0L
    self.n211 = 0L
    self.n180 = 0L
    self.n161 = 0L
    self.n153 = 0L
    self.n123 = 0L
    self.n105 = 0L
    self.n97 = 0L
    self.n68 = 0L
    self.n60 = 0L
    self.n52 = 0L
    self.n1195 = 0L
    self.n1195r = 0L
    self.n1195e = 0L
    self.n1195d = 0L
    self.n1165 = 0L
    self.n1135 = 0L
    self.n1110 = 0L
    self.n1110r = 0L
    self.n1110e = 0L
    self.n1110d = 0L
    self.n1081 = 0L
    self.n1052 = 0L
    self.n1027 = 0L
    self.n1027r = 0L
    self.n1027e = 0L
    self.n1027d = 0L
    self.n999 = 0L
    self.n971 = 0L
    self.n946 = 0L
    self.n946r = 0L
    self.n946e = 0L
    self.n946d = 0L
    self.n919 = 0L
    self.n892 = 0L
    self.n867 = 0L
    self.n867r = 0L
    self.n867e = 0L
    self.n867d = 0L
    self.n841 = 0L
    self.n815 = 0L
    self.n790 = 0L
    self.n790r = 0L
    self.n790e = 0L
    self.n790d = 0L
    self.n765 = 0L
    self.n740 = 0L
    self.n715 = 0L
    self.n715r = 0L
    self.n715e = 0L
    self.n715d = 0L
    self.n691 = 0L
    self.n667 = 0L
    self.n642 = 0L
    self.n642r = 0L
    self.n642e = 0L
    self.n642d = 0L
    self.n619 = 0L
    self.n596 = 0L
    self.n571 = 0L
    self.n571r = 0L
    self.n571e = 0L
    self.n571d = 0L
    self.n550 = 0L
    self.n528 = 0L
    self.n502 = 0L
    self.n502r = 0L
    self.n502e = 0L
    self.n502d = 0L
    self.n483 = 0L
    self.n482 = 0L
    self.n462 = 0L
    self.n461 = 0L
    self.n435 = 0L
    self.n435r = 0L
    self.n435e = 0L
    self.n435d = 0L
    self.n417 = 0L
    self.n397 = 0L
    self.n370 = 0L
    self.n370r = 0L
    self.n370e = 0L
    self.n370d = 0L
    self.n352 = 0L
    self.n340 = 0L
    self.n340r = 0L
    self.n340e = 0L
    self.n340d = 0L
    self.n307 = 0L
    self.n307r = 0L
    self.n307e = 0L
    self.n307d = 0L
    self.n289 = 0L
    self.n278 = 0L
    self.n278r = 0L
    self.n278e = 0L
    self.n278d = 0L
    self.n246 = 0L
    self.n246r = 0L
    self.n246e = 0L
    self.n246d = 0L
    self.n228 = 0L
    self.n218 = 0L
    self.n218r = 0L
    self.n218e = 0L
    self.n218d = 0L
    self.n187 = 0L
    self.n187r = 0L
    self.n187e = 0L
    self.n187d = 0L
    self.n169 = 0L
    self.n160 = 0L
    self.n160r = 0L
    self.n160e = 0L
    self.n160d = 0L
    self.n130 = 0L
    self.n130r = 0L
    self.n130e = 0L
    self.n130d = 0L
    self.n112 = 0L
    self.n104 = 0L
    self.n104r = 0L
    self.n104e = 0L
    self.n104d = 0L
    self.n75 = 0L
    self.n75r = 0L
    self.n75e = 0L
    self.n75d = 0L
    self.n67 = 0L
    self.n67r = 0L
    self.n67e = 0L
    self.n67d = 0L
    self.n59 = 0L
    self.n59r = 0L
    self.n59e = 0L
    self.n59d = 0L
    self.n1166 = 0L
    self.n1136 = 0L
    self.n1082 = 0L
    self.n1053 = 0L
    self.n1000 = 0L
    self.n972 = 0L
    self.n920 = 0L
    self.n893 = 0L
    self.n842 = 0L
    self.n816 = 0L
    self.n766 = 0L
    self.n741 = 0L
    self.n692 = 0L
    self.n668 = 0L
    self.n621 = 0L
    self.n598 = 0L
    self.n552 = 0L
    self.n551 = 0L
    self.n530 = 0L
    self.n529 = 0L
    self.n484 = 0L
    self.n463 = 0L
    self.n424 = 0L
    self.n424r = 0L
    self.n424e = 0L
    self.n424d = 0L
    self.n404 = 0L
    self.n404r = 0L
    self.n404e = 0L
    self.n404d = 0L
    self.n359 = 0L
    self.n359r = 0L
    self.n359e = 0L
    self.n359d = 0L
    self.n296 = 0L
    self.n296r = 0L
    self.n296e = 0L
    self.n296d = 0L
    self.n235 = 0L
    self.n235r = 0L
    self.n235e = 0L
    self.n235d = 0L
    self.n176 = 0L
    self.n176r = 0L
    self.n176e = 0L
    self.n176d = 0L
    self.n119 = 0L
    self.n119r = 0L
    self.n119e = 0L
    self.n119d = 0L
    self.n1167 = 0L
    self.n1137 = 0L
    self.n1083 = 0L
    self.n1054 = 0L
    self.n1001 = 0L
    self.n973 = 0L
    self.n921 = 0L
    self.n894 = 0L
    self.n843 = 0L
    self.n817 = 0L
    self.n767 = 0L
    self.n742 = 0L
    self.n694 = 0L
    self.n670 = 0L
    self.n623 = 0L
    self.n622 = 0L
    self.n600 = 0L
    self.n599 = 0L
    self.n553 = 0L
    self.n531 = 0L
    self.n491 = 0L
    self.n491r = 0L
    self.n491e = 0L
    self.n491d = 0L
    self.n470 = 0L
    self.n470r = 0L
    self.n470e = 0L
    self.n470d = 0L
    self.n1168 = 0L
    self.n1138 = 0L
    self.n1084 = 0L
    self.n1055 = 0L
    self.n1002 = 0L
    self.n974 = 0L
    self.n922 = 0L
    self.n895 = 0L
    self.n844 = 0L
    self.n818 = 0L
    self.n769 = 0L
    self.n744 = 0L
    self.n696 = 0L
    self.n695 = 0L
    self.n672 = 0L
    self.n671 = 0L
    self.n624 = 0L
    self.n601 = 0L
    self.n560 = 0L
    self.n560r = 0L
    self.n560e = 0L
    self.n560d = 0L
    self.n538 = 0L
    self.n538r = 0L
    self.n538e = 0L
    self.n538d = 0L
    self.n1169 = 0L
    self.n1139 = 0L
    self.n1085 = 0L
    self.n1056 = 0L
    self.n1003 = 0L
    self.n975 = 0L
    self.n923 = 0L
    self.n896 = 0L
    self.n846 = 0L
    self.n820 = 0L
    self.n771 = 0L
    self.n770 = 0L
    self.n746 = 0L
    self.n745 = 0L
    self.n697 = 0L
    self.n673 = 0L
    self.n631 = 0L
    self.n631r = 0L
    self.n631e = 0L
    self.n631d = 0L
    self.n608 = 0L
    self.n608r = 0L
    self.n608e = 0L
    self.n608d = 0L
    self.n1170 = 0L
    self.n1140 = 0L
    self.n1086 = 0L
    self.n1057 = 0L
    self.n1004 = 0L
    self.n976 = 0L
    self.n925 = 0L
    self.n898 = 0L
    self.n848 = 0L
    self.n847 = 0L
    self.n822 = 0L
    self.n821 = 0L
    self.n772 = 0L
    self.n747 = 0L
    self.n704 = 0L
    self.n704r = 0L
    self.n704e = 0L
    self.n704d = 0L
    self.n680 = 0L
    self.n680r = 0L
    self.n680e = 0L
    self.n680d = 0L
    self.n1171 = 0L
    self.n1141 = 0L
    self.n1087 = 0L
    self.n1058 = 0L
    self.n1006 = 0L
    self.n978 = 0L
    self.n927 = 0L
    self.n926 = 0L
    self.n900 = 0L
    self.n899 = 0L
    self.n849 = 0L
    self.n823 = 0L
    self.n779 = 0L
    self.n779r = 0L
    self.n779e = 0L
    self.n779d = 0L
    self.n754 = 0L
    self.n754r = 0L
    self.n754e = 0L
    self.n754d = 0L
    self.n1172 = 0L
    self.n1142 = 0L
    self.n1089 = 0L
    self.n1060 = 0L
    self.n1008 = 0L
    self.n1007 = 0L
    self.n980 = 0L
    self.n979 = 0L
    self.n928 = 0L
    self.n901 = 0L
    self.n856 = 0L
    self.n856r = 0L
    self.n856e = 0L
    self.n856d = 0L
    self.n830 = 0L
    self.n830r = 0L
    self.n830e = 0L
    self.n830d = 0L
    self.n1174 = 0L
    self.n1144 = 0L
    self.n1091 = 0L
    self.n1090 = 0L
    self.n1062 = 0L
    self.n1061 = 0L
    self.n1009 = 0L
    self.n981 = 0L
    self.n935 = 0L
    self.n935r = 0L
    self.n935e = 0L
    self.n935d = 0L
    self.n908 = 0L
    self.n908r = 0L
    self.n908e = 0L
    self.n908d = 0L
    self.n1176 = 0L
    self.n1175 = 0L
    self.n1146 = 0L
    self.n1145 = 0L
    self.n1092 = 0L
    self.n1063 = 0L
    self.n1016 = 0L
    self.n1016r = 0L
    self.n1016e = 0L
    self.n1016d = 0L
    self.n988 = 0L
    self.n988r = 0L
    self.n988e = 0L
    self.n988d = 0L
    self.n1177 = 0L
    self.n1147 = 0L
    self.n1099 = 0L
    self.n1099r = 0L
    self.n1099e = 0L
    self.n1099d = 0L
    self.n1070 = 0L
    self.n1070r = 0L
    self.n1070e = 0L
    self.n1070d = 0L
    self.n1184 = 0L
    self.n1184r = 0L
    self.n1184e = 0L
    self.n1184d = 0L
    self.n1154 = 0L
    self.n1154r = 0L
    self.n1154e = 0L
    self.n1154d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, )

  def calc(self, enable_i, reset_i, real_i, imag_i, ang_i, ):
    self.n1304 = 0x08000L
    self.n1302 = 0x08000L
    self.n1300 = 0x08000L
    self.n1298 = 0x08000L
    self.n1296 = 0x08000L
    self.n1294 = 0x08000L
    self.n1292 = 0x08000L
    self.n1290 = 0x08000L
    self.n1288 = 0x08000L
    self.n1286 = 0x08000L
    self.n1284 = 0x08000L
    self.n1282 = 0x08000L
    self.n1280 = 0x08000L
    self.n1278 = 0x08000L
    self.n1276 = 0x08000L
    self.n1274 = 0x08000L
    self.n1272 = 0x08000L
    self.n1203 = 0x8000L
    ang_o = self.n1195
    self.n1198 = self.n1195
    imag_o = self.n1184
    self.n1197 = self.n1184
    real_o = self.n1154
    self.n1196 = self.n1154
    self.n1185 = 0x0000L
    self.n1173 = ((self.n1070 & 0x8000L) >> 15)
    self.n1156 = ((self.n1070 & 0x8000L) >> 15)
    self.n1143 = ((self.n1099 & 0x8000L) >> 15)
    self.n1126 = ((self.n1099 & 0x8000L) >> 15)
    self.n1122 = 0x0L
    self.n1114 = (self.n1099 & 0x4000L) | (self.n1099 & 0x2000L) | (self.n1099 & 0x1000L) | (self.n1099 & 0x800L) | (self.n1099 & 0x400L) | (self.n1099 & 0x200L) | (self.n1099 & 0x100L) | (self.n1099 & 0x80L) | (self.n1099 & 0x40L) | (self.n1099 & 0x20L) | (self.n1099 & 0x10L) | (self.n1099 & 0x8L) | (self.n1099 & 0x4L) | (self.n1099 & 0x2L) | (self.n1099 & 0x1L)
    self.n1112 = ((self.n1099 & 0x8000L) >> 15)
    self.n1100 = 0x0001L
    self.n1088 = ((self.n988 & 0x8000L) >> 14) | ((self.n988 & 0x4000L) >> 14)
    self.n1072 = ((self.n988 & 0x8000L) >> 15)
    self.n1059 = ((self.n1016 & 0x8000L) >> 14) | ((self.n1016 & 0x4000L) >> 14)
    self.n1043 = ((self.n1016 & 0x8000L) >> 15)
    self.n1039 = 0x0L
    self.n1031 = (self.n1016 & 0x4000L) | (self.n1016 & 0x2000L) | (self.n1016 & 0x1000L) | (self.n1016 & 0x800L) | (self.n1016 & 0x400L) | (self.n1016 & 0x200L) | (self.n1016 & 0x100L) | (self.n1016 & 0x80L) | (self.n1016 & 0x40L) | (self.n1016 & 0x20L) | (self.n1016 & 0x10L) | (self.n1016 & 0x8L) | (self.n1016 & 0x4L) | (self.n1016 & 0x2L) | (self.n1016 & 0x1L)
    self.n1029 = ((self.n1016 & 0x8000L) >> 15)
    self.n1017 = 0x0001L
    self.n1005 = ((self.n908 & 0x8000L) >> 13) | ((self.n908 & 0x4000L) >> 13) | ((self.n908 & 0x2000L) >> 13)
    self.n990 = ((self.n908 & 0x8000L) >> 15)
    self.n977 = ((self.n935 & 0x8000L) >> 13) | ((self.n935 & 0x4000L) >> 13) | ((self.n935 & 0x2000L) >> 13)
    self.n962 = ((self.n935 & 0x8000L) >> 15)
    self.n958 = 0x0L
    self.n950 = (self.n935 & 0x4000L) | (self.n935 & 0x2000L) | (self.n935 & 0x1000L) | (self.n935 & 0x800L) | (self.n935 & 0x400L) | (self.n935 & 0x200L) | (self.n935 & 0x100L) | (self.n935 & 0x80L) | (self.n935 & 0x40L) | (self.n935 & 0x20L) | (self.n935 & 0x10L) | (self.n935 & 0x8L) | (self.n935 & 0x4L) | (self.n935 & 0x2L) | (self.n935 & 0x1L)
    self.n948 = ((self.n935 & 0x8000L) >> 15)
    self.n936 = 0x0003L
    self.n924 = ((self.n830 & 0x8000L) >> 12) | ((self.n830 & 0x4000L) >> 12) | ((self.n830 & 0x2000L) >> 12) | ((self.n830 & 0x1000L) >> 12)
    self.n910 = ((self.n830 & 0x8000L) >> 15)
    self.n897 = ((self.n856 & 0x8000L) >> 12) | ((self.n856 & 0x4000L) >> 12) | ((self.n856 & 0x2000L) >> 12) | ((self.n856 & 0x1000L) >> 12)
    self.n883 = ((self.n856 & 0x8000L) >> 15)
    self.n879 = 0x0L
    self.n871 = (self.n856 & 0x4000L) | (self.n856 & 0x2000L) | (self.n856 & 0x1000L) | (self.n856 & 0x800L) | (self.n856 & 0x400L) | (self.n856 & 0x200L) | (self.n856 & 0x100L) | (self.n856 & 0x80L) | (self.n856 & 0x40L) | (self.n856 & 0x20L) | (self.n856 & 0x10L) | (self.n856 & 0x8L) | (self.n856 & 0x4L) | (self.n856 & 0x2L) | (self.n856 & 0x1L)
    self.n869 = ((self.n856 & 0x8000L) >> 15)
    self.n857 = 0x0005L
    self.n845 = ((self.n754 & 0x8000L) >> 11) | ((self.n754 & 0x4000L) >> 11) | ((self.n754 & 0x2000L) >> 11) | ((self.n754 & 0x1000L) >> 11) | ((self.n754 & 0x800L) >> 11)
    self.n832 = ((self.n754 & 0x8000L) >> 15)
    self.n819 = ((self.n779 & 0x8000L) >> 11) | ((self.n779 & 0x4000L) >> 11) | ((self.n779 & 0x2000L) >> 11) | ((self.n779 & 0x1000L) >> 11) | ((self.n779 & 0x800L) >> 11)
    self.n806 = ((self.n779 & 0x8000L) >> 15)
    self.n802 = 0x0L
    self.n794 = (self.n779 & 0x4000L) | (self.n779 & 0x2000L) | (self.n779 & 0x1000L) | (self.n779 & 0x800L) | (self.n779 & 0x400L) | (self.n779 & 0x200L) | (self.n779 & 0x100L) | (self.n779 & 0x80L) | (self.n779 & 0x40L) | (self.n779 & 0x20L) | (self.n779 & 0x10L) | (self.n779 & 0x8L) | (self.n779 & 0x4L) | (self.n779 & 0x2L) | (self.n779 & 0x1L)
    self.n792 = ((self.n779 & 0x8000L) >> 15)
    self.n780 = 0x000AL
    self.n768 = ((self.n680 & 0x8000L) >> 10) | ((self.n680 & 0x4000L) >> 10) | ((self.n680 & 0x2000L) >> 10) | ((self.n680 & 0x1000L) >> 10) | ((self.n680 & 0x800L) >> 10) | ((self.n680 & 0x400L) >> 10)
    self.n756 = ((self.n680 & 0x8000L) >> 15)
    self.n743 = ((self.n704 & 0x8000L) >> 10) | ((self.n704 & 0x4000L) >> 10) | ((self.n704 & 0x2000L) >> 10) | ((self.n704 & 0x1000L) >> 10) | ((self.n704 & 0x800L) >> 10) | ((self.n704 & 0x400L) >> 10)
    self.n731 = ((self.n704 & 0x8000L) >> 15)
    self.n727 = 0x0L
    self.n719 = (self.n704 & 0x4000L) | (self.n704 & 0x2000L) | (self.n704 & 0x1000L) | (self.n704 & 0x800L) | (self.n704 & 0x400L) | (self.n704 & 0x200L) | (self.n704 & 0x100L) | (self.n704 & 0x80L) | (self.n704 & 0x40L) | (self.n704 & 0x20L) | (self.n704 & 0x10L) | (self.n704 & 0x8L) | (self.n704 & 0x4L) | (self.n704 & 0x2L) | (self.n704 & 0x1L)
    self.n717 = ((self.n704 & 0x8000L) >> 15)
    self.n705 = 0x0014L
    self.n693 = ((self.n608 & 0x8000L) >> 9) | ((self.n608 & 0x4000L) >> 9) | ((self.n608 & 0x2000L) >> 9) | ((self.n608 & 0x1000L) >> 9) | ((self.n608 & 0x800L) >> 9) | ((self.n608 & 0x400L) >> 9) | ((self.n608 & 0x200L) >> 9)
    self.n682 = ((self.n608 & 0x8000L) >> 15)
    self.n669 = ((self.n631 & 0x8000L) >> 9) | ((self.n631 & 0x4000L) >> 9) | ((self.n631 & 0x2000L) >> 9) | ((self.n631 & 0x1000L) >> 9) | ((self.n631 & 0x800L) >> 9) | ((self.n631 & 0x400L) >> 9) | ((self.n631 & 0x200L) >> 9)
    self.n658 = ((self.n631 & 0x8000L) >> 15)
    self.n654 = 0x0L
    self.n646 = (self.n631 & 0x4000L) | (self.n631 & 0x2000L) | (self.n631 & 0x1000L) | (self.n631 & 0x800L) | (self.n631 & 0x400L) | (self.n631 & 0x200L) | (self.n631 & 0x100L) | (self.n631 & 0x80L) | (self.n631 & 0x40L) | (self.n631 & 0x20L) | (self.n631 & 0x10L) | (self.n631 & 0x8L) | (self.n631 & 0x4L) | (self.n631 & 0x2L) | (self.n631 & 0x1L)
    self.n644 = ((self.n631 & 0x8000L) >> 15)
    self.n632 = 0x0029L
    self.n620 = ((self.n538 & 0x8000L) >> 8) | ((self.n538 & 0x4000L) >> 8) | ((self.n538 & 0x2000L) >> 8) | ((self.n538 & 0x1000L) >> 8) | ((self.n538 & 0x800L) >> 8) | ((self.n538 & 0x400L) >> 8) | ((self.n538 & 0x200L) >> 8) | ((self.n538 & 0x100L) >> 8)
    self.n610 = ((self.n538 & 0x8000L) >> 15)
    self.n597 = ((self.n560 & 0x8000L) >> 8) | ((self.n560 & 0x4000L) >> 8) | ((self.n560 & 0x2000L) >> 8) | ((self.n560 & 0x1000L) >> 8) | ((self.n560 & 0x800L) >> 8) | ((self.n560 & 0x400L) >> 8) | ((self.n560 & 0x200L) >> 8) | ((self.n560 & 0x100L) >> 8)
    self.n587 = ((self.n560 & 0x8000L) >> 15)
    self.n583 = 0x0L
    self.n575 = (self.n560 & 0x4000L) | (self.n560 & 0x2000L) | (self.n560 & 0x1000L) | (self.n560 & 0x800L) | (self.n560 & 0x400L) | (self.n560 & 0x200L) | (self.n560 & 0x100L) | (self.n560 & 0x80L) | (self.n560 & 0x40L) | (self.n560 & 0x20L) | (self.n560 & 0x10L) | (self.n560 & 0x8L) | (self.n560 & 0x4L) | (self.n560 & 0x2L) | (self.n560 & 0x1L)
    self.n573 = ((self.n560 & 0x8000L) >> 15)
    self.n561 = 0x0051L
    self.n549 = ((self.n470 & 0x8000L) >> 7) | ((self.n470 & 0x4000L) >> 7) | ((self.n470 & 0x2000L) >> 7) | ((self.n470 & 0x1000L) >> 7) | ((self.n470 & 0x800L) >> 7) | ((self.n470 & 0x400L) >> 7) | ((self.n470 & 0x200L) >> 7) | ((self.n470 & 0x100L) >> 7) | ((self.n470 & 0x80L) >> 7)
    self.n540 = ((self.n470 & 0x8000L) >> 15)
    self.n527 = ((self.n491 & 0x8000L) >> 7) | ((self.n491 & 0x4000L) >> 7) | ((self.n491 & 0x2000L) >> 7) | ((self.n491 & 0x1000L) >> 7) | ((self.n491 & 0x800L) >> 7) | ((self.n491 & 0x400L) >> 7) | ((self.n491 & 0x200L) >> 7) | ((self.n491 & 0x100L) >> 7) | ((self.n491 & 0x80L) >> 7)
    self.n518 = ((self.n491 & 0x8000L) >> 15)
    self.n514 = 0x0L
    self.n506 = (self.n491 & 0x4000L) | (self.n491 & 0x2000L) | (self.n491 & 0x1000L) | (self.n491 & 0x800L) | (self.n491 & 0x400L) | (self.n491 & 0x200L) | (self.n491 & 0x100L) | (self.n491 & 0x80L) | (self.n491 & 0x40L) | (self.n491 & 0x20L) | (self.n491 & 0x10L) | (self.n491 & 0x8L) | (self.n491 & 0x4L) | (self.n491 & 0x2L) | (self.n491 & 0x1L)
    self.n504 = ((self.n491 & 0x8000L) >> 15)
    self.n492 = 0x00A3L
    self.n480 = ((self.n404 & 0x8000L) >> 6) | ((self.n404 & 0x4000L) >> 6) | ((self.n404 & 0x2000L) >> 6) | ((self.n404 & 0x1000L) >> 6) | ((self.n404 & 0x800L) >> 6) | ((self.n404 & 0x400L) >> 6) | ((self.n404 & 0x200L) >> 6) | ((self.n404 & 0x100L) >> 6) | ((self.n404 & 0x80L) >> 6) | ((self.n404 & 0x40L) >> 6)
    self.n472 = ((self.n404 & 0x8000L) >> 15)
    self.n459 = ((self.n424 & 0x8000L) >> 6) | ((self.n424 & 0x4000L) >> 6) | ((self.n424 & 0x2000L) >> 6) | ((self.n424 & 0x1000L) >> 6) | ((self.n424 & 0x800L) >> 6) | ((self.n424 & 0x400L) >> 6) | ((self.n424 & 0x200L) >> 6) | ((self.n424 & 0x100L) >> 6) | ((self.n424 & 0x80L) >> 6) | ((self.n424 & 0x40L) >> 6)
    self.n451 = ((self.n424 & 0x8000L) >> 15)
    self.n447 = 0x0L
    self.n439 = (self.n424 & 0x4000L) | (self.n424 & 0x2000L) | (self.n424 & 0x1000L) | (self.n424 & 0x800L) | (self.n424 & 0x400L) | (self.n424 & 0x200L) | (self.n424 & 0x100L) | (self.n424 & 0x80L) | (self.n424 & 0x40L) | (self.n424 & 0x20L) | (self.n424 & 0x10L) | (self.n424 & 0x8L) | (self.n424 & 0x4L) | (self.n424 & 0x2L) | (self.n424 & 0x1L)
    self.n437 = ((self.n424 & 0x8000L) >> 15)
    self.n425 = 0x0146L
    self.n413 = ((self.n340 & 0x8000L) >> 5) | ((self.n340 & 0x4000L) >> 5) | ((self.n340 & 0x2000L) >> 5) | ((self.n340 & 0x1000L) >> 5) | ((self.n340 & 0x800L) >> 5) | ((self.n340 & 0x400L) >> 5) | ((self.n340 & 0x200L) >> 5) | ((self.n340 & 0x100L) >> 5) | ((self.n340 & 0x80L) >> 5) | ((self.n340 & 0x40L) >> 5) | ((self.n340 & 0x20L) >> 5)
    self.n406 = ((self.n340 & 0x8000L) >> 15)
    self.n393 = ((self.n359 & 0x8000L) >> 5) | ((self.n359 & 0x4000L) >> 5) | ((self.n359 & 0x2000L) >> 5) | ((self.n359 & 0x1000L) >> 5) | ((self.n359 & 0x800L) >> 5) | ((self.n359 & 0x400L) >> 5) | ((self.n359 & 0x200L) >> 5) | ((self.n359 & 0x100L) >> 5) | ((self.n359 & 0x80L) >> 5) | ((self.n359 & 0x40L) >> 5) | ((self.n359 & 0x20L) >> 5)
    self.n386 = ((self.n359 & 0x8000L) >> 15)
    self.n382 = 0x0L
    self.n374 = (self.n359 & 0x4000L) | (self.n359 & 0x2000L) | (self.n359 & 0x1000L) | (self.n359 & 0x800L) | (self.n359 & 0x400L) | (self.n359 & 0x200L) | (self.n359 & 0x100L) | (self.n359 & 0x80L) | (self.n359 & 0x40L) | (self.n359 & 0x20L) | (self.n359 & 0x10L) | (self.n359 & 0x8L) | (self.n359 & 0x4L) | (self.n359 & 0x2L) | (self.n359 & 0x1L)
    self.n372 = ((self.n359 & 0x8000L) >> 15)
    self.n360 = 0x028BL
    self.n348 = ((self.n278 & 0x8000L) >> 4) | ((self.n278 & 0x4000L) >> 4) | ((self.n278 & 0x2000L) >> 4) | ((self.n278 & 0x1000L) >> 4) | ((self.n278 & 0x800L) >> 4) | ((self.n278 & 0x400L) >> 4) | ((self.n278 & 0x200L) >> 4) | ((self.n278 & 0x100L) >> 4) | ((self.n278 & 0x80L) >> 4) | ((self.n278 & 0x40L) >> 4) | ((self.n278 & 0x20L) >> 4) | ((self.n278 & 0x10L) >> 4)
    self.n342 = ((self.n278 & 0x8000L) >> 15)
    self.n329 = ((self.n296 & 0x8000L) >> 4) | ((self.n296 & 0x4000L) >> 4) | ((self.n296 & 0x2000L) >> 4) | ((self.n296 & 0x1000L) >> 4) | ((self.n296 & 0x800L) >> 4) | ((self.n296 & 0x400L) >> 4) | ((self.n296 & 0x200L) >> 4) | ((self.n296 & 0x100L) >> 4) | ((self.n296 & 0x80L) >> 4) | ((self.n296 & 0x40L) >> 4) | ((self.n296 & 0x20L) >> 4) | ((self.n296 & 0x10L) >> 4)
    self.n323 = ((self.n296 & 0x8000L) >> 15)
    self.n319 = 0x0L
    self.n311 = (self.n296 & 0x4000L) | (self.n296 & 0x2000L) | (self.n296 & 0x1000L) | (self.n296 & 0x800L) | (self.n296 & 0x400L) | (self.n296 & 0x200L) | (self.n296 & 0x100L) | (self.n296 & 0x80L) | (self.n296 & 0x40L) | (self.n296 & 0x20L) | (self.n296 & 0x10L) | (self.n296 & 0x8L) | (self.n296 & 0x4L) | (self.n296 & 0x2L) | (self.n296 & 0x1L)
    self.n309 = ((self.n296 & 0x8000L) >> 15)
    self.n297 = 0x0511L
    self.n285 = ((self.n218 & 0x8000L) >> 3) | ((self.n218 & 0x4000L) >> 3) | ((self.n218 & 0x2000L) >> 3) | ((self.n218 & 0x1000L) >> 3) | ((self.n218 & 0x800L) >> 3) | ((self.n218 & 0x400L) >> 3) | ((self.n218 & 0x200L) >> 3) | ((self.n218 & 0x100L) >> 3) | ((self.n218 & 0x80L) >> 3) | ((self.n218 & 0x40L) >> 3) | ((self.n218 & 0x20L) >> 3) | ((self.n218 & 0x10L) >> 3) | ((self.n218 & 0x8L) >> 3)
    self.n280 = ((self.n218 & 0x8000L) >> 15)
    self.n267 = ((self.n235 & 0x8000L) >> 3) | ((self.n235 & 0x4000L) >> 3) | ((self.n235 & 0x2000L) >> 3) | ((self.n235 & 0x1000L) >> 3) | ((self.n235 & 0x800L) >> 3) | ((self.n235 & 0x400L) >> 3) | ((self.n235 & 0x200L) >> 3) | ((self.n235 & 0x100L) >> 3) | ((self.n235 & 0x80L) >> 3) | ((self.n235 & 0x40L) >> 3) | ((self.n235 & 0x20L) >> 3) | ((self.n235 & 0x10L) >> 3) | ((self.n235 & 0x8L) >> 3)
    self.n262 = ((self.n235 & 0x8000L) >> 15)
    self.n258 = 0x0L
    self.n250 = (self.n235 & 0x4000L) | (self.n235 & 0x2000L) | (self.n235 & 0x1000L) | (self.n235 & 0x800L) | (self.n235 & 0x400L) | (self.n235 & 0x200L) | (self.n235 & 0x100L) | (self.n235 & 0x80L) | (self.n235 & 0x40L) | (self.n235 & 0x20L) | (self.n235 & 0x10L) | (self.n235 & 0x8L) | (self.n235 & 0x4L) | (self.n235 & 0x2L) | (self.n235 & 0x1L)
    self.n248 = ((self.n235 & 0x8000L) >> 15)
    self.n236 = 0x09FBL
    self.n224 = ((self.n160 & 0x8000L) >> 2) | ((self.n160 & 0x4000L) >> 2) | ((self.n160 & 0x2000L) >> 2) | ((self.n160 & 0x1000L) >> 2) | ((self.n160 & 0x800L) >> 2) | ((self.n160 & 0x400L) >> 2) | ((self.n160 & 0x200L) >> 2) | ((self.n160 & 0x100L) >> 2) | ((self.n160 & 0x80L) >> 2) | ((self.n160 & 0x40L) >> 2) | ((self.n160 & 0x20L) >> 2) | ((self.n160 & 0x10L) >> 2) | ((self.n160 & 0x8L) >> 2) | ((self.n160 & 0x4L) >> 2)
    self.n220 = ((self.n160 & 0x8000L) >> 15)
    self.n207 = ((self.n176 & 0x8000L) >> 2) | ((self.n176 & 0x4000L) >> 2) | ((self.n176 & 0x2000L) >> 2) | ((self.n176 & 0x1000L) >> 2) | ((self.n176 & 0x800L) >> 2) | ((self.n176 & 0x400L) >> 2) | ((self.n176 & 0x200L) >> 2) | ((self.n176 & 0x100L) >> 2) | ((self.n176 & 0x80L) >> 2) | ((self.n176 & 0x40L) >> 2) | ((self.n176 & 0x20L) >> 2) | ((self.n176 & 0x10L) >> 2) | ((self.n176 & 0x8L) >> 2) | ((self.n176 & 0x4L) >> 2)
    self.n203 = ((self.n176 & 0x8000L) >> 15)
    self.n199 = 0x0L
    self.n191 = (self.n176 & 0x4000L) | (self.n176 & 0x2000L) | (self.n176 & 0x1000L) | (self.n176 & 0x800L) | (self.n176 & 0x400L) | (self.n176 & 0x200L) | (self.n176 & 0x100L) | (self.n176 & 0x80L) | (self.n176 & 0x40L) | (self.n176 & 0x20L) | (self.n176 & 0x10L) | (self.n176 & 0x8L) | (self.n176 & 0x4L) | (self.n176 & 0x2L) | (self.n176 & 0x1L)
    self.n189 = ((self.n176 & 0x8000L) >> 15)
    self.n177 = 0x12E4L
    self.n165 = ((self.n104 & 0x8000L) >> 1) | ((self.n104 & 0x4000L) >> 1) | ((self.n104 & 0x2000L) >> 1) | ((self.n104 & 0x1000L) >> 1) | ((self.n104 & 0x800L) >> 1) | ((self.n104 & 0x400L) >> 1) | ((self.n104 & 0x200L) >> 1) | ((self.n104 & 0x100L) >> 1) | ((self.n104 & 0x80L) >> 1) | ((self.n104 & 0x40L) >> 1) | ((self.n104 & 0x20L) >> 1) | ((self.n104 & 0x10L) >> 1) | ((self.n104 & 0x8L) >> 1) | ((self.n104 & 0x4L) >> 1) | ((self.n104 & 0x2L) >> 1)
    self.n162 = ((self.n104 & 0x8000L) >> 15)
    self.n149 = ((self.n119 & 0x8000L) >> 1) | ((self.n119 & 0x4000L) >> 1) | ((self.n119 & 0x2000L) >> 1) | ((self.n119 & 0x1000L) >> 1) | ((self.n119 & 0x800L) >> 1) | ((self.n119 & 0x400L) >> 1) | ((self.n119 & 0x200L) >> 1) | ((self.n119 & 0x100L) >> 1) | ((self.n119 & 0x80L) >> 1) | ((self.n119 & 0x40L) >> 1) | ((self.n119 & 0x20L) >> 1) | ((self.n119 & 0x10L) >> 1) | ((self.n119 & 0x8L) >> 1) | ((self.n119 & 0x4L) >> 1) | ((self.n119 & 0x2L) >> 1)
    self.n146 = ((self.n119 & 0x8000L) >> 15)
    self.n142 = 0x0L
    self.n134 = (self.n119 & 0x4000L) | (self.n119 & 0x2000L) | (self.n119 & 0x1000L) | (self.n119 & 0x800L) | (self.n119 & 0x400L) | (self.n119 & 0x200L) | (self.n119 & 0x100L) | (self.n119 & 0x80L) | (self.n119 & 0x40L) | (self.n119 & 0x20L) | (self.n119 & 0x10L) | (self.n119 & 0x8L) | (self.n119 & 0x4L) | (self.n119 & 0x2L) | (self.n119 & 0x1L)
    self.n132 = ((self.n119 & 0x8000L) >> 15)
    self.n120 = 0x2000L
    self.n108 = (self.n59 & 0x8000L) | (self.n59 & 0x4000L) | (self.n59 & 0x2000L) | (self.n59 & 0x1000L) | (self.n59 & 0x800L) | (self.n59 & 0x400L) | (self.n59 & 0x200L) | (self.n59 & 0x100L) | (self.n59 & 0x80L) | (self.n59 & 0x40L) | (self.n59 & 0x20L) | (self.n59 & 0x10L) | (self.n59 & 0x8L) | (self.n59 & 0x4L) | (self.n59 & 0x2L) | (self.n59 & 0x1L)
    self.n93 = (self.n67 & 0x8000L) | (self.n67 & 0x4000L) | (self.n67 & 0x2000L) | (self.n67 & 0x1000L) | (self.n67 & 0x800L) | (self.n67 & 0x400L) | (self.n67 & 0x200L) | (self.n67 & 0x100L) | (self.n67 & 0x80L) | (self.n67 & 0x40L) | (self.n67 & 0x20L) | (self.n67 & 0x10L) | (self.n67 & 0x8L) | (self.n67 & 0x4L) | (self.n67 & 0x2L) | (self.n67 & 0x1L)
    self.n87 = 0x0L
    self.n79 = (self.n67 & 0x4000L) | (self.n67 & 0x2000L) | (self.n67 & 0x1000L) | (self.n67 & 0x800L) | (self.n67 & 0x400L) | (self.n67 & 0x200L) | (self.n67 & 0x100L) | (self.n67 & 0x80L) | (self.n67 & 0x40L) | (self.n67 & 0x20L) | (self.n67 & 0x10L) | (self.n67 & 0x8L) | (self.n67 & 0x4L) | (self.n67 & 0x2L) | (self.n67 & 0x1L)
    self.n77 = ((self.n67 & 0x8000L) >> 15)
    self.n46 = 0x0000L
    self.n44 = 0x0000L
    self.n38 = 0x0L
    self.n32 = (self.n14 & 0x4000L) | (self.n14 & 0x2000L) | (self.n14 & 0x1000L) | (self.n14 & 0x800L) | (self.n14 & 0x400L) | (self.n14 & 0x200L) | (self.n14 & 0x100L) | (self.n14 & 0x80L) | (self.n14 & 0x40L) | (self.n14 & 0x20L) | (self.n14 & 0x10L) | (self.n14 & 0x8L) | (self.n14 & 0x4L) | (self.n14 & 0x2L) | (self.n14 & 0x1L)
    self.n30 = ((self.n14 & 0x8000L) >> 15)
    self.n7 = ang_i
    self.n6 = imag_i
    self.n5 = real_i
    self.n4 = reset_i
    self.n3 = enable_i
    self.n1187 = (self.n1110 - self.n1185) & 0xFFFFL
    self.n1186 = (self.n1110 + self.n1185) & 0xFFFFL
    self.n1159 = self.n1156 << 1 | self.n1156
    self.n1129 = self.n1126 << 1 | self.n1126
    self.n1113 = ~self.n1112 & 0x1L
    self.n1102 = (self.n1027 - self.n1100) & 0xFFFFL
    self.n1101 = (self.n1027 + self.n1100) & 0xFFFFL
    self.n1075 = self.n1072 << 1 | self.n1072
    self.n1046 = self.n1043 << 1 | self.n1043
    self.n1030 = ~self.n1029 & 0x1L
    self.n1019 = (self.n946 - self.n1017) & 0xFFFFL
    self.n1018 = (self.n946 + self.n1017) & 0xFFFFL
    self.n993 = self.n990 << 1 | self.n990
    self.n965 = self.n962 << 1 | self.n962
    self.n949 = ~self.n948 & 0x1L
    self.n938 = (self.n867 - self.n936) & 0xFFFFL
    self.n937 = (self.n867 + self.n936) & 0xFFFFL
    self.n913 = self.n910 << 1 | self.n910
    self.n886 = self.n883 << 1 | self.n883
    self.n870 = ~self.n869 & 0x1L
    self.n859 = (self.n790 - self.n857) & 0xFFFFL
    self.n858 = (self.n790 + self.n857) & 0xFFFFL
    self.n835 = self.n832 << 1 | self.n832
    self.n809 = self.n806 << 1 | self.n806
    self.n793 = ~self.n792 & 0x1L
    self.n782 = (self.n715 - self.n780) & 0xFFFFL
    self.n781 = (self.n715 + self.n780) & 0xFFFFL
    self.n759 = self.n756 << 1 | self.n756
    self.n734 = self.n731 << 1 | self.n731
    self.n718 = ~self.n717 & 0x1L
    self.n707 = (self.n642 - self.n705) & 0xFFFFL
    self.n706 = (self.n642 + self.n705) & 0xFFFFL
    self.n685 = self.n682 << 1 | self.n682
    self.n661 = self.n658 << 1 | self.n658
    self.n645 = ~self.n644 & 0x1L
    self.n634 = (self.n571 - self.n632) & 0xFFFFL
    self.n633 = (self.n571 + self.n632) & 0xFFFFL
    self.n613 = self.n610 << 1 | self.n610
    self.n590 = self.n587 << 1 | self.n587
    self.n574 = ~self.n573 & 0x1L
    self.n563 = (self.n502 - self.n561) & 0xFFFFL
    self.n562 = (self.n502 + self.n561) & 0xFFFFL
    self.n543 = self.n540 << 1 | self.n540
    self.n521 = self.n518 << 1 | self.n518
    self.n505 = ~self.n504 & 0x1L
    self.n494 = (self.n435 - self.n492) & 0xFFFFL
    self.n493 = (self.n435 + self.n492) & 0xFFFFL
    self.n475 = self.n472 << 1 | self.n472
    self.n454 = self.n451 << 1 | self.n451
    self.n438 = ~self.n437 & 0x1L
    self.n427 = (self.n370 - self.n425) & 0xFFFFL
    self.n426 = (self.n370 + self.n425) & 0xFFFFL
    self.n409 = self.n406 << 1 | self.n406
    self.n389 = self.n386 << 1 | self.n386
    self.n373 = ~self.n372 & 0x1L
    self.n362 = (self.n307 - self.n360) & 0xFFFFL
    self.n361 = (self.n307 + self.n360) & 0xFFFFL
    self.n345 = self.n342 << 1 | self.n342
    self.n326 = self.n323 << 1 | self.n323
    self.n310 = ~self.n309 & 0x1L
    self.n299 = (self.n246 - self.n297) & 0xFFFFL
    self.n298 = (self.n246 + self.n297) & 0xFFFFL
    self.n283 = self.n280 << 1 | self.n280
    self.n265 = self.n262 << 1 | self.n262
    self.n249 = ~self.n248 & 0x1L
    self.n238 = (self.n187 - self.n236) & 0xFFFFL
    self.n237 = (self.n187 + self.n236) & 0xFFFFL
    self.n223 = self.n220 << 1 | self.n220
    self.n206 = self.n203 << 1 | self.n203
    self.n190 = ~self.n189 & 0x1L
    self.n179 = (self.n130 - self.n177) & 0xFFFFL
    self.n178 = (self.n130 + self.n177) & 0xFFFFL
    self.n166 = self.n162 << 15 | self.n165
    self.n150 = self.n146 << 15 | self.n149
    self.n133 = ~self.n132 & 0x1L
    self.n122 = (self.n75 - self.n120) & 0xFFFFL
    self.n121 = (self.n75 + self.n120) & 0xFFFFL
    self.n111 = (self.n67 - self.n108) & 0xFFFFL
    self.n110 = (self.n67 + self.n108) & 0xFFFFL
    self.n96 = (self.n59 - self.n93) & 0xFFFFL
    self.n95 = (self.n59 + self.n93) & 0xFFFFL
    self.n78 = ~self.n77 & 0x1L
    self.n51 = (self.n28 - self.n1203) & 0xFFFFL
    self.n47 = (self.n46 - self.n21) & 0xFFFFL
    self.n45 = (self.n44 - self.n14) & 0xFFFFL
    self.n31 = ~self.n30 & 0x1L
    self.n28r = self.n4
    self.n28e = self.n3
    self.n28d = self.n7
    self.n21r = self.n4
    self.n21e = self.n3
    self.n21d = self.n6
    self.n14r = self.n4
    self.n14e = self.n3
    self.n14d = self.n5
    self.n1160 = self.n1156 << 2 | self.n1159
    self.n1130 = self.n1126 << 2 | self.n1129
    self.n1115 = self.n1113 << 15 | self.n1114
    self.n1076 = self.n1072 << 2 | self.n1075
    self.n1047 = self.n1043 << 2 | self.n1046
    self.n1032 = self.n1030 << 15 | self.n1031
    self.n994 = self.n990 << 2 | self.n993
    self.n966 = self.n962 << 2 | self.n965
    self.n951 = self.n949 << 15 | self.n950
    self.n914 = self.n910 << 2 | self.n913
    self.n887 = self.n883 << 2 | self.n886
    self.n872 = self.n870 << 15 | self.n871
    self.n836 = self.n832 << 2 | self.n835
    self.n810 = self.n806 << 2 | self.n809
    self.n795 = self.n793 << 15 | self.n794
    self.n760 = self.n756 << 2 | self.n759
    self.n735 = self.n731 << 2 | self.n734
    self.n720 = self.n718 << 15 | self.n719
    self.n686 = self.n682 << 2 | self.n685
    self.n662 = self.n658 << 2 | self.n661
    self.n647 = self.n645 << 15 | self.n646
    self.n614 = self.n610 << 2 | self.n613
    self.n591 = self.n587 << 2 | self.n590
    self.n576 = self.n574 << 15 | self.n575
    self.n544 = self.n540 << 2 | self.n543
    self.n522 = self.n518 << 2 | self.n521
    self.n507 = self.n505 << 15 | self.n506
    self.n476 = self.n472 << 2 | self.n475
    self.n455 = self.n451 << 2 | self.n454
    self.n440 = self.n438 << 15 | self.n439
    self.n410 = self.n406 << 2 | self.n409
    self.n390 = self.n386 << 2 | self.n389
    self.n375 = self.n373 << 15 | self.n374
    self.n346 = self.n342 << 2 | self.n345
    self.n327 = self.n323 << 2 | self.n326
    self.n312 = self.n310 << 15 | self.n311
    self.n284 = self.n280 << 2 | self.n283
    self.n266 = self.n262 << 2 | self.n265
    self.n251 = self.n249 << 15 | self.n250
    self.n225 = self.n223 << 14 | self.n224
    self.n208 = self.n206 << 14 | self.n207
    self.n192 = self.n190 << 15 | self.n191
    self.n168 = (self.n119 - self.n166) & 0xFFFFL
    self.n167 = (self.n119 + self.n166) & 0xFFFFL
    self.n152 = (self.n104 - self.n150) & 0xFFFFL
    self.n151 = (self.n104 + self.n150) & 0xFFFFL
    self.n135 = self.n133 << 15 | self.n134
    self.n80 = self.n78 << 15 | self.n79
    self.n33 = self.n31 << 15 | self.n32
    self.n1161 = self.n1156 << 3 | self.n1160
    self.n1131 = self.n1126 << 3 | self.n1130
    self.n1123 = self.n1122 << 16 | self.n1115
    self.n1077 = self.n1072 << 3 | self.n1076
    self.n1048 = self.n1043 << 3 | self.n1047
    self.n1040 = self.n1039 << 16 | self.n1032
    self.n995 = self.n990 << 3 | self.n994
    self.n967 = self.n962 << 3 | self.n966
    self.n959 = self.n958 << 16 | self.n951
    self.n915 = self.n910 << 3 | self.n914
    self.n888 = self.n883 << 3 | self.n887
    self.n880 = self.n879 << 16 | self.n872
    self.n837 = self.n832 << 3 | self.n836
    self.n811 = self.n806 << 3 | self.n810
    self.n803 = self.n802 << 16 | self.n795
    self.n761 = self.n756 << 3 | self.n760
    self.n736 = self.n731 << 3 | self.n735
    self.n728 = self.n727 << 16 | self.n720
    self.n687 = self.n682 << 3 | self.n686
    self.n663 = self.n658 << 3 | self.n662
    self.n655 = self.n654 << 16 | self.n647
    self.n615 = self.n610 << 3 | self.n614
    self.n592 = self.n587 << 3 | self.n591
    self.n584 = self.n583 << 16 | self.n576
    self.n545 = self.n540 << 3 | self.n544
    self.n523 = self.n518 << 3 | self.n522
    self.n515 = self.n514 << 16 | self.n507
    self.n477 = self.n472 << 3 | self.n476
    self.n456 = self.n451 << 3 | self.n455
    self.n448 = self.n447 << 16 | self.n440
    self.n411 = self.n406 << 3 | self.n410
    self.n391 = self.n386 << 3 | self.n390
    self.n383 = self.n382 << 16 | self.n375
    self.n347 = self.n342 << 3 | self.n346
    self.n328 = self.n323 << 3 | self.n327
    self.n320 = self.n319 << 16 | self.n312
    self.n286 = self.n284 << 13 | self.n285
    self.n268 = self.n266 << 13 | self.n267
    self.n259 = self.n258 << 16 | self.n251
    self.n227 = (self.n176 - self.n225) & 0xFFFFL
    self.n226 = (self.n176 + self.n225) & 0xFFFFL
    self.n210 = (self.n160 - self.n208) & 0xFFFFL
    self.n209 = (self.n160 + self.n208) & 0xFFFFL
    self.n200 = self.n199 << 16 | self.n192
    self.n143 = self.n142 << 16 | self.n135
    self.n88 = self.n87 << 16 | self.n80
    self.n39 = self.n38 << 16 | self.n33
    self.n1162 = self.n1156 << 4 | self.n1161
    self.n1132 = self.n1126 << 4 | self.n1131
    self.n1124 = (self.n1304 - self.n1123) & 0x1FFFFL
    self.n1078 = self.n1072 << 4 | self.n1077
    self.n1049 = self.n1043 << 4 | self.n1048
    self.n1041 = (self.n1302 - self.n1040) & 0x1FFFFL
    self.n996 = self.n990 << 4 | self.n995
    self.n968 = self.n962 << 4 | self.n967
    self.n960 = (self.n1300 - self.n959) & 0x1FFFFL
    self.n916 = self.n910 << 4 | self.n915
    self.n889 = self.n883 << 4 | self.n888
    self.n881 = (self.n1298 - self.n880) & 0x1FFFFL
    self.n838 = self.n832 << 4 | self.n837
    self.n812 = self.n806 << 4 | self.n811
    self.n804 = (self.n1296 - self.n803) & 0x1FFFFL
    self.n762 = self.n756 << 4 | self.n761
    self.n737 = self.n731 << 4 | self.n736
    self.n729 = (self.n1294 - self.n728) & 0x1FFFFL
    self.n688 = self.n682 << 4 | self.n687
    self.n664 = self.n658 << 4 | self.n663
    self.n656 = (self.n1292 - self.n655) & 0x1FFFFL
    self.n616 = self.n610 << 4 | self.n615
    self.n593 = self.n587 << 4 | self.n592
    self.n585 = (self.n1290 - self.n584) & 0x1FFFFL
    self.n546 = self.n540 << 4 | self.n545
    self.n524 = self.n518 << 4 | self.n523
    self.n516 = (self.n1288 - self.n515) & 0x1FFFFL
    self.n478 = self.n472 << 4 | self.n477
    self.n457 = self.n451 << 4 | self.n456
    self.n449 = (self.n1286 - self.n448) & 0x1FFFFL
    self.n412 = self.n406 << 4 | self.n411
    self.n392 = self.n386 << 4 | self.n391
    self.n384 = (self.n1284 - self.n383) & 0x1FFFFL
    self.n349 = self.n347 << 12 | self.n348
    self.n330 = self.n328 << 12 | self.n329
    self.n321 = (self.n1282 - self.n320) & 0x1FFFFL
    self.n288 = (self.n235 - self.n286) & 0xFFFFL
    self.n287 = (self.n235 + self.n286) & 0xFFFFL
    self.n270 = (self.n218 - self.n268) & 0xFFFFL
    self.n269 = (self.n218 + self.n268) & 0xFFFFL
    self.n260 = (self.n1280 - self.n259) & 0x1FFFFL
    self.n201 = (self.n1278 - self.n200) & 0x1FFFFL
    self.n144 = (self.n1276 - self.n143) & 0x1FFFFL
    self.n89 = (self.n1274 - self.n88) & 0x1FFFFL
    self.n42 = (self.n39 - self.n1272) & 0x1FFFFL
    self.n1163 = self.n1156 << 5 | self.n1162
    self.n1133 = self.n1126 << 5 | self.n1132
    self.n1125 = ((self.n1124 & 0x10000L) >> 16)
    self.n1079 = self.n1072 << 5 | self.n1078
    self.n1050 = self.n1043 << 5 | self.n1049
    self.n1042 = ((self.n1041 & 0x10000L) >> 16)
    self.n997 = self.n990 << 5 | self.n996
    self.n969 = self.n962 << 5 | self.n968
    self.n961 = ((self.n960 & 0x10000L) >> 16)
    self.n917 = self.n910 << 5 | self.n916
    self.n890 = self.n883 << 5 | self.n889
    self.n882 = ((self.n881 & 0x10000L) >> 16)
    self.n839 = self.n832 << 5 | self.n838
    self.n813 = self.n806 << 5 | self.n812
    self.n805 = ((self.n804 & 0x10000L) >> 16)
    self.n763 = self.n756 << 5 | self.n762
    self.n738 = self.n731 << 5 | self.n737
    self.n730 = ((self.n729 & 0x10000L) >> 16)
    self.n689 = self.n682 << 5 | self.n688
    self.n665 = self.n658 << 5 | self.n664
    self.n657 = ((self.n656 & 0x10000L) >> 16)
    self.n617 = self.n610 << 5 | self.n616
    self.n594 = self.n587 << 5 | self.n593
    self.n586 = ((self.n585 & 0x10000L) >> 16)
    self.n547 = self.n540 << 5 | self.n546
    self.n525 = self.n518 << 5 | self.n524
    self.n517 = ((self.n516 & 0x10000L) >> 16)
    self.n479 = self.n472 << 5 | self.n478
    self.n458 = self.n451 << 5 | self.n457
    self.n450 = ((self.n449 & 0x10000L) >> 16)
    self.n414 = self.n412 << 11 | self.n413
    self.n394 = self.n392 << 11 | self.n393
    self.n385 = ((self.n384 & 0x10000L) >> 16)
    self.n351 = (self.n296 - self.n349) & 0xFFFFL
    self.n350 = (self.n296 + self.n349) & 0xFFFFL
    self.n332 = (self.n278 - self.n330) & 0xFFFFL
    self.n331 = (self.n278 + self.n330) & 0xFFFFL
    self.n322 = ((self.n321 & 0x10000L) >> 16)
    self.n261 = ((self.n260 & 0x10000L) >> 16)
    self.n202 = ((self.n201 & 0x10000L) >> 16)
    self.n145 = ((self.n144 & 0x10000L) >> 16)
    self.n90 = ((self.n89 & 0x10000L) >> 16)
    self.n43 = ((self.n42 & 0x10000L) >> 16)
    if self.n1125:
      self.n1188 = self.n1186
    else:
      self.n1188 = self.n1187
    self.n1164 = self.n1156 << 6 | self.n1163
    self.n1155 = ~self.n1125 & 0x1L
    self.n1134 = self.n1126 << 6 | self.n1133
    if self.n1042:
      self.n1103 = self.n1101
    else:
      self.n1103 = self.n1102
    self.n1080 = self.n1072 << 6 | self.n1079
    self.n1071 = ~self.n1042 & 0x1L
    self.n1051 = self.n1043 << 6 | self.n1050
    if self.n961:
      self.n1020 = self.n1018
    else:
      self.n1020 = self.n1019
    self.n998 = self.n990 << 6 | self.n997
    self.n989 = ~self.n961 & 0x1L
    self.n970 = self.n962 << 6 | self.n969
    if self.n882:
      self.n939 = self.n937
    else:
      self.n939 = self.n938
    self.n918 = self.n910 << 6 | self.n917
    self.n909 = ~self.n882 & 0x1L
    self.n891 = self.n883 << 6 | self.n890
    if self.n805:
      self.n860 = self.n858
    else:
      self.n860 = self.n859
    self.n840 = self.n832 << 6 | self.n839
    self.n831 = ~self.n805 & 0x1L
    self.n814 = self.n806 << 6 | self.n813
    if self.n730:
      self.n783 = self.n781
    else:
      self.n783 = self.n782
    self.n764 = self.n756 << 6 | self.n763
    self.n755 = ~self.n730 & 0x1L
    self.n739 = self.n731 << 6 | self.n738
    if self.n657:
      self.n708 = self.n706
    else:
      self.n708 = self.n707
    self.n690 = self.n682 << 6 | self.n689
    self.n681 = ~self.n657 & 0x1L
    self.n666 = self.n658 << 6 | self.n665
    if self.n586:
      self.n635 = self.n633
    else:
      self.n635 = self.n634
    self.n618 = self.n610 << 6 | self.n617
    self.n609 = ~self.n586 & 0x1L
    self.n595 = self.n587 << 6 | self.n594
    if self.n517:
      self.n564 = self.n562
    else:
      self.n564 = self.n563
    self.n548 = self.n540 << 6 | self.n547
    self.n539 = ~self.n517 & 0x1L
    self.n526 = self.n518 << 6 | self.n525
    if self.n450:
      self.n495 = self.n493
    else:
      self.n495 = self.n494
    self.n481 = self.n479 << 10 | self.n480
    self.n471 = ~self.n450 & 0x1L
    self.n460 = self.n458 << 10 | self.n459
    if self.n385:
      self.n428 = self.n426
    else:
      self.n428 = self.n427
    self.n416 = (self.n359 - self.n414) & 0xFFFFL
    self.n415 = (self.n359 + self.n414) & 0xFFFFL
    self.n405 = ~self.n385 & 0x1L
    self.n396 = (self.n340 - self.n394) & 0xFFFFL
    self.n395 = (self.n340 + self.n394) & 0xFFFFL
    if self.n322:
      self.n363 = self.n361
    else:
      self.n363 = self.n362
    self.n341 = ~self.n322 & 0x1L
    if self.n322:
      self.n333 = self.n331
    else:
      self.n333 = self.n332
    if self.n261:
      self.n300 = self.n298
    else:
      self.n300 = self.n299
    self.n279 = ~self.n261 & 0x1L
    if self.n261:
      self.n271 = self.n269
    else:
      self.n271 = self.n270
    if self.n202:
      self.n239 = self.n237
    else:
      self.n239 = self.n238
    self.n219 = ~self.n202 & 0x1L
    if self.n202:
      self.n211 = self.n209
    else:
      self.n211 = self.n210
    if self.n145:
      self.n180 = self.n178
    else:
      self.n180 = self.n179
    self.n161 = ~self.n145 & 0x1L
    if self.n145:
      self.n153 = self.n151
    else:
      self.n153 = self.n152
    if self.n90:
      self.n123 = self.n121
    else:
      self.n123 = self.n122
    self.n105 = ~self.n90 & 0x1L
    if self.n90:
      self.n97 = self.n95
    else:
      self.n97 = self.n96
    if self.n43:
      self.n68 = self.n51
    else:
      self.n68 = self.n28
    if self.n43:
      self.n60 = self.n47
    else:
      self.n60 = self.n21
    if self.n43:
      self.n52 = self.n45
    else:
      self.n52 = self.n14
    self.n1195r = self.n4
    self.n1195e = self.n3
    self.n1195d = self.n1188
    self.n1165 = self.n1156 << 7 | self.n1164
    self.n1135 = self.n1126 << 7 | self.n1134
    self.n1110r = self.n4
    self.n1110e = self.n3
    self.n1110d = self.n1103
    self.n1081 = self.n1072 << 7 | self.n1080
    self.n1052 = self.n1043 << 7 | self.n1051
    self.n1027r = self.n4
    self.n1027e = self.n3
    self.n1027d = self.n1020
    self.n999 = self.n990 << 7 | self.n998
    self.n971 = self.n962 << 7 | self.n970
    self.n946r = self.n4
    self.n946e = self.n3
    self.n946d = self.n939
    self.n919 = self.n910 << 7 | self.n918
    self.n892 = self.n883 << 7 | self.n891
    self.n867r = self.n4
    self.n867e = self.n3
    self.n867d = self.n860
    self.n841 = self.n832 << 7 | self.n840
    self.n815 = self.n806 << 7 | self.n814
    self.n790r = self.n4
    self.n790e = self.n3
    self.n790d = self.n783
    self.n765 = self.n756 << 7 | self.n764
    self.n740 = self.n731 << 7 | self.n739
    self.n715r = self.n4
    self.n715e = self.n3
    self.n715d = self.n708
    self.n691 = self.n682 << 7 | self.n690
    self.n667 = self.n658 << 7 | self.n666
    self.n642r = self.n4
    self.n642e = self.n3
    self.n642d = self.n635
    self.n619 = self.n610 << 7 | self.n618
    self.n596 = self.n587 << 7 | self.n595
    self.n571r = self.n4
    self.n571e = self.n3
    self.n571d = self.n564
    self.n550 = self.n548 << 9 | self.n549
    self.n528 = self.n526 << 9 | self.n527
    self.n502r = self.n4
    self.n502e = self.n3
    self.n502d = self.n495
    self.n483 = (self.n424 - self.n481) & 0xFFFFL
    self.n482 = (self.n424 + self.n481) & 0xFFFFL
    self.n462 = (self.n404 - self.n460) & 0xFFFFL
    self.n461 = (self.n404 + self.n460) & 0xFFFFL
    self.n435r = self.n4
    self.n435e = self.n3
    self.n435d = self.n428
    if self.n405:
      self.n417 = self.n415
    else:
      self.n417 = self.n416
    if self.n385:
      self.n397 = self.n395
    else:
      self.n397 = self.n396
    self.n370r = self.n4
    self.n370e = self.n3
    self.n370d = self.n363
    if self.n341:
      self.n352 = self.n350
    else:
      self.n352 = self.n351
    self.n340r = self.n4
    self.n340e = self.n3
    self.n340d = self.n333
    self.n307r = self.n4
    self.n307e = self.n3
    self.n307d = self.n300
    if self.n279:
      self.n289 = self.n287
    else:
      self.n289 = self.n288
    self.n278r = self.n4
    self.n278e = self.n3
    self.n278d = self.n271
    self.n246r = self.n4
    self.n246e = self.n3
    self.n246d = self.n239
    if self.n219:
      self.n228 = self.n226
    else:
      self.n228 = self.n227
    self.n218r = self.n4
    self.n218e = self.n3
    self.n218d = self.n211
    self.n187r = self.n4
    self.n187e = self.n3
    self.n187d = self.n180
    if self.n161:
      self.n169 = self.n167
    else:
      self.n169 = self.n168
    self.n160r = self.n4
    self.n160e = self.n3
    self.n160d = self.n153
    self.n130r = self.n4
    self.n130e = self.n3
    self.n130d = self.n123
    if self.n105:
      self.n112 = self.n110
    else:
      self.n112 = self.n111
    self.n104r = self.n4
    self.n104e = self.n3
    self.n104d = self.n97
    self.n75r = self.n4
    self.n75e = self.n3
    self.n75d = self.n68
    self.n67r = self.n4
    self.n67e = self.n3
    self.n67d = self.n60
    self.n59r = self.n4
    self.n59e = self.n3
    self.n59d = self.n52
    self.n1166 = self.n1156 << 8 | self.n1165
    self.n1136 = self.n1126 << 8 | self.n1135
    self.n1082 = self.n1072 << 8 | self.n1081
    self.n1053 = self.n1043 << 8 | self.n1052
    self.n1000 = self.n990 << 8 | self.n999
    self.n972 = self.n962 << 8 | self.n971
    self.n920 = self.n910 << 8 | self.n919
    self.n893 = self.n883 << 8 | self.n892
    self.n842 = self.n832 << 8 | self.n841
    self.n816 = self.n806 << 8 | self.n815
    self.n766 = self.n756 << 8 | self.n765
    self.n741 = self.n731 << 8 | self.n740
    self.n692 = self.n682 << 8 | self.n691
    self.n668 = self.n658 << 8 | self.n667
    self.n621 = self.n619 << 8 | self.n620
    self.n598 = self.n596 << 8 | self.n597
    self.n552 = (self.n491 - self.n550) & 0xFFFFL
    self.n551 = (self.n491 + self.n550) & 0xFFFFL
    self.n530 = (self.n470 - self.n528) & 0xFFFFL
    self.n529 = (self.n470 + self.n528) & 0xFFFFL
    if self.n471:
      self.n484 = self.n482
    else:
      self.n484 = self.n483
    if self.n450:
      self.n463 = self.n461
    else:
      self.n463 = self.n462
    self.n424r = self.n4
    self.n424e = self.n3
    self.n424d = self.n417
    self.n404r = self.n4
    self.n404e = self.n3
    self.n404d = self.n397
    self.n359r = self.n4
    self.n359e = self.n3
    self.n359d = self.n352
    self.n296r = self.n4
    self.n296e = self.n3
    self.n296d = self.n289
    self.n235r = self.n4
    self.n235e = self.n3
    self.n235d = self.n228
    self.n176r = self.n4
    self.n176e = self.n3
    self.n176d = self.n169
    self.n119r = self.n4
    self.n119e = self.n3
    self.n119d = self.n112
    self.n1167 = self.n1156 << 9 | self.n1166
    self.n1137 = self.n1126 << 9 | self.n1136
    self.n1083 = self.n1072 << 9 | self.n1082
    self.n1054 = self.n1043 << 9 | self.n1053
    self.n1001 = self.n990 << 9 | self.n1000
    self.n973 = self.n962 << 9 | self.n972
    self.n921 = self.n910 << 9 | self.n920
    self.n894 = self.n883 << 9 | self.n893
    self.n843 = self.n832 << 9 | self.n842
    self.n817 = self.n806 << 9 | self.n816
    self.n767 = self.n756 << 9 | self.n766
    self.n742 = self.n731 << 9 | self.n741
    self.n694 = self.n692 << 7 | self.n693
    self.n670 = self.n668 << 7 | self.n669
    self.n623 = (self.n560 - self.n621) & 0xFFFFL
    self.n622 = (self.n560 + self.n621) & 0xFFFFL
    self.n600 = (self.n538 - self.n598) & 0xFFFFL
    self.n599 = (self.n538 + self.n598) & 0xFFFFL
    if self.n539:
      self.n553 = self.n551
    else:
      self.n553 = self.n552
    if self.n517:
      self.n531 = self.n529
    else:
      self.n531 = self.n530
    self.n491r = self.n4
    self.n491e = self.n3
    self.n491d = self.n484
    self.n470r = self.n4
    self.n470e = self.n3
    self.n470d = self.n463
    self.n1168 = self.n1156 << 10 | self.n1167
    self.n1138 = self.n1126 << 10 | self.n1137
    self.n1084 = self.n1072 << 10 | self.n1083
    self.n1055 = self.n1043 << 10 | self.n1054
    self.n1002 = self.n990 << 10 | self.n1001
    self.n974 = self.n962 << 10 | self.n973
    self.n922 = self.n910 << 10 | self.n921
    self.n895 = self.n883 << 10 | self.n894
    self.n844 = self.n832 << 10 | self.n843
    self.n818 = self.n806 << 10 | self.n817
    self.n769 = self.n767 << 6 | self.n768
    self.n744 = self.n742 << 6 | self.n743
    self.n696 = (self.n631 - self.n694) & 0xFFFFL
    self.n695 = (self.n631 + self.n694) & 0xFFFFL
    self.n672 = (self.n608 - self.n670) & 0xFFFFL
    self.n671 = (self.n608 + self.n670) & 0xFFFFL
    if self.n609:
      self.n624 = self.n622
    else:
      self.n624 = self.n623
    if self.n586:
      self.n601 = self.n599
    else:
      self.n601 = self.n600
    self.n560r = self.n4
    self.n560e = self.n3
    self.n560d = self.n553
    self.n538r = self.n4
    self.n538e = self.n3
    self.n538d = self.n531
    self.n1169 = self.n1156 << 11 | self.n1168
    self.n1139 = self.n1126 << 11 | self.n1138
    self.n1085 = self.n1072 << 11 | self.n1084
    self.n1056 = self.n1043 << 11 | self.n1055
    self.n1003 = self.n990 << 11 | self.n1002
    self.n975 = self.n962 << 11 | self.n974
    self.n923 = self.n910 << 11 | self.n922
    self.n896 = self.n883 << 11 | self.n895
    self.n846 = self.n844 << 5 | self.n845
    self.n820 = self.n818 << 5 | self.n819
    self.n771 = (self.n704 - self.n769) & 0xFFFFL
    self.n770 = (self.n704 + self.n769) & 0xFFFFL
    self.n746 = (self.n680 - self.n744) & 0xFFFFL
    self.n745 = (self.n680 + self.n744) & 0xFFFFL
    if self.n681:
      self.n697 = self.n695
    else:
      self.n697 = self.n696
    if self.n657:
      self.n673 = self.n671
    else:
      self.n673 = self.n672
    self.n631r = self.n4
    self.n631e = self.n3
    self.n631d = self.n624
    self.n608r = self.n4
    self.n608e = self.n3
    self.n608d = self.n601
    self.n1170 = self.n1156 << 12 | self.n1169
    self.n1140 = self.n1126 << 12 | self.n1139
    self.n1086 = self.n1072 << 12 | self.n1085
    self.n1057 = self.n1043 << 12 | self.n1056
    self.n1004 = self.n990 << 12 | self.n1003
    self.n976 = self.n962 << 12 | self.n975
    self.n925 = self.n923 << 4 | self.n924
    self.n898 = self.n896 << 4 | self.n897
    self.n848 = (self.n779 - self.n846) & 0xFFFFL
    self.n847 = (self.n779 + self.n846) & 0xFFFFL
    self.n822 = (self.n754 - self.n820) & 0xFFFFL
    self.n821 = (self.n754 + self.n820) & 0xFFFFL
    if self.n755:
      self.n772 = self.n770
    else:
      self.n772 = self.n771
    if self.n730:
      self.n747 = self.n745
    else:
      self.n747 = self.n746
    self.n704r = self.n4
    self.n704e = self.n3
    self.n704d = self.n697
    self.n680r = self.n4
    self.n680e = self.n3
    self.n680d = self.n673
    self.n1171 = self.n1156 << 13 | self.n1170
    self.n1141 = self.n1126 << 13 | self.n1140
    self.n1087 = self.n1072 << 13 | self.n1086
    self.n1058 = self.n1043 << 13 | self.n1057
    self.n1006 = self.n1004 << 3 | self.n1005
    self.n978 = self.n976 << 3 | self.n977
    self.n927 = (self.n856 - self.n925) & 0xFFFFL
    self.n926 = (self.n856 + self.n925) & 0xFFFFL
    self.n900 = (self.n830 - self.n898) & 0xFFFFL
    self.n899 = (self.n830 + self.n898) & 0xFFFFL
    if self.n831:
      self.n849 = self.n847
    else:
      self.n849 = self.n848
    if self.n805:
      self.n823 = self.n821
    else:
      self.n823 = self.n822
    self.n779r = self.n4
    self.n779e = self.n3
    self.n779d = self.n772
    self.n754r = self.n4
    self.n754e = self.n3
    self.n754d = self.n747
    self.n1172 = self.n1156 << 14 | self.n1171
    self.n1142 = self.n1126 << 14 | self.n1141
    self.n1089 = self.n1087 << 2 | self.n1088
    self.n1060 = self.n1058 << 2 | self.n1059
    self.n1008 = (self.n935 - self.n1006) & 0xFFFFL
    self.n1007 = (self.n935 + self.n1006) & 0xFFFFL
    self.n980 = (self.n908 - self.n978) & 0xFFFFL
    self.n979 = (self.n908 + self.n978) & 0xFFFFL
    if self.n909:
      self.n928 = self.n926
    else:
      self.n928 = self.n927
    if self.n882:
      self.n901 = self.n899
    else:
      self.n901 = self.n900
    self.n856r = self.n4
    self.n856e = self.n3
    self.n856d = self.n849
    self.n830r = self.n4
    self.n830e = self.n3
    self.n830d = self.n823
    self.n1174 = self.n1172 << 1 | self.n1173
    self.n1144 = self.n1142 << 1 | self.n1143
    self.n1091 = (self.n1016 - self.n1089) & 0xFFFFL
    self.n1090 = (self.n1016 + self.n1089) & 0xFFFFL
    self.n1062 = (self.n988 - self.n1060) & 0xFFFFL
    self.n1061 = (self.n988 + self.n1060) & 0xFFFFL
    if self.n989:
      self.n1009 = self.n1007
    else:
      self.n1009 = self.n1008
    if self.n961:
      self.n981 = self.n979
    else:
      self.n981 = self.n980
    self.n935r = self.n4
    self.n935e = self.n3
    self.n935d = self.n928
    self.n908r = self.n4
    self.n908e = self.n3
    self.n908d = self.n901
    self.n1176 = (self.n1099 - self.n1174) & 0xFFFFL
    self.n1175 = (self.n1099 + self.n1174) & 0xFFFFL
    self.n1146 = (self.n1070 - self.n1144) & 0xFFFFL
    self.n1145 = (self.n1070 + self.n1144) & 0xFFFFL
    if self.n1071:
      self.n1092 = self.n1090
    else:
      self.n1092 = self.n1091
    if self.n1042:
      self.n1063 = self.n1061
    else:
      self.n1063 = self.n1062
    self.n1016r = self.n4
    self.n1016e = self.n3
    self.n1016d = self.n1009
    self.n988r = self.n4
    self.n988e = self.n3
    self.n988d = self.n981
    if self.n1155:
      self.n1177 = self.n1175
    else:
      self.n1177 = self.n1176
    if self.n1125:
      self.n1147 = self.n1145
    else:
      self.n1147 = self.n1146
    self.n1099r = self.n4
    self.n1099e = self.n3
    self.n1099d = self.n1092
    self.n1070r = self.n4
    self.n1070e = self.n3
    self.n1070d = self.n1063
    self.n1184r = self.n4
    self.n1184e = self.n3
    self.n1184d = self.n1177
    self.n1154r = self.n4
    self.n1154e = self.n3
    self.n1154d = self.n1147
    return (real_o, imag_o, ang_o, )

  def cycle_clock(self):
    if self.n14r:
      self.n14 = 0L
    elif self.n14e:
        self.n14 = self.n14d
    if self.n21r:
      self.n21 = 0L
    elif self.n21e:
        self.n21 = self.n21d
    if self.n28r:
      self.n28 = 0L
    elif self.n28e:
        self.n28 = self.n28d
    if self.n59r:
      self.n59 = 0L
    elif self.n59e:
        self.n59 = self.n59d
    if self.n67r:
      self.n67 = 0L
    elif self.n67e:
        self.n67 = self.n67d
    if self.n75r:
      self.n75 = 0L
    elif self.n75e:
        self.n75 = self.n75d
    if self.n104r:
      self.n104 = 0L
    elif self.n104e:
        self.n104 = self.n104d
    if self.n119r:
      self.n119 = 0L
    elif self.n119e:
        self.n119 = self.n119d
    if self.n130r:
      self.n130 = 0L
    elif self.n130e:
        self.n130 = self.n130d
    if self.n160r:
      self.n160 = 0L
    elif self.n160e:
        self.n160 = self.n160d
    if self.n176r:
      self.n176 = 0L
    elif self.n176e:
        self.n176 = self.n176d
    if self.n187r:
      self.n187 = 0L
    elif self.n187e:
        self.n187 = self.n187d
    if self.n218r:
      self.n218 = 0L
    elif self.n218e:
        self.n218 = self.n218d
    if self.n235r:
      self.n235 = 0L
    elif self.n235e:
        self.n235 = self.n235d
    if self.n246r:
      self.n246 = 0L
    elif self.n246e:
        self.n246 = self.n246d
    if self.n278r:
      self.n278 = 0L
    elif self.n278e:
        self.n278 = self.n278d
    if self.n296r:
      self.n296 = 0L
    elif self.n296e:
        self.n296 = self.n296d
    if self.n307r:
      self.n307 = 0L
    elif self.n307e:
        self.n307 = self.n307d
    if self.n340r:
      self.n340 = 0L
    elif self.n340e:
        self.n340 = self.n340d
    if self.n359r:
      self.n359 = 0L
    elif self.n359e:
        self.n359 = self.n359d
    if self.n370r:
      self.n370 = 0L
    elif self.n370e:
        self.n370 = self.n370d
    if self.n404r:
      self.n404 = 0L
    elif self.n404e:
        self.n404 = self.n404d
    if self.n424r:
      self.n424 = 0L
    elif self.n424e:
        self.n424 = self.n424d
    if self.n435r:
      self.n435 = 0L
    elif self.n435e:
        self.n435 = self.n435d
    if self.n470r:
      self.n470 = 0L
    elif self.n470e:
        self.n470 = self.n470d
    if self.n491r:
      self.n491 = 0L
    elif self.n491e:
        self.n491 = self.n491d
    if self.n502r:
      self.n502 = 0L
    elif self.n502e:
        self.n502 = self.n502d
    if self.n538r:
      self.n538 = 0L
    elif self.n538e:
        self.n538 = self.n538d
    if self.n560r:
      self.n560 = 0L
    elif self.n560e:
        self.n560 = self.n560d
    if self.n571r:
      self.n571 = 0L
    elif self.n571e:
        self.n571 = self.n571d
    if self.n608r:
      self.n608 = 0L
    elif self.n608e:
        self.n608 = self.n608d
    if self.n631r:
      self.n631 = 0L
    elif self.n631e:
        self.n631 = self.n631d
    if self.n642r:
      self.n642 = 0L
    elif self.n642e:
        self.n642 = self.n642d
    if self.n680r:
      self.n680 = 0L
    elif self.n680e:
        self.n680 = self.n680d
    if self.n704r:
      self.n704 = 0L
    elif self.n704e:
        self.n704 = self.n704d
    if self.n715r:
      self.n715 = 0L
    elif self.n715e:
        self.n715 = self.n715d
    if self.n754r:
      self.n754 = 0L
    elif self.n754e:
        self.n754 = self.n754d
    if self.n779r:
      self.n779 = 0L
    elif self.n779e:
        self.n779 = self.n779d
    if self.n790r:
      self.n790 = 0L
    elif self.n790e:
        self.n790 = self.n790d
    if self.n830r:
      self.n830 = 0L
    elif self.n830e:
        self.n830 = self.n830d
    if self.n856r:
      self.n856 = 0L
    elif self.n856e:
        self.n856 = self.n856d
    if self.n867r:
      self.n867 = 0L
    elif self.n867e:
        self.n867 = self.n867d
    if self.n908r:
      self.n908 = 0L
    elif self.n908e:
        self.n908 = self.n908d
    if self.n935r:
      self.n935 = 0L
    elif self.n935e:
        self.n935 = self.n935d
    if self.n946r:
      self.n946 = 0L
    elif self.n946e:
        self.n946 = self.n946d
    if self.n988r:
      self.n988 = 0L
    elif self.n988e:
        self.n988 = self.n988d
    if self.n1016r:
      self.n1016 = 0L
    elif self.n1016e:
        self.n1016 = self.n1016d
    if self.n1027r:
      self.n1027 = 0L
    elif self.n1027e:
        self.n1027 = self.n1027d
    if self.n1070r:
      self.n1070 = 0L
    elif self.n1070e:
        self.n1070 = self.n1070d
    if self.n1099r:
      self.n1099 = 0L
    elif self.n1099e:
        self.n1099 = self.n1099d
    if self.n1110r:
      self.n1110 = 0L
    elif self.n1110e:
        self.n1110 = self.n1110d
    if self.n1154r:
      self.n1154 = 0L
    elif self.n1154e:
        self.n1154 = self.n1154d
    if self.n1184r:
      self.n1184 = 0L
    elif self.n1184e:
        self.n1184 = self.n1184d
    if self.n1195r:
      self.n1195 = 0L
    elif self.n1195e:
        self.n1195 = self.n1195d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n3 = self.n3
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6 = self.n6
    self.sim_n7 = self.n7
    self.sim_n1196 = self.n1196
    self.sim_n1197 = self.n1197
    self.sim_n1198 = self.n1198
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_cordic_v_16_16_16 $end\n")
    self.sim_file.write("$var wire 1 ! enable_i $end\n")
    self.sim_file.write("$var wire 1 \" reset_i $end\n")
    self.sim_file.write("$var wire 16 # real_i $end\n")
    self.sim_file.write("$var wire 16 $ imag_i $end\n")
    self.sim_file.write("$var wire 16 % ang_i $end\n")
    self.sim_file.write("$var wire 16 & real_o $end\n")
    self.sim_file.write("$var wire 16 ' imag_o $end\n")
    self.sim_file.write("$var wire 16 ( ang_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n3:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    if self.n4:
      self.sim_file.write("1\"\n")
    else:
      self.sim_file.write("0\"\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" #\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n6 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n7 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n7 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n1196 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n1196 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" &\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n1197 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n1197 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n1198 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n1198 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" (\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n3 = self.n3
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n4:
        self.sim_file.write("1\"\n")
      else:
        self.sim_file.write("0\"\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" #\n")
      self.sim_n5 = self.n5
    if self.sim_n6 != self.n6:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n6 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n6 = self.n6
    if self.sim_n7 != self.n7:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n7 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n7 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n7 = self.n7
    if self.sim_n1196 != self.n1196:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n1196 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n1196 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" &\n")
      self.sim_n1196 = self.n1196
    if self.sim_n1197 != self.n1197:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n1197 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n1197 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n1197 = self.n1197
    if self.sim_n1198 != self.n1198:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n1198 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n1198 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" (\n")
      self.sim_n1198 = self.n1198
    self.sim_count = self.sim_count + 1

