//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Cordics (COordinate Rotation DIgital Computers) are used to calculate
//    trigonometric functions and complex plane phase rotations.
//    This vector mode cordic rotates any complex vector to the positive real axis.
//    The resulting angle is the initial angle plus the angle of rotation.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      enable_i : Synchronous enable.
//      reset_i  : Synchronous reset.
//  
//    Inputs:
//      real_i   : Initial real component (signed).
//      imag_i   : Initial imaginary component (signed).
//      angle_i  : Initial angle (modulo 2PI).
//  
//    Outputs:
//      real_o   : Resulting real component (signed).
//      imag_o   : Resulting imaginary component (signed).
//      angle_o  : Resulting angle (modulo 2PI).
//  
//  Built In Parameters:
//  
//    Cordic Mode    = Vector
//    Vector Width   = 8
//    Angle Width    = 8
//    Cordic Stages  = 8
//  
//  Resulting Pipeline Latency is 10 clock cycles.
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:44:19 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_cordic_v_8_8_8
//    Clock Domains : clock_c  
//    Vector Input  : enable_i(1)
//    Vector Input  : reset_i(1)
//    Vector Input  : real_i(8)
//    Vector Input  : imag_i(8)
//    Vector Input  : ang_i(8)
//    Vector Output : real_o(8)
//    Vector Output : imag_o(8)
//    Vector Output : ang_o(8)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_cordic_v_8_8_8.h"

static unsigned char n632[2];
static unsigned char n630[2];
static unsigned char n628[2];
static unsigned char n626[2];
static unsigned char n624[2];
static unsigned char n622[2];
static unsigned char n620[2];
static unsigned char n618[2];
static unsigned char n616[2];
static unsigned char n579[1];
static unsigned char *ang_o;
static unsigned char *imag_o;
static unsigned char *real_o;
static unsigned char n561[1];
static unsigned char n549[1];
static unsigned char n540[1];
static unsigned char n527[1];
static unsigned char n518[1];
static unsigned char n514[1];
static unsigned char n506[1];
static unsigned char n504[1];
static unsigned char n492[1];
static unsigned char n480[1];
static unsigned char n472[1];
static unsigned char n459[1];
static unsigned char n451[1];
static unsigned char n447[1];
static unsigned char n439[1];
static unsigned char n437[1];
static unsigned char n425[1];
static unsigned char n413[1];
static unsigned char n406[1];
static unsigned char n393[1];
static unsigned char n386[1];
static unsigned char n382[1];
static unsigned char n374[1];
static unsigned char n372[1];
static unsigned char n360[1];
static unsigned char n348[1];
static unsigned char n342[1];
static unsigned char n329[1];
static unsigned char n323[1];
static unsigned char n319[1];
static unsigned char n311[1];
static unsigned char n309[1];
static unsigned char n297[1];
static unsigned char n285[1];
static unsigned char n280[1];
static unsigned char n267[1];
static unsigned char n262[1];
static unsigned char n258[1];
static unsigned char n250[1];
static unsigned char n248[1];
static unsigned char n236[1];
static unsigned char n224[1];
static unsigned char n220[1];
static unsigned char n207[1];
static unsigned char n203[1];
static unsigned char n199[1];
static unsigned char n191[1];
static unsigned char n189[1];
static unsigned char n177[1];
static unsigned char n165[1];
static unsigned char n162[1];
static unsigned char n149[1];
static unsigned char n146[1];
static unsigned char n142[1];
static unsigned char n134[1];
static unsigned char n132[1];
static unsigned char n120[1];
static unsigned char n108[1];
static unsigned char n93[1];
static unsigned char n87[1];
static unsigned char n79[1];
static unsigned char n77[1];
static unsigned char n46[1];
static unsigned char n44[1];
static unsigned char n38[1];
static unsigned char n32[1];
static unsigned char n30[1];
static unsigned char *ang_i;
static unsigned char *imag_i;
static unsigned char *real_i;
static unsigned char *reset_i;
static unsigned char *enable_i;
static unsigned char n563[1];
static unsigned char n562[1];
static unsigned char n543[1];
static unsigned char n521[1];
static unsigned char n505[1];
static unsigned char n494[1];
static unsigned char n493[1];
static unsigned char n475[1];
static unsigned char n454[1];
static unsigned char n438[1];
static unsigned char n427[1];
static unsigned char n426[1];
static unsigned char n409[1];
static unsigned char n389[1];
static unsigned char n373[1];
static unsigned char n362[1];
static unsigned char n361[1];
static unsigned char n345[1];
static unsigned char n326[1];
static unsigned char n310[1];
static unsigned char n299[1];
static unsigned char n298[1];
static unsigned char n283[1];
static unsigned char n265[1];
static unsigned char n249[1];
static unsigned char n238[1];
static unsigned char n237[1];
static unsigned char n223[1];
static unsigned char n206[1];
static unsigned char n190[1];
static unsigned char n179[1];
static unsigned char n178[1];
static unsigned char n166[1];
static unsigned char n150[1];
static unsigned char n133[1];
static unsigned char n122[1];
static unsigned char n121[1];
static unsigned char n111[1];
static unsigned char n110[1];
static unsigned char n96[1];
static unsigned char n95[1];
static unsigned char n78[1];
static unsigned char n51[1];
static unsigned char n47[1];
static unsigned char n45[1];
static unsigned char n31[1];
static unsigned char n28[1];
static unsigned char n28r[1];
static unsigned char n28e[1];
static unsigned char n28d[1];
static unsigned char n21[1];
static unsigned char n21r[1];
static unsigned char n21e[1];
static unsigned char n21d[1];
static unsigned char n14[1];
static unsigned char n14r[1];
static unsigned char n14e[1];
static unsigned char n14d[1];
static unsigned char n544[1];
static unsigned char n522[1];
static unsigned char n507[1];
static unsigned char n476[1];
static unsigned char n455[1];
static unsigned char n440[1];
static unsigned char n410[1];
static unsigned char n390[1];
static unsigned char n375[1];
static unsigned char n346[1];
static unsigned char n327[1];
static unsigned char n312[1];
static unsigned char n284[1];
static unsigned char n266[1];
static unsigned char n251[1];
static unsigned char n225[1];
static unsigned char n208[1];
static unsigned char n192[1];
static unsigned char n168[1];
static unsigned char n167[1];
static unsigned char n152[1];
static unsigned char n151[1];
static unsigned char n135[1];
static unsigned char n80[1];
static unsigned char n33[1];
static unsigned char n545[1];
static unsigned char n523[1];
static unsigned char n515[2];
static unsigned char n477[1];
static unsigned char n456[1];
static unsigned char n448[2];
static unsigned char n411[1];
static unsigned char n391[1];
static unsigned char n383[2];
static unsigned char n347[1];
static unsigned char n328[1];
static unsigned char n320[2];
static unsigned char n286[1];
static unsigned char n268[1];
static unsigned char n259[2];
static unsigned char n227[1];
static unsigned char n226[1];
static unsigned char n210[1];
static unsigned char n209[1];
static unsigned char n200[2];
static unsigned char n143[2];
static unsigned char n88[2];
static unsigned char n39[2];
static unsigned char n546[1];
static unsigned char n524[1];
static unsigned char n516[2];
static unsigned char n478[1];
static unsigned char n457[1];
static unsigned char n449[2];
static unsigned char n412[1];
static unsigned char n392[1];
static unsigned char n384[2];
static unsigned char n349[1];
static unsigned char n330[1];
static unsigned char n321[2];
static unsigned char n288[1];
static unsigned char n287[1];
static unsigned char n270[1];
static unsigned char n269[1];
static unsigned char n260[2];
static unsigned char n201[2];
static unsigned char n144[2];
static unsigned char n89[2];
static unsigned char n42[2];
static unsigned char n547[1];
static unsigned char n525[1];
static unsigned char n517[1];
static unsigned char n479[1];
static unsigned char n458[1];
static unsigned char n450[1];
static unsigned char n414[1];
static unsigned char n394[1];
static unsigned char n385[1];
static unsigned char n351[1];
static unsigned char n350[1];
static unsigned char n332[1];
static unsigned char n331[1];
static unsigned char n322[1];
static unsigned char n261[1];
static unsigned char n202[1];
static unsigned char n145[1];
static unsigned char n90[1];
static unsigned char n43[1];
static unsigned char n564[1];
static unsigned char n548[1];
static unsigned char n539[1];
static unsigned char n526[1];
static unsigned char n495[1];
static unsigned char n481[1];
static unsigned char n471[1];
static unsigned char n460[1];
static unsigned char n428[1];
static unsigned char n416[1];
static unsigned char n415[1];
static unsigned char n405[1];
static unsigned char n396[1];
static unsigned char n395[1];
static unsigned char n363[1];
static unsigned char n341[1];
static unsigned char n333[1];
static unsigned char n300[1];
static unsigned char n279[1];
static unsigned char n271[1];
static unsigned char n239[1];
static unsigned char n219[1];
static unsigned char n211[1];
static unsigned char n180[1];
static unsigned char n161[1];
static unsigned char n153[1];
static unsigned char n123[1];
static unsigned char n105[1];
static unsigned char n97[1];
static unsigned char n68[1];
static unsigned char n60[1];
static unsigned char n52[1];
static unsigned char n571[1];
static unsigned char n571r[1];
static unsigned char n571e[1];
static unsigned char n571d[1];
static unsigned char n550[1];
static unsigned char n528[1];
static unsigned char n502[1];
static unsigned char n502r[1];
static unsigned char n502e[1];
static unsigned char n502d[1];
static unsigned char n483[1];
static unsigned char n482[1];
static unsigned char n462[1];
static unsigned char n461[1];
static unsigned char n435[1];
static unsigned char n435r[1];
static unsigned char n435e[1];
static unsigned char n435d[1];
static unsigned char n417[1];
static unsigned char n397[1];
static unsigned char n370[1];
static unsigned char n370r[1];
static unsigned char n370e[1];
static unsigned char n370d[1];
static unsigned char n352[1];
static unsigned char n340[1];
static unsigned char n340r[1];
static unsigned char n340e[1];
static unsigned char n340d[1];
static unsigned char n307[1];
static unsigned char n307r[1];
static unsigned char n307e[1];
static unsigned char n307d[1];
static unsigned char n289[1];
static unsigned char n278[1];
static unsigned char n278r[1];
static unsigned char n278e[1];
static unsigned char n278d[1];
static unsigned char n246[1];
static unsigned char n246r[1];
static unsigned char n246e[1];
static unsigned char n246d[1];
static unsigned char n228[1];
static unsigned char n218[1];
static unsigned char n218r[1];
static unsigned char n218e[1];
static unsigned char n218d[1];
static unsigned char n187[1];
static unsigned char n187r[1];
static unsigned char n187e[1];
static unsigned char n187d[1];
static unsigned char n169[1];
static unsigned char n160[1];
static unsigned char n160r[1];
static unsigned char n160e[1];
static unsigned char n160d[1];
static unsigned char n130[1];
static unsigned char n130r[1];
static unsigned char n130e[1];
static unsigned char n130d[1];
static unsigned char n112[1];
static unsigned char n104[1];
static unsigned char n104r[1];
static unsigned char n104e[1];
static unsigned char n104d[1];
static unsigned char n75[1];
static unsigned char n75r[1];
static unsigned char n75e[1];
static unsigned char n75d[1];
static unsigned char n67[1];
static unsigned char n67r[1];
static unsigned char n67e[1];
static unsigned char n67d[1];
static unsigned char n59[1];
static unsigned char n59r[1];
static unsigned char n59e[1];
static unsigned char n59d[1];
static unsigned char n552[1];
static unsigned char n551[1];
static unsigned char n530[1];
static unsigned char n529[1];
static unsigned char n484[1];
static unsigned char n463[1];
static unsigned char n424[1];
static unsigned char n424r[1];
static unsigned char n424e[1];
static unsigned char n424d[1];
static unsigned char n404[1];
static unsigned char n404r[1];
static unsigned char n404e[1];
static unsigned char n404d[1];
static unsigned char n359[1];
static unsigned char n359r[1];
static unsigned char n359e[1];
static unsigned char n359d[1];
static unsigned char n296[1];
static unsigned char n296r[1];
static unsigned char n296e[1];
static unsigned char n296d[1];
static unsigned char n235[1];
static unsigned char n235r[1];
static unsigned char n235e[1];
static unsigned char n235d[1];
static unsigned char n176[1];
static unsigned char n176r[1];
static unsigned char n176e[1];
static unsigned char n176d[1];
static unsigned char n119[1];
static unsigned char n119r[1];
static unsigned char n119e[1];
static unsigned char n119d[1];
static unsigned char n553[1];
static unsigned char n531[1];
static unsigned char n491[1];
static unsigned char n491r[1];
static unsigned char n491e[1];
static unsigned char n491d[1];
static unsigned char n470[1];
static unsigned char n470r[1];
static unsigned char n470e[1];
static unsigned char n470d[1];
static unsigned char n560[1];
static unsigned char n560r[1];
static unsigned char n560e[1];
static unsigned char n560d[1];
static unsigned char n538[1];
static unsigned char n538r[1];
static unsigned char n538e[1];
static unsigned char n538d[1];

void cf_cordic_v_8_8_8_ports(unsigned char* port_enable_i, unsigned char* port_reset_i, unsigned char* port_real_i, unsigned char* port_imag_i, unsigned char* port_ang_i, unsigned char* port_real_o, unsigned char* port_imag_o, unsigned char* port_ang_o) {
  enable_i = port_enable_i;
  reset_i = port_reset_i;
  real_i = port_real_i;
  imag_i = port_imag_i;
  ang_i = port_ang_i;
  real_o = port_real_o;
  imag_o = port_imag_o;
  ang_o = port_ang_o;
}

void cf_cordic_v_8_8_8_calc() {
  n632[0] = 128;
  n632[1] = 0;
  n630[0] = 128;
  n630[1] = 0;
  n628[0] = 128;
  n628[1] = 0;
  n626[0] = 128;
  n626[1] = 0;
  n624[0] = 128;
  n624[1] = 0;
  n622[0] = 128;
  n622[1] = 0;
  n620[0] = 128;
  n620[1] = 0;
  n618[0] = 128;
  n618[1] = 0;
  n616[0] = 128;
  n616[1] = 0;
  n579[0] = 128;
  ang_o[0] = n571[0];
  imag_o[0] = n560[0];
  real_o[0] = n538[0];
  n561[0] = 0;
  n549[0] = (1 & (n470[0] >> 7));
  n540[0] = (1 & (n470[0] >> 7));
  n527[0] = (1 & (n491[0] >> 7));
  n518[0] = (1 & (n491[0] >> 7));
  n514[0] = 0;
  n506[0] = (1 & (n491[0])) | (2 & (n491[0])) | (4 & (n491[0])) | (8 & (n491[0])) | (16 & (n491[0])) | (32 & (n491[0])) | (64 & (n491[0]));
  n504[0] = (1 & (n491[0] >> 7));
  n492[0] = 1;
  n480[0] = (1 & (n404[0] >> 6)) | (2 & (n404[0] >> 6));
  n472[0] = (1 & (n404[0] >> 7));
  n459[0] = (1 & (n424[0] >> 6)) | (2 & (n424[0] >> 6));
  n451[0] = (1 & (n424[0] >> 7));
  n447[0] = 0;
  n439[0] = (1 & (n424[0])) | (2 & (n424[0])) | (4 & (n424[0])) | (8 & (n424[0])) | (16 & (n424[0])) | (32 & (n424[0])) | (64 & (n424[0]));
  n437[0] = (1 & (n424[0] >> 7));
  n425[0] = 1;
  n413[0] = (1 & (n340[0] >> 5)) | (2 & (n340[0] >> 5)) | (4 & (n340[0] >> 5));
  n406[0] = (1 & (n340[0] >> 7));
  n393[0] = (1 & (n359[0] >> 5)) | (2 & (n359[0] >> 5)) | (4 & (n359[0] >> 5));
  n386[0] = (1 & (n359[0] >> 7));
  n382[0] = 0;
  n374[0] = (1 & (n359[0])) | (2 & (n359[0])) | (4 & (n359[0])) | (8 & (n359[0])) | (16 & (n359[0])) | (32 & (n359[0])) | (64 & (n359[0]));
  n372[0] = (1 & (n359[0] >> 7));
  n360[0] = 3;
  n348[0] = (1 & (n278[0] >> 4)) | (2 & (n278[0] >> 4)) | (4 & (n278[0] >> 4)) | (8 & (n278[0] >> 4));
  n342[0] = (1 & (n278[0] >> 7));
  n329[0] = (1 & (n296[0] >> 4)) | (2 & (n296[0] >> 4)) | (4 & (n296[0] >> 4)) | (8 & (n296[0] >> 4));
  n323[0] = (1 & (n296[0] >> 7));
  n319[0] = 0;
  n311[0] = (1 & (n296[0])) | (2 & (n296[0])) | (4 & (n296[0])) | (8 & (n296[0])) | (16 & (n296[0])) | (32 & (n296[0])) | (64 & (n296[0]));
  n309[0] = (1 & (n296[0] >> 7));
  n297[0] = 5;
  n285[0] = (1 & (n218[0] >> 3)) | (2 & (n218[0] >> 3)) | (4 & (n218[0] >> 3)) | (8 & (n218[0] >> 3)) | (16 & (n218[0] >> 3));
  n280[0] = (1 & (n218[0] >> 7));
  n267[0] = (1 & (n235[0] >> 3)) | (2 & (n235[0] >> 3)) | (4 & (n235[0] >> 3)) | (8 & (n235[0] >> 3)) | (16 & (n235[0] >> 3));
  n262[0] = (1 & (n235[0] >> 7));
  n258[0] = 0;
  n250[0] = (1 & (n235[0])) | (2 & (n235[0])) | (4 & (n235[0])) | (8 & (n235[0])) | (16 & (n235[0])) | (32 & (n235[0])) | (64 & (n235[0]));
  n248[0] = (1 & (n235[0] >> 7));
  n236[0] = 10;
  n224[0] = (1 & (n160[0] >> 2)) | (2 & (n160[0] >> 2)) | (4 & (n160[0] >> 2)) | (8 & (n160[0] >> 2)) | (16 & (n160[0] >> 2)) | (32 & (n160[0] >> 2));
  n220[0] = (1 & (n160[0] >> 7));
  n207[0] = (1 & (n176[0] >> 2)) | (2 & (n176[0] >> 2)) | (4 & (n176[0] >> 2)) | (8 & (n176[0] >> 2)) | (16 & (n176[0] >> 2)) | (32 & (n176[0] >> 2));
  n203[0] = (1 & (n176[0] >> 7));
  n199[0] = 0;
  n191[0] = (1 & (n176[0])) | (2 & (n176[0])) | (4 & (n176[0])) | (8 & (n176[0])) | (16 & (n176[0])) | (32 & (n176[0])) | (64 & (n176[0]));
  n189[0] = (1 & (n176[0] >> 7));
  n177[0] = 19;
  n165[0] = (1 & (n104[0] >> 1)) | (2 & (n104[0] >> 1)) | (4 & (n104[0] >> 1)) | (8 & (n104[0] >> 1)) | (16 & (n104[0] >> 1)) | (32 & (n104[0] >> 1)) | (64 & (n104[0] >> 1));
  n162[0] = (1 & (n104[0] >> 7));
  n149[0] = (1 & (n119[0] >> 1)) | (2 & (n119[0] >> 1)) | (4 & (n119[0] >> 1)) | (8 & (n119[0] >> 1)) | (16 & (n119[0] >> 1)) | (32 & (n119[0] >> 1)) | (64 & (n119[0] >> 1));
  n146[0] = (1 & (n119[0] >> 7));
  n142[0] = 0;
  n134[0] = (1 & (n119[0])) | (2 & (n119[0])) | (4 & (n119[0])) | (8 & (n119[0])) | (16 & (n119[0])) | (32 & (n119[0])) | (64 & (n119[0]));
  n132[0] = (1 & (n119[0] >> 7));
  n120[0] = 32;
  n108[0] = (1 & (n59[0])) | (2 & (n59[0])) | (4 & (n59[0])) | (8 & (n59[0])) | (16 & (n59[0])) | (32 & (n59[0])) | (64 & (n59[0])) | (128 & (n59[0]));
  n93[0] = (1 & (n67[0])) | (2 & (n67[0])) | (4 & (n67[0])) | (8 & (n67[0])) | (16 & (n67[0])) | (32 & (n67[0])) | (64 & (n67[0])) | (128 & (n67[0]));
  n87[0] = 0;
  n79[0] = (1 & (n67[0])) | (2 & (n67[0])) | (4 & (n67[0])) | (8 & (n67[0])) | (16 & (n67[0])) | (32 & (n67[0])) | (64 & (n67[0]));
  n77[0] = (1 & (n67[0] >> 7));
  n46[0] = 0;
  n44[0] = 0;
  n38[0] = 0;
  n32[0] = (1 & (n14[0])) | (2 & (n14[0])) | (4 & (n14[0])) | (8 & (n14[0])) | (16 & (n14[0])) | (32 & (n14[0])) | (64 & (n14[0]));
  n30[0] = (1 & (n14[0] >> 7));
  { unsigned int tmp; (tmp = (unsigned int) n502[0] - (unsigned int) n561[0], n563[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n502[0] + (unsigned int) n561[0], n562[0] = 255 & (unsigned char) tmp); }
  n543[0] = 255 & (n540[0] << 1 | n540[0]);
  n521[0] = 255 & (n518[0] << 1 | n518[0]);
  n505[0] = 1 & ~n504[0];
  { unsigned int tmp; (tmp = (unsigned int) n435[0] - (unsigned int) n492[0], n494[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n435[0] + (unsigned int) n492[0], n493[0] = 255 & (unsigned char) tmp); }
  n475[0] = 255 & (n472[0] << 1 | n472[0]);
  n454[0] = 255 & (n451[0] << 1 | n451[0]);
  n438[0] = 1 & ~n437[0];
  { unsigned int tmp; (tmp = (unsigned int) n370[0] - (unsigned int) n425[0], n427[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n370[0] + (unsigned int) n425[0], n426[0] = 255 & (unsigned char) tmp); }
  n409[0] = 255 & (n406[0] << 1 | n406[0]);
  n389[0] = 255 & (n386[0] << 1 | n386[0]);
  n373[0] = 1 & ~n372[0];
  { unsigned int tmp; (tmp = (unsigned int) n307[0] - (unsigned int) n360[0], n362[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n307[0] + (unsigned int) n360[0], n361[0] = 255 & (unsigned char) tmp); }
  n345[0] = 255 & (n342[0] << 1 | n342[0]);
  n326[0] = 255 & (n323[0] << 1 | n323[0]);
  n310[0] = 1 & ~n309[0];
  { unsigned int tmp; (tmp = (unsigned int) n246[0] - (unsigned int) n297[0], n299[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n246[0] + (unsigned int) n297[0], n298[0] = 255 & (unsigned char) tmp); }
  n283[0] = 255 & (n280[0] << 1 | n280[0]);
  n265[0] = 255 & (n262[0] << 1 | n262[0]);
  n249[0] = 1 & ~n248[0];
  { unsigned int tmp; (tmp = (unsigned int) n187[0] - (unsigned int) n236[0], n238[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n187[0] + (unsigned int) n236[0], n237[0] = 255 & (unsigned char) tmp); }
  n223[0] = 255 & (n220[0] << 1 | n220[0]);
  n206[0] = 255 & (n203[0] << 1 | n203[0]);
  n190[0] = 1 & ~n189[0];
  { unsigned int tmp; (tmp = (unsigned int) n130[0] - (unsigned int) n177[0], n179[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n130[0] + (unsigned int) n177[0], n178[0] = 255 & (unsigned char) tmp); }
  n166[0] = 255 & (n162[0] << 7 | n165[0]);
  n150[0] = 255 & (n146[0] << 7 | n149[0]);
  n133[0] = 1 & ~n132[0];
  { unsigned int tmp; (tmp = (unsigned int) n75[0] - (unsigned int) n120[0], n122[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n75[0] + (unsigned int) n120[0], n121[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n67[0] - (unsigned int) n108[0], n111[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n67[0] + (unsigned int) n108[0], n110[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n59[0] - (unsigned int) n93[0], n96[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n59[0] + (unsigned int) n93[0], n95[0] = 255 & (unsigned char) tmp); }
  n78[0] = 1 & ~n77[0];
  { unsigned int tmp; (tmp = (unsigned int) n28[0] - (unsigned int) n579[0], n51[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n46[0] - (unsigned int) n21[0], n47[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n44[0] - (unsigned int) n14[0], n45[0] = 255 & (unsigned char) tmp); }
  n31[0] = 1 & ~n30[0];
  n28r[0] = reset_i[0];
  n28e[0] = enable_i[0];
  n28d[0] = ang_i[0];
  n21r[0] = reset_i[0];
  n21e[0] = enable_i[0];
  n21d[0] = imag_i[0];
  n14r[0] = reset_i[0];
  n14e[0] = enable_i[0];
  n14d[0] = real_i[0];
  n544[0] = 255 & (n540[0] << 2 | n543[0]);
  n522[0] = 255 & (n518[0] << 2 | n521[0]);
  n507[0] = 255 & (n505[0] << 7 | n506[0]);
  n476[0] = 255 & (n472[0] << 2 | n475[0]);
  n455[0] = 255 & (n451[0] << 2 | n454[0]);
  n440[0] = 255 & (n438[0] << 7 | n439[0]);
  n410[0] = 255 & (n406[0] << 2 | n409[0]);
  n390[0] = 255 & (n386[0] << 2 | n389[0]);
  n375[0] = 255 & (n373[0] << 7 | n374[0]);
  n346[0] = 255 & (n342[0] << 2 | n345[0]);
  n327[0] = 255 & (n323[0] << 2 | n326[0]);
  n312[0] = 255 & (n310[0] << 7 | n311[0]);
  n284[0] = 255 & (n280[0] << 2 | n283[0]);
  n266[0] = 255 & (n262[0] << 2 | n265[0]);
  n251[0] = 255 & (n249[0] << 7 | n250[0]);
  n225[0] = 255 & (n223[0] << 6 | n224[0]);
  n208[0] = 255 & (n206[0] << 6 | n207[0]);
  n192[0] = 255 & (n190[0] << 7 | n191[0]);
  { unsigned int tmp; (tmp = (unsigned int) n119[0] - (unsigned int) n166[0], n168[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n119[0] + (unsigned int) n166[0], n167[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n104[0] - (unsigned int) n150[0], n152[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n104[0] + (unsigned int) n150[0], n151[0] = 255 & (unsigned char) tmp); }
  n135[0] = 255 & (n133[0] << 7 | n134[0]);
  n80[0] = 255 & (n78[0] << 7 | n79[0]);
  n33[0] = 255 & (n31[0] << 7 | n32[0]);
  n545[0] = 255 & (n540[0] << 3 | n544[0]);
  n523[0] = 255 & (n518[0] << 3 | n522[0]);
  n515[0] = n507[0];
  n515[1] = n514[0];
  n477[0] = 255 & (n472[0] << 3 | n476[0]);
  n456[0] = 255 & (n451[0] << 3 | n455[0]);
  n448[0] = n440[0];
  n448[1] = n447[0];
  n411[0] = 255 & (n406[0] << 3 | n410[0]);
  n391[0] = 255 & (n386[0] << 3 | n390[0]);
  n383[0] = n375[0];
  n383[1] = n382[0];
  n347[0] = 255 & (n342[0] << 3 | n346[0]);
  n328[0] = 255 & (n323[0] << 3 | n327[0]);
  n320[0] = n312[0];
  n320[1] = n319[0];
  n286[0] = 255 & (n284[0] << 5 | n285[0]);
  n268[0] = 255 & (n266[0] << 5 | n267[0]);
  n259[0] = n251[0];
  n259[1] = n258[0];
  { unsigned int tmp; (tmp = (unsigned int) n176[0] - (unsigned int) n225[0], n227[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n176[0] + (unsigned int) n225[0], n226[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n160[0] - (unsigned int) n208[0], n210[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n160[0] + (unsigned int) n208[0], n209[0] = 255 & (unsigned char) tmp); }
  n200[0] = n192[0];
  n200[1] = n199[0];
  n143[0] = n135[0];
  n143[1] = n142[0];
  n88[0] = n80[0];
  n88[1] = n87[0];
  n39[0] = n33[0];
  n39[1] = n38[0];
  n546[0] = 255 & (n540[0] << 4 | n545[0]);
  n524[0] = 255 & (n518[0] << 4 | n523[0]);
  { unsigned int tmp; (tmp = (unsigned int) n632[1] - (unsigned int) n515[1] - (tmp = (unsigned int) n632[0] - (unsigned int) n515[0], n516[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n516[1] = 1 & (unsigned char) tmp); }
  n478[0] = 255 & (n472[0] << 4 | n477[0]);
  n457[0] = 255 & (n451[0] << 4 | n456[0]);
  { unsigned int tmp; (tmp = (unsigned int) n630[1] - (unsigned int) n448[1] - (tmp = (unsigned int) n630[0] - (unsigned int) n448[0], n449[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n449[1] = 1 & (unsigned char) tmp); }
  n412[0] = 255 & (n406[0] << 4 | n411[0]);
  n392[0] = 255 & (n386[0] << 4 | n391[0]);
  { unsigned int tmp; (tmp = (unsigned int) n628[1] - (unsigned int) n383[1] - (tmp = (unsigned int) n628[0] - (unsigned int) n383[0], n384[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n384[1] = 1 & (unsigned char) tmp); }
  n349[0] = 255 & (n347[0] << 4 | n348[0]);
  n330[0] = 255 & (n328[0] << 4 | n329[0]);
  { unsigned int tmp; (tmp = (unsigned int) n626[1] - (unsigned int) n320[1] - (tmp = (unsigned int) n626[0] - (unsigned int) n320[0], n321[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n321[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n235[0] - (unsigned int) n286[0], n288[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n235[0] + (unsigned int) n286[0], n287[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n218[0] - (unsigned int) n268[0], n270[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n218[0] + (unsigned int) n268[0], n269[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n624[1] - (unsigned int) n259[1] - (tmp = (unsigned int) n624[0] - (unsigned int) n259[0], n260[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n260[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n622[1] - (unsigned int) n200[1] - (tmp = (unsigned int) n622[0] - (unsigned int) n200[0], n201[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n201[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n620[1] - (unsigned int) n143[1] - (tmp = (unsigned int) n620[0] - (unsigned int) n143[0], n144[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n144[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n618[1] - (unsigned int) n88[1] - (tmp = (unsigned int) n618[0] - (unsigned int) n88[0], n89[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n89[1] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n39[1] - (unsigned int) n616[1] - (tmp = (unsigned int) n39[0] - (unsigned int) n616[0], n42[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n42[1] = 1 & (unsigned char) tmp); }
  n547[0] = 255 & (n540[0] << 5 | n546[0]);
  n525[0] = 255 & (n518[0] << 5 | n524[0]);
  n517[0] = (1 & (n516[1]));
  n479[0] = 255 & (n472[0] << 5 | n478[0]);
  n458[0] = 255 & (n451[0] << 5 | n457[0]);
  n450[0] = (1 & (n449[1]));
  n414[0] = 255 & (n412[0] << 3 | n413[0]);
  n394[0] = 255 & (n392[0] << 3 | n393[0]);
  n385[0] = (1 & (n384[1]));
  { unsigned int tmp; (tmp = (unsigned int) n296[0] - (unsigned int) n349[0], n351[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n296[0] + (unsigned int) n349[0], n350[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n278[0] - (unsigned int) n330[0], n332[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n278[0] + (unsigned int) n330[0], n331[0] = 255 & (unsigned char) tmp); }
  n322[0] = (1 & (n321[1]));
  n261[0] = (1 & (n260[1]));
  n202[0] = (1 & (n201[1]));
  n145[0] = (1 & (n144[1]));
  n90[0] = (1 & (n89[1]));
  n43[0] = (1 & (n42[1]));
  if (n517[0]) {
    n564[0] = n562[0];
  }
  else {
    n564[0] = n563[0];
  }
  n548[0] = 255 & (n540[0] << 6 | n547[0]);
  n539[0] = 1 & ~n517[0];
  n526[0] = 255 & (n518[0] << 6 | n525[0]);
  if (n450[0]) {
    n495[0] = n493[0];
  }
  else {
    n495[0] = n494[0];
  }
  n481[0] = 255 & (n479[0] << 2 | n480[0]);
  n471[0] = 1 & ~n450[0];
  n460[0] = 255 & (n458[0] << 2 | n459[0]);
  if (n385[0]) {
    n428[0] = n426[0];
  }
  else {
    n428[0] = n427[0];
  }
  { unsigned int tmp; (tmp = (unsigned int) n359[0] - (unsigned int) n414[0], n416[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n359[0] + (unsigned int) n414[0], n415[0] = 255 & (unsigned char) tmp); }
  n405[0] = 1 & ~n385[0];
  { unsigned int tmp; (tmp = (unsigned int) n340[0] - (unsigned int) n394[0], n396[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n340[0] + (unsigned int) n394[0], n395[0] = 255 & (unsigned char) tmp); }
  if (n322[0]) {
    n363[0] = n361[0];
  }
  else {
    n363[0] = n362[0];
  }
  n341[0] = 1 & ~n322[0];
  if (n322[0]) {
    n333[0] = n331[0];
  }
  else {
    n333[0] = n332[0];
  }
  if (n261[0]) {
    n300[0] = n298[0];
  }
  else {
    n300[0] = n299[0];
  }
  n279[0] = 1 & ~n261[0];
  if (n261[0]) {
    n271[0] = n269[0];
  }
  else {
    n271[0] = n270[0];
  }
  if (n202[0]) {
    n239[0] = n237[0];
  }
  else {
    n239[0] = n238[0];
  }
  n219[0] = 1 & ~n202[0];
  if (n202[0]) {
    n211[0] = n209[0];
  }
  else {
    n211[0] = n210[0];
  }
  if (n145[0]) {
    n180[0] = n178[0];
  }
  else {
    n180[0] = n179[0];
  }
  n161[0] = 1 & ~n145[0];
  if (n145[0]) {
    n153[0] = n151[0];
  }
  else {
    n153[0] = n152[0];
  }
  if (n90[0]) {
    n123[0] = n121[0];
  }
  else {
    n123[0] = n122[0];
  }
  n105[0] = 1 & ~n90[0];
  if (n90[0]) {
    n97[0] = n95[0];
  }
  else {
    n97[0] = n96[0];
  }
  if (n43[0]) {
    n68[0] = n51[0];
  }
  else {
    n68[0] = n28[0];
  }
  if (n43[0]) {
    n60[0] = n47[0];
  }
  else {
    n60[0] = n21[0];
  }
  if (n43[0]) {
    n52[0] = n45[0];
  }
  else {
    n52[0] = n14[0];
  }
  n571r[0] = reset_i[0];
  n571e[0] = enable_i[0];
  n571d[0] = n564[0];
  n550[0] = 255 & (n548[0] << 1 | n549[0]);
  n528[0] = 255 & (n526[0] << 1 | n527[0]);
  n502r[0] = reset_i[0];
  n502e[0] = enable_i[0];
  n502d[0] = n495[0];
  { unsigned int tmp; (tmp = (unsigned int) n424[0] - (unsigned int) n481[0], n483[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n424[0] + (unsigned int) n481[0], n482[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n404[0] - (unsigned int) n460[0], n462[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n404[0] + (unsigned int) n460[0], n461[0] = 255 & (unsigned char) tmp); }
  n435r[0] = reset_i[0];
  n435e[0] = enable_i[0];
  n435d[0] = n428[0];
  if (n405[0]) {
    n417[0] = n415[0];
  }
  else {
    n417[0] = n416[0];
  }
  if (n385[0]) {
    n397[0] = n395[0];
  }
  else {
    n397[0] = n396[0];
  }
  n370r[0] = reset_i[0];
  n370e[0] = enable_i[0];
  n370d[0] = n363[0];
  if (n341[0]) {
    n352[0] = n350[0];
  }
  else {
    n352[0] = n351[0];
  }
  n340r[0] = reset_i[0];
  n340e[0] = enable_i[0];
  n340d[0] = n333[0];
  n307r[0] = reset_i[0];
  n307e[0] = enable_i[0];
  n307d[0] = n300[0];
  if (n279[0]) {
    n289[0] = n287[0];
  }
  else {
    n289[0] = n288[0];
  }
  n278r[0] = reset_i[0];
  n278e[0] = enable_i[0];
  n278d[0] = n271[0];
  n246r[0] = reset_i[0];
  n246e[0] = enable_i[0];
  n246d[0] = n239[0];
  if (n219[0]) {
    n228[0] = n226[0];
  }
  else {
    n228[0] = n227[0];
  }
  n218r[0] = reset_i[0];
  n218e[0] = enable_i[0];
  n218d[0] = n211[0];
  n187r[0] = reset_i[0];
  n187e[0] = enable_i[0];
  n187d[0] = n180[0];
  if (n161[0]) {
    n169[0] = n167[0];
  }
  else {
    n169[0] = n168[0];
  }
  n160r[0] = reset_i[0];
  n160e[0] = enable_i[0];
  n160d[0] = n153[0];
  n130r[0] = reset_i[0];
  n130e[0] = enable_i[0];
  n130d[0] = n123[0];
  if (n105[0]) {
    n112[0] = n110[0];
  }
  else {
    n112[0] = n111[0];
  }
  n104r[0] = reset_i[0];
  n104e[0] = enable_i[0];
  n104d[0] = n97[0];
  n75r[0] = reset_i[0];
  n75e[0] = enable_i[0];
  n75d[0] = n68[0];
  n67r[0] = reset_i[0];
  n67e[0] = enable_i[0];
  n67d[0] = n60[0];
  n59r[0] = reset_i[0];
  n59e[0] = enable_i[0];
  n59d[0] = n52[0];
  { unsigned int tmp; (tmp = (unsigned int) n491[0] - (unsigned int) n550[0], n552[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n491[0] + (unsigned int) n550[0], n551[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n470[0] - (unsigned int) n528[0], n530[0] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n470[0] + (unsigned int) n528[0], n529[0] = 255 & (unsigned char) tmp); }
  if (n471[0]) {
    n484[0] = n482[0];
  }
  else {
    n484[0] = n483[0];
  }
  if (n450[0]) {
    n463[0] = n461[0];
  }
  else {
    n463[0] = n462[0];
  }
  n424r[0] = reset_i[0];
  n424e[0] = enable_i[0];
  n424d[0] = n417[0];
  n404r[0] = reset_i[0];
  n404e[0] = enable_i[0];
  n404d[0] = n397[0];
  n359r[0] = reset_i[0];
  n359e[0] = enable_i[0];
  n359d[0] = n352[0];
  n296r[0] = reset_i[0];
  n296e[0] = enable_i[0];
  n296d[0] = n289[0];
  n235r[0] = reset_i[0];
  n235e[0] = enable_i[0];
  n235d[0] = n228[0];
  n176r[0] = reset_i[0];
  n176e[0] = enable_i[0];
  n176d[0] = n169[0];
  n119r[0] = reset_i[0];
  n119e[0] = enable_i[0];
  n119d[0] = n112[0];
  if (n539[0]) {
    n553[0] = n551[0];
  }
  else {
    n553[0] = n552[0];
  }
  if (n517[0]) {
    n531[0] = n529[0];
  }
  else {
    n531[0] = n530[0];
  }
  n491r[0] = reset_i[0];
  n491e[0] = enable_i[0];
  n491d[0] = n484[0];
  n470r[0] = reset_i[0];
  n470e[0] = enable_i[0];
  n470d[0] = n463[0];
  n560r[0] = reset_i[0];
  n560e[0] = enable_i[0];
  n560d[0] = n553[0];
  n538r[0] = reset_i[0];
  n538e[0] = enable_i[0];
  n538d[0] = n531[0];
}

void cf_cordic_v_8_8_8_init() {
  { int index; for (index = 2; index > 0;) n632[--index] = 0; }
  { int index; for (index = 2; index > 0;) n630[--index] = 0; }
  { int index; for (index = 2; index > 0;) n628[--index] = 0; }
  { int index; for (index = 2; index > 0;) n626[--index] = 0; }
  { int index; for (index = 2; index > 0;) n624[--index] = 0; }
  { int index; for (index = 2; index > 0;) n622[--index] = 0; }
  { int index; for (index = 2; index > 0;) n620[--index] = 0; }
  { int index; for (index = 2; index > 0;) n618[--index] = 0; }
  { int index; for (index = 2; index > 0;) n616[--index] = 0; }
  n579[0] = 0;
  n561[0] = 0;
  n549[0] = 0;
  n540[0] = 0;
  n527[0] = 0;
  n518[0] = 0;
  n514[0] = 0;
  n506[0] = 0;
  n504[0] = 0;
  n492[0] = 0;
  n480[0] = 0;
  n472[0] = 0;
  n459[0] = 0;
  n451[0] = 0;
  n447[0] = 0;
  n439[0] = 0;
  n437[0] = 0;
  n425[0] = 0;
  n413[0] = 0;
  n406[0] = 0;
  n393[0] = 0;
  n386[0] = 0;
  n382[0] = 0;
  n374[0] = 0;
  n372[0] = 0;
  n360[0] = 0;
  n348[0] = 0;
  n342[0] = 0;
  n329[0] = 0;
  n323[0] = 0;
  n319[0] = 0;
  n311[0] = 0;
  n309[0] = 0;
  n297[0] = 0;
  n285[0] = 0;
  n280[0] = 0;
  n267[0] = 0;
  n262[0] = 0;
  n258[0] = 0;
  n250[0] = 0;
  n248[0] = 0;
  n236[0] = 0;
  n224[0] = 0;
  n220[0] = 0;
  n207[0] = 0;
  n203[0] = 0;
  n199[0] = 0;
  n191[0] = 0;
  n189[0] = 0;
  n177[0] = 0;
  n165[0] = 0;
  n162[0] = 0;
  n149[0] = 0;
  n146[0] = 0;
  n142[0] = 0;
  n134[0] = 0;
  n132[0] = 0;
  n120[0] = 0;
  n108[0] = 0;
  n93[0] = 0;
  n87[0] = 0;
  n79[0] = 0;
  n77[0] = 0;
  n46[0] = 0;
  n44[0] = 0;
  n38[0] = 0;
  n32[0] = 0;
  n30[0] = 0;
  n563[0] = 0;
  n562[0] = 0;
  n543[0] = 0;
  n521[0] = 0;
  n505[0] = 0;
  n494[0] = 0;
  n493[0] = 0;
  n475[0] = 0;
  n454[0] = 0;
  n438[0] = 0;
  n427[0] = 0;
  n426[0] = 0;
  n409[0] = 0;
  n389[0] = 0;
  n373[0] = 0;
  n362[0] = 0;
  n361[0] = 0;
  n345[0] = 0;
  n326[0] = 0;
  n310[0] = 0;
  n299[0] = 0;
  n298[0] = 0;
  n283[0] = 0;
  n265[0] = 0;
  n249[0] = 0;
  n238[0] = 0;
  n237[0] = 0;
  n223[0] = 0;
  n206[0] = 0;
  n190[0] = 0;
  n179[0] = 0;
  n178[0] = 0;
  n166[0] = 0;
  n150[0] = 0;
  n133[0] = 0;
  n122[0] = 0;
  n121[0] = 0;
  n111[0] = 0;
  n110[0] = 0;
  n96[0] = 0;
  n95[0] = 0;
  n78[0] = 0;
  n51[0] = 0;
  n47[0] = 0;
  n45[0] = 0;
  n31[0] = 0;
  n28[0] = 0;
  n28r[0] = 0;
  n28e[0] = 0;
  n28d[0] = 0;
  n21[0] = 0;
  n21r[0] = 0;
  n21e[0] = 0;
  n21d[0] = 0;
  n14[0] = 0;
  n14r[0] = 0;
  n14e[0] = 0;
  n14d[0] = 0;
  n544[0] = 0;
  n522[0] = 0;
  n507[0] = 0;
  n476[0] = 0;
  n455[0] = 0;
  n440[0] = 0;
  n410[0] = 0;
  n390[0] = 0;
  n375[0] = 0;
  n346[0] = 0;
  n327[0] = 0;
  n312[0] = 0;
  n284[0] = 0;
  n266[0] = 0;
  n251[0] = 0;
  n225[0] = 0;
  n208[0] = 0;
  n192[0] = 0;
  n168[0] = 0;
  n167[0] = 0;
  n152[0] = 0;
  n151[0] = 0;
  n135[0] = 0;
  n80[0] = 0;
  n33[0] = 0;
  n545[0] = 0;
  n523[0] = 0;
  { int index; for (index = 2; index > 0;) n515[--index] = 0; }
  n477[0] = 0;
  n456[0] = 0;
  { int index; for (index = 2; index > 0;) n448[--index] = 0; }
  n411[0] = 0;
  n391[0] = 0;
  { int index; for (index = 2; index > 0;) n383[--index] = 0; }
  n347[0] = 0;
  n328[0] = 0;
  { int index; for (index = 2; index > 0;) n320[--index] = 0; }
  n286[0] = 0;
  n268[0] = 0;
  { int index; for (index = 2; index > 0;) n259[--index] = 0; }
  n227[0] = 0;
  n226[0] = 0;
  n210[0] = 0;
  n209[0] = 0;
  { int index; for (index = 2; index > 0;) n200[--index] = 0; }
  { int index; for (index = 2; index > 0;) n143[--index] = 0; }
  { int index; for (index = 2; index > 0;) n88[--index] = 0; }
  { int index; for (index = 2; index > 0;) n39[--index] = 0; }
  n546[0] = 0;
  n524[0] = 0;
  { int index; for (index = 2; index > 0;) n516[--index] = 0; }
  n478[0] = 0;
  n457[0] = 0;
  { int index; for (index = 2; index > 0;) n449[--index] = 0; }
  n412[0] = 0;
  n392[0] = 0;
  { int index; for (index = 2; index > 0;) n384[--index] = 0; }
  n349[0] = 0;
  n330[0] = 0;
  { int index; for (index = 2; index > 0;) n321[--index] = 0; }
  n288[0] = 0;
  n287[0] = 0;
  n270[0] = 0;
  n269[0] = 0;
  { int index; for (index = 2; index > 0;) n260[--index] = 0; }
  { int index; for (index = 2; index > 0;) n201[--index] = 0; }
  { int index; for (index = 2; index > 0;) n144[--index] = 0; }
  { int index; for (index = 2; index > 0;) n89[--index] = 0; }
  { int index; for (index = 2; index > 0;) n42[--index] = 0; }
  n547[0] = 0;
  n525[0] = 0;
  n517[0] = 0;
  n479[0] = 0;
  n458[0] = 0;
  n450[0] = 0;
  n414[0] = 0;
  n394[0] = 0;
  n385[0] = 0;
  n351[0] = 0;
  n350[0] = 0;
  n332[0] = 0;
  n331[0] = 0;
  n322[0] = 0;
  n261[0] = 0;
  n202[0] = 0;
  n145[0] = 0;
  n90[0] = 0;
  n43[0] = 0;
  n564[0] = 0;
  n548[0] = 0;
  n539[0] = 0;
  n526[0] = 0;
  n495[0] = 0;
  n481[0] = 0;
  n471[0] = 0;
  n460[0] = 0;
  n428[0] = 0;
  n416[0] = 0;
  n415[0] = 0;
  n405[0] = 0;
  n396[0] = 0;
  n395[0] = 0;
  n363[0] = 0;
  n341[0] = 0;
  n333[0] = 0;
  n300[0] = 0;
  n279[0] = 0;
  n271[0] = 0;
  n239[0] = 0;
  n219[0] = 0;
  n211[0] = 0;
  n180[0] = 0;
  n161[0] = 0;
  n153[0] = 0;
  n123[0] = 0;
  n105[0] = 0;
  n97[0] = 0;
  n68[0] = 0;
  n60[0] = 0;
  n52[0] = 0;
  n571[0] = 0;
  n571r[0] = 0;
  n571e[0] = 0;
  n571d[0] = 0;
  n550[0] = 0;
  n528[0] = 0;
  n502[0] = 0;
  n502r[0] = 0;
  n502e[0] = 0;
  n502d[0] = 0;
  n483[0] = 0;
  n482[0] = 0;
  n462[0] = 0;
  n461[0] = 0;
  n435[0] = 0;
  n435r[0] = 0;
  n435e[0] = 0;
  n435d[0] = 0;
  n417[0] = 0;
  n397[0] = 0;
  n370[0] = 0;
  n370r[0] = 0;
  n370e[0] = 0;
  n370d[0] = 0;
  n352[0] = 0;
  n340[0] = 0;
  n340r[0] = 0;
  n340e[0] = 0;
  n340d[0] = 0;
  n307[0] = 0;
  n307r[0] = 0;
  n307e[0] = 0;
  n307d[0] = 0;
  n289[0] = 0;
  n278[0] = 0;
  n278r[0] = 0;
  n278e[0] = 0;
  n278d[0] = 0;
  n246[0] = 0;
  n246r[0] = 0;
  n246e[0] = 0;
  n246d[0] = 0;
  n228[0] = 0;
  n218[0] = 0;
  n218r[0] = 0;
  n218e[0] = 0;
  n218d[0] = 0;
  n187[0] = 0;
  n187r[0] = 0;
  n187e[0] = 0;
  n187d[0] = 0;
  n169[0] = 0;
  n160[0] = 0;
  n160r[0] = 0;
  n160e[0] = 0;
  n160d[0] = 0;
  n130[0] = 0;
  n130r[0] = 0;
  n130e[0] = 0;
  n130d[0] = 0;
  n112[0] = 0;
  n104[0] = 0;
  n104r[0] = 0;
  n104e[0] = 0;
  n104d[0] = 0;
  n75[0] = 0;
  n75r[0] = 0;
  n75e[0] = 0;
  n75d[0] = 0;
  n67[0] = 0;
  n67r[0] = 0;
  n67e[0] = 0;
  n67d[0] = 0;
  n59[0] = 0;
  n59r[0] = 0;
  n59e[0] = 0;
  n59d[0] = 0;
  n552[0] = 0;
  n551[0] = 0;
  n530[0] = 0;
  n529[0] = 0;
  n484[0] = 0;
  n463[0] = 0;
  n424[0] = 0;
  n424r[0] = 0;
  n424e[0] = 0;
  n424d[0] = 0;
  n404[0] = 0;
  n404r[0] = 0;
  n404e[0] = 0;
  n404d[0] = 0;
  n359[0] = 0;
  n359r[0] = 0;
  n359e[0] = 0;
  n359d[0] = 0;
  n296[0] = 0;
  n296r[0] = 0;
  n296e[0] = 0;
  n296d[0] = 0;
  n235[0] = 0;
  n235r[0] = 0;
  n235e[0] = 0;
  n235d[0] = 0;
  n176[0] = 0;
  n176r[0] = 0;
  n176e[0] = 0;
  n176d[0] = 0;
  n119[0] = 0;
  n119r[0] = 0;
  n119e[0] = 0;
  n119d[0] = 0;
  n553[0] = 0;
  n531[0] = 0;
  n491[0] = 0;
  n491r[0] = 0;
  n491e[0] = 0;
  n491d[0] = 0;
  n470[0] = 0;
  n470r[0] = 0;
  n470e[0] = 0;
  n470d[0] = 0;
  n560[0] = 0;
  n560r[0] = 0;
  n560e[0] = 0;
  n560d[0] = 0;
  n538[0] = 0;
  n538r[0] = 0;
  n538e[0] = 0;
  n538d[0] = 0;
  cf_cordic_v_8_8_8_calc();
}

void cf_cordic_v_8_8_8_cycle_clock()
{
  if (n14r[0]) {
    n14[0] = 0;
  }
  else if (n14e[0]) {
    n14[0] = n14d[0];
  }
  if (n21r[0]) {
    n21[0] = 0;
  }
  else if (n21e[0]) {
    n21[0] = n21d[0];
  }
  if (n28r[0]) {
    n28[0] = 0;
  }
  else if (n28e[0]) {
    n28[0] = n28d[0];
  }
  if (n59r[0]) {
    n59[0] = 0;
  }
  else if (n59e[0]) {
    n59[0] = n59d[0];
  }
  if (n67r[0]) {
    n67[0] = 0;
  }
  else if (n67e[0]) {
    n67[0] = n67d[0];
  }
  if (n75r[0]) {
    n75[0] = 0;
  }
  else if (n75e[0]) {
    n75[0] = n75d[0];
  }
  if (n104r[0]) {
    n104[0] = 0;
  }
  else if (n104e[0]) {
    n104[0] = n104d[0];
  }
  if (n119r[0]) {
    n119[0] = 0;
  }
  else if (n119e[0]) {
    n119[0] = n119d[0];
  }
  if (n130r[0]) {
    n130[0] = 0;
  }
  else if (n130e[0]) {
    n130[0] = n130d[0];
  }
  if (n160r[0]) {
    n160[0] = 0;
  }
  else if (n160e[0]) {
    n160[0] = n160d[0];
  }
  if (n176r[0]) {
    n176[0] = 0;
  }
  else if (n176e[0]) {
    n176[0] = n176d[0];
  }
  if (n187r[0]) {
    n187[0] = 0;
  }
  else if (n187e[0]) {
    n187[0] = n187d[0];
  }
  if (n218r[0]) {
    n218[0] = 0;
  }
  else if (n218e[0]) {
    n218[0] = n218d[0];
  }
  if (n235r[0]) {
    n235[0] = 0;
  }
  else if (n235e[0]) {
    n235[0] = n235d[0];
  }
  if (n246r[0]) {
    n246[0] = 0;
  }
  else if (n246e[0]) {
    n246[0] = n246d[0];
  }
  if (n278r[0]) {
    n278[0] = 0;
  }
  else if (n278e[0]) {
    n278[0] = n278d[0];
  }
  if (n296r[0]) {
    n296[0] = 0;
  }
  else if (n296e[0]) {
    n296[0] = n296d[0];
  }
  if (n307r[0]) {
    n307[0] = 0;
  }
  else if (n307e[0]) {
    n307[0] = n307d[0];
  }
  if (n340r[0]) {
    n340[0] = 0;
  }
  else if (n340e[0]) {
    n340[0] = n340d[0];
  }
  if (n359r[0]) {
    n359[0] = 0;
  }
  else if (n359e[0]) {
    n359[0] = n359d[0];
  }
  if (n370r[0]) {
    n370[0] = 0;
  }
  else if (n370e[0]) {
    n370[0] = n370d[0];
  }
  if (n404r[0]) {
    n404[0] = 0;
  }
  else if (n404e[0]) {
    n404[0] = n404d[0];
  }
  if (n424r[0]) {
    n424[0] = 0;
  }
  else if (n424e[0]) {
    n424[0] = n424d[0];
  }
  if (n435r[0]) {
    n435[0] = 0;
  }
  else if (n435e[0]) {
    n435[0] = n435d[0];
  }
  if (n470r[0]) {
    n470[0] = 0;
  }
  else if (n470e[0]) {
    n470[0] = n470d[0];
  }
  if (n491r[0]) {
    n491[0] = 0;
  }
  else if (n491e[0]) {
    n491[0] = n491d[0];
  }
  if (n502r[0]) {
    n502[0] = 0;
  }
  else if (n502e[0]) {
    n502[0] = n502d[0];
  }
  if (n538r[0]) {
    n538[0] = 0;
  }
  else if (n538e[0]) {
    n538[0] = n538d[0];
  }
  if (n560r[0]) {
    n560[0] = 0;
  }
  else if (n560e[0]) {
    n560[0] = n560d[0];
  }
  if (n571r[0]) {
    n571[0] = 0;
  }
  else if (n571e[0]) {
    n571[0] = n571d[0];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_enable_i[1];
static unsigned char sim_reset_i[1];
static unsigned char sim_real_i[1];
static unsigned char sim_imag_i[1];
static unsigned char sim_ang_i[1];
static unsigned char sim_real_o[1];
static unsigned char sim_imag_o[1];
static unsigned char sim_ang_o[1];

void cf_cordic_v_8_8_8_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_cordic_v_8_8_8_init();
  sim_enable_i[0] = enable_i[0];
  sim_reset_i[0] = reset_i[0];
  sim_real_i[0] = real_i[0];
  sim_imag_i[0] = imag_i[0];
  sim_ang_i[0] = ang_i[0];
  sim_real_o[0] = real_o[0];
  sim_imag_o[0] = imag_o[0];
  sim_ang_o[0] = ang_o[0];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_cordic_v_8_8_8 $end\n"
    "$var wire 1 ! enable_i $end\n"
    "$var wire 1 \" reset_i $end\n"
    "$var wire 8 # real_i $end\n"
    "$var wire 8 $ imag_i $end\n"
    "$var wire 8 %% ang_i $end\n"
    "$var wire 8 & real_o $end\n"
    "$var wire 8 ' imag_o $end\n"
    "$var wire 8 ( ang_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, enable_i[0] ? "1!\n" : "0!\n");
  fprintf(sim_file, reset_i[0] ? "1\"\n" : "0\"\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & real_i[byte]) ? "1" : "0");
        else if (bit & real_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & imag_i[byte]) ? "1" : "0");
        else if (bit & imag_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & ang_i[byte]) ? "1" : "0");
        else if (bit & ang_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & real_o[byte]) ? "1" : "0");
        else if (bit & real_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & imag_o[byte]) ? "1" : "0");
        else if (bit & imag_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 0; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & ang_o[byte]) ? "1" : "0");
        else if (bit & ang_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_cordic_v_8_8_8_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_cordic_v_8_8_8_sim_sample() {
  int changed = 0;
  if (sim_enable_i[0] != enable_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, enable_i[0] ? "1!\n" : "0!\n");
    sim_enable_i[0] = enable_i[0];
  }
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1\"\n" : "0\"\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_real_i[0] != real_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & real_i[byte]) ? "1" : "0");
          else if (bit & real_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_real_i[0] = real_i[0];
  }
  if (sim_imag_i[0] != imag_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & imag_i[byte]) ? "1" : "0");
          else if (bit & imag_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_imag_i[0] = imag_i[0];
  }
  if (sim_ang_i[0] != ang_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & ang_i[byte]) ? "1" : "0");
          else if (bit & ang_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_ang_i[0] = ang_i[0];
  }
  if (sim_real_o[0] != real_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & real_o[byte]) ? "1" : "0");
          else if (bit & real_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_real_o[0] = real_o[0];
  }
  if (sim_imag_o[0] != imag_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & imag_o[byte]) ? "1" : "0");
          else if (bit & imag_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_imag_o[0] = imag_o[0];
  }
  if (sim_ang_o[0] != ang_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 0; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & ang_o[byte]) ? "1" : "0");
          else if (bit & ang_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_ang_o[0] = ang_o[0];
  }
  sim_count++;
}

