//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Cordics (COordinate Rotation DIgital Computers) are used to calculate
//    trigonometric functions and complex plane phase rotations.
//    This rotation mode cordic rotates a complex vector by the initial angle.
//    If the rotation will transition through +-PI/2 then the "flip_i" control
//    input must be set.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      enable_i : Synchronous enable.
//      reset_i  : Synchronous reset.
//  
//    Inputs:
//      flip_i   : Set to perform initial rotation if rotation will transition through +-PI/2
//      real_i   : Initial real component (signed).
//      imag_i   : Initial imaginary component (signed).
//      angle_i  : Initial angle (modulo 2PI).
//  
//    Outputs:
//      real_o   : Resulting real component (signed).
//      imag_o   : Resulting imaginary component (signed).
//      angle_o  : Resulting angle (modulo 2PI).
//  
//  Built In Parameters:
//  
//    Cordic Mode    = Rotation
//    Vector Width   = 16
//    Angle Width    = 16
//    Cordic Stages  = 16
//  
//  Resulting Pipeline Latency is 18 clock cycles.
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:44:21 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_cordic_r_16_16_16
//    Clock Domains : clock_c  
//    Vector Input  : enable_i(1)
//    Vector Input  : reset_i(1)
//    Vector Input  : flip_i(1)
//    Vector Input  : real_i(16)
//    Vector Input  : imag_i(16)
//    Vector Input  : ang_i(16)
//    Vector Output : real_o(16)
//    Vector Output : imag_o(16)
//    Vector Output : ang_o(16)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_cordic_r_16_16_16.h"

static unsigned char n1291[3];
static unsigned char n1289[3];
static unsigned char n1287[3];
static unsigned char n1285[3];
static unsigned char n1283[3];
static unsigned char n1281[3];
static unsigned char n1279[3];
static unsigned char n1277[3];
static unsigned char n1275[3];
static unsigned char n1273[3];
static unsigned char n1271[3];
static unsigned char n1269[3];
static unsigned char n1267[3];
static unsigned char n1265[3];
static unsigned char n1263[3];
static unsigned char n1261[3];
static unsigned char n1194[2];
static unsigned char *ang_o;
static unsigned char *imag_o;
static unsigned char *real_o;
static unsigned char n1178[2];
static unsigned char n1166[1];
static unsigned char n1149[1];
static unsigned char n1136[1];
static unsigned char n1119[1];
static unsigned char n1113[1];
static unsigned char n1107[2];
static unsigned char n1105[1];
static unsigned char n1093[2];
static unsigned char n1081[1];
static unsigned char n1065[1];
static unsigned char n1052[1];
static unsigned char n1036[1];
static unsigned char n1030[1];
static unsigned char n1024[2];
static unsigned char n1022[1];
static unsigned char n1010[2];
static unsigned char n998[1];
static unsigned char n983[1];
static unsigned char n970[1];
static unsigned char n955[1];
static unsigned char n949[1];
static unsigned char n943[2];
static unsigned char n941[1];
static unsigned char n929[2];
static unsigned char n917[1];
static unsigned char n903[1];
static unsigned char n890[1];
static unsigned char n876[1];
static unsigned char n870[1];
static unsigned char n864[2];
static unsigned char n862[1];
static unsigned char n850[2];
static unsigned char n838[1];
static unsigned char n825[1];
static unsigned char n812[1];
static unsigned char n799[1];
static unsigned char n793[1];
static unsigned char n787[2];
static unsigned char n785[1];
static unsigned char n773[2];
static unsigned char n761[1];
static unsigned char n749[1];
static unsigned char n736[1];
static unsigned char n724[1];
static unsigned char n718[1];
static unsigned char n712[2];
static unsigned char n710[1];
static unsigned char n698[2];
static unsigned char n686[1];
static unsigned char n675[1];
static unsigned char n662[1];
static unsigned char n651[1];
static unsigned char n645[1];
static unsigned char n639[2];
static unsigned char n637[1];
static unsigned char n625[2];
static unsigned char n613[1];
static unsigned char n603[1];
static unsigned char n590[1];
static unsigned char n580[1];
static unsigned char n574[1];
static unsigned char n568[2];
static unsigned char n566[1];
static unsigned char n554[2];
static unsigned char n542[2];
static unsigned char n533[1];
static unsigned char n520[2];
static unsigned char n511[1];
static unsigned char n505[1];
static unsigned char n499[2];
static unsigned char n497[1];
static unsigned char n485[2];
static unsigned char n473[2];
static unsigned char n465[1];
static unsigned char n452[2];
static unsigned char n444[1];
static unsigned char n438[1];
static unsigned char n432[2];
static unsigned char n430[1];
static unsigned char n418[2];
static unsigned char n406[2];
static unsigned char n399[1];
static unsigned char n386[2];
static unsigned char n379[1];
static unsigned char n373[1];
static unsigned char n367[2];
static unsigned char n365[1];
static unsigned char n353[2];
static unsigned char n341[2];
static unsigned char n335[1];
static unsigned char n322[2];
static unsigned char n316[1];
static unsigned char n310[1];
static unsigned char n304[2];
static unsigned char n302[1];
static unsigned char n290[2];
static unsigned char n278[2];
static unsigned char n273[1];
static unsigned char n260[2];
static unsigned char n255[1];
static unsigned char n249[1];
static unsigned char n243[2];
static unsigned char n241[1];
static unsigned char n229[2];
static unsigned char n217[2];
static unsigned char n213[1];
static unsigned char n200[2];
static unsigned char n196[1];
static unsigned char n190[1];
static unsigned char n184[2];
static unsigned char n182[1];
static unsigned char n170[2];
static unsigned char n158[2];
static unsigned char n155[1];
static unsigned char n142[2];
static unsigned char n139[1];
static unsigned char n133[1];
static unsigned char n127[2];
static unsigned char n125[1];
static unsigned char n113[2];
static unsigned char n101[2];
static unsigned char n86[2];
static unsigned char n78[1];
static unsigned char n72[2];
static unsigned char n70[1];
static unsigned char n39[2];
static unsigned char n37[2];
static unsigned char *ang_i;
static unsigned char *imag_i;
static unsigned char *real_i;
static unsigned char *flip_i;
static unsigned char *reset_i;
static unsigned char *enable_i;
static unsigned char n1180[2];
static unsigned char n1179[2];
static unsigned char n1152[1];
static unsigned char n1122[1];
static unsigned char n1106[1];
static unsigned char n1095[2];
static unsigned char n1094[2];
static unsigned char n1068[1];
static unsigned char n1039[1];
static unsigned char n1023[1];
static unsigned char n1012[2];
static unsigned char n1011[2];
static unsigned char n986[1];
static unsigned char n958[1];
static unsigned char n942[1];
static unsigned char n931[2];
static unsigned char n930[2];
static unsigned char n906[1];
static unsigned char n879[1];
static unsigned char n863[1];
static unsigned char n852[2];
static unsigned char n851[2];
static unsigned char n828[1];
static unsigned char n802[1];
static unsigned char n786[1];
static unsigned char n775[2];
static unsigned char n774[2];
static unsigned char n752[1];
static unsigned char n727[1];
static unsigned char n711[1];
static unsigned char n700[2];
static unsigned char n699[2];
static unsigned char n678[1];
static unsigned char n654[1];
static unsigned char n638[1];
static unsigned char n627[2];
static unsigned char n626[2];
static unsigned char n606[1];
static unsigned char n583[1];
static unsigned char n567[1];
static unsigned char n556[2];
static unsigned char n555[2];
static unsigned char n536[1];
static unsigned char n514[1];
static unsigned char n498[1];
static unsigned char n487[2];
static unsigned char n486[2];
static unsigned char n468[1];
static unsigned char n447[1];
static unsigned char n431[1];
static unsigned char n420[2];
static unsigned char n419[2];
static unsigned char n402[1];
static unsigned char n382[1];
static unsigned char n366[1];
static unsigned char n355[2];
static unsigned char n354[2];
static unsigned char n338[1];
static unsigned char n319[1];
static unsigned char n303[1];
static unsigned char n292[2];
static unsigned char n291[2];
static unsigned char n276[1];
static unsigned char n258[1];
static unsigned char n242[1];
static unsigned char n231[2];
static unsigned char n230[2];
static unsigned char n216[1];
static unsigned char n199[1];
static unsigned char n183[1];
static unsigned char n172[2];
static unsigned char n171[2];
static unsigned char n159[2];
static unsigned char n143[2];
static unsigned char n126[1];
static unsigned char n115[2];
static unsigned char n114[2];
static unsigned char n104[2];
static unsigned char n103[2];
static unsigned char n89[2];
static unsigned char n88[2];
static unsigned char n71[1];
static unsigned char n44[2];
static unsigned char n40[2];
static unsigned char n38[2];
static unsigned char n36[2];
static unsigned char n36r[1];
static unsigned char n36e[1];
static unsigned char n36d[2];
static unsigned char n29[2];
static unsigned char n29r[1];
static unsigned char n29e[1];
static unsigned char n29d[2];
static unsigned char n22[2];
static unsigned char n22r[1];
static unsigned char n22e[1];
static unsigned char n22d[2];
static unsigned char n15[1];
static unsigned char n15r[1];
static unsigned char n15e[1];
static unsigned char n15d[1];
static unsigned char n1153[1];
static unsigned char n1123[1];
static unsigned char n1108[2];
static unsigned char n1069[1];
static unsigned char n1040[1];
static unsigned char n1025[2];
static unsigned char n987[1];
static unsigned char n959[1];
static unsigned char n944[2];
static unsigned char n907[1];
static unsigned char n880[1];
static unsigned char n865[2];
static unsigned char n829[1];
static unsigned char n803[1];
static unsigned char n788[2];
static unsigned char n753[1];
static unsigned char n728[1];
static unsigned char n713[2];
static unsigned char n679[1];
static unsigned char n655[1];
static unsigned char n640[2];
static unsigned char n607[1];
static unsigned char n584[1];
static unsigned char n569[2];
static unsigned char n537[1];
static unsigned char n515[1];
static unsigned char n500[2];
static unsigned char n469[1];
static unsigned char n448[1];
static unsigned char n433[2];
static unsigned char n403[1];
static unsigned char n383[1];
static unsigned char n368[2];
static unsigned char n339[1];
static unsigned char n320[1];
static unsigned char n305[2];
static unsigned char n277[1];
static unsigned char n259[1];
static unsigned char n244[2];
static unsigned char n218[2];
static unsigned char n201[2];
static unsigned char n185[2];
static unsigned char n161[2];
static unsigned char n160[2];
static unsigned char n145[2];
static unsigned char n144[2];
static unsigned char n128[2];
static unsigned char n73[2];
static unsigned char n61[2];
static unsigned char n53[2];
static unsigned char n45[2];
static unsigned char n1154[1];
static unsigned char n1124[1];
static unsigned char n1114[3];
static unsigned char n1070[1];
static unsigned char n1041[1];
static unsigned char n1031[3];
static unsigned char n988[1];
static unsigned char n960[1];
static unsigned char n950[3];
static unsigned char n908[1];
static unsigned char n881[1];
static unsigned char n871[3];
static unsigned char n830[1];
static unsigned char n804[1];
static unsigned char n794[3];
static unsigned char n754[1];
static unsigned char n729[1];
static unsigned char n719[3];
static unsigned char n680[1];
static unsigned char n656[1];
static unsigned char n646[3];
static unsigned char n608[1];
static unsigned char n585[1];
static unsigned char n575[3];
static unsigned char n538[1];
static unsigned char n516[1];
static unsigned char n506[3];
static unsigned char n470[1];
static unsigned char n449[1];
static unsigned char n439[3];
static unsigned char n404[1];
static unsigned char n384[1];
static unsigned char n374[3];
static unsigned char n340[1];
static unsigned char n321[1];
static unsigned char n311[3];
static unsigned char n279[2];
static unsigned char n261[2];
static unsigned char n250[3];
static unsigned char n220[2];
static unsigned char n219[2];
static unsigned char n203[2];
static unsigned char n202[2];
static unsigned char n191[3];
static unsigned char n134[3];
static unsigned char n79[3];
static unsigned char n68[2];
static unsigned char n68r[1];
static unsigned char n68e[1];
static unsigned char n68d[2];
static unsigned char n60[2];
static unsigned char n60r[1];
static unsigned char n60e[1];
static unsigned char n60d[2];
static unsigned char n52[2];
static unsigned char n52r[1];
static unsigned char n52e[1];
static unsigned char n52d[2];
static unsigned char n1155[1];
static unsigned char n1125[1];
static unsigned char n1117[3];
static unsigned char n1071[1];
static unsigned char n1042[1];
static unsigned char n1034[3];
static unsigned char n989[1];
static unsigned char n961[1];
static unsigned char n953[3];
static unsigned char n909[1];
static unsigned char n882[1];
static unsigned char n874[3];
static unsigned char n831[1];
static unsigned char n805[1];
static unsigned char n797[3];
static unsigned char n755[1];
static unsigned char n730[1];
static unsigned char n722[3];
static unsigned char n681[1];
static unsigned char n657[1];
static unsigned char n649[3];
static unsigned char n609[1];
static unsigned char n586[1];
static unsigned char n578[3];
static unsigned char n539[1];
static unsigned char n517[1];
static unsigned char n509[3];
static unsigned char n471[1];
static unsigned char n450[1];
static unsigned char n442[3];
static unsigned char n405[1];
static unsigned char n385[1];
static unsigned char n377[3];
static unsigned char n342[2];
static unsigned char n323[2];
static unsigned char n314[3];
static unsigned char n281[2];
static unsigned char n280[2];
static unsigned char n263[2];
static unsigned char n262[2];
static unsigned char n253[3];
static unsigned char n194[3];
static unsigned char n137[3];
static unsigned char n82[3];
static unsigned char n1156[1];
static unsigned char n1126[1];
static unsigned char n1118[1];
static unsigned char n1072[1];
static unsigned char n1043[1];
static unsigned char n1035[1];
static unsigned char n990[1];
static unsigned char n962[1];
static unsigned char n954[1];
static unsigned char n910[1];
static unsigned char n883[1];
static unsigned char n875[1];
static unsigned char n832[1];
static unsigned char n806[1];
static unsigned char n798[1];
static unsigned char n756[1];
static unsigned char n731[1];
static unsigned char n723[1];
static unsigned char n682[1];
static unsigned char n658[1];
static unsigned char n650[1];
static unsigned char n610[1];
static unsigned char n587[1];
static unsigned char n579[1];
static unsigned char n540[1];
static unsigned char n518[1];
static unsigned char n510[1];
static unsigned char n472[1];
static unsigned char n451[1];
static unsigned char n443[1];
static unsigned char n407[2];
static unsigned char n387[2];
static unsigned char n378[1];
static unsigned char n344[2];
static unsigned char n343[2];
static unsigned char n325[2];
static unsigned char n324[2];
static unsigned char n315[1];
static unsigned char n254[1];
static unsigned char n195[1];
static unsigned char n138[1];
static unsigned char n83[1];
static unsigned char n1181[2];
static unsigned char n1157[1];
static unsigned char n1148[1];
static unsigned char n1127[1];
static unsigned char n1096[2];
static unsigned char n1073[1];
static unsigned char n1064[1];
static unsigned char n1044[1];
static unsigned char n1013[2];
static unsigned char n991[1];
static unsigned char n982[1];
static unsigned char n963[1];
static unsigned char n932[2];
static unsigned char n911[1];
static unsigned char n902[1];
static unsigned char n884[1];
static unsigned char n853[2];
static unsigned char n833[1];
static unsigned char n824[1];
static unsigned char n807[1];
static unsigned char n776[2];
static unsigned char n757[1];
static unsigned char n748[1];
static unsigned char n732[1];
static unsigned char n701[2];
static unsigned char n683[1];
static unsigned char n674[1];
static unsigned char n659[1];
static unsigned char n628[2];
static unsigned char n611[1];
static unsigned char n602[1];
static unsigned char n588[1];
static unsigned char n557[2];
static unsigned char n541[1];
static unsigned char n532[1];
static unsigned char n519[1];
static unsigned char n488[2];
static unsigned char n474[2];
static unsigned char n464[1];
static unsigned char n453[2];
static unsigned char n421[2];
static unsigned char n409[2];
static unsigned char n408[2];
static unsigned char n398[1];
static unsigned char n389[2];
static unsigned char n388[2];
static unsigned char n356[2];
static unsigned char n334[1];
static unsigned char n326[2];
static unsigned char n293[2];
static unsigned char n272[1];
static unsigned char n264[2];
static unsigned char n232[2];
static unsigned char n212[1];
static unsigned char n204[2];
static unsigned char n173[2];
static unsigned char n154[1];
static unsigned char n146[2];
static unsigned char n116[2];
static unsigned char n98[1];
static unsigned char n90[2];
static unsigned char n1188[2];
static unsigned char n1188r[1];
static unsigned char n1188e[1];
static unsigned char n1188d[2];
static unsigned char n1158[1];
static unsigned char n1128[1];
static unsigned char n1103[2];
static unsigned char n1103r[1];
static unsigned char n1103e[1];
static unsigned char n1103d[2];
static unsigned char n1074[1];
static unsigned char n1045[1];
static unsigned char n1020[2];
static unsigned char n1020r[1];
static unsigned char n1020e[1];
static unsigned char n1020d[2];
static unsigned char n992[1];
static unsigned char n964[1];
static unsigned char n939[2];
static unsigned char n939r[1];
static unsigned char n939e[1];
static unsigned char n939d[2];
static unsigned char n912[1];
static unsigned char n885[1];
static unsigned char n860[2];
static unsigned char n860r[1];
static unsigned char n860e[1];
static unsigned char n860d[2];
static unsigned char n834[1];
static unsigned char n808[1];
static unsigned char n783[2];
static unsigned char n783r[1];
static unsigned char n783e[1];
static unsigned char n783d[2];
static unsigned char n758[1];
static unsigned char n733[1];
static unsigned char n708[2];
static unsigned char n708r[1];
static unsigned char n708e[1];
static unsigned char n708d[2];
static unsigned char n684[1];
static unsigned char n660[1];
static unsigned char n635[2];
static unsigned char n635r[1];
static unsigned char n635e[1];
static unsigned char n635d[2];
static unsigned char n612[1];
static unsigned char n589[1];
static unsigned char n564[2];
static unsigned char n564r[1];
static unsigned char n564e[1];
static unsigned char n564d[2];
static unsigned char n543[2];
static unsigned char n521[2];
static unsigned char n495[2];
static unsigned char n495r[1];
static unsigned char n495e[1];
static unsigned char n495d[2];
static unsigned char n476[2];
static unsigned char n475[2];
static unsigned char n455[2];
static unsigned char n454[2];
static unsigned char n428[2];
static unsigned char n428r[1];
static unsigned char n428e[1];
static unsigned char n428d[2];
static unsigned char n410[2];
static unsigned char n390[2];
static unsigned char n363[2];
static unsigned char n363r[1];
static unsigned char n363e[1];
static unsigned char n363d[2];
static unsigned char n345[2];
static unsigned char n333[2];
static unsigned char n333r[1];
static unsigned char n333e[1];
static unsigned char n333d[2];
static unsigned char n300[2];
static unsigned char n300r[1];
static unsigned char n300e[1];
static unsigned char n300d[2];
static unsigned char n282[2];
static unsigned char n271[2];
static unsigned char n271r[1];
static unsigned char n271e[1];
static unsigned char n271d[2];
static unsigned char n239[2];
static unsigned char n239r[1];
static unsigned char n239e[1];
static unsigned char n239d[2];
static unsigned char n221[2];
static unsigned char n211[2];
static unsigned char n211r[1];
static unsigned char n211e[1];
static unsigned char n211d[2];
static unsigned char n180[2];
static unsigned char n180r[1];
static unsigned char n180e[1];
static unsigned char n180d[2];
static unsigned char n162[2];
static unsigned char n153[2];
static unsigned char n153r[1];
static unsigned char n153e[1];
static unsigned char n153d[2];
static unsigned char n123[2];
static unsigned char n123r[1];
static unsigned char n123e[1];
static unsigned char n123d[2];
static unsigned char n105[2];
static unsigned char n97[2];
static unsigned char n97r[1];
static unsigned char n97e[1];
static unsigned char n97d[2];
static unsigned char n1159[2];
static unsigned char n1129[2];
static unsigned char n1075[2];
static unsigned char n1046[2];
static unsigned char n993[2];
static unsigned char n965[2];
static unsigned char n913[2];
static unsigned char n886[2];
static unsigned char n835[2];
static unsigned char n809[2];
static unsigned char n759[2];
static unsigned char n734[2];
static unsigned char n685[2];
static unsigned char n661[2];
static unsigned char n614[2];
static unsigned char n591[2];
static unsigned char n545[2];
static unsigned char n544[2];
static unsigned char n523[2];
static unsigned char n522[2];
static unsigned char n477[2];
static unsigned char n456[2];
static unsigned char n417[2];
static unsigned char n417r[1];
static unsigned char n417e[1];
static unsigned char n417d[2];
static unsigned char n397[2];
static unsigned char n397r[1];
static unsigned char n397e[1];
static unsigned char n397d[2];
static unsigned char n352[2];
static unsigned char n352r[1];
static unsigned char n352e[1];
static unsigned char n352d[2];
static unsigned char n289[2];
static unsigned char n289r[1];
static unsigned char n289e[1];
static unsigned char n289d[2];
static unsigned char n228[2];
static unsigned char n228r[1];
static unsigned char n228e[1];
static unsigned char n228d[2];
static unsigned char n169[2];
static unsigned char n169r[1];
static unsigned char n169e[1];
static unsigned char n169d[2];
static unsigned char n112[2];
static unsigned char n112r[1];
static unsigned char n112e[1];
static unsigned char n112d[2];
static unsigned char n1160[2];
static unsigned char n1130[2];
static unsigned char n1076[2];
static unsigned char n1047[2];
static unsigned char n994[2];
static unsigned char n966[2];
static unsigned char n914[2];
static unsigned char n887[2];
static unsigned char n836[2];
static unsigned char n810[2];
static unsigned char n760[2];
static unsigned char n735[2];
static unsigned char n687[2];
static unsigned char n663[2];
static unsigned char n616[2];
static unsigned char n615[2];
static unsigned char n593[2];
static unsigned char n592[2];
static unsigned char n546[2];
static unsigned char n524[2];
static unsigned char n484[2];
static unsigned char n484r[1];
static unsigned char n484e[1];
static unsigned char n484d[2];
static unsigned char n463[2];
static unsigned char n463r[1];
static unsigned char n463e[1];
static unsigned char n463d[2];
static unsigned char n1161[2];
static unsigned char n1131[2];
static unsigned char n1077[2];
static unsigned char n1048[2];
static unsigned char n995[2];
static unsigned char n967[2];
static unsigned char n915[2];
static unsigned char n888[2];
static unsigned char n837[2];
static unsigned char n811[2];
static unsigned char n762[2];
static unsigned char n737[2];
static unsigned char n689[2];
static unsigned char n688[2];
static unsigned char n665[2];
static unsigned char n664[2];
static unsigned char n617[2];
static unsigned char n594[2];
static unsigned char n553[2];
static unsigned char n553r[1];
static unsigned char n553e[1];
static unsigned char n553d[2];
static unsigned char n531[2];
static unsigned char n531r[1];
static unsigned char n531e[1];
static unsigned char n531d[2];
static unsigned char n1162[2];
static unsigned char n1132[2];
static unsigned char n1078[2];
static unsigned char n1049[2];
static unsigned char n996[2];
static unsigned char n968[2];
static unsigned char n916[2];
static unsigned char n889[2];
static unsigned char n839[2];
static unsigned char n813[2];
static unsigned char n764[2];
static unsigned char n763[2];
static unsigned char n739[2];
static unsigned char n738[2];
static unsigned char n690[2];
static unsigned char n666[2];
static unsigned char n624[2];
static unsigned char n624r[1];
static unsigned char n624e[1];
static unsigned char n624d[2];
static unsigned char n601[2];
static unsigned char n601r[1];
static unsigned char n601e[1];
static unsigned char n601d[2];
static unsigned char n1163[2];
static unsigned char n1133[2];
static unsigned char n1079[2];
static unsigned char n1050[2];
static unsigned char n997[2];
static unsigned char n969[2];
static unsigned char n918[2];
static unsigned char n891[2];
static unsigned char n841[2];
static unsigned char n840[2];
static unsigned char n815[2];
static unsigned char n814[2];
static unsigned char n765[2];
static unsigned char n740[2];
static unsigned char n697[2];
static unsigned char n697r[1];
static unsigned char n697e[1];
static unsigned char n697d[2];
static unsigned char n673[2];
static unsigned char n673r[1];
static unsigned char n673e[1];
static unsigned char n673d[2];
static unsigned char n1164[2];
static unsigned char n1134[2];
static unsigned char n1080[2];
static unsigned char n1051[2];
static unsigned char n999[2];
static unsigned char n971[2];
static unsigned char n920[2];
static unsigned char n919[2];
static unsigned char n893[2];
static unsigned char n892[2];
static unsigned char n842[2];
static unsigned char n816[2];
static unsigned char n772[2];
static unsigned char n772r[1];
static unsigned char n772e[1];
static unsigned char n772d[2];
static unsigned char n747[2];
static unsigned char n747r[1];
static unsigned char n747e[1];
static unsigned char n747d[2];
static unsigned char n1165[2];
static unsigned char n1135[2];
static unsigned char n1082[2];
static unsigned char n1053[2];
static unsigned char n1001[2];
static unsigned char n1000[2];
static unsigned char n973[2];
static unsigned char n972[2];
static unsigned char n921[2];
static unsigned char n894[2];
static unsigned char n849[2];
static unsigned char n849r[1];
static unsigned char n849e[1];
static unsigned char n849d[2];
static unsigned char n823[2];
static unsigned char n823r[1];
static unsigned char n823e[1];
static unsigned char n823d[2];
static unsigned char n1167[2];
static unsigned char n1137[2];
static unsigned char n1084[2];
static unsigned char n1083[2];
static unsigned char n1055[2];
static unsigned char n1054[2];
static unsigned char n1002[2];
static unsigned char n974[2];
static unsigned char n928[2];
static unsigned char n928r[1];
static unsigned char n928e[1];
static unsigned char n928d[2];
static unsigned char n901[2];
static unsigned char n901r[1];
static unsigned char n901e[1];
static unsigned char n901d[2];
static unsigned char n1169[2];
static unsigned char n1168[2];
static unsigned char n1139[2];
static unsigned char n1138[2];
static unsigned char n1085[2];
static unsigned char n1056[2];
static unsigned char n1009[2];
static unsigned char n1009r[1];
static unsigned char n1009e[1];
static unsigned char n1009d[2];
static unsigned char n981[2];
static unsigned char n981r[1];
static unsigned char n981e[1];
static unsigned char n981d[2];
static unsigned char n1170[2];
static unsigned char n1140[2];
static unsigned char n1092[2];
static unsigned char n1092r[1];
static unsigned char n1092e[1];
static unsigned char n1092d[2];
static unsigned char n1063[2];
static unsigned char n1063r[1];
static unsigned char n1063e[1];
static unsigned char n1063d[2];
static unsigned char n1177[2];
static unsigned char n1177r[1];
static unsigned char n1177e[1];
static unsigned char n1177d[2];
static unsigned char n1147[2];
static unsigned char n1147r[1];
static unsigned char n1147e[1];
static unsigned char n1147d[2];

void cf_cordic_r_16_16_16_ports(unsigned char* port_enable_i, unsigned char* port_reset_i, unsigned char* port_flip_i, unsigned char* port_real_i, unsigned char* port_imag_i, unsigned char* port_ang_i, unsigned char* port_real_o, unsigned char* port_imag_o, unsigned char* port_ang_o) {
  enable_i = port_enable_i;
  reset_i = port_reset_i;
  flip_i = port_flip_i;
  real_i = port_real_i;
  imag_i = port_imag_i;
  ang_i = port_ang_i;
  real_o = port_real_o;
  imag_o = port_imag_o;
  ang_o = port_ang_o;
}

void cf_cordic_r_16_16_16_calc() {
  n1291[0] = 0;
  n1291[1] = 128;
  n1291[2] = 0;
  n1289[0] = 0;
  n1289[1] = 128;
  n1289[2] = 0;
  n1287[0] = 0;
  n1287[1] = 128;
  n1287[2] = 0;
  n1285[0] = 0;
  n1285[1] = 128;
  n1285[2] = 0;
  n1283[0] = 0;
  n1283[1] = 128;
  n1283[2] = 0;
  n1281[0] = 0;
  n1281[1] = 128;
  n1281[2] = 0;
  n1279[0] = 0;
  n1279[1] = 128;
  n1279[2] = 0;
  n1277[0] = 0;
  n1277[1] = 128;
  n1277[2] = 0;
  n1275[0] = 0;
  n1275[1] = 128;
  n1275[2] = 0;
  n1273[0] = 0;
  n1273[1] = 128;
  n1273[2] = 0;
  n1271[0] = 0;
  n1271[1] = 128;
  n1271[2] = 0;
  n1269[0] = 0;
  n1269[1] = 128;
  n1269[2] = 0;
  n1267[0] = 0;
  n1267[1] = 128;
  n1267[2] = 0;
  n1265[0] = 0;
  n1265[1] = 128;
  n1265[2] = 0;
  n1263[0] = 0;
  n1263[1] = 128;
  n1263[2] = 0;
  n1261[0] = 0;
  n1261[1] = 128;
  n1261[2] = 0;
  n1194[0] = 0;
  n1194[1] = 128;
  ang_o[0] = n1188[0];
  ang_o[1] = n1188[1];
  imag_o[0] = n1177[0];
  imag_o[1] = n1177[1];
  real_o[0] = n1147[0];
  real_o[1] = n1147[1];
  n1178[0] = 0;
  n1178[1] = 0;
  n1166[0] = (1 & (n1063[1] >> 7));
  n1149[0] = (1 & (n1063[1] >> 7));
  n1136[0] = (1 & (n1092[1] >> 7));
  n1119[0] = (1 & (n1092[1] >> 7));
  n1113[0] = 0;
  n1107[0] = (1 & (n1103[0])) | (2 & (n1103[0])) | (4 & (n1103[0])) | (8 & (n1103[0])) | (16 & (n1103[0])) | (32 & (n1103[0])) | (64 & (n1103[0])) | (128 & (n1103[0]));
  n1107[1] = (1 & (n1103[1])) | (2 & (n1103[1])) | (4 & (n1103[1])) | (8 & (n1103[1])) | (16 & (n1103[1])) | (32 & (n1103[1])) | (64 & (n1103[1]));
  n1105[0] = (1 & (n1103[1] >> 7));
  n1093[0] = 1;
  n1093[1] = 0;
  n1081[0] = (1 & (n981[1] >> 6)) | (2 & (n981[1] >> 6));
  n1065[0] = (1 & (n981[1] >> 7));
  n1052[0] = (1 & (n1009[1] >> 6)) | (2 & (n1009[1] >> 6));
  n1036[0] = (1 & (n1009[1] >> 7));
  n1030[0] = 0;
  n1024[0] = (1 & (n1020[0])) | (2 & (n1020[0])) | (4 & (n1020[0])) | (8 & (n1020[0])) | (16 & (n1020[0])) | (32 & (n1020[0])) | (64 & (n1020[0])) | (128 & (n1020[0]));
  n1024[1] = (1 & (n1020[1])) | (2 & (n1020[1])) | (4 & (n1020[1])) | (8 & (n1020[1])) | (16 & (n1020[1])) | (32 & (n1020[1])) | (64 & (n1020[1]));
  n1022[0] = (1 & (n1020[1] >> 7));
  n1010[0] = 1;
  n1010[1] = 0;
  n998[0] = (1 & (n901[1] >> 5)) | (2 & (n901[1] >> 5)) | (4 & (n901[1] >> 5));
  n983[0] = (1 & (n901[1] >> 7));
  n970[0] = (1 & (n928[1] >> 5)) | (2 & (n928[1] >> 5)) | (4 & (n928[1] >> 5));
  n955[0] = (1 & (n928[1] >> 7));
  n949[0] = 0;
  n943[0] = (1 & (n939[0])) | (2 & (n939[0])) | (4 & (n939[0])) | (8 & (n939[0])) | (16 & (n939[0])) | (32 & (n939[0])) | (64 & (n939[0])) | (128 & (n939[0]));
  n943[1] = (1 & (n939[1])) | (2 & (n939[1])) | (4 & (n939[1])) | (8 & (n939[1])) | (16 & (n939[1])) | (32 & (n939[1])) | (64 & (n939[1]));
  n941[0] = (1 & (n939[1] >> 7));
  n929[0] = 3;
  n929[1] = 0;
  n917[0] = (1 & (n823[1] >> 4)) | (2 & (n823[1] >> 4)) | (4 & (n823[1] >> 4)) | (8 & (n823[1] >> 4));
  n903[0] = (1 & (n823[1] >> 7));
  n890[0] = (1 & (n849[1] >> 4)) | (2 & (n849[1] >> 4)) | (4 & (n849[1] >> 4)) | (8 & (n849[1] >> 4));
  n876[0] = (1 & (n849[1] >> 7));
  n870[0] = 0;
  n864[0] = (1 & (n860[0])) | (2 & (n860[0])) | (4 & (n860[0])) | (8 & (n860[0])) | (16 & (n860[0])) | (32 & (n860[0])) | (64 & (n860[0])) | (128 & (n860[0]));
  n864[1] = (1 & (n860[1])) | (2 & (n860[1])) | (4 & (n860[1])) | (8 & (n860[1])) | (16 & (n860[1])) | (32 & (n860[1])) | (64 & (n860[1]));
  n862[0] = (1 & (n860[1] >> 7));
  n850[0] = 5;
  n850[1] = 0;
  n838[0] = (1 & (n747[1] >> 3)) | (2 & (n747[1] >> 3)) | (4 & (n747[1] >> 3)) | (8 & (n747[1] >> 3)) | (16 & (n747[1] >> 3));
  n825[0] = (1 & (n747[1] >> 7));
  n812[0] = (1 & (n772[1] >> 3)) | (2 & (n772[1] >> 3)) | (4 & (n772[1] >> 3)) | (8 & (n772[1] >> 3)) | (16 & (n772[1] >> 3));
  n799[0] = (1 & (n772[1] >> 7));
  n793[0] = 0;
  n787[0] = (1 & (n783[0])) | (2 & (n783[0])) | (4 & (n783[0])) | (8 & (n783[0])) | (16 & (n783[0])) | (32 & (n783[0])) | (64 & (n783[0])) | (128 & (n783[0]));
  n787[1] = (1 & (n783[1])) | (2 & (n783[1])) | (4 & (n783[1])) | (8 & (n783[1])) | (16 & (n783[1])) | (32 & (n783[1])) | (64 & (n783[1]));
  n785[0] = (1 & (n783[1] >> 7));
  n773[0] = 10;
  n773[1] = 0;
  n761[0] = (1 & (n673[1] >> 2)) | (2 & (n673[1] >> 2)) | (4 & (n673[1] >> 2)) | (8 & (n673[1] >> 2)) | (16 & (n673[1] >> 2)) | (32 & (n673[1] >> 2));
  n749[0] = (1 & (n673[1] >> 7));
  n736[0] = (1 & (n697[1] >> 2)) | (2 & (n697[1] >> 2)) | (4 & (n697[1] >> 2)) | (8 & (n697[1] >> 2)) | (16 & (n697[1] >> 2)) | (32 & (n697[1] >> 2));
  n724[0] = (1 & (n697[1] >> 7));
  n718[0] = 0;
  n712[0] = (1 & (n708[0])) | (2 & (n708[0])) | (4 & (n708[0])) | (8 & (n708[0])) | (16 & (n708[0])) | (32 & (n708[0])) | (64 & (n708[0])) | (128 & (n708[0]));
  n712[1] = (1 & (n708[1])) | (2 & (n708[1])) | (4 & (n708[1])) | (8 & (n708[1])) | (16 & (n708[1])) | (32 & (n708[1])) | (64 & (n708[1]));
  n710[0] = (1 & (n708[1] >> 7));
  n698[0] = 20;
  n698[1] = 0;
  n686[0] = (1 & (n601[1] >> 1)) | (2 & (n601[1] >> 1)) | (4 & (n601[1] >> 1)) | (8 & (n601[1] >> 1)) | (16 & (n601[1] >> 1)) | (32 & (n601[1] >> 1)) | (64 & (n601[1] >> 1));
  n675[0] = (1 & (n601[1] >> 7));
  n662[0] = (1 & (n624[1] >> 1)) | (2 & (n624[1] >> 1)) | (4 & (n624[1] >> 1)) | (8 & (n624[1] >> 1)) | (16 & (n624[1] >> 1)) | (32 & (n624[1] >> 1)) | (64 & (n624[1] >> 1));
  n651[0] = (1 & (n624[1] >> 7));
  n645[0] = 0;
  n639[0] = (1 & (n635[0])) | (2 & (n635[0])) | (4 & (n635[0])) | (8 & (n635[0])) | (16 & (n635[0])) | (32 & (n635[0])) | (64 & (n635[0])) | (128 & (n635[0]));
  n639[1] = (1 & (n635[1])) | (2 & (n635[1])) | (4 & (n635[1])) | (8 & (n635[1])) | (16 & (n635[1])) | (32 & (n635[1])) | (64 & (n635[1]));
  n637[0] = (1 & (n635[1] >> 7));
  n625[0] = 41;
  n625[1] = 0;
  n613[0] = (1 & (n531[1])) | (2 & (n531[1])) | (4 & (n531[1])) | (8 & (n531[1])) | (16 & (n531[1])) | (32 & (n531[1])) | (64 & (n531[1])) | (128 & (n531[1]));
  n603[0] = (1 & (n531[1] >> 7));
  n590[0] = (1 & (n553[1])) | (2 & (n553[1])) | (4 & (n553[1])) | (8 & (n553[1])) | (16 & (n553[1])) | (32 & (n553[1])) | (64 & (n553[1])) | (128 & (n553[1]));
  n580[0] = (1 & (n553[1] >> 7));
  n574[0] = 0;
  n568[0] = (1 & (n564[0])) | (2 & (n564[0])) | (4 & (n564[0])) | (8 & (n564[0])) | (16 & (n564[0])) | (32 & (n564[0])) | (64 & (n564[0])) | (128 & (n564[0]));
  n568[1] = (1 & (n564[1])) | (2 & (n564[1])) | (4 & (n564[1])) | (8 & (n564[1])) | (16 & (n564[1])) | (32 & (n564[1])) | (64 & (n564[1]));
  n566[0] = (1 & (n564[1] >> 7));
  n554[0] = 81;
  n554[1] = 0;
  n542[0] = (1 & (n463[0] >> 7)) | (2 & (n463[1] << 1)) | (4 & (n463[1] << 1)) | (8 & (n463[1] << 1)) | (16 & (n463[1] << 1)) | (32 & (n463[1] << 1)) | (64 & (n463[1] << 1)) | (128 & (n463[1] << 1));
  n542[1] = (1 & (n463[1] >> 7));
  n533[0] = (1 & (n463[1] >> 7));
  n520[0] = (1 & (n484[0] >> 7)) | (2 & (n484[1] << 1)) | (4 & (n484[1] << 1)) | (8 & (n484[1] << 1)) | (16 & (n484[1] << 1)) | (32 & (n484[1] << 1)) | (64 & (n484[1] << 1)) | (128 & (n484[1] << 1));
  n520[1] = (1 & (n484[1] >> 7));
  n511[0] = (1 & (n484[1] >> 7));
  n505[0] = 0;
  n499[0] = (1 & (n495[0])) | (2 & (n495[0])) | (4 & (n495[0])) | (8 & (n495[0])) | (16 & (n495[0])) | (32 & (n495[0])) | (64 & (n495[0])) | (128 & (n495[0]));
  n499[1] = (1 & (n495[1])) | (2 & (n495[1])) | (4 & (n495[1])) | (8 & (n495[1])) | (16 & (n495[1])) | (32 & (n495[1])) | (64 & (n495[1]));
  n497[0] = (1 & (n495[1] >> 7));
  n485[0] = 163;
  n485[1] = 0;
  n473[0] = (1 & (n397[0] >> 6)) | (2 & (n397[0] >> 6)) | (4 & (n397[1] << 2)) | (8 & (n397[1] << 2)) | (16 & (n397[1] << 2)) | (32 & (n397[1] << 2)) | (64 & (n397[1] << 2)) | (128 & (n397[1] << 2));
  n473[1] = (1 & (n397[1] >> 6)) | (2 & (n397[1] >> 6));
  n465[0] = (1 & (n397[1] >> 7));
  n452[0] = (1 & (n417[0] >> 6)) | (2 & (n417[0] >> 6)) | (4 & (n417[1] << 2)) | (8 & (n417[1] << 2)) | (16 & (n417[1] << 2)) | (32 & (n417[1] << 2)) | (64 & (n417[1] << 2)) | (128 & (n417[1] << 2));
  n452[1] = (1 & (n417[1] >> 6)) | (2 & (n417[1] >> 6));
  n444[0] = (1 & (n417[1] >> 7));
  n438[0] = 0;
  n432[0] = (1 & (n428[0])) | (2 & (n428[0])) | (4 & (n428[0])) | (8 & (n428[0])) | (16 & (n428[0])) | (32 & (n428[0])) | (64 & (n428[0])) | (128 & (n428[0]));
  n432[1] = (1 & (n428[1])) | (2 & (n428[1])) | (4 & (n428[1])) | (8 & (n428[1])) | (16 & (n428[1])) | (32 & (n428[1])) | (64 & (n428[1]));
  n430[0] = (1 & (n428[1] >> 7));
  n418[0] = 70;
  n418[1] = 1;
  n406[0] = (1 & (n333[0] >> 5)) | (2 & (n333[0] >> 5)) | (4 & (n333[0] >> 5)) | (8 & (n333[1] << 3)) | (16 & (n333[1] << 3)) | (32 & (n333[1] << 3)) | (64 & (n333[1] << 3)) | (128 & (n333[1] << 3));
  n406[1] = (1 & (n333[1] >> 5)) | (2 & (n333[1] >> 5)) | (4 & (n333[1] >> 5));
  n399[0] = (1 & (n333[1] >> 7));
  n386[0] = (1 & (n352[0] >> 5)) | (2 & (n352[0] >> 5)) | (4 & (n352[0] >> 5)) | (8 & (n352[1] << 3)) | (16 & (n352[1] << 3)) | (32 & (n352[1] << 3)) | (64 & (n352[1] << 3)) | (128 & (n352[1] << 3));
  n386[1] = (1 & (n352[1] >> 5)) | (2 & (n352[1] >> 5)) | (4 & (n352[1] >> 5));
  n379[0] = (1 & (n352[1] >> 7));
  n373[0] = 0;
  n367[0] = (1 & (n363[0])) | (2 & (n363[0])) | (4 & (n363[0])) | (8 & (n363[0])) | (16 & (n363[0])) | (32 & (n363[0])) | (64 & (n363[0])) | (128 & (n363[0]));
  n367[1] = (1 & (n363[1])) | (2 & (n363[1])) | (4 & (n363[1])) | (8 & (n363[1])) | (16 & (n363[1])) | (32 & (n363[1])) | (64 & (n363[1]));
  n365[0] = (1 & (n363[1] >> 7));
  n353[0] = 139;
  n353[1] = 2;
  n341[0] = (1 & (n271[0] >> 4)) | (2 & (n271[0] >> 4)) | (4 & (n271[0] >> 4)) | (8 & (n271[0] >> 4)) | (16 & (n271[1] << 4)) | (32 & (n271[1] << 4)) | (64 & (n271[1] << 4)) | (128 & (n271[1] << 4));
  n341[1] = (1 & (n271[1] >> 4)) | (2 & (n271[1] >> 4)) | (4 & (n271[1] >> 4)) | (8 & (n271[1] >> 4));
  n335[0] = (1 & (n271[1] >> 7));
  n322[0] = (1 & (n289[0] >> 4)) | (2 & (n289[0] >> 4)) | (4 & (n289[0] >> 4)) | (8 & (n289[0] >> 4)) | (16 & (n289[1] << 4)) | (32 & (n289[1] << 4)) | (64 & (n289[1] << 4)) | (128 & (n289[1] << 4));
  n322[1] = (1 & (n289[1] >> 4)) | (2 & (n289[1] >> 4)) | (4 & (n289[1] >> 4)) | (8 & (n289[1] >> 4));
  n316[0] = (1 & (n289[1] >> 7));
  n310[0] = 0;
  n304[0] = (1 & (n300[0])) | (2 & (n300[0])) | (4 & (n300[0])) | (8 & (n300[0])) | (16 & (n300[0])) | (32 & (n300[0])) | (64 & (n300[0])) | (128 & (n300[0]));
  n304[1] = (1 & (n300[1])) | (2 & (n300[1])) | (4 & (n300[1])) | (8 & (n300[1])) | (16 & (n300[1])) | (32 & (n300[1])) | (64 & (n300[1]));
  n302[0] = (1 & (n300[1] >> 7));
  n290[0] = 17;
  n290[1] = 5;
  n278[0] = (1 & (n211[0] >> 3)) | (2 & (n211[0] >> 3)) | (4 & (n211[0] >> 3)) | (8 & (n211[0] >> 3)) | (16 & (n211[0] >> 3)) | (32 & (n211[1] << 5)) | (64 & (n211[1] << 5)) | (128 & (n211[1] << 5));
  n278[1] = (1 & (n211[1] >> 3)) | (2 & (n211[1] >> 3)) | (4 & (n211[1] >> 3)) | (8 & (n211[1] >> 3)) | (16 & (n211[1] >> 3));
  n273[0] = (1 & (n211[1] >> 7));
  n260[0] = (1 & (n228[0] >> 3)) | (2 & (n228[0] >> 3)) | (4 & (n228[0] >> 3)) | (8 & (n228[0] >> 3)) | (16 & (n228[0] >> 3)) | (32 & (n228[1] << 5)) | (64 & (n228[1] << 5)) | (128 & (n228[1] << 5));
  n260[1] = (1 & (n228[1] >> 3)) | (2 & (n228[1] >> 3)) | (4 & (n228[1] >> 3)) | (8 & (n228[1] >> 3)) | (16 & (n228[1] >> 3));
  n255[0] = (1 & (n228[1] >> 7));
  n249[0] = 0;
  n243[0] = (1 & (n239[0])) | (2 & (n239[0])) | (4 & (n239[0])) | (8 & (n239[0])) | (16 & (n239[0])) | (32 & (n239[0])) | (64 & (n239[0])) | (128 & (n239[0]));
  n243[1] = (1 & (n239[1])) | (2 & (n239[1])) | (4 & (n239[1])) | (8 & (n239[1])) | (16 & (n239[1])) | (32 & (n239[1])) | (64 & (n239[1]));
  n241[0] = (1 & (n239[1] >> 7));
  n229[0] = 251;
  n229[1] = 9;
  n217[0] = (1 & (n153[0] >> 2)) | (2 & (n153[0] >> 2)) | (4 & (n153[0] >> 2)) | (8 & (n153[0] >> 2)) | (16 & (n153[0] >> 2)) | (32 & (n153[0] >> 2)) | (64 & (n153[1] << 6)) | (128 & (n153[1] << 6));
  n217[1] = (1 & (n153[1] >> 2)) | (2 & (n153[1] >> 2)) | (4 & (n153[1] >> 2)) | (8 & (n153[1] >> 2)) | (16 & (n153[1] >> 2)) | (32 & (n153[1] >> 2));
  n213[0] = (1 & (n153[1] >> 7));
  n200[0] = (1 & (n169[0] >> 2)) | (2 & (n169[0] >> 2)) | (4 & (n169[0] >> 2)) | (8 & (n169[0] >> 2)) | (16 & (n169[0] >> 2)) | (32 & (n169[0] >> 2)) | (64 & (n169[1] << 6)) | (128 & (n169[1] << 6));
  n200[1] = (1 & (n169[1] >> 2)) | (2 & (n169[1] >> 2)) | (4 & (n169[1] >> 2)) | (8 & (n169[1] >> 2)) | (16 & (n169[1] >> 2)) | (32 & (n169[1] >> 2));
  n196[0] = (1 & (n169[1] >> 7));
  n190[0] = 0;
  n184[0] = (1 & (n180[0])) | (2 & (n180[0])) | (4 & (n180[0])) | (8 & (n180[0])) | (16 & (n180[0])) | (32 & (n180[0])) | (64 & (n180[0])) | (128 & (n180[0]));
  n184[1] = (1 & (n180[1])) | (2 & (n180[1])) | (4 & (n180[1])) | (8 & (n180[1])) | (16 & (n180[1])) | (32 & (n180[1])) | (64 & (n180[1]));
  n182[0] = (1 & (n180[1] >> 7));
  n170[0] = 228;
  n170[1] = 18;
  n158[0] = (1 & (n97[0] >> 1)) | (2 & (n97[0] >> 1)) | (4 & (n97[0] >> 1)) | (8 & (n97[0] >> 1)) | (16 & (n97[0] >> 1)) | (32 & (n97[0] >> 1)) | (64 & (n97[0] >> 1)) | (128 & (n97[1] << 7));
  n158[1] = (1 & (n97[1] >> 1)) | (2 & (n97[1] >> 1)) | (4 & (n97[1] >> 1)) | (8 & (n97[1] >> 1)) | (16 & (n97[1] >> 1)) | (32 & (n97[1] >> 1)) | (64 & (n97[1] >> 1));
  n155[0] = (1 & (n97[1] >> 7));
  n142[0] = (1 & (n112[0] >> 1)) | (2 & (n112[0] >> 1)) | (4 & (n112[0] >> 1)) | (8 & (n112[0] >> 1)) | (16 & (n112[0] >> 1)) | (32 & (n112[0] >> 1)) | (64 & (n112[0] >> 1)) | (128 & (n112[1] << 7));
  n142[1] = (1 & (n112[1] >> 1)) | (2 & (n112[1] >> 1)) | (4 & (n112[1] >> 1)) | (8 & (n112[1] >> 1)) | (16 & (n112[1] >> 1)) | (32 & (n112[1] >> 1)) | (64 & (n112[1] >> 1));
  n139[0] = (1 & (n112[1] >> 7));
  n133[0] = 0;
  n127[0] = (1 & (n123[0])) | (2 & (n123[0])) | (4 & (n123[0])) | (8 & (n123[0])) | (16 & (n123[0])) | (32 & (n123[0])) | (64 & (n123[0])) | (128 & (n123[0]));
  n127[1] = (1 & (n123[1])) | (2 & (n123[1])) | (4 & (n123[1])) | (8 & (n123[1])) | (16 & (n123[1])) | (32 & (n123[1])) | (64 & (n123[1]));
  n125[0] = (1 & (n123[1] >> 7));
  n113[0] = 0;
  n113[1] = 32;
  n101[0] = (1 & (n52[0])) | (2 & (n52[0])) | (4 & (n52[0])) | (8 & (n52[0])) | (16 & (n52[0])) | (32 & (n52[0])) | (64 & (n52[0])) | (128 & (n52[0]));
  n101[1] = (1 & (n52[1])) | (2 & (n52[1])) | (4 & (n52[1])) | (8 & (n52[1])) | (16 & (n52[1])) | (32 & (n52[1])) | (64 & (n52[1])) | (128 & (n52[1]));
  n86[0] = (1 & (n60[0])) | (2 & (n60[0])) | (4 & (n60[0])) | (8 & (n60[0])) | (16 & (n60[0])) | (32 & (n60[0])) | (64 & (n60[0])) | (128 & (n60[0]));
  n86[1] = (1 & (n60[1])) | (2 & (n60[1])) | (4 & (n60[1])) | (8 & (n60[1])) | (16 & (n60[1])) | (32 & (n60[1])) | (64 & (n60[1])) | (128 & (n60[1]));
  n78[0] = 0;
  n72[0] = (1 & (n68[0])) | (2 & (n68[0])) | (4 & (n68[0])) | (8 & (n68[0])) | (16 & (n68[0])) | (32 & (n68[0])) | (64 & (n68[0])) | (128 & (n68[0]));
  n72[1] = (1 & (n68[1])) | (2 & (n68[1])) | (4 & (n68[1])) | (8 & (n68[1])) | (16 & (n68[1])) | (32 & (n68[1])) | (64 & (n68[1]));
  n70[0] = (1 & (n68[1] >> 7));
  n39[0] = 0;
  n39[1] = 0;
  n37[0] = 0;
  n37[1] = 0;
  { unsigned int tmp; (tmp = (unsigned int) n1103[1] - (unsigned int) n1178[1] - (tmp = (unsigned int) n1103[0] - (unsigned int) n1178[0], n1180[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1180[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1103[1] + (unsigned int) n1178[1] + (tmp = (unsigned int) n1103[0] + (unsigned int) n1178[0], n1179[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1179[1] = 255 & (unsigned char) tmp); }
  n1152[0] = 255 & (n1149[0] << 1 | n1149[0]);
  n1122[0] = 255 & (n1119[0] << 1 | n1119[0]);
  n1106[0] = 1 & ~n1105[0];
  { unsigned int tmp; (tmp = (unsigned int) n1020[1] - (unsigned int) n1093[1] - (tmp = (unsigned int) n1020[0] - (unsigned int) n1093[0], n1095[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1095[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1020[1] + (unsigned int) n1093[1] + (tmp = (unsigned int) n1020[0] + (unsigned int) n1093[0], n1094[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1094[1] = 255 & (unsigned char) tmp); }
  n1068[0] = 255 & (n1065[0] << 1 | n1065[0]);
  n1039[0] = 255 & (n1036[0] << 1 | n1036[0]);
  n1023[0] = 1 & ~n1022[0];
  { unsigned int tmp; (tmp = (unsigned int) n939[1] - (unsigned int) n1010[1] - (tmp = (unsigned int) n939[0] - (unsigned int) n1010[0], n1012[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1012[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n939[1] + (unsigned int) n1010[1] + (tmp = (unsigned int) n939[0] + (unsigned int) n1010[0], n1011[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1011[1] = 255 & (unsigned char) tmp); }
  n986[0] = 255 & (n983[0] << 1 | n983[0]);
  n958[0] = 255 & (n955[0] << 1 | n955[0]);
  n942[0] = 1 & ~n941[0];
  { unsigned int tmp; (tmp = (unsigned int) n860[1] - (unsigned int) n929[1] - (tmp = (unsigned int) n860[0] - (unsigned int) n929[0], n931[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n931[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n860[1] + (unsigned int) n929[1] + (tmp = (unsigned int) n860[0] + (unsigned int) n929[0], n930[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n930[1] = 255 & (unsigned char) tmp); }
  n906[0] = 255 & (n903[0] << 1 | n903[0]);
  n879[0] = 255 & (n876[0] << 1 | n876[0]);
  n863[0] = 1 & ~n862[0];
  { unsigned int tmp; (tmp = (unsigned int) n783[1] - (unsigned int) n850[1] - (tmp = (unsigned int) n783[0] - (unsigned int) n850[0], n852[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n852[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n783[1] + (unsigned int) n850[1] + (tmp = (unsigned int) n783[0] + (unsigned int) n850[0], n851[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n851[1] = 255 & (unsigned char) tmp); }
  n828[0] = 255 & (n825[0] << 1 | n825[0]);
  n802[0] = 255 & (n799[0] << 1 | n799[0]);
  n786[0] = 1 & ~n785[0];
  { unsigned int tmp; (tmp = (unsigned int) n708[1] - (unsigned int) n773[1] - (tmp = (unsigned int) n708[0] - (unsigned int) n773[0], n775[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n775[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n708[1] + (unsigned int) n773[1] + (tmp = (unsigned int) n708[0] + (unsigned int) n773[0], n774[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n774[1] = 255 & (unsigned char) tmp); }
  n752[0] = 255 & (n749[0] << 1 | n749[0]);
  n727[0] = 255 & (n724[0] << 1 | n724[0]);
  n711[0] = 1 & ~n710[0];
  { unsigned int tmp; (tmp = (unsigned int) n635[1] - (unsigned int) n698[1] - (tmp = (unsigned int) n635[0] - (unsigned int) n698[0], n700[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n700[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n635[1] + (unsigned int) n698[1] + (tmp = (unsigned int) n635[0] + (unsigned int) n698[0], n699[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n699[1] = 255 & (unsigned char) tmp); }
  n678[0] = 255 & (n675[0] << 1 | n675[0]);
  n654[0] = 255 & (n651[0] << 1 | n651[0]);
  n638[0] = 1 & ~n637[0];
  { unsigned int tmp; (tmp = (unsigned int) n564[1] - (unsigned int) n625[1] - (tmp = (unsigned int) n564[0] - (unsigned int) n625[0], n627[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n627[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n564[1] + (unsigned int) n625[1] + (tmp = (unsigned int) n564[0] + (unsigned int) n625[0], n626[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n626[1] = 255 & (unsigned char) tmp); }
  n606[0] = 255 & (n603[0] << 1 | n603[0]);
  n583[0] = 255 & (n580[0] << 1 | n580[0]);
  n567[0] = 1 & ~n566[0];
  { unsigned int tmp; (tmp = (unsigned int) n495[1] - (unsigned int) n554[1] - (tmp = (unsigned int) n495[0] - (unsigned int) n554[0], n556[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n556[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n495[1] + (unsigned int) n554[1] + (tmp = (unsigned int) n495[0] + (unsigned int) n554[0], n555[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n555[1] = 255 & (unsigned char) tmp); }
  n536[0] = 255 & (n533[0] << 1 | n533[0]);
  n514[0] = 255 & (n511[0] << 1 | n511[0]);
  n498[0] = 1 & ~n497[0];
  { unsigned int tmp; (tmp = (unsigned int) n428[1] - (unsigned int) n485[1] - (tmp = (unsigned int) n428[0] - (unsigned int) n485[0], n487[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n487[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n428[1] + (unsigned int) n485[1] + (tmp = (unsigned int) n428[0] + (unsigned int) n485[0], n486[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n486[1] = 255 & (unsigned char) tmp); }
  n468[0] = 255 & (n465[0] << 1 | n465[0]);
  n447[0] = 255 & (n444[0] << 1 | n444[0]);
  n431[0] = 1 & ~n430[0];
  { unsigned int tmp; (tmp = (unsigned int) n363[1] - (unsigned int) n418[1] - (tmp = (unsigned int) n363[0] - (unsigned int) n418[0], n420[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n420[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n363[1] + (unsigned int) n418[1] + (tmp = (unsigned int) n363[0] + (unsigned int) n418[0], n419[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n419[1] = 255 & (unsigned char) tmp); }
  n402[0] = 255 & (n399[0] << 1 | n399[0]);
  n382[0] = 255 & (n379[0] << 1 | n379[0]);
  n366[0] = 1 & ~n365[0];
  { unsigned int tmp; (tmp = (unsigned int) n300[1] - (unsigned int) n353[1] - (tmp = (unsigned int) n300[0] - (unsigned int) n353[0], n355[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n355[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n300[1] + (unsigned int) n353[1] + (tmp = (unsigned int) n300[0] + (unsigned int) n353[0], n354[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n354[1] = 255 & (unsigned char) tmp); }
  n338[0] = 255 & (n335[0] << 1 | n335[0]);
  n319[0] = 255 & (n316[0] << 1 | n316[0]);
  n303[0] = 1 & ~n302[0];
  { unsigned int tmp; (tmp = (unsigned int) n239[1] - (unsigned int) n290[1] - (tmp = (unsigned int) n239[0] - (unsigned int) n290[0], n292[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n292[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n239[1] + (unsigned int) n290[1] + (tmp = (unsigned int) n239[0] + (unsigned int) n290[0], n291[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n291[1] = 255 & (unsigned char) tmp); }
  n276[0] = 255 & (n273[0] << 1 | n273[0]);
  n258[0] = 255 & (n255[0] << 1 | n255[0]);
  n242[0] = 1 & ~n241[0];
  { unsigned int tmp; (tmp = (unsigned int) n180[1] - (unsigned int) n229[1] - (tmp = (unsigned int) n180[0] - (unsigned int) n229[0], n231[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n231[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n180[1] + (unsigned int) n229[1] + (tmp = (unsigned int) n180[0] + (unsigned int) n229[0], n230[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n230[1] = 255 & (unsigned char) tmp); }
  n216[0] = 255 & (n213[0] << 1 | n213[0]);
  n199[0] = 255 & (n196[0] << 1 | n196[0]);
  n183[0] = 1 & ~n182[0];
  { unsigned int tmp; (tmp = (unsigned int) n123[1] - (unsigned int) n170[1] - (tmp = (unsigned int) n123[0] - (unsigned int) n170[0], n172[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n172[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n123[1] + (unsigned int) n170[1] + (tmp = (unsigned int) n123[0] + (unsigned int) n170[0], n171[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n171[1] = 255 & (unsigned char) tmp); }
  n159[0] = n158[0];
  n159[1] = 255 & (n155[0] << 7 | n158[1]);
  n143[0] = n142[0];
  n143[1] = 255 & (n139[0] << 7 | n142[1]);
  n126[0] = 1 & ~n125[0];
  { unsigned int tmp; (tmp = (unsigned int) n68[1] - (unsigned int) n113[1] - (tmp = (unsigned int) n68[0] - (unsigned int) n113[0], n115[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n115[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n68[1] + (unsigned int) n113[1] + (tmp = (unsigned int) n68[0] + (unsigned int) n113[0], n114[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n114[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n60[1] - (unsigned int) n101[1] - (tmp = (unsigned int) n60[0] - (unsigned int) n101[0], n104[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n104[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n60[1] + (unsigned int) n101[1] + (tmp = (unsigned int) n60[0] + (unsigned int) n101[0], n103[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n103[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n52[1] - (unsigned int) n86[1] - (tmp = (unsigned int) n52[0] - (unsigned int) n86[0], n89[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n89[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n52[1] + (unsigned int) n86[1] + (tmp = (unsigned int) n52[0] + (unsigned int) n86[0], n88[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n88[1] = 255 & (unsigned char) tmp); }
  n71[0] = 1 & ~n70[0];
  { unsigned int tmp; (tmp = (unsigned int) n36[1] - (unsigned int) n1194[1] - (tmp = (unsigned int) n36[0] - (unsigned int) n1194[0], n44[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n44[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n39[1] - (unsigned int) n29[1] - (tmp = (unsigned int) n39[0] - (unsigned int) n29[0], n40[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n40[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n37[1] - (unsigned int) n22[1] - (tmp = (unsigned int) n37[0] - (unsigned int) n22[0], n38[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n38[1] = 255 & (unsigned char) tmp); }
  n36r[0] = reset_i[0];
  n36e[0] = enable_i[0];
  n36d[0] = ang_i[0];
  n36d[1] = ang_i[1];
  n29r[0] = reset_i[0];
  n29e[0] = enable_i[0];
  n29d[0] = imag_i[0];
  n29d[1] = imag_i[1];
  n22r[0] = reset_i[0];
  n22e[0] = enable_i[0];
  n22d[0] = real_i[0];
  n22d[1] = real_i[1];
  n15r[0] = reset_i[0];
  n15e[0] = enable_i[0];
  n15d[0] = flip_i[0];
  n1153[0] = 255 & (n1149[0] << 2 | n1152[0]);
  n1123[0] = 255 & (n1119[0] << 2 | n1122[0]);
  n1108[0] = n1107[0];
  n1108[1] = 255 & (n1106[0] << 7 | n1107[1]);
  n1069[0] = 255 & (n1065[0] << 2 | n1068[0]);
  n1040[0] = 255 & (n1036[0] << 2 | n1039[0]);
  n1025[0] = n1024[0];
  n1025[1] = 255 & (n1023[0] << 7 | n1024[1]);
  n987[0] = 255 & (n983[0] << 2 | n986[0]);
  n959[0] = 255 & (n955[0] << 2 | n958[0]);
  n944[0] = n943[0];
  n944[1] = 255 & (n942[0] << 7 | n943[1]);
  n907[0] = 255 & (n903[0] << 2 | n906[0]);
  n880[0] = 255 & (n876[0] << 2 | n879[0]);
  n865[0] = n864[0];
  n865[1] = 255 & (n863[0] << 7 | n864[1]);
  n829[0] = 255 & (n825[0] << 2 | n828[0]);
  n803[0] = 255 & (n799[0] << 2 | n802[0]);
  n788[0] = n787[0];
  n788[1] = 255 & (n786[0] << 7 | n787[1]);
  n753[0] = 255 & (n749[0] << 2 | n752[0]);
  n728[0] = 255 & (n724[0] << 2 | n727[0]);
  n713[0] = n712[0];
  n713[1] = 255 & (n711[0] << 7 | n712[1]);
  n679[0] = 255 & (n675[0] << 2 | n678[0]);
  n655[0] = 255 & (n651[0] << 2 | n654[0]);
  n640[0] = n639[0];
  n640[1] = 255 & (n638[0] << 7 | n639[1]);
  n607[0] = 255 & (n603[0] << 2 | n606[0]);
  n584[0] = 255 & (n580[0] << 2 | n583[0]);
  n569[0] = n568[0];
  n569[1] = 255 & (n567[0] << 7 | n568[1]);
  n537[0] = 255 & (n533[0] << 2 | n536[0]);
  n515[0] = 255 & (n511[0] << 2 | n514[0]);
  n500[0] = n499[0];
  n500[1] = 255 & (n498[0] << 7 | n499[1]);
  n469[0] = 255 & (n465[0] << 2 | n468[0]);
  n448[0] = 255 & (n444[0] << 2 | n447[0]);
  n433[0] = n432[0];
  n433[1] = 255 & (n431[0] << 7 | n432[1]);
  n403[0] = 255 & (n399[0] << 2 | n402[0]);
  n383[0] = 255 & (n379[0] << 2 | n382[0]);
  n368[0] = n367[0];
  n368[1] = 255 & (n366[0] << 7 | n367[1]);
  n339[0] = 255 & (n335[0] << 2 | n338[0]);
  n320[0] = 255 & (n316[0] << 2 | n319[0]);
  n305[0] = n304[0];
  n305[1] = 255 & (n303[0] << 7 | n304[1]);
  n277[0] = 255 & (n273[0] << 2 | n276[0]);
  n259[0] = 255 & (n255[0] << 2 | n258[0]);
  n244[0] = n243[0];
  n244[1] = 255 & (n242[0] << 7 | n243[1]);
  n218[0] = n217[0];
  n218[1] = 255 & (n216[0] << 6 | n217[1]);
  n201[0] = n200[0];
  n201[1] = 255 & (n199[0] << 6 | n200[1]);
  n185[0] = n184[0];
  n185[1] = 255 & (n183[0] << 7 | n184[1]);
  { unsigned int tmp; (tmp = (unsigned int) n112[1] - (unsigned int) n159[1] - (tmp = (unsigned int) n112[0] - (unsigned int) n159[0], n161[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n161[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n112[1] + (unsigned int) n159[1] + (tmp = (unsigned int) n112[0] + (unsigned int) n159[0], n160[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n160[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n97[1] - (unsigned int) n143[1] - (tmp = (unsigned int) n97[0] - (unsigned int) n143[0], n145[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n145[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n97[1] + (unsigned int) n143[1] + (tmp = (unsigned int) n97[0] + (unsigned int) n143[0], n144[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n144[1] = 255 & (unsigned char) tmp); }
  n128[0] = n127[0];
  n128[1] = 255 & (n126[0] << 7 | n127[1]);
  n73[0] = n72[0];
  n73[1] = 255 & (n71[0] << 7 | n72[1]);
  if (n15[0]) {
    n61[0] = n44[0];
    n61[1] = n44[1];
  }
  else {
    n61[0] = n36[0];
    n61[1] = n36[1];
  }
  if (n15[0]) {
    n53[0] = n40[0];
    n53[1] = n40[1];
  }
  else {
    n53[0] = n29[0];
    n53[1] = n29[1];
  }
  if (n15[0]) {
    n45[0] = n38[0];
    n45[1] = n38[1];
  }
  else {
    n45[0] = n22[0];
    n45[1] = n22[1];
  }
  n1154[0] = 255 & (n1149[0] << 3 | n1153[0]);
  n1124[0] = 255 & (n1119[0] << 3 | n1123[0]);
  n1114[0] = n1108[0];
  n1114[1] = n1108[1];
  n1114[2] = n1113[0];
  n1070[0] = 255 & (n1065[0] << 3 | n1069[0]);
  n1041[0] = 255 & (n1036[0] << 3 | n1040[0]);
  n1031[0] = n1025[0];
  n1031[1] = n1025[1];
  n1031[2] = n1030[0];
  n988[0] = 255 & (n983[0] << 3 | n987[0]);
  n960[0] = 255 & (n955[0] << 3 | n959[0]);
  n950[0] = n944[0];
  n950[1] = n944[1];
  n950[2] = n949[0];
  n908[0] = 255 & (n903[0] << 3 | n907[0]);
  n881[0] = 255 & (n876[0] << 3 | n880[0]);
  n871[0] = n865[0];
  n871[1] = n865[1];
  n871[2] = n870[0];
  n830[0] = 255 & (n825[0] << 3 | n829[0]);
  n804[0] = 255 & (n799[0] << 3 | n803[0]);
  n794[0] = n788[0];
  n794[1] = n788[1];
  n794[2] = n793[0];
  n754[0] = 255 & (n749[0] << 3 | n753[0]);
  n729[0] = 255 & (n724[0] << 3 | n728[0]);
  n719[0] = n713[0];
  n719[1] = n713[1];
  n719[2] = n718[0];
  n680[0] = 255 & (n675[0] << 3 | n679[0]);
  n656[0] = 255 & (n651[0] << 3 | n655[0]);
  n646[0] = n640[0];
  n646[1] = n640[1];
  n646[2] = n645[0];
  n608[0] = 255 & (n603[0] << 3 | n607[0]);
  n585[0] = 255 & (n580[0] << 3 | n584[0]);
  n575[0] = n569[0];
  n575[1] = n569[1];
  n575[2] = n574[0];
  n538[0] = 255 & (n533[0] << 3 | n537[0]);
  n516[0] = 255 & (n511[0] << 3 | n515[0]);
  n506[0] = n500[0];
  n506[1] = n500[1];
  n506[2] = n505[0];
  n470[0] = 255 & (n465[0] << 3 | n469[0]);
  n449[0] = 255 & (n444[0] << 3 | n448[0]);
  n439[0] = n433[0];
  n439[1] = n433[1];
  n439[2] = n438[0];
  n404[0] = 255 & (n399[0] << 3 | n403[0]);
  n384[0] = 255 & (n379[0] << 3 | n383[0]);
  n374[0] = n368[0];
  n374[1] = n368[1];
  n374[2] = n373[0];
  n340[0] = 255 & (n335[0] << 3 | n339[0]);
  n321[0] = 255 & (n316[0] << 3 | n320[0]);
  n311[0] = n305[0];
  n311[1] = n305[1];
  n311[2] = n310[0];
  n279[0] = n278[0];
  n279[1] = 255 & (n277[0] << 5 | n278[1]);
  n261[0] = n260[0];
  n261[1] = 255 & (n259[0] << 5 | n260[1]);
  n250[0] = n244[0];
  n250[1] = n244[1];
  n250[2] = n249[0];
  { unsigned int tmp; (tmp = (unsigned int) n169[1] - (unsigned int) n218[1] - (tmp = (unsigned int) n169[0] - (unsigned int) n218[0], n220[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n220[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n169[1] + (unsigned int) n218[1] + (tmp = (unsigned int) n169[0] + (unsigned int) n218[0], n219[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n219[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n153[1] - (unsigned int) n201[1] - (tmp = (unsigned int) n153[0] - (unsigned int) n201[0], n203[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n203[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n153[1] + (unsigned int) n201[1] + (tmp = (unsigned int) n153[0] + (unsigned int) n201[0], n202[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n202[1] = 255 & (unsigned char) tmp); }
  n191[0] = n185[0];
  n191[1] = n185[1];
  n191[2] = n190[0];
  n134[0] = n128[0];
  n134[1] = n128[1];
  n134[2] = n133[0];
  n79[0] = n73[0];
  n79[1] = n73[1];
  n79[2] = n78[0];
  n68r[0] = reset_i[0];
  n68e[0] = enable_i[0];
  n68d[0] = n61[0];
  n68d[1] = n61[1];
  n60r[0] = reset_i[0];
  n60e[0] = enable_i[0];
  n60d[0] = n53[0];
  n60d[1] = n53[1];
  n52r[0] = reset_i[0];
  n52e[0] = enable_i[0];
  n52d[0] = n45[0];
  n52d[1] = n45[1];
  n1155[0] = 255 & (n1149[0] << 4 | n1154[0]);
  n1125[0] = 255 & (n1119[0] << 4 | n1124[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1114[2] - (unsigned int) n1291[2] - (tmp = (unsigned int) n1114[1] - (unsigned int) n1291[1] - (tmp = (unsigned int) n1114[0] - (unsigned int) n1291[0], n1117[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1117[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1117[2] = 1 & (unsigned char) tmp); }
  n1071[0] = 255 & (n1065[0] << 4 | n1070[0]);
  n1042[0] = 255 & (n1036[0] << 4 | n1041[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1031[2] - (unsigned int) n1289[2] - (tmp = (unsigned int) n1031[1] - (unsigned int) n1289[1] - (tmp = (unsigned int) n1031[0] - (unsigned int) n1289[0], n1034[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1034[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1034[2] = 1 & (unsigned char) tmp); }
  n989[0] = 255 & (n983[0] << 4 | n988[0]);
  n961[0] = 255 & (n955[0] << 4 | n960[0]);
  { unsigned int tmp; (tmp = (unsigned int) n950[2] - (unsigned int) n1287[2] - (tmp = (unsigned int) n950[1] - (unsigned int) n1287[1] - (tmp = (unsigned int) n950[0] - (unsigned int) n1287[0], n953[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n953[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n953[2] = 1 & (unsigned char) tmp); }
  n909[0] = 255 & (n903[0] << 4 | n908[0]);
  n882[0] = 255 & (n876[0] << 4 | n881[0]);
  { unsigned int tmp; (tmp = (unsigned int) n871[2] - (unsigned int) n1285[2] - (tmp = (unsigned int) n871[1] - (unsigned int) n1285[1] - (tmp = (unsigned int) n871[0] - (unsigned int) n1285[0], n874[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n874[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n874[2] = 1 & (unsigned char) tmp); }
  n831[0] = 255 & (n825[0] << 4 | n830[0]);
  n805[0] = 255 & (n799[0] << 4 | n804[0]);
  { unsigned int tmp; (tmp = (unsigned int) n794[2] - (unsigned int) n1283[2] - (tmp = (unsigned int) n794[1] - (unsigned int) n1283[1] - (tmp = (unsigned int) n794[0] - (unsigned int) n1283[0], n797[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n797[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n797[2] = 1 & (unsigned char) tmp); }
  n755[0] = 255 & (n749[0] << 4 | n754[0]);
  n730[0] = 255 & (n724[0] << 4 | n729[0]);
  { unsigned int tmp; (tmp = (unsigned int) n719[2] - (unsigned int) n1281[2] - (tmp = (unsigned int) n719[1] - (unsigned int) n1281[1] - (tmp = (unsigned int) n719[0] - (unsigned int) n1281[0], n722[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n722[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n722[2] = 1 & (unsigned char) tmp); }
  n681[0] = 255 & (n675[0] << 4 | n680[0]);
  n657[0] = 255 & (n651[0] << 4 | n656[0]);
  { unsigned int tmp; (tmp = (unsigned int) n646[2] - (unsigned int) n1279[2] - (tmp = (unsigned int) n646[1] - (unsigned int) n1279[1] - (tmp = (unsigned int) n646[0] - (unsigned int) n1279[0], n649[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n649[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n649[2] = 1 & (unsigned char) tmp); }
  n609[0] = 255 & (n603[0] << 4 | n608[0]);
  n586[0] = 255 & (n580[0] << 4 | n585[0]);
  { unsigned int tmp; (tmp = (unsigned int) n575[2] - (unsigned int) n1277[2] - (tmp = (unsigned int) n575[1] - (unsigned int) n1277[1] - (tmp = (unsigned int) n575[0] - (unsigned int) n1277[0], n578[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n578[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n578[2] = 1 & (unsigned char) tmp); }
  n539[0] = 255 & (n533[0] << 4 | n538[0]);
  n517[0] = 255 & (n511[0] << 4 | n516[0]);
  { unsigned int tmp; (tmp = (unsigned int) n506[2] - (unsigned int) n1275[2] - (tmp = (unsigned int) n506[1] - (unsigned int) n1275[1] - (tmp = (unsigned int) n506[0] - (unsigned int) n1275[0], n509[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n509[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n509[2] = 1 & (unsigned char) tmp); }
  n471[0] = 255 & (n465[0] << 4 | n470[0]);
  n450[0] = 255 & (n444[0] << 4 | n449[0]);
  { unsigned int tmp; (tmp = (unsigned int) n439[2] - (unsigned int) n1273[2] - (tmp = (unsigned int) n439[1] - (unsigned int) n1273[1] - (tmp = (unsigned int) n439[0] - (unsigned int) n1273[0], n442[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n442[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n442[2] = 1 & (unsigned char) tmp); }
  n405[0] = 255 & (n399[0] << 4 | n404[0]);
  n385[0] = 255 & (n379[0] << 4 | n384[0]);
  { unsigned int tmp; (tmp = (unsigned int) n374[2] - (unsigned int) n1271[2] - (tmp = (unsigned int) n374[1] - (unsigned int) n1271[1] - (tmp = (unsigned int) n374[0] - (unsigned int) n1271[0], n377[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n377[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n377[2] = 1 & (unsigned char) tmp); }
  n342[0] = n341[0];
  n342[1] = 255 & (n340[0] << 4 | n341[1]);
  n323[0] = n322[0];
  n323[1] = 255 & (n321[0] << 4 | n322[1]);
  { unsigned int tmp; (tmp = (unsigned int) n311[2] - (unsigned int) n1269[2] - (tmp = (unsigned int) n311[1] - (unsigned int) n1269[1] - (tmp = (unsigned int) n311[0] - (unsigned int) n1269[0], n314[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n314[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n314[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n228[1] - (unsigned int) n279[1] - (tmp = (unsigned int) n228[0] - (unsigned int) n279[0], n281[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n281[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n228[1] + (unsigned int) n279[1] + (tmp = (unsigned int) n228[0] + (unsigned int) n279[0], n280[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n280[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n211[1] - (unsigned int) n261[1] - (tmp = (unsigned int) n211[0] - (unsigned int) n261[0], n263[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n263[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n211[1] + (unsigned int) n261[1] + (tmp = (unsigned int) n211[0] + (unsigned int) n261[0], n262[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n262[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n250[2] - (unsigned int) n1267[2] - (tmp = (unsigned int) n250[1] - (unsigned int) n1267[1] - (tmp = (unsigned int) n250[0] - (unsigned int) n1267[0], n253[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n253[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n253[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n191[2] - (unsigned int) n1265[2] - (tmp = (unsigned int) n191[1] - (unsigned int) n1265[1] - (tmp = (unsigned int) n191[0] - (unsigned int) n1265[0], n194[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n194[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n194[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n134[2] - (unsigned int) n1263[2] - (tmp = (unsigned int) n134[1] - (unsigned int) n1263[1] - (tmp = (unsigned int) n134[0] - (unsigned int) n1263[0], n137[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n137[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n137[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n79[2] - (unsigned int) n1261[2] - (tmp = (unsigned int) n79[1] - (unsigned int) n1261[1] - (tmp = (unsigned int) n79[0] - (unsigned int) n1261[0], n82[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n82[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n82[2] = 1 & (unsigned char) tmp); }
  n1156[0] = 255 & (n1149[0] << 5 | n1155[0]);
  n1126[0] = 255 & (n1119[0] << 5 | n1125[0]);
  n1118[0] = (1 & (n1117[2]));
  n1072[0] = 255 & (n1065[0] << 5 | n1071[0]);
  n1043[0] = 255 & (n1036[0] << 5 | n1042[0]);
  n1035[0] = (1 & (n1034[2]));
  n990[0] = 255 & (n983[0] << 5 | n989[0]);
  n962[0] = 255 & (n955[0] << 5 | n961[0]);
  n954[0] = (1 & (n953[2]));
  n910[0] = 255 & (n903[0] << 5 | n909[0]);
  n883[0] = 255 & (n876[0] << 5 | n882[0]);
  n875[0] = (1 & (n874[2]));
  n832[0] = 255 & (n825[0] << 5 | n831[0]);
  n806[0] = 255 & (n799[0] << 5 | n805[0]);
  n798[0] = (1 & (n797[2]));
  n756[0] = 255 & (n749[0] << 5 | n755[0]);
  n731[0] = 255 & (n724[0] << 5 | n730[0]);
  n723[0] = (1 & (n722[2]));
  n682[0] = 255 & (n675[0] << 5 | n681[0]);
  n658[0] = 255 & (n651[0] << 5 | n657[0]);
  n650[0] = (1 & (n649[2]));
  n610[0] = 255 & (n603[0] << 5 | n609[0]);
  n587[0] = 255 & (n580[0] << 5 | n586[0]);
  n579[0] = (1 & (n578[2]));
  n540[0] = 255 & (n533[0] << 5 | n539[0]);
  n518[0] = 255 & (n511[0] << 5 | n517[0]);
  n510[0] = (1 & (n509[2]));
  n472[0] = 255 & (n465[0] << 5 | n471[0]);
  n451[0] = 255 & (n444[0] << 5 | n450[0]);
  n443[0] = (1 & (n442[2]));
  n407[0] = n406[0];
  n407[1] = 255 & (n405[0] << 3 | n406[1]);
  n387[0] = n386[0];
  n387[1] = 255 & (n385[0] << 3 | n386[1]);
  n378[0] = (1 & (n377[2]));
  { unsigned int tmp; (tmp = (unsigned int) n289[1] - (unsigned int) n342[1] - (tmp = (unsigned int) n289[0] - (unsigned int) n342[0], n344[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n344[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n289[1] + (unsigned int) n342[1] + (tmp = (unsigned int) n289[0] + (unsigned int) n342[0], n343[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n343[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n271[1] - (unsigned int) n323[1] - (tmp = (unsigned int) n271[0] - (unsigned int) n323[0], n325[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n325[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n271[1] + (unsigned int) n323[1] + (tmp = (unsigned int) n271[0] + (unsigned int) n323[0], n324[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n324[1] = 255 & (unsigned char) tmp); }
  n315[0] = (1 & (n314[2]));
  n254[0] = (1 & (n253[2]));
  n195[0] = (1 & (n194[2]));
  n138[0] = (1 & (n137[2]));
  n83[0] = (1 & (n82[2]));
  if (n1118[0]) {
    n1181[0] = n1179[0];
    n1181[1] = n1179[1];
  }
  else {
    n1181[0] = n1180[0];
    n1181[1] = n1180[1];
  }
  n1157[0] = 255 & (n1149[0] << 6 | n1156[0]);
  n1148[0] = 1 & ~n1118[0];
  n1127[0] = 255 & (n1119[0] << 6 | n1126[0]);
  if (n1035[0]) {
    n1096[0] = n1094[0];
    n1096[1] = n1094[1];
  }
  else {
    n1096[0] = n1095[0];
    n1096[1] = n1095[1];
  }
  n1073[0] = 255 & (n1065[0] << 6 | n1072[0]);
  n1064[0] = 1 & ~n1035[0];
  n1044[0] = 255 & (n1036[0] << 6 | n1043[0]);
  if (n954[0]) {
    n1013[0] = n1011[0];
    n1013[1] = n1011[1];
  }
  else {
    n1013[0] = n1012[0];
    n1013[1] = n1012[1];
  }
  n991[0] = 255 & (n983[0] << 6 | n990[0]);
  n982[0] = 1 & ~n954[0];
  n963[0] = 255 & (n955[0] << 6 | n962[0]);
  if (n875[0]) {
    n932[0] = n930[0];
    n932[1] = n930[1];
  }
  else {
    n932[0] = n931[0];
    n932[1] = n931[1];
  }
  n911[0] = 255 & (n903[0] << 6 | n910[0]);
  n902[0] = 1 & ~n875[0];
  n884[0] = 255 & (n876[0] << 6 | n883[0]);
  if (n798[0]) {
    n853[0] = n851[0];
    n853[1] = n851[1];
  }
  else {
    n853[0] = n852[0];
    n853[1] = n852[1];
  }
  n833[0] = 255 & (n825[0] << 6 | n832[0]);
  n824[0] = 1 & ~n798[0];
  n807[0] = 255 & (n799[0] << 6 | n806[0]);
  if (n723[0]) {
    n776[0] = n774[0];
    n776[1] = n774[1];
  }
  else {
    n776[0] = n775[0];
    n776[1] = n775[1];
  }
  n757[0] = 255 & (n749[0] << 6 | n756[0]);
  n748[0] = 1 & ~n723[0];
  n732[0] = 255 & (n724[0] << 6 | n731[0]);
  if (n650[0]) {
    n701[0] = n699[0];
    n701[1] = n699[1];
  }
  else {
    n701[0] = n700[0];
    n701[1] = n700[1];
  }
  n683[0] = 255 & (n675[0] << 6 | n682[0]);
  n674[0] = 1 & ~n650[0];
  n659[0] = 255 & (n651[0] << 6 | n658[0]);
  if (n579[0]) {
    n628[0] = n626[0];
    n628[1] = n626[1];
  }
  else {
    n628[0] = n627[0];
    n628[1] = n627[1];
  }
  n611[0] = 255 & (n603[0] << 6 | n610[0]);
  n602[0] = 1 & ~n579[0];
  n588[0] = 255 & (n580[0] << 6 | n587[0]);
  if (n510[0]) {
    n557[0] = n555[0];
    n557[1] = n555[1];
  }
  else {
    n557[0] = n556[0];
    n557[1] = n556[1];
  }
  n541[0] = 255 & (n533[0] << 6 | n540[0]);
  n532[0] = 1 & ~n510[0];
  n519[0] = 255 & (n511[0] << 6 | n518[0]);
  if (n443[0]) {
    n488[0] = n486[0];
    n488[1] = n486[1];
  }
  else {
    n488[0] = n487[0];
    n488[1] = n487[1];
  }
  n474[0] = n473[0];
  n474[1] = 255 & (n472[0] << 2 | n473[1]);
  n464[0] = 1 & ~n443[0];
  n453[0] = n452[0];
  n453[1] = 255 & (n451[0] << 2 | n452[1]);
  if (n378[0]) {
    n421[0] = n419[0];
    n421[1] = n419[1];
  }
  else {
    n421[0] = n420[0];
    n421[1] = n420[1];
  }
  { unsigned int tmp; (tmp = (unsigned int) n352[1] - (unsigned int) n407[1] - (tmp = (unsigned int) n352[0] - (unsigned int) n407[0], n409[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n409[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n352[1] + (unsigned int) n407[1] + (tmp = (unsigned int) n352[0] + (unsigned int) n407[0], n408[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n408[1] = 255 & (unsigned char) tmp); }
  n398[0] = 1 & ~n378[0];
  { unsigned int tmp; (tmp = (unsigned int) n333[1] - (unsigned int) n387[1] - (tmp = (unsigned int) n333[0] - (unsigned int) n387[0], n389[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n389[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n333[1] + (unsigned int) n387[1] + (tmp = (unsigned int) n333[0] + (unsigned int) n387[0], n388[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n388[1] = 255 & (unsigned char) tmp); }
  if (n315[0]) {
    n356[0] = n354[0];
    n356[1] = n354[1];
  }
  else {
    n356[0] = n355[0];
    n356[1] = n355[1];
  }
  n334[0] = 1 & ~n315[0];
  if (n315[0]) {
    n326[0] = n324[0];
    n326[1] = n324[1];
  }
  else {
    n326[0] = n325[0];
    n326[1] = n325[1];
  }
  if (n254[0]) {
    n293[0] = n291[0];
    n293[1] = n291[1];
  }
  else {
    n293[0] = n292[0];
    n293[1] = n292[1];
  }
  n272[0] = 1 & ~n254[0];
  if (n254[0]) {
    n264[0] = n262[0];
    n264[1] = n262[1];
  }
  else {
    n264[0] = n263[0];
    n264[1] = n263[1];
  }
  if (n195[0]) {
    n232[0] = n230[0];
    n232[1] = n230[1];
  }
  else {
    n232[0] = n231[0];
    n232[1] = n231[1];
  }
  n212[0] = 1 & ~n195[0];
  if (n195[0]) {
    n204[0] = n202[0];
    n204[1] = n202[1];
  }
  else {
    n204[0] = n203[0];
    n204[1] = n203[1];
  }
  if (n138[0]) {
    n173[0] = n171[0];
    n173[1] = n171[1];
  }
  else {
    n173[0] = n172[0];
    n173[1] = n172[1];
  }
  n154[0] = 1 & ~n138[0];
  if (n138[0]) {
    n146[0] = n144[0];
    n146[1] = n144[1];
  }
  else {
    n146[0] = n145[0];
    n146[1] = n145[1];
  }
  if (n83[0]) {
    n116[0] = n114[0];
    n116[1] = n114[1];
  }
  else {
    n116[0] = n115[0];
    n116[1] = n115[1];
  }
  n98[0] = 1 & ~n83[0];
  if (n83[0]) {
    n90[0] = n88[0];
    n90[1] = n88[1];
  }
  else {
    n90[0] = n89[0];
    n90[1] = n89[1];
  }
  n1188r[0] = reset_i[0];
  n1188e[0] = enable_i[0];
  n1188d[0] = n1181[0];
  n1188d[1] = n1181[1];
  n1158[0] = 255 & (n1149[0] << 7 | n1157[0]);
  n1128[0] = 255 & (n1119[0] << 7 | n1127[0]);
  n1103r[0] = reset_i[0];
  n1103e[0] = enable_i[0];
  n1103d[0] = n1096[0];
  n1103d[1] = n1096[1];
  n1074[0] = 255 & (n1065[0] << 7 | n1073[0]);
  n1045[0] = 255 & (n1036[0] << 7 | n1044[0]);
  n1020r[0] = reset_i[0];
  n1020e[0] = enable_i[0];
  n1020d[0] = n1013[0];
  n1020d[1] = n1013[1];
  n992[0] = 255 & (n983[0] << 7 | n991[0]);
  n964[0] = 255 & (n955[0] << 7 | n963[0]);
  n939r[0] = reset_i[0];
  n939e[0] = enable_i[0];
  n939d[0] = n932[0];
  n939d[1] = n932[1];
  n912[0] = 255 & (n903[0] << 7 | n911[0]);
  n885[0] = 255 & (n876[0] << 7 | n884[0]);
  n860r[0] = reset_i[0];
  n860e[0] = enable_i[0];
  n860d[0] = n853[0];
  n860d[1] = n853[1];
  n834[0] = 255 & (n825[0] << 7 | n833[0]);
  n808[0] = 255 & (n799[0] << 7 | n807[0]);
  n783r[0] = reset_i[0];
  n783e[0] = enable_i[0];
  n783d[0] = n776[0];
  n783d[1] = n776[1];
  n758[0] = 255 & (n749[0] << 7 | n757[0]);
  n733[0] = 255 & (n724[0] << 7 | n732[0]);
  n708r[0] = reset_i[0];
  n708e[0] = enable_i[0];
  n708d[0] = n701[0];
  n708d[1] = n701[1];
  n684[0] = 255 & (n675[0] << 7 | n683[0]);
  n660[0] = 255 & (n651[0] << 7 | n659[0]);
  n635r[0] = reset_i[0];
  n635e[0] = enable_i[0];
  n635d[0] = n628[0];
  n635d[1] = n628[1];
  n612[0] = 255 & (n603[0] << 7 | n611[0]);
  n589[0] = 255 & (n580[0] << 7 | n588[0]);
  n564r[0] = reset_i[0];
  n564e[0] = enable_i[0];
  n564d[0] = n557[0];
  n564d[1] = n557[1];
  n543[0] = n542[0];
  n543[1] = 255 & (n541[0] << 1 | n542[1]);
  n521[0] = n520[0];
  n521[1] = 255 & (n519[0] << 1 | n520[1]);
  n495r[0] = reset_i[0];
  n495e[0] = enable_i[0];
  n495d[0] = n488[0];
  n495d[1] = n488[1];
  { unsigned int tmp; (tmp = (unsigned int) n417[1] - (unsigned int) n474[1] - (tmp = (unsigned int) n417[0] - (unsigned int) n474[0], n476[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n476[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n417[1] + (unsigned int) n474[1] + (tmp = (unsigned int) n417[0] + (unsigned int) n474[0], n475[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n475[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n397[1] - (unsigned int) n453[1] - (tmp = (unsigned int) n397[0] - (unsigned int) n453[0], n455[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n455[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n397[1] + (unsigned int) n453[1] + (tmp = (unsigned int) n397[0] + (unsigned int) n453[0], n454[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n454[1] = 255 & (unsigned char) tmp); }
  n428r[0] = reset_i[0];
  n428e[0] = enable_i[0];
  n428d[0] = n421[0];
  n428d[1] = n421[1];
  if (n398[0]) {
    n410[0] = n408[0];
    n410[1] = n408[1];
  }
  else {
    n410[0] = n409[0];
    n410[1] = n409[1];
  }
  if (n378[0]) {
    n390[0] = n388[0];
    n390[1] = n388[1];
  }
  else {
    n390[0] = n389[0];
    n390[1] = n389[1];
  }
  n363r[0] = reset_i[0];
  n363e[0] = enable_i[0];
  n363d[0] = n356[0];
  n363d[1] = n356[1];
  if (n334[0]) {
    n345[0] = n343[0];
    n345[1] = n343[1];
  }
  else {
    n345[0] = n344[0];
    n345[1] = n344[1];
  }
  n333r[0] = reset_i[0];
  n333e[0] = enable_i[0];
  n333d[0] = n326[0];
  n333d[1] = n326[1];
  n300r[0] = reset_i[0];
  n300e[0] = enable_i[0];
  n300d[0] = n293[0];
  n300d[1] = n293[1];
  if (n272[0]) {
    n282[0] = n280[0];
    n282[1] = n280[1];
  }
  else {
    n282[0] = n281[0];
    n282[1] = n281[1];
  }
  n271r[0] = reset_i[0];
  n271e[0] = enable_i[0];
  n271d[0] = n264[0];
  n271d[1] = n264[1];
  n239r[0] = reset_i[0];
  n239e[0] = enable_i[0];
  n239d[0] = n232[0];
  n239d[1] = n232[1];
  if (n212[0]) {
    n221[0] = n219[0];
    n221[1] = n219[1];
  }
  else {
    n221[0] = n220[0];
    n221[1] = n220[1];
  }
  n211r[0] = reset_i[0];
  n211e[0] = enable_i[0];
  n211d[0] = n204[0];
  n211d[1] = n204[1];
  n180r[0] = reset_i[0];
  n180e[0] = enable_i[0];
  n180d[0] = n173[0];
  n180d[1] = n173[1];
  if (n154[0]) {
    n162[0] = n160[0];
    n162[1] = n160[1];
  }
  else {
    n162[0] = n161[0];
    n162[1] = n161[1];
  }
  n153r[0] = reset_i[0];
  n153e[0] = enable_i[0];
  n153d[0] = n146[0];
  n153d[1] = n146[1];
  n123r[0] = reset_i[0];
  n123e[0] = enable_i[0];
  n123d[0] = n116[0];
  n123d[1] = n116[1];
  if (n98[0]) {
    n105[0] = n103[0];
    n105[1] = n103[1];
  }
  else {
    n105[0] = n104[0];
    n105[1] = n104[1];
  }
  n97r[0] = reset_i[0];
  n97e[0] = enable_i[0];
  n97d[0] = n90[0];
  n97d[1] = n90[1];
  n1159[0] = n1158[0];
  n1159[1] = n1149[0];
  n1129[0] = n1128[0];
  n1129[1] = n1119[0];
  n1075[0] = n1074[0];
  n1075[1] = n1065[0];
  n1046[0] = n1045[0];
  n1046[1] = n1036[0];
  n993[0] = n992[0];
  n993[1] = n983[0];
  n965[0] = n964[0];
  n965[1] = n955[0];
  n913[0] = n912[0];
  n913[1] = n903[0];
  n886[0] = n885[0];
  n886[1] = n876[0];
  n835[0] = n834[0];
  n835[1] = n825[0];
  n809[0] = n808[0];
  n809[1] = n799[0];
  n759[0] = n758[0];
  n759[1] = n749[0];
  n734[0] = n733[0];
  n734[1] = n724[0];
  n685[0] = n684[0];
  n685[1] = n675[0];
  n661[0] = n660[0];
  n661[1] = n651[0];
  n614[0] = n613[0];
  n614[1] = n612[0];
  n591[0] = n590[0];
  n591[1] = n589[0];
  { unsigned int tmp; (tmp = (unsigned int) n484[1] - (unsigned int) n543[1] - (tmp = (unsigned int) n484[0] - (unsigned int) n543[0], n545[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n545[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n484[1] + (unsigned int) n543[1] + (tmp = (unsigned int) n484[0] + (unsigned int) n543[0], n544[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n544[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n463[1] - (unsigned int) n521[1] - (tmp = (unsigned int) n463[0] - (unsigned int) n521[0], n523[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n523[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n463[1] + (unsigned int) n521[1] + (tmp = (unsigned int) n463[0] + (unsigned int) n521[0], n522[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n522[1] = 255 & (unsigned char) tmp); }
  if (n464[0]) {
    n477[0] = n475[0];
    n477[1] = n475[1];
  }
  else {
    n477[0] = n476[0];
    n477[1] = n476[1];
  }
  if (n443[0]) {
    n456[0] = n454[0];
    n456[1] = n454[1];
  }
  else {
    n456[0] = n455[0];
    n456[1] = n455[1];
  }
  n417r[0] = reset_i[0];
  n417e[0] = enable_i[0];
  n417d[0] = n410[0];
  n417d[1] = n410[1];
  n397r[0] = reset_i[0];
  n397e[0] = enable_i[0];
  n397d[0] = n390[0];
  n397d[1] = n390[1];
  n352r[0] = reset_i[0];
  n352e[0] = enable_i[0];
  n352d[0] = n345[0];
  n352d[1] = n345[1];
  n289r[0] = reset_i[0];
  n289e[0] = enable_i[0];
  n289d[0] = n282[0];
  n289d[1] = n282[1];
  n228r[0] = reset_i[0];
  n228e[0] = enable_i[0];
  n228d[0] = n221[0];
  n228d[1] = n221[1];
  n169r[0] = reset_i[0];
  n169e[0] = enable_i[0];
  n169d[0] = n162[0];
  n169d[1] = n162[1];
  n112r[0] = reset_i[0];
  n112e[0] = enable_i[0];
  n112d[0] = n105[0];
  n112d[1] = n105[1];
  n1160[0] = n1159[0];
  n1160[1] = 255 & (n1149[0] << 1 | n1159[1]);
  n1130[0] = n1129[0];
  n1130[1] = 255 & (n1119[0] << 1 | n1129[1]);
  n1076[0] = n1075[0];
  n1076[1] = 255 & (n1065[0] << 1 | n1075[1]);
  n1047[0] = n1046[0];
  n1047[1] = 255 & (n1036[0] << 1 | n1046[1]);
  n994[0] = n993[0];
  n994[1] = 255 & (n983[0] << 1 | n993[1]);
  n966[0] = n965[0];
  n966[1] = 255 & (n955[0] << 1 | n965[1]);
  n914[0] = n913[0];
  n914[1] = 255 & (n903[0] << 1 | n913[1]);
  n887[0] = n886[0];
  n887[1] = 255 & (n876[0] << 1 | n886[1]);
  n836[0] = n835[0];
  n836[1] = 255 & (n825[0] << 1 | n835[1]);
  n810[0] = n809[0];
  n810[1] = 255 & (n799[0] << 1 | n809[1]);
  n760[0] = n759[0];
  n760[1] = 255 & (n749[0] << 1 | n759[1]);
  n735[0] = n734[0];
  n735[1] = 255 & (n724[0] << 1 | n734[1]);
  n687[0] = 255 & (n685[0] << 7 | n686[0]);
  n687[1] = 255 & (n685[1] << 7 | n685[0] >> 1);
  n663[0] = 255 & (n661[0] << 7 | n662[0]);
  n663[1] = 255 & (n661[1] << 7 | n661[0] >> 1);
  { unsigned int tmp; (tmp = (unsigned int) n553[1] - (unsigned int) n614[1] - (tmp = (unsigned int) n553[0] - (unsigned int) n614[0], n616[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n616[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n553[1] + (unsigned int) n614[1] + (tmp = (unsigned int) n553[0] + (unsigned int) n614[0], n615[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n615[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n531[1] - (unsigned int) n591[1] - (tmp = (unsigned int) n531[0] - (unsigned int) n591[0], n593[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n593[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n531[1] + (unsigned int) n591[1] + (tmp = (unsigned int) n531[0] + (unsigned int) n591[0], n592[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n592[1] = 255 & (unsigned char) tmp); }
  if (n532[0]) {
    n546[0] = n544[0];
    n546[1] = n544[1];
  }
  else {
    n546[0] = n545[0];
    n546[1] = n545[1];
  }
  if (n510[0]) {
    n524[0] = n522[0];
    n524[1] = n522[1];
  }
  else {
    n524[0] = n523[0];
    n524[1] = n523[1];
  }
  n484r[0] = reset_i[0];
  n484e[0] = enable_i[0];
  n484d[0] = n477[0];
  n484d[1] = n477[1];
  n463r[0] = reset_i[0];
  n463e[0] = enable_i[0];
  n463d[0] = n456[0];
  n463d[1] = n456[1];
  n1161[0] = n1160[0];
  n1161[1] = 255 & (n1149[0] << 2 | n1160[1]);
  n1131[0] = n1130[0];
  n1131[1] = 255 & (n1119[0] << 2 | n1130[1]);
  n1077[0] = n1076[0];
  n1077[1] = 255 & (n1065[0] << 2 | n1076[1]);
  n1048[0] = n1047[0];
  n1048[1] = 255 & (n1036[0] << 2 | n1047[1]);
  n995[0] = n994[0];
  n995[1] = 255 & (n983[0] << 2 | n994[1]);
  n967[0] = n966[0];
  n967[1] = 255 & (n955[0] << 2 | n966[1]);
  n915[0] = n914[0];
  n915[1] = 255 & (n903[0] << 2 | n914[1]);
  n888[0] = n887[0];
  n888[1] = 255 & (n876[0] << 2 | n887[1]);
  n837[0] = n836[0];
  n837[1] = 255 & (n825[0] << 2 | n836[1]);
  n811[0] = n810[0];
  n811[1] = 255 & (n799[0] << 2 | n810[1]);
  n762[0] = 255 & (n760[0] << 6 | n761[0]);
  n762[1] = 255 & (n760[1] << 6 | n760[0] >> 2);
  n737[0] = 255 & (n735[0] << 6 | n736[0]);
  n737[1] = 255 & (n735[1] << 6 | n735[0] >> 2);
  { unsigned int tmp; (tmp = (unsigned int) n624[1] - (unsigned int) n687[1] - (tmp = (unsigned int) n624[0] - (unsigned int) n687[0], n689[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n689[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n624[1] + (unsigned int) n687[1] + (tmp = (unsigned int) n624[0] + (unsigned int) n687[0], n688[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n688[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n601[1] - (unsigned int) n663[1] - (tmp = (unsigned int) n601[0] - (unsigned int) n663[0], n665[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n665[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n601[1] + (unsigned int) n663[1] + (tmp = (unsigned int) n601[0] + (unsigned int) n663[0], n664[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n664[1] = 255 & (unsigned char) tmp); }
  if (n602[0]) {
    n617[0] = n615[0];
    n617[1] = n615[1];
  }
  else {
    n617[0] = n616[0];
    n617[1] = n616[1];
  }
  if (n579[0]) {
    n594[0] = n592[0];
    n594[1] = n592[1];
  }
  else {
    n594[0] = n593[0];
    n594[1] = n593[1];
  }
  n553r[0] = reset_i[0];
  n553e[0] = enable_i[0];
  n553d[0] = n546[0];
  n553d[1] = n546[1];
  n531r[0] = reset_i[0];
  n531e[0] = enable_i[0];
  n531d[0] = n524[0];
  n531d[1] = n524[1];
  n1162[0] = n1161[0];
  n1162[1] = 255 & (n1149[0] << 3 | n1161[1]);
  n1132[0] = n1131[0];
  n1132[1] = 255 & (n1119[0] << 3 | n1131[1]);
  n1078[0] = n1077[0];
  n1078[1] = 255 & (n1065[0] << 3 | n1077[1]);
  n1049[0] = n1048[0];
  n1049[1] = 255 & (n1036[0] << 3 | n1048[1]);
  n996[0] = n995[0];
  n996[1] = 255 & (n983[0] << 3 | n995[1]);
  n968[0] = n967[0];
  n968[1] = 255 & (n955[0] << 3 | n967[1]);
  n916[0] = n915[0];
  n916[1] = 255 & (n903[0] << 3 | n915[1]);
  n889[0] = n888[0];
  n889[1] = 255 & (n876[0] << 3 | n888[1]);
  n839[0] = 255 & (n837[0] << 5 | n838[0]);
  n839[1] = 255 & (n837[1] << 5 | n837[0] >> 3);
  n813[0] = 255 & (n811[0] << 5 | n812[0]);
  n813[1] = 255 & (n811[1] << 5 | n811[0] >> 3);
  { unsigned int tmp; (tmp = (unsigned int) n697[1] - (unsigned int) n762[1] - (tmp = (unsigned int) n697[0] - (unsigned int) n762[0], n764[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n764[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n697[1] + (unsigned int) n762[1] + (tmp = (unsigned int) n697[0] + (unsigned int) n762[0], n763[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n763[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n673[1] - (unsigned int) n737[1] - (tmp = (unsigned int) n673[0] - (unsigned int) n737[0], n739[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n739[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n673[1] + (unsigned int) n737[1] + (tmp = (unsigned int) n673[0] + (unsigned int) n737[0], n738[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n738[1] = 255 & (unsigned char) tmp); }
  if (n674[0]) {
    n690[0] = n688[0];
    n690[1] = n688[1];
  }
  else {
    n690[0] = n689[0];
    n690[1] = n689[1];
  }
  if (n650[0]) {
    n666[0] = n664[0];
    n666[1] = n664[1];
  }
  else {
    n666[0] = n665[0];
    n666[1] = n665[1];
  }
  n624r[0] = reset_i[0];
  n624e[0] = enable_i[0];
  n624d[0] = n617[0];
  n624d[1] = n617[1];
  n601r[0] = reset_i[0];
  n601e[0] = enable_i[0];
  n601d[0] = n594[0];
  n601d[1] = n594[1];
  n1163[0] = n1162[0];
  n1163[1] = 255 & (n1149[0] << 4 | n1162[1]);
  n1133[0] = n1132[0];
  n1133[1] = 255 & (n1119[0] << 4 | n1132[1]);
  n1079[0] = n1078[0];
  n1079[1] = 255 & (n1065[0] << 4 | n1078[1]);
  n1050[0] = n1049[0];
  n1050[1] = 255 & (n1036[0] << 4 | n1049[1]);
  n997[0] = n996[0];
  n997[1] = 255 & (n983[0] << 4 | n996[1]);
  n969[0] = n968[0];
  n969[1] = 255 & (n955[0] << 4 | n968[1]);
  n918[0] = 255 & (n916[0] << 4 | n917[0]);
  n918[1] = 255 & (n916[1] << 4 | n916[0] >> 4);
  n891[0] = 255 & (n889[0] << 4 | n890[0]);
  n891[1] = 255 & (n889[1] << 4 | n889[0] >> 4);
  { unsigned int tmp; (tmp = (unsigned int) n772[1] - (unsigned int) n839[1] - (tmp = (unsigned int) n772[0] - (unsigned int) n839[0], n841[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n841[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n772[1] + (unsigned int) n839[1] + (tmp = (unsigned int) n772[0] + (unsigned int) n839[0], n840[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n840[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n747[1] - (unsigned int) n813[1] - (tmp = (unsigned int) n747[0] - (unsigned int) n813[0], n815[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n815[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n747[1] + (unsigned int) n813[1] + (tmp = (unsigned int) n747[0] + (unsigned int) n813[0], n814[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n814[1] = 255 & (unsigned char) tmp); }
  if (n748[0]) {
    n765[0] = n763[0];
    n765[1] = n763[1];
  }
  else {
    n765[0] = n764[0];
    n765[1] = n764[1];
  }
  if (n723[0]) {
    n740[0] = n738[0];
    n740[1] = n738[1];
  }
  else {
    n740[0] = n739[0];
    n740[1] = n739[1];
  }
  n697r[0] = reset_i[0];
  n697e[0] = enable_i[0];
  n697d[0] = n690[0];
  n697d[1] = n690[1];
  n673r[0] = reset_i[0];
  n673e[0] = enable_i[0];
  n673d[0] = n666[0];
  n673d[1] = n666[1];
  n1164[0] = n1163[0];
  n1164[1] = 255 & (n1149[0] << 5 | n1163[1]);
  n1134[0] = n1133[0];
  n1134[1] = 255 & (n1119[0] << 5 | n1133[1]);
  n1080[0] = n1079[0];
  n1080[1] = 255 & (n1065[0] << 5 | n1079[1]);
  n1051[0] = n1050[0];
  n1051[1] = 255 & (n1036[0] << 5 | n1050[1]);
  n999[0] = 255 & (n997[0] << 3 | n998[0]);
  n999[1] = 255 & (n997[1] << 3 | n997[0] >> 5);
  n971[0] = 255 & (n969[0] << 3 | n970[0]);
  n971[1] = 255 & (n969[1] << 3 | n969[0] >> 5);
  { unsigned int tmp; (tmp = (unsigned int) n849[1] - (unsigned int) n918[1] - (tmp = (unsigned int) n849[0] - (unsigned int) n918[0], n920[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n920[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n849[1] + (unsigned int) n918[1] + (tmp = (unsigned int) n849[0] + (unsigned int) n918[0], n919[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n919[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n823[1] - (unsigned int) n891[1] - (tmp = (unsigned int) n823[0] - (unsigned int) n891[0], n893[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n893[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n823[1] + (unsigned int) n891[1] + (tmp = (unsigned int) n823[0] + (unsigned int) n891[0], n892[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n892[1] = 255 & (unsigned char) tmp); }
  if (n824[0]) {
    n842[0] = n840[0];
    n842[1] = n840[1];
  }
  else {
    n842[0] = n841[0];
    n842[1] = n841[1];
  }
  if (n798[0]) {
    n816[0] = n814[0];
    n816[1] = n814[1];
  }
  else {
    n816[0] = n815[0];
    n816[1] = n815[1];
  }
  n772r[0] = reset_i[0];
  n772e[0] = enable_i[0];
  n772d[0] = n765[0];
  n772d[1] = n765[1];
  n747r[0] = reset_i[0];
  n747e[0] = enable_i[0];
  n747d[0] = n740[0];
  n747d[1] = n740[1];
  n1165[0] = n1164[0];
  n1165[1] = 255 & (n1149[0] << 6 | n1164[1]);
  n1135[0] = n1134[0];
  n1135[1] = 255 & (n1119[0] << 6 | n1134[1]);
  n1082[0] = 255 & (n1080[0] << 2 | n1081[0]);
  n1082[1] = 255 & (n1080[1] << 2 | n1080[0] >> 6);
  n1053[0] = 255 & (n1051[0] << 2 | n1052[0]);
  n1053[1] = 255 & (n1051[1] << 2 | n1051[0] >> 6);
  { unsigned int tmp; (tmp = (unsigned int) n928[1] - (unsigned int) n999[1] - (tmp = (unsigned int) n928[0] - (unsigned int) n999[0], n1001[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1001[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n928[1] + (unsigned int) n999[1] + (tmp = (unsigned int) n928[0] + (unsigned int) n999[0], n1000[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1000[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n901[1] - (unsigned int) n971[1] - (tmp = (unsigned int) n901[0] - (unsigned int) n971[0], n973[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n973[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n901[1] + (unsigned int) n971[1] + (tmp = (unsigned int) n901[0] + (unsigned int) n971[0], n972[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n972[1] = 255 & (unsigned char) tmp); }
  if (n902[0]) {
    n921[0] = n919[0];
    n921[1] = n919[1];
  }
  else {
    n921[0] = n920[0];
    n921[1] = n920[1];
  }
  if (n875[0]) {
    n894[0] = n892[0];
    n894[1] = n892[1];
  }
  else {
    n894[0] = n893[0];
    n894[1] = n893[1];
  }
  n849r[0] = reset_i[0];
  n849e[0] = enable_i[0];
  n849d[0] = n842[0];
  n849d[1] = n842[1];
  n823r[0] = reset_i[0];
  n823e[0] = enable_i[0];
  n823d[0] = n816[0];
  n823d[1] = n816[1];
  n1167[0] = 255 & (n1165[0] << 1 | n1166[0]);
  n1167[1] = 255 & (n1165[1] << 1 | n1165[0] >> 7);
  n1137[0] = 255 & (n1135[0] << 1 | n1136[0]);
  n1137[1] = 255 & (n1135[1] << 1 | n1135[0] >> 7);
  { unsigned int tmp; (tmp = (unsigned int) n1009[1] - (unsigned int) n1082[1] - (tmp = (unsigned int) n1009[0] - (unsigned int) n1082[0], n1084[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1084[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1009[1] + (unsigned int) n1082[1] + (tmp = (unsigned int) n1009[0] + (unsigned int) n1082[0], n1083[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1083[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n981[1] - (unsigned int) n1053[1] - (tmp = (unsigned int) n981[0] - (unsigned int) n1053[0], n1055[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1055[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n981[1] + (unsigned int) n1053[1] + (tmp = (unsigned int) n981[0] + (unsigned int) n1053[0], n1054[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1054[1] = 255 & (unsigned char) tmp); }
  if (n982[0]) {
    n1002[0] = n1000[0];
    n1002[1] = n1000[1];
  }
  else {
    n1002[0] = n1001[0];
    n1002[1] = n1001[1];
  }
  if (n954[0]) {
    n974[0] = n972[0];
    n974[1] = n972[1];
  }
  else {
    n974[0] = n973[0];
    n974[1] = n973[1];
  }
  n928r[0] = reset_i[0];
  n928e[0] = enable_i[0];
  n928d[0] = n921[0];
  n928d[1] = n921[1];
  n901r[0] = reset_i[0];
  n901e[0] = enable_i[0];
  n901d[0] = n894[0];
  n901d[1] = n894[1];
  { unsigned int tmp; (tmp = (unsigned int) n1092[1] - (unsigned int) n1167[1] - (tmp = (unsigned int) n1092[0] - (unsigned int) n1167[0], n1169[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1169[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1092[1] + (unsigned int) n1167[1] + (tmp = (unsigned int) n1092[0] + (unsigned int) n1167[0], n1168[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1168[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1063[1] - (unsigned int) n1137[1] - (tmp = (unsigned int) n1063[0] - (unsigned int) n1137[0], n1139[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1139[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1063[1] + (unsigned int) n1137[1] + (tmp = (unsigned int) n1063[0] + (unsigned int) n1137[0], n1138[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1138[1] = 255 & (unsigned char) tmp); }
  if (n1064[0]) {
    n1085[0] = n1083[0];
    n1085[1] = n1083[1];
  }
  else {
    n1085[0] = n1084[0];
    n1085[1] = n1084[1];
  }
  if (n1035[0]) {
    n1056[0] = n1054[0];
    n1056[1] = n1054[1];
  }
  else {
    n1056[0] = n1055[0];
    n1056[1] = n1055[1];
  }
  n1009r[0] = reset_i[0];
  n1009e[0] = enable_i[0];
  n1009d[0] = n1002[0];
  n1009d[1] = n1002[1];
  n981r[0] = reset_i[0];
  n981e[0] = enable_i[0];
  n981d[0] = n974[0];
  n981d[1] = n974[1];
  if (n1148[0]) {
    n1170[0] = n1168[0];
    n1170[1] = n1168[1];
  }
  else {
    n1170[0] = n1169[0];
    n1170[1] = n1169[1];
  }
  if (n1118[0]) {
    n1140[0] = n1138[0];
    n1140[1] = n1138[1];
  }
  else {
    n1140[0] = n1139[0];
    n1140[1] = n1139[1];
  }
  n1092r[0] = reset_i[0];
  n1092e[0] = enable_i[0];
  n1092d[0] = n1085[0];
  n1092d[1] = n1085[1];
  n1063r[0] = reset_i[0];
  n1063e[0] = enable_i[0];
  n1063d[0] = n1056[0];
  n1063d[1] = n1056[1];
  n1177r[0] = reset_i[0];
  n1177e[0] = enable_i[0];
  n1177d[0] = n1170[0];
  n1177d[1] = n1170[1];
  n1147r[0] = reset_i[0];
  n1147e[0] = enable_i[0];
  n1147d[0] = n1140[0];
  n1147d[1] = n1140[1];
}

void cf_cordic_r_16_16_16_init() {
  { int index; for (index = 3; index > 0;) n1291[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1289[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1287[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1285[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1283[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1281[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1279[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1277[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1275[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1273[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1271[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1269[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1267[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1265[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1263[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1261[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1194[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1178[--index] = 0; }
  n1166[0] = 0;
  n1149[0] = 0;
  n1136[0] = 0;
  n1119[0] = 0;
  n1113[0] = 0;
  { int index; for (index = 2; index > 0;) n1107[--index] = 0; }
  n1105[0] = 0;
  { int index; for (index = 2; index > 0;) n1093[--index] = 0; }
  n1081[0] = 0;
  n1065[0] = 0;
  n1052[0] = 0;
  n1036[0] = 0;
  n1030[0] = 0;
  { int index; for (index = 2; index > 0;) n1024[--index] = 0; }
  n1022[0] = 0;
  { int index; for (index = 2; index > 0;) n1010[--index] = 0; }
  n998[0] = 0;
  n983[0] = 0;
  n970[0] = 0;
  n955[0] = 0;
  n949[0] = 0;
  { int index; for (index = 2; index > 0;) n943[--index] = 0; }
  n941[0] = 0;
  { int index; for (index = 2; index > 0;) n929[--index] = 0; }
  n917[0] = 0;
  n903[0] = 0;
  n890[0] = 0;
  n876[0] = 0;
  n870[0] = 0;
  { int index; for (index = 2; index > 0;) n864[--index] = 0; }
  n862[0] = 0;
  { int index; for (index = 2; index > 0;) n850[--index] = 0; }
  n838[0] = 0;
  n825[0] = 0;
  n812[0] = 0;
  n799[0] = 0;
  n793[0] = 0;
  { int index; for (index = 2; index > 0;) n787[--index] = 0; }
  n785[0] = 0;
  { int index; for (index = 2; index > 0;) n773[--index] = 0; }
  n761[0] = 0;
  n749[0] = 0;
  n736[0] = 0;
  n724[0] = 0;
  n718[0] = 0;
  { int index; for (index = 2; index > 0;) n712[--index] = 0; }
  n710[0] = 0;
  { int index; for (index = 2; index > 0;) n698[--index] = 0; }
  n686[0] = 0;
  n675[0] = 0;
  n662[0] = 0;
  n651[0] = 0;
  n645[0] = 0;
  { int index; for (index = 2; index > 0;) n639[--index] = 0; }
  n637[0] = 0;
  { int index; for (index = 2; index > 0;) n625[--index] = 0; }
  n613[0] = 0;
  n603[0] = 0;
  n590[0] = 0;
  n580[0] = 0;
  n574[0] = 0;
  { int index; for (index = 2; index > 0;) n568[--index] = 0; }
  n566[0] = 0;
  { int index; for (index = 2; index > 0;) n554[--index] = 0; }
  { int index; for (index = 2; index > 0;) n542[--index] = 0; }
  n533[0] = 0;
  { int index; for (index = 2; index > 0;) n520[--index] = 0; }
  n511[0] = 0;
  n505[0] = 0;
  { int index; for (index = 2; index > 0;) n499[--index] = 0; }
  n497[0] = 0;
  { int index; for (index = 2; index > 0;) n485[--index] = 0; }
  { int index; for (index = 2; index > 0;) n473[--index] = 0; }
  n465[0] = 0;
  { int index; for (index = 2; index > 0;) n452[--index] = 0; }
  n444[0] = 0;
  n438[0] = 0;
  { int index; for (index = 2; index > 0;) n432[--index] = 0; }
  n430[0] = 0;
  { int index; for (index = 2; index > 0;) n418[--index] = 0; }
  { int index; for (index = 2; index > 0;) n406[--index] = 0; }
  n399[0] = 0;
  { int index; for (index = 2; index > 0;) n386[--index] = 0; }
  n379[0] = 0;
  n373[0] = 0;
  { int index; for (index = 2; index > 0;) n367[--index] = 0; }
  n365[0] = 0;
  { int index; for (index = 2; index > 0;) n353[--index] = 0; }
  { int index; for (index = 2; index > 0;) n341[--index] = 0; }
  n335[0] = 0;
  { int index; for (index = 2; index > 0;) n322[--index] = 0; }
  n316[0] = 0;
  n310[0] = 0;
  { int index; for (index = 2; index > 0;) n304[--index] = 0; }
  n302[0] = 0;
  { int index; for (index = 2; index > 0;) n290[--index] = 0; }
  { int index; for (index = 2; index > 0;) n278[--index] = 0; }
  n273[0] = 0;
  { int index; for (index = 2; index > 0;) n260[--index] = 0; }
  n255[0] = 0;
  n249[0] = 0;
  { int index; for (index = 2; index > 0;) n243[--index] = 0; }
  n241[0] = 0;
  { int index; for (index = 2; index > 0;) n229[--index] = 0; }
  { int index; for (index = 2; index > 0;) n217[--index] = 0; }
  n213[0] = 0;
  { int index; for (index = 2; index > 0;) n200[--index] = 0; }
  n196[0] = 0;
  n190[0] = 0;
  { int index; for (index = 2; index > 0;) n184[--index] = 0; }
  n182[0] = 0;
  { int index; for (index = 2; index > 0;) n170[--index] = 0; }
  { int index; for (index = 2; index > 0;) n158[--index] = 0; }
  n155[0] = 0;
  { int index; for (index = 2; index > 0;) n142[--index] = 0; }
  n139[0] = 0;
  n133[0] = 0;
  { int index; for (index = 2; index > 0;) n127[--index] = 0; }
  n125[0] = 0;
  { int index; for (index = 2; index > 0;) n113[--index] = 0; }
  { int index; for (index = 2; index > 0;) n101[--index] = 0; }
  { int index; for (index = 2; index > 0;) n86[--index] = 0; }
  n78[0] = 0;
  { int index; for (index = 2; index > 0;) n72[--index] = 0; }
  n70[0] = 0;
  { int index; for (index = 2; index > 0;) n39[--index] = 0; }
  { int index; for (index = 2; index > 0;) n37[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1180[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1179[--index] = 0; }
  n1152[0] = 0;
  n1122[0] = 0;
  n1106[0] = 0;
  { int index; for (index = 2; index > 0;) n1095[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1094[--index] = 0; }
  n1068[0] = 0;
  n1039[0] = 0;
  n1023[0] = 0;
  { int index; for (index = 2; index > 0;) n1012[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1011[--index] = 0; }
  n986[0] = 0;
  n958[0] = 0;
  n942[0] = 0;
  { int index; for (index = 2; index > 0;) n931[--index] = 0; }
  { int index; for (index = 2; index > 0;) n930[--index] = 0; }
  n906[0] = 0;
  n879[0] = 0;
  n863[0] = 0;
  { int index; for (index = 2; index > 0;) n852[--index] = 0; }
  { int index; for (index = 2; index > 0;) n851[--index] = 0; }
  n828[0] = 0;
  n802[0] = 0;
  n786[0] = 0;
  { int index; for (index = 2; index > 0;) n775[--index] = 0; }
  { int index; for (index = 2; index > 0;) n774[--index] = 0; }
  n752[0] = 0;
  n727[0] = 0;
  n711[0] = 0;
  { int index; for (index = 2; index > 0;) n700[--index] = 0; }
  { int index; for (index = 2; index > 0;) n699[--index] = 0; }
  n678[0] = 0;
  n654[0] = 0;
  n638[0] = 0;
  { int index; for (index = 2; index > 0;) n627[--index] = 0; }
  { int index; for (index = 2; index > 0;) n626[--index] = 0; }
  n606[0] = 0;
  n583[0] = 0;
  n567[0] = 0;
  { int index; for (index = 2; index > 0;) n556[--index] = 0; }
  { int index; for (index = 2; index > 0;) n555[--index] = 0; }
  n536[0] = 0;
  n514[0] = 0;
  n498[0] = 0;
  { int index; for (index = 2; index > 0;) n487[--index] = 0; }
  { int index; for (index = 2; index > 0;) n486[--index] = 0; }
  n468[0] = 0;
  n447[0] = 0;
  n431[0] = 0;
  { int index; for (index = 2; index > 0;) n420[--index] = 0; }
  { int index; for (index = 2; index > 0;) n419[--index] = 0; }
  n402[0] = 0;
  n382[0] = 0;
  n366[0] = 0;
  { int index; for (index = 2; index > 0;) n355[--index] = 0; }
  { int index; for (index = 2; index > 0;) n354[--index] = 0; }
  n338[0] = 0;
  n319[0] = 0;
  n303[0] = 0;
  { int index; for (index = 2; index > 0;) n292[--index] = 0; }
  { int index; for (index = 2; index > 0;) n291[--index] = 0; }
  n276[0] = 0;
  n258[0] = 0;
  n242[0] = 0;
  { int index; for (index = 2; index > 0;) n231[--index] = 0; }
  { int index; for (index = 2; index > 0;) n230[--index] = 0; }
  n216[0] = 0;
  n199[0] = 0;
  n183[0] = 0;
  { int index; for (index = 2; index > 0;) n172[--index] = 0; }
  { int index; for (index = 2; index > 0;) n171[--index] = 0; }
  { int index; for (index = 2; index > 0;) n159[--index] = 0; }
  { int index; for (index = 2; index > 0;) n143[--index] = 0; }
  n126[0] = 0;
  { int index; for (index = 2; index > 0;) n115[--index] = 0; }
  { int index; for (index = 2; index > 0;) n114[--index] = 0; }
  { int index; for (index = 2; index > 0;) n104[--index] = 0; }
  { int index; for (index = 2; index > 0;) n103[--index] = 0; }
  { int index; for (index = 2; index > 0;) n89[--index] = 0; }
  { int index; for (index = 2; index > 0;) n88[--index] = 0; }
  n71[0] = 0;
  { int index; for (index = 2; index > 0;) n44[--index] = 0; }
  { int index; for (index = 2; index > 0;) n40[--index] = 0; }
  { int index; for (index = 2; index > 0;) n38[--index] = 0; }
  { int index; for (index = 2; index > 0;) n36[--index] = 0; }
  n36r[0] = 0;
  n36e[0] = 0;
  { int index; for (index = 2; index > 0;) n36d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n29[--index] = 0; }
  n29r[0] = 0;
  n29e[0] = 0;
  { int index; for (index = 2; index > 0;) n29d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n22[--index] = 0; }
  n22r[0] = 0;
  n22e[0] = 0;
  { int index; for (index = 2; index > 0;) n22d[--index] = 0; }
  n15[0] = 0;
  n15r[0] = 0;
  n15e[0] = 0;
  n15d[0] = 0;
  n1153[0] = 0;
  n1123[0] = 0;
  { int index; for (index = 2; index > 0;) n1108[--index] = 0; }
  n1069[0] = 0;
  n1040[0] = 0;
  { int index; for (index = 2; index > 0;) n1025[--index] = 0; }
  n987[0] = 0;
  n959[0] = 0;
  { int index; for (index = 2; index > 0;) n944[--index] = 0; }
  n907[0] = 0;
  n880[0] = 0;
  { int index; for (index = 2; index > 0;) n865[--index] = 0; }
  n829[0] = 0;
  n803[0] = 0;
  { int index; for (index = 2; index > 0;) n788[--index] = 0; }
  n753[0] = 0;
  n728[0] = 0;
  { int index; for (index = 2; index > 0;) n713[--index] = 0; }
  n679[0] = 0;
  n655[0] = 0;
  { int index; for (index = 2; index > 0;) n640[--index] = 0; }
  n607[0] = 0;
  n584[0] = 0;
  { int index; for (index = 2; index > 0;) n569[--index] = 0; }
  n537[0] = 0;
  n515[0] = 0;
  { int index; for (index = 2; index > 0;) n500[--index] = 0; }
  n469[0] = 0;
  n448[0] = 0;
  { int index; for (index = 2; index > 0;) n433[--index] = 0; }
  n403[0] = 0;
  n383[0] = 0;
  { int index; for (index = 2; index > 0;) n368[--index] = 0; }
  n339[0] = 0;
  n320[0] = 0;
  { int index; for (index = 2; index > 0;) n305[--index] = 0; }
  n277[0] = 0;
  n259[0] = 0;
  { int index; for (index = 2; index > 0;) n244[--index] = 0; }
  { int index; for (index = 2; index > 0;) n218[--index] = 0; }
  { int index; for (index = 2; index > 0;) n201[--index] = 0; }
  { int index; for (index = 2; index > 0;) n185[--index] = 0; }
  { int index; for (index = 2; index > 0;) n161[--index] = 0; }
  { int index; for (index = 2; index > 0;) n160[--index] = 0; }
  { int index; for (index = 2; index > 0;) n145[--index] = 0; }
  { int index; for (index = 2; index > 0;) n144[--index] = 0; }
  { int index; for (index = 2; index > 0;) n128[--index] = 0; }
  { int index; for (index = 2; index > 0;) n73[--index] = 0; }
  { int index; for (index = 2; index > 0;) n61[--index] = 0; }
  { int index; for (index = 2; index > 0;) n53[--index] = 0; }
  { int index; for (index = 2; index > 0;) n45[--index] = 0; }
  n1154[0] = 0;
  n1124[0] = 0;
  { int index; for (index = 3; index > 0;) n1114[--index] = 0; }
  n1070[0] = 0;
  n1041[0] = 0;
  { int index; for (index = 3; index > 0;) n1031[--index] = 0; }
  n988[0] = 0;
  n960[0] = 0;
  { int index; for (index = 3; index > 0;) n950[--index] = 0; }
  n908[0] = 0;
  n881[0] = 0;
  { int index; for (index = 3; index > 0;) n871[--index] = 0; }
  n830[0] = 0;
  n804[0] = 0;
  { int index; for (index = 3; index > 0;) n794[--index] = 0; }
  n754[0] = 0;
  n729[0] = 0;
  { int index; for (index = 3; index > 0;) n719[--index] = 0; }
  n680[0] = 0;
  n656[0] = 0;
  { int index; for (index = 3; index > 0;) n646[--index] = 0; }
  n608[0] = 0;
  n585[0] = 0;
  { int index; for (index = 3; index > 0;) n575[--index] = 0; }
  n538[0] = 0;
  n516[0] = 0;
  { int index; for (index = 3; index > 0;) n506[--index] = 0; }
  n470[0] = 0;
  n449[0] = 0;
  { int index; for (index = 3; index > 0;) n439[--index] = 0; }
  n404[0] = 0;
  n384[0] = 0;
  { int index; for (index = 3; index > 0;) n374[--index] = 0; }
  n340[0] = 0;
  n321[0] = 0;
  { int index; for (index = 3; index > 0;) n311[--index] = 0; }
  { int index; for (index = 2; index > 0;) n279[--index] = 0; }
  { int index; for (index = 2; index > 0;) n261[--index] = 0; }
  { int index; for (index = 3; index > 0;) n250[--index] = 0; }
  { int index; for (index = 2; index > 0;) n220[--index] = 0; }
  { int index; for (index = 2; index > 0;) n219[--index] = 0; }
  { int index; for (index = 2; index > 0;) n203[--index] = 0; }
  { int index; for (index = 2; index > 0;) n202[--index] = 0; }
  { int index; for (index = 3; index > 0;) n191[--index] = 0; }
  { int index; for (index = 3; index > 0;) n134[--index] = 0; }
  { int index; for (index = 3; index > 0;) n79[--index] = 0; }
  { int index; for (index = 2; index > 0;) n68[--index] = 0; }
  n68r[0] = 0;
  n68e[0] = 0;
  { int index; for (index = 2; index > 0;) n68d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n60[--index] = 0; }
  n60r[0] = 0;
  n60e[0] = 0;
  { int index; for (index = 2; index > 0;) n60d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n52[--index] = 0; }
  n52r[0] = 0;
  n52e[0] = 0;
  { int index; for (index = 2; index > 0;) n52d[--index] = 0; }
  n1155[0] = 0;
  n1125[0] = 0;
  { int index; for (index = 3; index > 0;) n1117[--index] = 0; }
  n1071[0] = 0;
  n1042[0] = 0;
  { int index; for (index = 3; index > 0;) n1034[--index] = 0; }
  n989[0] = 0;
  n961[0] = 0;
  { int index; for (index = 3; index > 0;) n953[--index] = 0; }
  n909[0] = 0;
  n882[0] = 0;
  { int index; for (index = 3; index > 0;) n874[--index] = 0; }
  n831[0] = 0;
  n805[0] = 0;
  { int index; for (index = 3; index > 0;) n797[--index] = 0; }
  n755[0] = 0;
  n730[0] = 0;
  { int index; for (index = 3; index > 0;) n722[--index] = 0; }
  n681[0] = 0;
  n657[0] = 0;
  { int index; for (index = 3; index > 0;) n649[--index] = 0; }
  n609[0] = 0;
  n586[0] = 0;
  { int index; for (index = 3; index > 0;) n578[--index] = 0; }
  n539[0] = 0;
  n517[0] = 0;
  { int index; for (index = 3; index > 0;) n509[--index] = 0; }
  n471[0] = 0;
  n450[0] = 0;
  { int index; for (index = 3; index > 0;) n442[--index] = 0; }
  n405[0] = 0;
  n385[0] = 0;
  { int index; for (index = 3; index > 0;) n377[--index] = 0; }
  { int index; for (index = 2; index > 0;) n342[--index] = 0; }
  { int index; for (index = 2; index > 0;) n323[--index] = 0; }
  { int index; for (index = 3; index > 0;) n314[--index] = 0; }
  { int index; for (index = 2; index > 0;) n281[--index] = 0; }
  { int index; for (index = 2; index > 0;) n280[--index] = 0; }
  { int index; for (index = 2; index > 0;) n263[--index] = 0; }
  { int index; for (index = 2; index > 0;) n262[--index] = 0; }
  { int index; for (index = 3; index > 0;) n253[--index] = 0; }
  { int index; for (index = 3; index > 0;) n194[--index] = 0; }
  { int index; for (index = 3; index > 0;) n137[--index] = 0; }
  { int index; for (index = 3; index > 0;) n82[--index] = 0; }
  n1156[0] = 0;
  n1126[0] = 0;
  n1118[0] = 0;
  n1072[0] = 0;
  n1043[0] = 0;
  n1035[0] = 0;
  n990[0] = 0;
  n962[0] = 0;
  n954[0] = 0;
  n910[0] = 0;
  n883[0] = 0;
  n875[0] = 0;
  n832[0] = 0;
  n806[0] = 0;
  n798[0] = 0;
  n756[0] = 0;
  n731[0] = 0;
  n723[0] = 0;
  n682[0] = 0;
  n658[0] = 0;
  n650[0] = 0;
  n610[0] = 0;
  n587[0] = 0;
  n579[0] = 0;
  n540[0] = 0;
  n518[0] = 0;
  n510[0] = 0;
  n472[0] = 0;
  n451[0] = 0;
  n443[0] = 0;
  { int index; for (index = 2; index > 0;) n407[--index] = 0; }
  { int index; for (index = 2; index > 0;) n387[--index] = 0; }
  n378[0] = 0;
  { int index; for (index = 2; index > 0;) n344[--index] = 0; }
  { int index; for (index = 2; index > 0;) n343[--index] = 0; }
  { int index; for (index = 2; index > 0;) n325[--index] = 0; }
  { int index; for (index = 2; index > 0;) n324[--index] = 0; }
  n315[0] = 0;
  n254[0] = 0;
  n195[0] = 0;
  n138[0] = 0;
  n83[0] = 0;
  { int index; for (index = 2; index > 0;) n1181[--index] = 0; }
  n1157[0] = 0;
  n1148[0] = 0;
  n1127[0] = 0;
  { int index; for (index = 2; index > 0;) n1096[--index] = 0; }
  n1073[0] = 0;
  n1064[0] = 0;
  n1044[0] = 0;
  { int index; for (index = 2; index > 0;) n1013[--index] = 0; }
  n991[0] = 0;
  n982[0] = 0;
  n963[0] = 0;
  { int index; for (index = 2; index > 0;) n932[--index] = 0; }
  n911[0] = 0;
  n902[0] = 0;
  n884[0] = 0;
  { int index; for (index = 2; index > 0;) n853[--index] = 0; }
  n833[0] = 0;
  n824[0] = 0;
  n807[0] = 0;
  { int index; for (index = 2; index > 0;) n776[--index] = 0; }
  n757[0] = 0;
  n748[0] = 0;
  n732[0] = 0;
  { int index; for (index = 2; index > 0;) n701[--index] = 0; }
  n683[0] = 0;
  n674[0] = 0;
  n659[0] = 0;
  { int index; for (index = 2; index > 0;) n628[--index] = 0; }
  n611[0] = 0;
  n602[0] = 0;
  n588[0] = 0;
  { int index; for (index = 2; index > 0;) n557[--index] = 0; }
  n541[0] = 0;
  n532[0] = 0;
  n519[0] = 0;
  { int index; for (index = 2; index > 0;) n488[--index] = 0; }
  { int index; for (index = 2; index > 0;) n474[--index] = 0; }
  n464[0] = 0;
  { int index; for (index = 2; index > 0;) n453[--index] = 0; }
  { int index; for (index = 2; index > 0;) n421[--index] = 0; }
  { int index; for (index = 2; index > 0;) n409[--index] = 0; }
  { int index; for (index = 2; index > 0;) n408[--index] = 0; }
  n398[0] = 0;
  { int index; for (index = 2; index > 0;) n389[--index] = 0; }
  { int index; for (index = 2; index > 0;) n388[--index] = 0; }
  { int index; for (index = 2; index > 0;) n356[--index] = 0; }
  n334[0] = 0;
  { int index; for (index = 2; index > 0;) n326[--index] = 0; }
  { int index; for (index = 2; index > 0;) n293[--index] = 0; }
  n272[0] = 0;
  { int index; for (index = 2; index > 0;) n264[--index] = 0; }
  { int index; for (index = 2; index > 0;) n232[--index] = 0; }
  n212[0] = 0;
  { int index; for (index = 2; index > 0;) n204[--index] = 0; }
  { int index; for (index = 2; index > 0;) n173[--index] = 0; }
  n154[0] = 0;
  { int index; for (index = 2; index > 0;) n146[--index] = 0; }
  { int index; for (index = 2; index > 0;) n116[--index] = 0; }
  n98[0] = 0;
  { int index; for (index = 2; index > 0;) n90[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1188[--index] = 0; }
  n1188r[0] = 0;
  n1188e[0] = 0;
  { int index; for (index = 2; index > 0;) n1188d[--index] = 0; }
  n1158[0] = 0;
  n1128[0] = 0;
  { int index; for (index = 2; index > 0;) n1103[--index] = 0; }
  n1103r[0] = 0;
  n1103e[0] = 0;
  { int index; for (index = 2; index > 0;) n1103d[--index] = 0; }
  n1074[0] = 0;
  n1045[0] = 0;
  { int index; for (index = 2; index > 0;) n1020[--index] = 0; }
  n1020r[0] = 0;
  n1020e[0] = 0;
  { int index; for (index = 2; index > 0;) n1020d[--index] = 0; }
  n992[0] = 0;
  n964[0] = 0;
  { int index; for (index = 2; index > 0;) n939[--index] = 0; }
  n939r[0] = 0;
  n939e[0] = 0;
  { int index; for (index = 2; index > 0;) n939d[--index] = 0; }
  n912[0] = 0;
  n885[0] = 0;
  { int index; for (index = 2; index > 0;) n860[--index] = 0; }
  n860r[0] = 0;
  n860e[0] = 0;
  { int index; for (index = 2; index > 0;) n860d[--index] = 0; }
  n834[0] = 0;
  n808[0] = 0;
  { int index; for (index = 2; index > 0;) n783[--index] = 0; }
  n783r[0] = 0;
  n783e[0] = 0;
  { int index; for (index = 2; index > 0;) n783d[--index] = 0; }
  n758[0] = 0;
  n733[0] = 0;
  { int index; for (index = 2; index > 0;) n708[--index] = 0; }
  n708r[0] = 0;
  n708e[0] = 0;
  { int index; for (index = 2; index > 0;) n708d[--index] = 0; }
  n684[0] = 0;
  n660[0] = 0;
  { int index; for (index = 2; index > 0;) n635[--index] = 0; }
  n635r[0] = 0;
  n635e[0] = 0;
  { int index; for (index = 2; index > 0;) n635d[--index] = 0; }
  n612[0] = 0;
  n589[0] = 0;
  { int index; for (index = 2; index > 0;) n564[--index] = 0; }
  n564r[0] = 0;
  n564e[0] = 0;
  { int index; for (index = 2; index > 0;) n564d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n543[--index] = 0; }
  { int index; for (index = 2; index > 0;) n521[--index] = 0; }
  { int index; for (index = 2; index > 0;) n495[--index] = 0; }
  n495r[0] = 0;
  n495e[0] = 0;
  { int index; for (index = 2; index > 0;) n495d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n476[--index] = 0; }
  { int index; for (index = 2; index > 0;) n475[--index] = 0; }
  { int index; for (index = 2; index > 0;) n455[--index] = 0; }
  { int index; for (index = 2; index > 0;) n454[--index] = 0; }
  { int index; for (index = 2; index > 0;) n428[--index] = 0; }
  n428r[0] = 0;
  n428e[0] = 0;
  { int index; for (index = 2; index > 0;) n428d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n410[--index] = 0; }
  { int index; for (index = 2; index > 0;) n390[--index] = 0; }
  { int index; for (index = 2; index > 0;) n363[--index] = 0; }
  n363r[0] = 0;
  n363e[0] = 0;
  { int index; for (index = 2; index > 0;) n363d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n345[--index] = 0; }
  { int index; for (index = 2; index > 0;) n333[--index] = 0; }
  n333r[0] = 0;
  n333e[0] = 0;
  { int index; for (index = 2; index > 0;) n333d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n300[--index] = 0; }
  n300r[0] = 0;
  n300e[0] = 0;
  { int index; for (index = 2; index > 0;) n300d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n282[--index] = 0; }
  { int index; for (index = 2; index > 0;) n271[--index] = 0; }
  n271r[0] = 0;
  n271e[0] = 0;
  { int index; for (index = 2; index > 0;) n271d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n239[--index] = 0; }
  n239r[0] = 0;
  n239e[0] = 0;
  { int index; for (index = 2; index > 0;) n239d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n221[--index] = 0; }
  { int index; for (index = 2; index > 0;) n211[--index] = 0; }
  n211r[0] = 0;
  n211e[0] = 0;
  { int index; for (index = 2; index > 0;) n211d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n180[--index] = 0; }
  n180r[0] = 0;
  n180e[0] = 0;
  { int index; for (index = 2; index > 0;) n180d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n162[--index] = 0; }
  { int index; for (index = 2; index > 0;) n153[--index] = 0; }
  n153r[0] = 0;
  n153e[0] = 0;
  { int index; for (index = 2; index > 0;) n153d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n123[--index] = 0; }
  n123r[0] = 0;
  n123e[0] = 0;
  { int index; for (index = 2; index > 0;) n123d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n105[--index] = 0; }
  { int index; for (index = 2; index > 0;) n97[--index] = 0; }
  n97r[0] = 0;
  n97e[0] = 0;
  { int index; for (index = 2; index > 0;) n97d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1159[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1129[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1075[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1046[--index] = 0; }
  { int index; for (index = 2; index > 0;) n993[--index] = 0; }
  { int index; for (index = 2; index > 0;) n965[--index] = 0; }
  { int index; for (index = 2; index > 0;) n913[--index] = 0; }
  { int index; for (index = 2; index > 0;) n886[--index] = 0; }
  { int index; for (index = 2; index > 0;) n835[--index] = 0; }
  { int index; for (index = 2; index > 0;) n809[--index] = 0; }
  { int index; for (index = 2; index > 0;) n759[--index] = 0; }
  { int index; for (index = 2; index > 0;) n734[--index] = 0; }
  { int index; for (index = 2; index > 0;) n685[--index] = 0; }
  { int index; for (index = 2; index > 0;) n661[--index] = 0; }
  { int index; for (index = 2; index > 0;) n614[--index] = 0; }
  { int index; for (index = 2; index > 0;) n591[--index] = 0; }
  { int index; for (index = 2; index > 0;) n545[--index] = 0; }
  { int index; for (index = 2; index > 0;) n544[--index] = 0; }
  { int index; for (index = 2; index > 0;) n523[--index] = 0; }
  { int index; for (index = 2; index > 0;) n522[--index] = 0; }
  { int index; for (index = 2; index > 0;) n477[--index] = 0; }
  { int index; for (index = 2; index > 0;) n456[--index] = 0; }
  { int index; for (index = 2; index > 0;) n417[--index] = 0; }
  n417r[0] = 0;
  n417e[0] = 0;
  { int index; for (index = 2; index > 0;) n417d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n397[--index] = 0; }
  n397r[0] = 0;
  n397e[0] = 0;
  { int index; for (index = 2; index > 0;) n397d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n352[--index] = 0; }
  n352r[0] = 0;
  n352e[0] = 0;
  { int index; for (index = 2; index > 0;) n352d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n289[--index] = 0; }
  n289r[0] = 0;
  n289e[0] = 0;
  { int index; for (index = 2; index > 0;) n289d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n228[--index] = 0; }
  n228r[0] = 0;
  n228e[0] = 0;
  { int index; for (index = 2; index > 0;) n228d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n169[--index] = 0; }
  n169r[0] = 0;
  n169e[0] = 0;
  { int index; for (index = 2; index > 0;) n169d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n112[--index] = 0; }
  n112r[0] = 0;
  n112e[0] = 0;
  { int index; for (index = 2; index > 0;) n112d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1160[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1130[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1076[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1047[--index] = 0; }
  { int index; for (index = 2; index > 0;) n994[--index] = 0; }
  { int index; for (index = 2; index > 0;) n966[--index] = 0; }
  { int index; for (index = 2; index > 0;) n914[--index] = 0; }
  { int index; for (index = 2; index > 0;) n887[--index] = 0; }
  { int index; for (index = 2; index > 0;) n836[--index] = 0; }
  { int index; for (index = 2; index > 0;) n810[--index] = 0; }
  { int index; for (index = 2; index > 0;) n760[--index] = 0; }
  { int index; for (index = 2; index > 0;) n735[--index] = 0; }
  { int index; for (index = 2; index > 0;) n687[--index] = 0; }
  { int index; for (index = 2; index > 0;) n663[--index] = 0; }
  { int index; for (index = 2; index > 0;) n616[--index] = 0; }
  { int index; for (index = 2; index > 0;) n615[--index] = 0; }
  { int index; for (index = 2; index > 0;) n593[--index] = 0; }
  { int index; for (index = 2; index > 0;) n592[--index] = 0; }
  { int index; for (index = 2; index > 0;) n546[--index] = 0; }
  { int index; for (index = 2; index > 0;) n524[--index] = 0; }
  { int index; for (index = 2; index > 0;) n484[--index] = 0; }
  n484r[0] = 0;
  n484e[0] = 0;
  { int index; for (index = 2; index > 0;) n484d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n463[--index] = 0; }
  n463r[0] = 0;
  n463e[0] = 0;
  { int index; for (index = 2; index > 0;) n463d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1161[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1131[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1077[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1048[--index] = 0; }
  { int index; for (index = 2; index > 0;) n995[--index] = 0; }
  { int index; for (index = 2; index > 0;) n967[--index] = 0; }
  { int index; for (index = 2; index > 0;) n915[--index] = 0; }
  { int index; for (index = 2; index > 0;) n888[--index] = 0; }
  { int index; for (index = 2; index > 0;) n837[--index] = 0; }
  { int index; for (index = 2; index > 0;) n811[--index] = 0; }
  { int index; for (index = 2; index > 0;) n762[--index] = 0; }
  { int index; for (index = 2; index > 0;) n737[--index] = 0; }
  { int index; for (index = 2; index > 0;) n689[--index] = 0; }
  { int index; for (index = 2; index > 0;) n688[--index] = 0; }
  { int index; for (index = 2; index > 0;) n665[--index] = 0; }
  { int index; for (index = 2; index > 0;) n664[--index] = 0; }
  { int index; for (index = 2; index > 0;) n617[--index] = 0; }
  { int index; for (index = 2; index > 0;) n594[--index] = 0; }
  { int index; for (index = 2; index > 0;) n553[--index] = 0; }
  n553r[0] = 0;
  n553e[0] = 0;
  { int index; for (index = 2; index > 0;) n553d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n531[--index] = 0; }
  n531r[0] = 0;
  n531e[0] = 0;
  { int index; for (index = 2; index > 0;) n531d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1162[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1132[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1078[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1049[--index] = 0; }
  { int index; for (index = 2; index > 0;) n996[--index] = 0; }
  { int index; for (index = 2; index > 0;) n968[--index] = 0; }
  { int index; for (index = 2; index > 0;) n916[--index] = 0; }
  { int index; for (index = 2; index > 0;) n889[--index] = 0; }
  { int index; for (index = 2; index > 0;) n839[--index] = 0; }
  { int index; for (index = 2; index > 0;) n813[--index] = 0; }
  { int index; for (index = 2; index > 0;) n764[--index] = 0; }
  { int index; for (index = 2; index > 0;) n763[--index] = 0; }
  { int index; for (index = 2; index > 0;) n739[--index] = 0; }
  { int index; for (index = 2; index > 0;) n738[--index] = 0; }
  { int index; for (index = 2; index > 0;) n690[--index] = 0; }
  { int index; for (index = 2; index > 0;) n666[--index] = 0; }
  { int index; for (index = 2; index > 0;) n624[--index] = 0; }
  n624r[0] = 0;
  n624e[0] = 0;
  { int index; for (index = 2; index > 0;) n624d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n601[--index] = 0; }
  n601r[0] = 0;
  n601e[0] = 0;
  { int index; for (index = 2; index > 0;) n601d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1163[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1133[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1079[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1050[--index] = 0; }
  { int index; for (index = 2; index > 0;) n997[--index] = 0; }
  { int index; for (index = 2; index > 0;) n969[--index] = 0; }
  { int index; for (index = 2; index > 0;) n918[--index] = 0; }
  { int index; for (index = 2; index > 0;) n891[--index] = 0; }
  { int index; for (index = 2; index > 0;) n841[--index] = 0; }
  { int index; for (index = 2; index > 0;) n840[--index] = 0; }
  { int index; for (index = 2; index > 0;) n815[--index] = 0; }
  { int index; for (index = 2; index > 0;) n814[--index] = 0; }
  { int index; for (index = 2; index > 0;) n765[--index] = 0; }
  { int index; for (index = 2; index > 0;) n740[--index] = 0; }
  { int index; for (index = 2; index > 0;) n697[--index] = 0; }
  n697r[0] = 0;
  n697e[0] = 0;
  { int index; for (index = 2; index > 0;) n697d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n673[--index] = 0; }
  n673r[0] = 0;
  n673e[0] = 0;
  { int index; for (index = 2; index > 0;) n673d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1164[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1134[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1080[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1051[--index] = 0; }
  { int index; for (index = 2; index > 0;) n999[--index] = 0; }
  { int index; for (index = 2; index > 0;) n971[--index] = 0; }
  { int index; for (index = 2; index > 0;) n920[--index] = 0; }
  { int index; for (index = 2; index > 0;) n919[--index] = 0; }
  { int index; for (index = 2; index > 0;) n893[--index] = 0; }
  { int index; for (index = 2; index > 0;) n892[--index] = 0; }
  { int index; for (index = 2; index > 0;) n842[--index] = 0; }
  { int index; for (index = 2; index > 0;) n816[--index] = 0; }
  { int index; for (index = 2; index > 0;) n772[--index] = 0; }
  n772r[0] = 0;
  n772e[0] = 0;
  { int index; for (index = 2; index > 0;) n772d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n747[--index] = 0; }
  n747r[0] = 0;
  n747e[0] = 0;
  { int index; for (index = 2; index > 0;) n747d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1165[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1135[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1082[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1053[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1001[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1000[--index] = 0; }
  { int index; for (index = 2; index > 0;) n973[--index] = 0; }
  { int index; for (index = 2; index > 0;) n972[--index] = 0; }
  { int index; for (index = 2; index > 0;) n921[--index] = 0; }
  { int index; for (index = 2; index > 0;) n894[--index] = 0; }
  { int index; for (index = 2; index > 0;) n849[--index] = 0; }
  n849r[0] = 0;
  n849e[0] = 0;
  { int index; for (index = 2; index > 0;) n849d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n823[--index] = 0; }
  n823r[0] = 0;
  n823e[0] = 0;
  { int index; for (index = 2; index > 0;) n823d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1167[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1137[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1084[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1083[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1055[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1054[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1002[--index] = 0; }
  { int index; for (index = 2; index > 0;) n974[--index] = 0; }
  { int index; for (index = 2; index > 0;) n928[--index] = 0; }
  n928r[0] = 0;
  n928e[0] = 0;
  { int index; for (index = 2; index > 0;) n928d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n901[--index] = 0; }
  n901r[0] = 0;
  n901e[0] = 0;
  { int index; for (index = 2; index > 0;) n901d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1169[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1168[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1139[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1138[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1085[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1056[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1009[--index] = 0; }
  n1009r[0] = 0;
  n1009e[0] = 0;
  { int index; for (index = 2; index > 0;) n1009d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n981[--index] = 0; }
  n981r[0] = 0;
  n981e[0] = 0;
  { int index; for (index = 2; index > 0;) n981d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1170[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1140[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1092[--index] = 0; }
  n1092r[0] = 0;
  n1092e[0] = 0;
  { int index; for (index = 2; index > 0;) n1092d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1063[--index] = 0; }
  n1063r[0] = 0;
  n1063e[0] = 0;
  { int index; for (index = 2; index > 0;) n1063d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1177[--index] = 0; }
  n1177r[0] = 0;
  n1177e[0] = 0;
  { int index; for (index = 2; index > 0;) n1177d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1147[--index] = 0; }
  n1147r[0] = 0;
  n1147e[0] = 0;
  { int index; for (index = 2; index > 0;) n1147d[--index] = 0; }
  cf_cordic_r_16_16_16_calc();
}

void cf_cordic_r_16_16_16_cycle_clock()
{
  if (n15r[0]) {
    n15[0] = 0;
  }
  else if (n15e[0]) {
    n15[0] = n15d[0];
  }
  if (n22r[0]) {
    n22[0] = 0;
    n22[1] = 0;
  }
  else if (n22e[0]) {
    n22[0] = n22d[0];
    n22[1] = n22d[1];
  }
  if (n29r[0]) {
    n29[0] = 0;
    n29[1] = 0;
  }
  else if (n29e[0]) {
    n29[0] = n29d[0];
    n29[1] = n29d[1];
  }
  if (n36r[0]) {
    n36[0] = 0;
    n36[1] = 0;
  }
  else if (n36e[0]) {
    n36[0] = n36d[0];
    n36[1] = n36d[1];
  }
  if (n52r[0]) {
    n52[0] = 0;
    n52[1] = 0;
  }
  else if (n52e[0]) {
    n52[0] = n52d[0];
    n52[1] = n52d[1];
  }
  if (n60r[0]) {
    n60[0] = 0;
    n60[1] = 0;
  }
  else if (n60e[0]) {
    n60[0] = n60d[0];
    n60[1] = n60d[1];
  }
  if (n68r[0]) {
    n68[0] = 0;
    n68[1] = 0;
  }
  else if (n68e[0]) {
    n68[0] = n68d[0];
    n68[1] = n68d[1];
  }
  if (n97r[0]) {
    n97[0] = 0;
    n97[1] = 0;
  }
  else if (n97e[0]) {
    n97[0] = n97d[0];
    n97[1] = n97d[1];
  }
  if (n112r[0]) {
    n112[0] = 0;
    n112[1] = 0;
  }
  else if (n112e[0]) {
    n112[0] = n112d[0];
    n112[1] = n112d[1];
  }
  if (n123r[0]) {
    n123[0] = 0;
    n123[1] = 0;
  }
  else if (n123e[0]) {
    n123[0] = n123d[0];
    n123[1] = n123d[1];
  }
  if (n153r[0]) {
    n153[0] = 0;
    n153[1] = 0;
  }
  else if (n153e[0]) {
    n153[0] = n153d[0];
    n153[1] = n153d[1];
  }
  if (n169r[0]) {
    n169[0] = 0;
    n169[1] = 0;
  }
  else if (n169e[0]) {
    n169[0] = n169d[0];
    n169[1] = n169d[1];
  }
  if (n180r[0]) {
    n180[0] = 0;
    n180[1] = 0;
  }
  else if (n180e[0]) {
    n180[0] = n180d[0];
    n180[1] = n180d[1];
  }
  if (n211r[0]) {
    n211[0] = 0;
    n211[1] = 0;
  }
  else if (n211e[0]) {
    n211[0] = n211d[0];
    n211[1] = n211d[1];
  }
  if (n228r[0]) {
    n228[0] = 0;
    n228[1] = 0;
  }
  else if (n228e[0]) {
    n228[0] = n228d[0];
    n228[1] = n228d[1];
  }
  if (n239r[0]) {
    n239[0] = 0;
    n239[1] = 0;
  }
  else if (n239e[0]) {
    n239[0] = n239d[0];
    n239[1] = n239d[1];
  }
  if (n271r[0]) {
    n271[0] = 0;
    n271[1] = 0;
  }
  else if (n271e[0]) {
    n271[0] = n271d[0];
    n271[1] = n271d[1];
  }
  if (n289r[0]) {
    n289[0] = 0;
    n289[1] = 0;
  }
  else if (n289e[0]) {
    n289[0] = n289d[0];
    n289[1] = n289d[1];
  }
  if (n300r[0]) {
    n300[0] = 0;
    n300[1] = 0;
  }
  else if (n300e[0]) {
    n300[0] = n300d[0];
    n300[1] = n300d[1];
  }
  if (n333r[0]) {
    n333[0] = 0;
    n333[1] = 0;
  }
  else if (n333e[0]) {
    n333[0] = n333d[0];
    n333[1] = n333d[1];
  }
  if (n352r[0]) {
    n352[0] = 0;
    n352[1] = 0;
  }
  else if (n352e[0]) {
    n352[0] = n352d[0];
    n352[1] = n352d[1];
  }
  if (n363r[0]) {
    n363[0] = 0;
    n363[1] = 0;
  }
  else if (n363e[0]) {
    n363[0] = n363d[0];
    n363[1] = n363d[1];
  }
  if (n397r[0]) {
    n397[0] = 0;
    n397[1] = 0;
  }
  else if (n397e[0]) {
    n397[0] = n397d[0];
    n397[1] = n397d[1];
  }
  if (n417r[0]) {
    n417[0] = 0;
    n417[1] = 0;
  }
  else if (n417e[0]) {
    n417[0] = n417d[0];
    n417[1] = n417d[1];
  }
  if (n428r[0]) {
    n428[0] = 0;
    n428[1] = 0;
  }
  else if (n428e[0]) {
    n428[0] = n428d[0];
    n428[1] = n428d[1];
  }
  if (n463r[0]) {
    n463[0] = 0;
    n463[1] = 0;
  }
  else if (n463e[0]) {
    n463[0] = n463d[0];
    n463[1] = n463d[1];
  }
  if (n484r[0]) {
    n484[0] = 0;
    n484[1] = 0;
  }
  else if (n484e[0]) {
    n484[0] = n484d[0];
    n484[1] = n484d[1];
  }
  if (n495r[0]) {
    n495[0] = 0;
    n495[1] = 0;
  }
  else if (n495e[0]) {
    n495[0] = n495d[0];
    n495[1] = n495d[1];
  }
  if (n531r[0]) {
    n531[0] = 0;
    n531[1] = 0;
  }
  else if (n531e[0]) {
    n531[0] = n531d[0];
    n531[1] = n531d[1];
  }
  if (n553r[0]) {
    n553[0] = 0;
    n553[1] = 0;
  }
  else if (n553e[0]) {
    n553[0] = n553d[0];
    n553[1] = n553d[1];
  }
  if (n564r[0]) {
    n564[0] = 0;
    n564[1] = 0;
  }
  else if (n564e[0]) {
    n564[0] = n564d[0];
    n564[1] = n564d[1];
  }
  if (n601r[0]) {
    n601[0] = 0;
    n601[1] = 0;
  }
  else if (n601e[0]) {
    n601[0] = n601d[0];
    n601[1] = n601d[1];
  }
  if (n624r[0]) {
    n624[0] = 0;
    n624[1] = 0;
  }
  else if (n624e[0]) {
    n624[0] = n624d[0];
    n624[1] = n624d[1];
  }
  if (n635r[0]) {
    n635[0] = 0;
    n635[1] = 0;
  }
  else if (n635e[0]) {
    n635[0] = n635d[0];
    n635[1] = n635d[1];
  }
  if (n673r[0]) {
    n673[0] = 0;
    n673[1] = 0;
  }
  else if (n673e[0]) {
    n673[0] = n673d[0];
    n673[1] = n673d[1];
  }
  if (n697r[0]) {
    n697[0] = 0;
    n697[1] = 0;
  }
  else if (n697e[0]) {
    n697[0] = n697d[0];
    n697[1] = n697d[1];
  }
  if (n708r[0]) {
    n708[0] = 0;
    n708[1] = 0;
  }
  else if (n708e[0]) {
    n708[0] = n708d[0];
    n708[1] = n708d[1];
  }
  if (n747r[0]) {
    n747[0] = 0;
    n747[1] = 0;
  }
  else if (n747e[0]) {
    n747[0] = n747d[0];
    n747[1] = n747d[1];
  }
  if (n772r[0]) {
    n772[0] = 0;
    n772[1] = 0;
  }
  else if (n772e[0]) {
    n772[0] = n772d[0];
    n772[1] = n772d[1];
  }
  if (n783r[0]) {
    n783[0] = 0;
    n783[1] = 0;
  }
  else if (n783e[0]) {
    n783[0] = n783d[0];
    n783[1] = n783d[1];
  }
  if (n823r[0]) {
    n823[0] = 0;
    n823[1] = 0;
  }
  else if (n823e[0]) {
    n823[0] = n823d[0];
    n823[1] = n823d[1];
  }
  if (n849r[0]) {
    n849[0] = 0;
    n849[1] = 0;
  }
  else if (n849e[0]) {
    n849[0] = n849d[0];
    n849[1] = n849d[1];
  }
  if (n860r[0]) {
    n860[0] = 0;
    n860[1] = 0;
  }
  else if (n860e[0]) {
    n860[0] = n860d[0];
    n860[1] = n860d[1];
  }
  if (n901r[0]) {
    n901[0] = 0;
    n901[1] = 0;
  }
  else if (n901e[0]) {
    n901[0] = n901d[0];
    n901[1] = n901d[1];
  }
  if (n928r[0]) {
    n928[0] = 0;
    n928[1] = 0;
  }
  else if (n928e[0]) {
    n928[0] = n928d[0];
    n928[1] = n928d[1];
  }
  if (n939r[0]) {
    n939[0] = 0;
    n939[1] = 0;
  }
  else if (n939e[0]) {
    n939[0] = n939d[0];
    n939[1] = n939d[1];
  }
  if (n981r[0]) {
    n981[0] = 0;
    n981[1] = 0;
  }
  else if (n981e[0]) {
    n981[0] = n981d[0];
    n981[1] = n981d[1];
  }
  if (n1009r[0]) {
    n1009[0] = 0;
    n1009[1] = 0;
  }
  else if (n1009e[0]) {
    n1009[0] = n1009d[0];
    n1009[1] = n1009d[1];
  }
  if (n1020r[0]) {
    n1020[0] = 0;
    n1020[1] = 0;
  }
  else if (n1020e[0]) {
    n1020[0] = n1020d[0];
    n1020[1] = n1020d[1];
  }
  if (n1063r[0]) {
    n1063[0] = 0;
    n1063[1] = 0;
  }
  else if (n1063e[0]) {
    n1063[0] = n1063d[0];
    n1063[1] = n1063d[1];
  }
  if (n1092r[0]) {
    n1092[0] = 0;
    n1092[1] = 0;
  }
  else if (n1092e[0]) {
    n1092[0] = n1092d[0];
    n1092[1] = n1092d[1];
  }
  if (n1103r[0]) {
    n1103[0] = 0;
    n1103[1] = 0;
  }
  else if (n1103e[0]) {
    n1103[0] = n1103d[0];
    n1103[1] = n1103d[1];
  }
  if (n1147r[0]) {
    n1147[0] = 0;
    n1147[1] = 0;
  }
  else if (n1147e[0]) {
    n1147[0] = n1147d[0];
    n1147[1] = n1147d[1];
  }
  if (n1177r[0]) {
    n1177[0] = 0;
    n1177[1] = 0;
  }
  else if (n1177e[0]) {
    n1177[0] = n1177d[0];
    n1177[1] = n1177d[1];
  }
  if (n1188r[0]) {
    n1188[0] = 0;
    n1188[1] = 0;
  }
  else if (n1188e[0]) {
    n1188[0] = n1188d[0];
    n1188[1] = n1188d[1];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_enable_i[1];
static unsigned char sim_reset_i[1];
static unsigned char sim_flip_i[1];
static unsigned char sim_real_i[2];
static unsigned char sim_imag_i[2];
static unsigned char sim_ang_i[2];
static unsigned char sim_real_o[2];
static unsigned char sim_imag_o[2];
static unsigned char sim_ang_o[2];

void cf_cordic_r_16_16_16_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_cordic_r_16_16_16_init();
  sim_enable_i[0] = enable_i[0];
  sim_reset_i[0] = reset_i[0];
  sim_flip_i[0] = flip_i[0];
  sim_real_i[0] = real_i[0];
  sim_real_i[1] = real_i[1];
  sim_imag_i[0] = imag_i[0];
  sim_imag_i[1] = imag_i[1];
  sim_ang_i[0] = ang_i[0];
  sim_ang_i[1] = ang_i[1];
  sim_real_o[0] = real_o[0];
  sim_real_o[1] = real_o[1];
  sim_imag_o[0] = imag_o[0];
  sim_imag_o[1] = imag_o[1];
  sim_ang_o[0] = ang_o[0];
  sim_ang_o[1] = ang_o[1];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_cordic_r_16_16_16 $end\n"
    "$var wire 1 ! enable_i $end\n"
    "$var wire 1 \" reset_i $end\n"
    "$var wire 1 # flip_i $end\n"
    "$var wire 16 $ real_i $end\n"
    "$var wire 16 %% imag_i $end\n"
    "$var wire 16 & ang_i $end\n"
    "$var wire 16 ' real_o $end\n"
    "$var wire 16 ( imag_o $end\n"
    "$var wire 16 ) ang_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, enable_i[0] ? "1!\n" : "0!\n");
  fprintf(sim_file, reset_i[0] ? "1\"\n" : "0\"\n");
  fprintf(sim_file, flip_i[0] ? "1#\n" : "0#\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & real_i[byte]) ? "1" : "0");
        else if (bit & real_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & imag_i[byte]) ? "1" : "0");
        else if (bit & imag_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & ang_i[byte]) ? "1" : "0");
        else if (bit & ang_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & real_o[byte]) ? "1" : "0");
        else if (bit & real_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & imag_o[byte]) ? "1" : "0");
        else if (bit & imag_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & ang_o[byte]) ? "1" : "0");
        else if (bit & ang_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " )\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_cordic_r_16_16_16_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_cordic_r_16_16_16_sim_sample() {
  int changed = 0;
  if (sim_enable_i[0] != enable_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, enable_i[0] ? "1!\n" : "0!\n");
    sim_enable_i[0] = enable_i[0];
  }
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1\"\n" : "0\"\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_flip_i[0] != flip_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, flip_i[0] ? "1#\n" : "0#\n");
    sim_flip_i[0] = flip_i[0];
  }
  if (sim_real_i[1] != real_i[1] || sim_real_i[0] != real_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & real_i[byte]) ? "1" : "0");
          else if (bit & real_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_real_i[0] = real_i[0];
    sim_real_i[1] = real_i[1];
  }
  if (sim_imag_i[1] != imag_i[1] || sim_imag_i[0] != imag_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & imag_i[byte]) ? "1" : "0");
          else if (bit & imag_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_imag_i[0] = imag_i[0];
    sim_imag_i[1] = imag_i[1];
  }
  if (sim_ang_i[1] != ang_i[1] || sim_ang_i[0] != ang_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & ang_i[byte]) ? "1" : "0");
          else if (bit & ang_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_ang_i[0] = ang_i[0];
    sim_ang_i[1] = ang_i[1];
  }
  if (sim_real_o[1] != real_o[1] || sim_real_o[0] != real_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & real_o[byte]) ? "1" : "0");
          else if (bit & real_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_real_o[0] = real_o[0];
    sim_real_o[1] = real_o[1];
  }
  if (sim_imag_o[1] != imag_o[1] || sim_imag_o[0] != imag_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & imag_o[byte]) ? "1" : "0");
          else if (bit & imag_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_imag_o[0] = imag_o[0];
    sim_imag_o[1] = imag_o[1];
  }
  if (sim_ang_o[1] != ang_o[1] || sim_ang_o[0] != ang_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & ang_o[byte]) ? "1" : "0");
          else if (bit & ang_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " )\n");
    }
    sim_ang_o[0] = ang_o[0];
    sim_ang_o[1] = ang_o[1];
  }
  sim_count++;
}

