//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Cordics (COordinate Rotation DIgital Computers) are used to calculate
//    trigonometric functions and complex plane phase rotations.
//    This vector mode cordic rotates any complex vector to the positive real axis.
//    The resulting angle is the initial angle plus the angle of rotation.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      enable_i : Synchronous enable.
//      reset_i  : Synchronous reset.
//  
//    Inputs:
//      real_i   : Initial real component (signed).
//      imag_i   : Initial imaginary component (signed).
//      angle_i  : Initial angle (modulo 2PI).
//  
//    Outputs:
//      real_o   : Resulting real component (signed).
//      imag_o   : Resulting imaginary component (signed).
//      angle_o  : Resulting angle (modulo 2PI).
//  
//  Built In Parameters:
//  
//    Cordic Mode    = Vector
//    Vector Width   = 16
//    Angle Width    = 16
//    Cordic Stages  = 16
//  
//  Resulting Pipeline Latency is 18 clock cycles.
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:44:24 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_cordic_v_16_16_16
//    Clock Domains : clock_c  
//    Vector Input  : enable_i(1)
//    Vector Input  : reset_i(1)
//    Vector Input  : real_i(16)
//    Vector Input  : imag_i(16)
//    Vector Input  : ang_i(16)
//    Vector Output : real_o(16)
//    Vector Output : imag_o(16)
//    Vector Output : ang_o(16)
//  
//  
//  

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "cf_cordic_v_16_16_16.h"

static unsigned char n1304[3];
static unsigned char n1302[3];
static unsigned char n1300[3];
static unsigned char n1298[3];
static unsigned char n1296[3];
static unsigned char n1294[3];
static unsigned char n1292[3];
static unsigned char n1290[3];
static unsigned char n1288[3];
static unsigned char n1286[3];
static unsigned char n1284[3];
static unsigned char n1282[3];
static unsigned char n1280[3];
static unsigned char n1278[3];
static unsigned char n1276[3];
static unsigned char n1274[3];
static unsigned char n1272[3];
static unsigned char n1203[2];
static unsigned char *ang_o;
static unsigned char *imag_o;
static unsigned char *real_o;
static unsigned char n1185[2];
static unsigned char n1173[1];
static unsigned char n1156[1];
static unsigned char n1143[1];
static unsigned char n1126[1];
static unsigned char n1122[1];
static unsigned char n1114[2];
static unsigned char n1112[1];
static unsigned char n1100[2];
static unsigned char n1088[1];
static unsigned char n1072[1];
static unsigned char n1059[1];
static unsigned char n1043[1];
static unsigned char n1039[1];
static unsigned char n1031[2];
static unsigned char n1029[1];
static unsigned char n1017[2];
static unsigned char n1005[1];
static unsigned char n990[1];
static unsigned char n977[1];
static unsigned char n962[1];
static unsigned char n958[1];
static unsigned char n950[2];
static unsigned char n948[1];
static unsigned char n936[2];
static unsigned char n924[1];
static unsigned char n910[1];
static unsigned char n897[1];
static unsigned char n883[1];
static unsigned char n879[1];
static unsigned char n871[2];
static unsigned char n869[1];
static unsigned char n857[2];
static unsigned char n845[1];
static unsigned char n832[1];
static unsigned char n819[1];
static unsigned char n806[1];
static unsigned char n802[1];
static unsigned char n794[2];
static unsigned char n792[1];
static unsigned char n780[2];
static unsigned char n768[1];
static unsigned char n756[1];
static unsigned char n743[1];
static unsigned char n731[1];
static unsigned char n727[1];
static unsigned char n719[2];
static unsigned char n717[1];
static unsigned char n705[2];
static unsigned char n693[1];
static unsigned char n682[1];
static unsigned char n669[1];
static unsigned char n658[1];
static unsigned char n654[1];
static unsigned char n646[2];
static unsigned char n644[1];
static unsigned char n632[2];
static unsigned char n620[1];
static unsigned char n610[1];
static unsigned char n597[1];
static unsigned char n587[1];
static unsigned char n583[1];
static unsigned char n575[2];
static unsigned char n573[1];
static unsigned char n561[2];
static unsigned char n549[2];
static unsigned char n540[1];
static unsigned char n527[2];
static unsigned char n518[1];
static unsigned char n514[1];
static unsigned char n506[2];
static unsigned char n504[1];
static unsigned char n492[2];
static unsigned char n480[2];
static unsigned char n472[1];
static unsigned char n459[2];
static unsigned char n451[1];
static unsigned char n447[1];
static unsigned char n439[2];
static unsigned char n437[1];
static unsigned char n425[2];
static unsigned char n413[2];
static unsigned char n406[1];
static unsigned char n393[2];
static unsigned char n386[1];
static unsigned char n382[1];
static unsigned char n374[2];
static unsigned char n372[1];
static unsigned char n360[2];
static unsigned char n348[2];
static unsigned char n342[1];
static unsigned char n329[2];
static unsigned char n323[1];
static unsigned char n319[1];
static unsigned char n311[2];
static unsigned char n309[1];
static unsigned char n297[2];
static unsigned char n285[2];
static unsigned char n280[1];
static unsigned char n267[2];
static unsigned char n262[1];
static unsigned char n258[1];
static unsigned char n250[2];
static unsigned char n248[1];
static unsigned char n236[2];
static unsigned char n224[2];
static unsigned char n220[1];
static unsigned char n207[2];
static unsigned char n203[1];
static unsigned char n199[1];
static unsigned char n191[2];
static unsigned char n189[1];
static unsigned char n177[2];
static unsigned char n165[2];
static unsigned char n162[1];
static unsigned char n149[2];
static unsigned char n146[1];
static unsigned char n142[1];
static unsigned char n134[2];
static unsigned char n132[1];
static unsigned char n120[2];
static unsigned char n108[2];
static unsigned char n93[2];
static unsigned char n87[1];
static unsigned char n79[2];
static unsigned char n77[1];
static unsigned char n46[2];
static unsigned char n44[2];
static unsigned char n38[1];
static unsigned char n32[2];
static unsigned char n30[1];
static unsigned char *ang_i;
static unsigned char *imag_i;
static unsigned char *real_i;
static unsigned char *reset_i;
static unsigned char *enable_i;
static unsigned char n1187[2];
static unsigned char n1186[2];
static unsigned char n1159[1];
static unsigned char n1129[1];
static unsigned char n1113[1];
static unsigned char n1102[2];
static unsigned char n1101[2];
static unsigned char n1075[1];
static unsigned char n1046[1];
static unsigned char n1030[1];
static unsigned char n1019[2];
static unsigned char n1018[2];
static unsigned char n993[1];
static unsigned char n965[1];
static unsigned char n949[1];
static unsigned char n938[2];
static unsigned char n937[2];
static unsigned char n913[1];
static unsigned char n886[1];
static unsigned char n870[1];
static unsigned char n859[2];
static unsigned char n858[2];
static unsigned char n835[1];
static unsigned char n809[1];
static unsigned char n793[1];
static unsigned char n782[2];
static unsigned char n781[2];
static unsigned char n759[1];
static unsigned char n734[1];
static unsigned char n718[1];
static unsigned char n707[2];
static unsigned char n706[2];
static unsigned char n685[1];
static unsigned char n661[1];
static unsigned char n645[1];
static unsigned char n634[2];
static unsigned char n633[2];
static unsigned char n613[1];
static unsigned char n590[1];
static unsigned char n574[1];
static unsigned char n563[2];
static unsigned char n562[2];
static unsigned char n543[1];
static unsigned char n521[1];
static unsigned char n505[1];
static unsigned char n494[2];
static unsigned char n493[2];
static unsigned char n475[1];
static unsigned char n454[1];
static unsigned char n438[1];
static unsigned char n427[2];
static unsigned char n426[2];
static unsigned char n409[1];
static unsigned char n389[1];
static unsigned char n373[1];
static unsigned char n362[2];
static unsigned char n361[2];
static unsigned char n345[1];
static unsigned char n326[1];
static unsigned char n310[1];
static unsigned char n299[2];
static unsigned char n298[2];
static unsigned char n283[1];
static unsigned char n265[1];
static unsigned char n249[1];
static unsigned char n238[2];
static unsigned char n237[2];
static unsigned char n223[1];
static unsigned char n206[1];
static unsigned char n190[1];
static unsigned char n179[2];
static unsigned char n178[2];
static unsigned char n166[2];
static unsigned char n150[2];
static unsigned char n133[1];
static unsigned char n122[2];
static unsigned char n121[2];
static unsigned char n111[2];
static unsigned char n110[2];
static unsigned char n96[2];
static unsigned char n95[2];
static unsigned char n78[1];
static unsigned char n51[2];
static unsigned char n47[2];
static unsigned char n45[2];
static unsigned char n31[1];
static unsigned char n28[2];
static unsigned char n28r[1];
static unsigned char n28e[1];
static unsigned char n28d[2];
static unsigned char n21[2];
static unsigned char n21r[1];
static unsigned char n21e[1];
static unsigned char n21d[2];
static unsigned char n14[2];
static unsigned char n14r[1];
static unsigned char n14e[1];
static unsigned char n14d[2];
static unsigned char n1160[1];
static unsigned char n1130[1];
static unsigned char n1115[2];
static unsigned char n1076[1];
static unsigned char n1047[1];
static unsigned char n1032[2];
static unsigned char n994[1];
static unsigned char n966[1];
static unsigned char n951[2];
static unsigned char n914[1];
static unsigned char n887[1];
static unsigned char n872[2];
static unsigned char n836[1];
static unsigned char n810[1];
static unsigned char n795[2];
static unsigned char n760[1];
static unsigned char n735[1];
static unsigned char n720[2];
static unsigned char n686[1];
static unsigned char n662[1];
static unsigned char n647[2];
static unsigned char n614[1];
static unsigned char n591[1];
static unsigned char n576[2];
static unsigned char n544[1];
static unsigned char n522[1];
static unsigned char n507[2];
static unsigned char n476[1];
static unsigned char n455[1];
static unsigned char n440[2];
static unsigned char n410[1];
static unsigned char n390[1];
static unsigned char n375[2];
static unsigned char n346[1];
static unsigned char n327[1];
static unsigned char n312[2];
static unsigned char n284[1];
static unsigned char n266[1];
static unsigned char n251[2];
static unsigned char n225[2];
static unsigned char n208[2];
static unsigned char n192[2];
static unsigned char n168[2];
static unsigned char n167[2];
static unsigned char n152[2];
static unsigned char n151[2];
static unsigned char n135[2];
static unsigned char n80[2];
static unsigned char n33[2];
static unsigned char n1161[1];
static unsigned char n1131[1];
static unsigned char n1123[3];
static unsigned char n1077[1];
static unsigned char n1048[1];
static unsigned char n1040[3];
static unsigned char n995[1];
static unsigned char n967[1];
static unsigned char n959[3];
static unsigned char n915[1];
static unsigned char n888[1];
static unsigned char n880[3];
static unsigned char n837[1];
static unsigned char n811[1];
static unsigned char n803[3];
static unsigned char n761[1];
static unsigned char n736[1];
static unsigned char n728[3];
static unsigned char n687[1];
static unsigned char n663[1];
static unsigned char n655[3];
static unsigned char n615[1];
static unsigned char n592[1];
static unsigned char n584[3];
static unsigned char n545[1];
static unsigned char n523[1];
static unsigned char n515[3];
static unsigned char n477[1];
static unsigned char n456[1];
static unsigned char n448[3];
static unsigned char n411[1];
static unsigned char n391[1];
static unsigned char n383[3];
static unsigned char n347[1];
static unsigned char n328[1];
static unsigned char n320[3];
static unsigned char n286[2];
static unsigned char n268[2];
static unsigned char n259[3];
static unsigned char n227[2];
static unsigned char n226[2];
static unsigned char n210[2];
static unsigned char n209[2];
static unsigned char n200[3];
static unsigned char n143[3];
static unsigned char n88[3];
static unsigned char n39[3];
static unsigned char n1162[1];
static unsigned char n1132[1];
static unsigned char n1124[3];
static unsigned char n1078[1];
static unsigned char n1049[1];
static unsigned char n1041[3];
static unsigned char n996[1];
static unsigned char n968[1];
static unsigned char n960[3];
static unsigned char n916[1];
static unsigned char n889[1];
static unsigned char n881[3];
static unsigned char n838[1];
static unsigned char n812[1];
static unsigned char n804[3];
static unsigned char n762[1];
static unsigned char n737[1];
static unsigned char n729[3];
static unsigned char n688[1];
static unsigned char n664[1];
static unsigned char n656[3];
static unsigned char n616[1];
static unsigned char n593[1];
static unsigned char n585[3];
static unsigned char n546[1];
static unsigned char n524[1];
static unsigned char n516[3];
static unsigned char n478[1];
static unsigned char n457[1];
static unsigned char n449[3];
static unsigned char n412[1];
static unsigned char n392[1];
static unsigned char n384[3];
static unsigned char n349[2];
static unsigned char n330[2];
static unsigned char n321[3];
static unsigned char n288[2];
static unsigned char n287[2];
static unsigned char n270[2];
static unsigned char n269[2];
static unsigned char n260[3];
static unsigned char n201[3];
static unsigned char n144[3];
static unsigned char n89[3];
static unsigned char n42[3];
static unsigned char n1163[1];
static unsigned char n1133[1];
static unsigned char n1125[1];
static unsigned char n1079[1];
static unsigned char n1050[1];
static unsigned char n1042[1];
static unsigned char n997[1];
static unsigned char n969[1];
static unsigned char n961[1];
static unsigned char n917[1];
static unsigned char n890[1];
static unsigned char n882[1];
static unsigned char n839[1];
static unsigned char n813[1];
static unsigned char n805[1];
static unsigned char n763[1];
static unsigned char n738[1];
static unsigned char n730[1];
static unsigned char n689[1];
static unsigned char n665[1];
static unsigned char n657[1];
static unsigned char n617[1];
static unsigned char n594[1];
static unsigned char n586[1];
static unsigned char n547[1];
static unsigned char n525[1];
static unsigned char n517[1];
static unsigned char n479[1];
static unsigned char n458[1];
static unsigned char n450[1];
static unsigned char n414[2];
static unsigned char n394[2];
static unsigned char n385[1];
static unsigned char n351[2];
static unsigned char n350[2];
static unsigned char n332[2];
static unsigned char n331[2];
static unsigned char n322[1];
static unsigned char n261[1];
static unsigned char n202[1];
static unsigned char n145[1];
static unsigned char n90[1];
static unsigned char n43[1];
static unsigned char n1188[2];
static unsigned char n1164[1];
static unsigned char n1155[1];
static unsigned char n1134[1];
static unsigned char n1103[2];
static unsigned char n1080[1];
static unsigned char n1071[1];
static unsigned char n1051[1];
static unsigned char n1020[2];
static unsigned char n998[1];
static unsigned char n989[1];
static unsigned char n970[1];
static unsigned char n939[2];
static unsigned char n918[1];
static unsigned char n909[1];
static unsigned char n891[1];
static unsigned char n860[2];
static unsigned char n840[1];
static unsigned char n831[1];
static unsigned char n814[1];
static unsigned char n783[2];
static unsigned char n764[1];
static unsigned char n755[1];
static unsigned char n739[1];
static unsigned char n708[2];
static unsigned char n690[1];
static unsigned char n681[1];
static unsigned char n666[1];
static unsigned char n635[2];
static unsigned char n618[1];
static unsigned char n609[1];
static unsigned char n595[1];
static unsigned char n564[2];
static unsigned char n548[1];
static unsigned char n539[1];
static unsigned char n526[1];
static unsigned char n495[2];
static unsigned char n481[2];
static unsigned char n471[1];
static unsigned char n460[2];
static unsigned char n428[2];
static unsigned char n416[2];
static unsigned char n415[2];
static unsigned char n405[1];
static unsigned char n396[2];
static unsigned char n395[2];
static unsigned char n363[2];
static unsigned char n341[1];
static unsigned char n333[2];
static unsigned char n300[2];
static unsigned char n279[1];
static unsigned char n271[2];
static unsigned char n239[2];
static unsigned char n219[1];
static unsigned char n211[2];
static unsigned char n180[2];
static unsigned char n161[1];
static unsigned char n153[2];
static unsigned char n123[2];
static unsigned char n105[1];
static unsigned char n97[2];
static unsigned char n68[2];
static unsigned char n60[2];
static unsigned char n52[2];
static unsigned char n1195[2];
static unsigned char n1195r[1];
static unsigned char n1195e[1];
static unsigned char n1195d[2];
static unsigned char n1165[1];
static unsigned char n1135[1];
static unsigned char n1110[2];
static unsigned char n1110r[1];
static unsigned char n1110e[1];
static unsigned char n1110d[2];
static unsigned char n1081[1];
static unsigned char n1052[1];
static unsigned char n1027[2];
static unsigned char n1027r[1];
static unsigned char n1027e[1];
static unsigned char n1027d[2];
static unsigned char n999[1];
static unsigned char n971[1];
static unsigned char n946[2];
static unsigned char n946r[1];
static unsigned char n946e[1];
static unsigned char n946d[2];
static unsigned char n919[1];
static unsigned char n892[1];
static unsigned char n867[2];
static unsigned char n867r[1];
static unsigned char n867e[1];
static unsigned char n867d[2];
static unsigned char n841[1];
static unsigned char n815[1];
static unsigned char n790[2];
static unsigned char n790r[1];
static unsigned char n790e[1];
static unsigned char n790d[2];
static unsigned char n765[1];
static unsigned char n740[1];
static unsigned char n715[2];
static unsigned char n715r[1];
static unsigned char n715e[1];
static unsigned char n715d[2];
static unsigned char n691[1];
static unsigned char n667[1];
static unsigned char n642[2];
static unsigned char n642r[1];
static unsigned char n642e[1];
static unsigned char n642d[2];
static unsigned char n619[1];
static unsigned char n596[1];
static unsigned char n571[2];
static unsigned char n571r[1];
static unsigned char n571e[1];
static unsigned char n571d[2];
static unsigned char n550[2];
static unsigned char n528[2];
static unsigned char n502[2];
static unsigned char n502r[1];
static unsigned char n502e[1];
static unsigned char n502d[2];
static unsigned char n483[2];
static unsigned char n482[2];
static unsigned char n462[2];
static unsigned char n461[2];
static unsigned char n435[2];
static unsigned char n435r[1];
static unsigned char n435e[1];
static unsigned char n435d[2];
static unsigned char n417[2];
static unsigned char n397[2];
static unsigned char n370[2];
static unsigned char n370r[1];
static unsigned char n370e[1];
static unsigned char n370d[2];
static unsigned char n352[2];
static unsigned char n340[2];
static unsigned char n340r[1];
static unsigned char n340e[1];
static unsigned char n340d[2];
static unsigned char n307[2];
static unsigned char n307r[1];
static unsigned char n307e[1];
static unsigned char n307d[2];
static unsigned char n289[2];
static unsigned char n278[2];
static unsigned char n278r[1];
static unsigned char n278e[1];
static unsigned char n278d[2];
static unsigned char n246[2];
static unsigned char n246r[1];
static unsigned char n246e[1];
static unsigned char n246d[2];
static unsigned char n228[2];
static unsigned char n218[2];
static unsigned char n218r[1];
static unsigned char n218e[1];
static unsigned char n218d[2];
static unsigned char n187[2];
static unsigned char n187r[1];
static unsigned char n187e[1];
static unsigned char n187d[2];
static unsigned char n169[2];
static unsigned char n160[2];
static unsigned char n160r[1];
static unsigned char n160e[1];
static unsigned char n160d[2];
static unsigned char n130[2];
static unsigned char n130r[1];
static unsigned char n130e[1];
static unsigned char n130d[2];
static unsigned char n112[2];
static unsigned char n104[2];
static unsigned char n104r[1];
static unsigned char n104e[1];
static unsigned char n104d[2];
static unsigned char n75[2];
static unsigned char n75r[1];
static unsigned char n75e[1];
static unsigned char n75d[2];
static unsigned char n67[2];
static unsigned char n67r[1];
static unsigned char n67e[1];
static unsigned char n67d[2];
static unsigned char n59[2];
static unsigned char n59r[1];
static unsigned char n59e[1];
static unsigned char n59d[2];
static unsigned char n1166[2];
static unsigned char n1136[2];
static unsigned char n1082[2];
static unsigned char n1053[2];
static unsigned char n1000[2];
static unsigned char n972[2];
static unsigned char n920[2];
static unsigned char n893[2];
static unsigned char n842[2];
static unsigned char n816[2];
static unsigned char n766[2];
static unsigned char n741[2];
static unsigned char n692[2];
static unsigned char n668[2];
static unsigned char n621[2];
static unsigned char n598[2];
static unsigned char n552[2];
static unsigned char n551[2];
static unsigned char n530[2];
static unsigned char n529[2];
static unsigned char n484[2];
static unsigned char n463[2];
static unsigned char n424[2];
static unsigned char n424r[1];
static unsigned char n424e[1];
static unsigned char n424d[2];
static unsigned char n404[2];
static unsigned char n404r[1];
static unsigned char n404e[1];
static unsigned char n404d[2];
static unsigned char n359[2];
static unsigned char n359r[1];
static unsigned char n359e[1];
static unsigned char n359d[2];
static unsigned char n296[2];
static unsigned char n296r[1];
static unsigned char n296e[1];
static unsigned char n296d[2];
static unsigned char n235[2];
static unsigned char n235r[1];
static unsigned char n235e[1];
static unsigned char n235d[2];
static unsigned char n176[2];
static unsigned char n176r[1];
static unsigned char n176e[1];
static unsigned char n176d[2];
static unsigned char n119[2];
static unsigned char n119r[1];
static unsigned char n119e[1];
static unsigned char n119d[2];
static unsigned char n1167[2];
static unsigned char n1137[2];
static unsigned char n1083[2];
static unsigned char n1054[2];
static unsigned char n1001[2];
static unsigned char n973[2];
static unsigned char n921[2];
static unsigned char n894[2];
static unsigned char n843[2];
static unsigned char n817[2];
static unsigned char n767[2];
static unsigned char n742[2];
static unsigned char n694[2];
static unsigned char n670[2];
static unsigned char n623[2];
static unsigned char n622[2];
static unsigned char n600[2];
static unsigned char n599[2];
static unsigned char n553[2];
static unsigned char n531[2];
static unsigned char n491[2];
static unsigned char n491r[1];
static unsigned char n491e[1];
static unsigned char n491d[2];
static unsigned char n470[2];
static unsigned char n470r[1];
static unsigned char n470e[1];
static unsigned char n470d[2];
static unsigned char n1168[2];
static unsigned char n1138[2];
static unsigned char n1084[2];
static unsigned char n1055[2];
static unsigned char n1002[2];
static unsigned char n974[2];
static unsigned char n922[2];
static unsigned char n895[2];
static unsigned char n844[2];
static unsigned char n818[2];
static unsigned char n769[2];
static unsigned char n744[2];
static unsigned char n696[2];
static unsigned char n695[2];
static unsigned char n672[2];
static unsigned char n671[2];
static unsigned char n624[2];
static unsigned char n601[2];
static unsigned char n560[2];
static unsigned char n560r[1];
static unsigned char n560e[1];
static unsigned char n560d[2];
static unsigned char n538[2];
static unsigned char n538r[1];
static unsigned char n538e[1];
static unsigned char n538d[2];
static unsigned char n1169[2];
static unsigned char n1139[2];
static unsigned char n1085[2];
static unsigned char n1056[2];
static unsigned char n1003[2];
static unsigned char n975[2];
static unsigned char n923[2];
static unsigned char n896[2];
static unsigned char n846[2];
static unsigned char n820[2];
static unsigned char n771[2];
static unsigned char n770[2];
static unsigned char n746[2];
static unsigned char n745[2];
static unsigned char n697[2];
static unsigned char n673[2];
static unsigned char n631[2];
static unsigned char n631r[1];
static unsigned char n631e[1];
static unsigned char n631d[2];
static unsigned char n608[2];
static unsigned char n608r[1];
static unsigned char n608e[1];
static unsigned char n608d[2];
static unsigned char n1170[2];
static unsigned char n1140[2];
static unsigned char n1086[2];
static unsigned char n1057[2];
static unsigned char n1004[2];
static unsigned char n976[2];
static unsigned char n925[2];
static unsigned char n898[2];
static unsigned char n848[2];
static unsigned char n847[2];
static unsigned char n822[2];
static unsigned char n821[2];
static unsigned char n772[2];
static unsigned char n747[2];
static unsigned char n704[2];
static unsigned char n704r[1];
static unsigned char n704e[1];
static unsigned char n704d[2];
static unsigned char n680[2];
static unsigned char n680r[1];
static unsigned char n680e[1];
static unsigned char n680d[2];
static unsigned char n1171[2];
static unsigned char n1141[2];
static unsigned char n1087[2];
static unsigned char n1058[2];
static unsigned char n1006[2];
static unsigned char n978[2];
static unsigned char n927[2];
static unsigned char n926[2];
static unsigned char n900[2];
static unsigned char n899[2];
static unsigned char n849[2];
static unsigned char n823[2];
static unsigned char n779[2];
static unsigned char n779r[1];
static unsigned char n779e[1];
static unsigned char n779d[2];
static unsigned char n754[2];
static unsigned char n754r[1];
static unsigned char n754e[1];
static unsigned char n754d[2];
static unsigned char n1172[2];
static unsigned char n1142[2];
static unsigned char n1089[2];
static unsigned char n1060[2];
static unsigned char n1008[2];
static unsigned char n1007[2];
static unsigned char n980[2];
static unsigned char n979[2];
static unsigned char n928[2];
static unsigned char n901[2];
static unsigned char n856[2];
static unsigned char n856r[1];
static unsigned char n856e[1];
static unsigned char n856d[2];
static unsigned char n830[2];
static unsigned char n830r[1];
static unsigned char n830e[1];
static unsigned char n830d[2];
static unsigned char n1174[2];
static unsigned char n1144[2];
static unsigned char n1091[2];
static unsigned char n1090[2];
static unsigned char n1062[2];
static unsigned char n1061[2];
static unsigned char n1009[2];
static unsigned char n981[2];
static unsigned char n935[2];
static unsigned char n935r[1];
static unsigned char n935e[1];
static unsigned char n935d[2];
static unsigned char n908[2];
static unsigned char n908r[1];
static unsigned char n908e[1];
static unsigned char n908d[2];
static unsigned char n1176[2];
static unsigned char n1175[2];
static unsigned char n1146[2];
static unsigned char n1145[2];
static unsigned char n1092[2];
static unsigned char n1063[2];
static unsigned char n1016[2];
static unsigned char n1016r[1];
static unsigned char n1016e[1];
static unsigned char n1016d[2];
static unsigned char n988[2];
static unsigned char n988r[1];
static unsigned char n988e[1];
static unsigned char n988d[2];
static unsigned char n1177[2];
static unsigned char n1147[2];
static unsigned char n1099[2];
static unsigned char n1099r[1];
static unsigned char n1099e[1];
static unsigned char n1099d[2];
static unsigned char n1070[2];
static unsigned char n1070r[1];
static unsigned char n1070e[1];
static unsigned char n1070d[2];
static unsigned char n1184[2];
static unsigned char n1184r[1];
static unsigned char n1184e[1];
static unsigned char n1184d[2];
static unsigned char n1154[2];
static unsigned char n1154r[1];
static unsigned char n1154e[1];
static unsigned char n1154d[2];

void cf_cordic_v_16_16_16_ports(unsigned char* port_enable_i, unsigned char* port_reset_i, unsigned char* port_real_i, unsigned char* port_imag_i, unsigned char* port_ang_i, unsigned char* port_real_o, unsigned char* port_imag_o, unsigned char* port_ang_o) {
  enable_i = port_enable_i;
  reset_i = port_reset_i;
  real_i = port_real_i;
  imag_i = port_imag_i;
  ang_i = port_ang_i;
  real_o = port_real_o;
  imag_o = port_imag_o;
  ang_o = port_ang_o;
}

void cf_cordic_v_16_16_16_calc() {
  n1304[0] = 0;
  n1304[1] = 128;
  n1304[2] = 0;
  n1302[0] = 0;
  n1302[1] = 128;
  n1302[2] = 0;
  n1300[0] = 0;
  n1300[1] = 128;
  n1300[2] = 0;
  n1298[0] = 0;
  n1298[1] = 128;
  n1298[2] = 0;
  n1296[0] = 0;
  n1296[1] = 128;
  n1296[2] = 0;
  n1294[0] = 0;
  n1294[1] = 128;
  n1294[2] = 0;
  n1292[0] = 0;
  n1292[1] = 128;
  n1292[2] = 0;
  n1290[0] = 0;
  n1290[1] = 128;
  n1290[2] = 0;
  n1288[0] = 0;
  n1288[1] = 128;
  n1288[2] = 0;
  n1286[0] = 0;
  n1286[1] = 128;
  n1286[2] = 0;
  n1284[0] = 0;
  n1284[1] = 128;
  n1284[2] = 0;
  n1282[0] = 0;
  n1282[1] = 128;
  n1282[2] = 0;
  n1280[0] = 0;
  n1280[1] = 128;
  n1280[2] = 0;
  n1278[0] = 0;
  n1278[1] = 128;
  n1278[2] = 0;
  n1276[0] = 0;
  n1276[1] = 128;
  n1276[2] = 0;
  n1274[0] = 0;
  n1274[1] = 128;
  n1274[2] = 0;
  n1272[0] = 0;
  n1272[1] = 128;
  n1272[2] = 0;
  n1203[0] = 0;
  n1203[1] = 128;
  ang_o[0] = n1195[0];
  ang_o[1] = n1195[1];
  imag_o[0] = n1184[0];
  imag_o[1] = n1184[1];
  real_o[0] = n1154[0];
  real_o[1] = n1154[1];
  n1185[0] = 0;
  n1185[1] = 0;
  n1173[0] = (1 & (n1070[1] >> 7));
  n1156[0] = (1 & (n1070[1] >> 7));
  n1143[0] = (1 & (n1099[1] >> 7));
  n1126[0] = (1 & (n1099[1] >> 7));
  n1122[0] = 0;
  n1114[0] = (1 & (n1099[0])) | (2 & (n1099[0])) | (4 & (n1099[0])) | (8 & (n1099[0])) | (16 & (n1099[0])) | (32 & (n1099[0])) | (64 & (n1099[0])) | (128 & (n1099[0]));
  n1114[1] = (1 & (n1099[1])) | (2 & (n1099[1])) | (4 & (n1099[1])) | (8 & (n1099[1])) | (16 & (n1099[1])) | (32 & (n1099[1])) | (64 & (n1099[1]));
  n1112[0] = (1 & (n1099[1] >> 7));
  n1100[0] = 1;
  n1100[1] = 0;
  n1088[0] = (1 & (n988[1] >> 6)) | (2 & (n988[1] >> 6));
  n1072[0] = (1 & (n988[1] >> 7));
  n1059[0] = (1 & (n1016[1] >> 6)) | (2 & (n1016[1] >> 6));
  n1043[0] = (1 & (n1016[1] >> 7));
  n1039[0] = 0;
  n1031[0] = (1 & (n1016[0])) | (2 & (n1016[0])) | (4 & (n1016[0])) | (8 & (n1016[0])) | (16 & (n1016[0])) | (32 & (n1016[0])) | (64 & (n1016[0])) | (128 & (n1016[0]));
  n1031[1] = (1 & (n1016[1])) | (2 & (n1016[1])) | (4 & (n1016[1])) | (8 & (n1016[1])) | (16 & (n1016[1])) | (32 & (n1016[1])) | (64 & (n1016[1]));
  n1029[0] = (1 & (n1016[1] >> 7));
  n1017[0] = 1;
  n1017[1] = 0;
  n1005[0] = (1 & (n908[1] >> 5)) | (2 & (n908[1] >> 5)) | (4 & (n908[1] >> 5));
  n990[0] = (1 & (n908[1] >> 7));
  n977[0] = (1 & (n935[1] >> 5)) | (2 & (n935[1] >> 5)) | (4 & (n935[1] >> 5));
  n962[0] = (1 & (n935[1] >> 7));
  n958[0] = 0;
  n950[0] = (1 & (n935[0])) | (2 & (n935[0])) | (4 & (n935[0])) | (8 & (n935[0])) | (16 & (n935[0])) | (32 & (n935[0])) | (64 & (n935[0])) | (128 & (n935[0]));
  n950[1] = (1 & (n935[1])) | (2 & (n935[1])) | (4 & (n935[1])) | (8 & (n935[1])) | (16 & (n935[1])) | (32 & (n935[1])) | (64 & (n935[1]));
  n948[0] = (1 & (n935[1] >> 7));
  n936[0] = 3;
  n936[1] = 0;
  n924[0] = (1 & (n830[1] >> 4)) | (2 & (n830[1] >> 4)) | (4 & (n830[1] >> 4)) | (8 & (n830[1] >> 4));
  n910[0] = (1 & (n830[1] >> 7));
  n897[0] = (1 & (n856[1] >> 4)) | (2 & (n856[1] >> 4)) | (4 & (n856[1] >> 4)) | (8 & (n856[1] >> 4));
  n883[0] = (1 & (n856[1] >> 7));
  n879[0] = 0;
  n871[0] = (1 & (n856[0])) | (2 & (n856[0])) | (4 & (n856[0])) | (8 & (n856[0])) | (16 & (n856[0])) | (32 & (n856[0])) | (64 & (n856[0])) | (128 & (n856[0]));
  n871[1] = (1 & (n856[1])) | (2 & (n856[1])) | (4 & (n856[1])) | (8 & (n856[1])) | (16 & (n856[1])) | (32 & (n856[1])) | (64 & (n856[1]));
  n869[0] = (1 & (n856[1] >> 7));
  n857[0] = 5;
  n857[1] = 0;
  n845[0] = (1 & (n754[1] >> 3)) | (2 & (n754[1] >> 3)) | (4 & (n754[1] >> 3)) | (8 & (n754[1] >> 3)) | (16 & (n754[1] >> 3));
  n832[0] = (1 & (n754[1] >> 7));
  n819[0] = (1 & (n779[1] >> 3)) | (2 & (n779[1] >> 3)) | (4 & (n779[1] >> 3)) | (8 & (n779[1] >> 3)) | (16 & (n779[1] >> 3));
  n806[0] = (1 & (n779[1] >> 7));
  n802[0] = 0;
  n794[0] = (1 & (n779[0])) | (2 & (n779[0])) | (4 & (n779[0])) | (8 & (n779[0])) | (16 & (n779[0])) | (32 & (n779[0])) | (64 & (n779[0])) | (128 & (n779[0]));
  n794[1] = (1 & (n779[1])) | (2 & (n779[1])) | (4 & (n779[1])) | (8 & (n779[1])) | (16 & (n779[1])) | (32 & (n779[1])) | (64 & (n779[1]));
  n792[0] = (1 & (n779[1] >> 7));
  n780[0] = 10;
  n780[1] = 0;
  n768[0] = (1 & (n680[1] >> 2)) | (2 & (n680[1] >> 2)) | (4 & (n680[1] >> 2)) | (8 & (n680[1] >> 2)) | (16 & (n680[1] >> 2)) | (32 & (n680[1] >> 2));
  n756[0] = (1 & (n680[1] >> 7));
  n743[0] = (1 & (n704[1] >> 2)) | (2 & (n704[1] >> 2)) | (4 & (n704[1] >> 2)) | (8 & (n704[1] >> 2)) | (16 & (n704[1] >> 2)) | (32 & (n704[1] >> 2));
  n731[0] = (1 & (n704[1] >> 7));
  n727[0] = 0;
  n719[0] = (1 & (n704[0])) | (2 & (n704[0])) | (4 & (n704[0])) | (8 & (n704[0])) | (16 & (n704[0])) | (32 & (n704[0])) | (64 & (n704[0])) | (128 & (n704[0]));
  n719[1] = (1 & (n704[1])) | (2 & (n704[1])) | (4 & (n704[1])) | (8 & (n704[1])) | (16 & (n704[1])) | (32 & (n704[1])) | (64 & (n704[1]));
  n717[0] = (1 & (n704[1] >> 7));
  n705[0] = 20;
  n705[1] = 0;
  n693[0] = (1 & (n608[1] >> 1)) | (2 & (n608[1] >> 1)) | (4 & (n608[1] >> 1)) | (8 & (n608[1] >> 1)) | (16 & (n608[1] >> 1)) | (32 & (n608[1] >> 1)) | (64 & (n608[1] >> 1));
  n682[0] = (1 & (n608[1] >> 7));
  n669[0] = (1 & (n631[1] >> 1)) | (2 & (n631[1] >> 1)) | (4 & (n631[1] >> 1)) | (8 & (n631[1] >> 1)) | (16 & (n631[1] >> 1)) | (32 & (n631[1] >> 1)) | (64 & (n631[1] >> 1));
  n658[0] = (1 & (n631[1] >> 7));
  n654[0] = 0;
  n646[0] = (1 & (n631[0])) | (2 & (n631[0])) | (4 & (n631[0])) | (8 & (n631[0])) | (16 & (n631[0])) | (32 & (n631[0])) | (64 & (n631[0])) | (128 & (n631[0]));
  n646[1] = (1 & (n631[1])) | (2 & (n631[1])) | (4 & (n631[1])) | (8 & (n631[1])) | (16 & (n631[1])) | (32 & (n631[1])) | (64 & (n631[1]));
  n644[0] = (1 & (n631[1] >> 7));
  n632[0] = 41;
  n632[1] = 0;
  n620[0] = (1 & (n538[1])) | (2 & (n538[1])) | (4 & (n538[1])) | (8 & (n538[1])) | (16 & (n538[1])) | (32 & (n538[1])) | (64 & (n538[1])) | (128 & (n538[1]));
  n610[0] = (1 & (n538[1] >> 7));
  n597[0] = (1 & (n560[1])) | (2 & (n560[1])) | (4 & (n560[1])) | (8 & (n560[1])) | (16 & (n560[1])) | (32 & (n560[1])) | (64 & (n560[1])) | (128 & (n560[1]));
  n587[0] = (1 & (n560[1] >> 7));
  n583[0] = 0;
  n575[0] = (1 & (n560[0])) | (2 & (n560[0])) | (4 & (n560[0])) | (8 & (n560[0])) | (16 & (n560[0])) | (32 & (n560[0])) | (64 & (n560[0])) | (128 & (n560[0]));
  n575[1] = (1 & (n560[1])) | (2 & (n560[1])) | (4 & (n560[1])) | (8 & (n560[1])) | (16 & (n560[1])) | (32 & (n560[1])) | (64 & (n560[1]));
  n573[0] = (1 & (n560[1] >> 7));
  n561[0] = 81;
  n561[1] = 0;
  n549[0] = (1 & (n470[0] >> 7)) | (2 & (n470[1] << 1)) | (4 & (n470[1] << 1)) | (8 & (n470[1] << 1)) | (16 & (n470[1] << 1)) | (32 & (n470[1] << 1)) | (64 & (n470[1] << 1)) | (128 & (n470[1] << 1));
  n549[1] = (1 & (n470[1] >> 7));
  n540[0] = (1 & (n470[1] >> 7));
  n527[0] = (1 & (n491[0] >> 7)) | (2 & (n491[1] << 1)) | (4 & (n491[1] << 1)) | (8 & (n491[1] << 1)) | (16 & (n491[1] << 1)) | (32 & (n491[1] << 1)) | (64 & (n491[1] << 1)) | (128 & (n491[1] << 1));
  n527[1] = (1 & (n491[1] >> 7));
  n518[0] = (1 & (n491[1] >> 7));
  n514[0] = 0;
  n506[0] = (1 & (n491[0])) | (2 & (n491[0])) | (4 & (n491[0])) | (8 & (n491[0])) | (16 & (n491[0])) | (32 & (n491[0])) | (64 & (n491[0])) | (128 & (n491[0]));
  n506[1] = (1 & (n491[1])) | (2 & (n491[1])) | (4 & (n491[1])) | (8 & (n491[1])) | (16 & (n491[1])) | (32 & (n491[1])) | (64 & (n491[1]));
  n504[0] = (1 & (n491[1] >> 7));
  n492[0] = 163;
  n492[1] = 0;
  n480[0] = (1 & (n404[0] >> 6)) | (2 & (n404[0] >> 6)) | (4 & (n404[1] << 2)) | (8 & (n404[1] << 2)) | (16 & (n404[1] << 2)) | (32 & (n404[1] << 2)) | (64 & (n404[1] << 2)) | (128 & (n404[1] << 2));
  n480[1] = (1 & (n404[1] >> 6)) | (2 & (n404[1] >> 6));
  n472[0] = (1 & (n404[1] >> 7));
  n459[0] = (1 & (n424[0] >> 6)) | (2 & (n424[0] >> 6)) | (4 & (n424[1] << 2)) | (8 & (n424[1] << 2)) | (16 & (n424[1] << 2)) | (32 & (n424[1] << 2)) | (64 & (n424[1] << 2)) | (128 & (n424[1] << 2));
  n459[1] = (1 & (n424[1] >> 6)) | (2 & (n424[1] >> 6));
  n451[0] = (1 & (n424[1] >> 7));
  n447[0] = 0;
  n439[0] = (1 & (n424[0])) | (2 & (n424[0])) | (4 & (n424[0])) | (8 & (n424[0])) | (16 & (n424[0])) | (32 & (n424[0])) | (64 & (n424[0])) | (128 & (n424[0]));
  n439[1] = (1 & (n424[1])) | (2 & (n424[1])) | (4 & (n424[1])) | (8 & (n424[1])) | (16 & (n424[1])) | (32 & (n424[1])) | (64 & (n424[1]));
  n437[0] = (1 & (n424[1] >> 7));
  n425[0] = 70;
  n425[1] = 1;
  n413[0] = (1 & (n340[0] >> 5)) | (2 & (n340[0] >> 5)) | (4 & (n340[0] >> 5)) | (8 & (n340[1] << 3)) | (16 & (n340[1] << 3)) | (32 & (n340[1] << 3)) | (64 & (n340[1] << 3)) | (128 & (n340[1] << 3));
  n413[1] = (1 & (n340[1] >> 5)) | (2 & (n340[1] >> 5)) | (4 & (n340[1] >> 5));
  n406[0] = (1 & (n340[1] >> 7));
  n393[0] = (1 & (n359[0] >> 5)) | (2 & (n359[0] >> 5)) | (4 & (n359[0] >> 5)) | (8 & (n359[1] << 3)) | (16 & (n359[1] << 3)) | (32 & (n359[1] << 3)) | (64 & (n359[1] << 3)) | (128 & (n359[1] << 3));
  n393[1] = (1 & (n359[1] >> 5)) | (2 & (n359[1] >> 5)) | (4 & (n359[1] >> 5));
  n386[0] = (1 & (n359[1] >> 7));
  n382[0] = 0;
  n374[0] = (1 & (n359[0])) | (2 & (n359[0])) | (4 & (n359[0])) | (8 & (n359[0])) | (16 & (n359[0])) | (32 & (n359[0])) | (64 & (n359[0])) | (128 & (n359[0]));
  n374[1] = (1 & (n359[1])) | (2 & (n359[1])) | (4 & (n359[1])) | (8 & (n359[1])) | (16 & (n359[1])) | (32 & (n359[1])) | (64 & (n359[1]));
  n372[0] = (1 & (n359[1] >> 7));
  n360[0] = 139;
  n360[1] = 2;
  n348[0] = (1 & (n278[0] >> 4)) | (2 & (n278[0] >> 4)) | (4 & (n278[0] >> 4)) | (8 & (n278[0] >> 4)) | (16 & (n278[1] << 4)) | (32 & (n278[1] << 4)) | (64 & (n278[1] << 4)) | (128 & (n278[1] << 4));
  n348[1] = (1 & (n278[1] >> 4)) | (2 & (n278[1] >> 4)) | (4 & (n278[1] >> 4)) | (8 & (n278[1] >> 4));
  n342[0] = (1 & (n278[1] >> 7));
  n329[0] = (1 & (n296[0] >> 4)) | (2 & (n296[0] >> 4)) | (4 & (n296[0] >> 4)) | (8 & (n296[0] >> 4)) | (16 & (n296[1] << 4)) | (32 & (n296[1] << 4)) | (64 & (n296[1] << 4)) | (128 & (n296[1] << 4));
  n329[1] = (1 & (n296[1] >> 4)) | (2 & (n296[1] >> 4)) | (4 & (n296[1] >> 4)) | (8 & (n296[1] >> 4));
  n323[0] = (1 & (n296[1] >> 7));
  n319[0] = 0;
  n311[0] = (1 & (n296[0])) | (2 & (n296[0])) | (4 & (n296[0])) | (8 & (n296[0])) | (16 & (n296[0])) | (32 & (n296[0])) | (64 & (n296[0])) | (128 & (n296[0]));
  n311[1] = (1 & (n296[1])) | (2 & (n296[1])) | (4 & (n296[1])) | (8 & (n296[1])) | (16 & (n296[1])) | (32 & (n296[1])) | (64 & (n296[1]));
  n309[0] = (1 & (n296[1] >> 7));
  n297[0] = 17;
  n297[1] = 5;
  n285[0] = (1 & (n218[0] >> 3)) | (2 & (n218[0] >> 3)) | (4 & (n218[0] >> 3)) | (8 & (n218[0] >> 3)) | (16 & (n218[0] >> 3)) | (32 & (n218[1] << 5)) | (64 & (n218[1] << 5)) | (128 & (n218[1] << 5));
  n285[1] = (1 & (n218[1] >> 3)) | (2 & (n218[1] >> 3)) | (4 & (n218[1] >> 3)) | (8 & (n218[1] >> 3)) | (16 & (n218[1] >> 3));
  n280[0] = (1 & (n218[1] >> 7));
  n267[0] = (1 & (n235[0] >> 3)) | (2 & (n235[0] >> 3)) | (4 & (n235[0] >> 3)) | (8 & (n235[0] >> 3)) | (16 & (n235[0] >> 3)) | (32 & (n235[1] << 5)) | (64 & (n235[1] << 5)) | (128 & (n235[1] << 5));
  n267[1] = (1 & (n235[1] >> 3)) | (2 & (n235[1] >> 3)) | (4 & (n235[1] >> 3)) | (8 & (n235[1] >> 3)) | (16 & (n235[1] >> 3));
  n262[0] = (1 & (n235[1] >> 7));
  n258[0] = 0;
  n250[0] = (1 & (n235[0])) | (2 & (n235[0])) | (4 & (n235[0])) | (8 & (n235[0])) | (16 & (n235[0])) | (32 & (n235[0])) | (64 & (n235[0])) | (128 & (n235[0]));
  n250[1] = (1 & (n235[1])) | (2 & (n235[1])) | (4 & (n235[1])) | (8 & (n235[1])) | (16 & (n235[1])) | (32 & (n235[1])) | (64 & (n235[1]));
  n248[0] = (1 & (n235[1] >> 7));
  n236[0] = 251;
  n236[1] = 9;
  n224[0] = (1 & (n160[0] >> 2)) | (2 & (n160[0] >> 2)) | (4 & (n160[0] >> 2)) | (8 & (n160[0] >> 2)) | (16 & (n160[0] >> 2)) | (32 & (n160[0] >> 2)) | (64 & (n160[1] << 6)) | (128 & (n160[1] << 6));
  n224[1] = (1 & (n160[1] >> 2)) | (2 & (n160[1] >> 2)) | (4 & (n160[1] >> 2)) | (8 & (n160[1] >> 2)) | (16 & (n160[1] >> 2)) | (32 & (n160[1] >> 2));
  n220[0] = (1 & (n160[1] >> 7));
  n207[0] = (1 & (n176[0] >> 2)) | (2 & (n176[0] >> 2)) | (4 & (n176[0] >> 2)) | (8 & (n176[0] >> 2)) | (16 & (n176[0] >> 2)) | (32 & (n176[0] >> 2)) | (64 & (n176[1] << 6)) | (128 & (n176[1] << 6));
  n207[1] = (1 & (n176[1] >> 2)) | (2 & (n176[1] >> 2)) | (4 & (n176[1] >> 2)) | (8 & (n176[1] >> 2)) | (16 & (n176[1] >> 2)) | (32 & (n176[1] >> 2));
  n203[0] = (1 & (n176[1] >> 7));
  n199[0] = 0;
  n191[0] = (1 & (n176[0])) | (2 & (n176[0])) | (4 & (n176[0])) | (8 & (n176[0])) | (16 & (n176[0])) | (32 & (n176[0])) | (64 & (n176[0])) | (128 & (n176[0]));
  n191[1] = (1 & (n176[1])) | (2 & (n176[1])) | (4 & (n176[1])) | (8 & (n176[1])) | (16 & (n176[1])) | (32 & (n176[1])) | (64 & (n176[1]));
  n189[0] = (1 & (n176[1] >> 7));
  n177[0] = 228;
  n177[1] = 18;
  n165[0] = (1 & (n104[0] >> 1)) | (2 & (n104[0] >> 1)) | (4 & (n104[0] >> 1)) | (8 & (n104[0] >> 1)) | (16 & (n104[0] >> 1)) | (32 & (n104[0] >> 1)) | (64 & (n104[0] >> 1)) | (128 & (n104[1] << 7));
  n165[1] = (1 & (n104[1] >> 1)) | (2 & (n104[1] >> 1)) | (4 & (n104[1] >> 1)) | (8 & (n104[1] >> 1)) | (16 & (n104[1] >> 1)) | (32 & (n104[1] >> 1)) | (64 & (n104[1] >> 1));
  n162[0] = (1 & (n104[1] >> 7));
  n149[0] = (1 & (n119[0] >> 1)) | (2 & (n119[0] >> 1)) | (4 & (n119[0] >> 1)) | (8 & (n119[0] >> 1)) | (16 & (n119[0] >> 1)) | (32 & (n119[0] >> 1)) | (64 & (n119[0] >> 1)) | (128 & (n119[1] << 7));
  n149[1] = (1 & (n119[1] >> 1)) | (2 & (n119[1] >> 1)) | (4 & (n119[1] >> 1)) | (8 & (n119[1] >> 1)) | (16 & (n119[1] >> 1)) | (32 & (n119[1] >> 1)) | (64 & (n119[1] >> 1));
  n146[0] = (1 & (n119[1] >> 7));
  n142[0] = 0;
  n134[0] = (1 & (n119[0])) | (2 & (n119[0])) | (4 & (n119[0])) | (8 & (n119[0])) | (16 & (n119[0])) | (32 & (n119[0])) | (64 & (n119[0])) | (128 & (n119[0]));
  n134[1] = (1 & (n119[1])) | (2 & (n119[1])) | (4 & (n119[1])) | (8 & (n119[1])) | (16 & (n119[1])) | (32 & (n119[1])) | (64 & (n119[1]));
  n132[0] = (1 & (n119[1] >> 7));
  n120[0] = 0;
  n120[1] = 32;
  n108[0] = (1 & (n59[0])) | (2 & (n59[0])) | (4 & (n59[0])) | (8 & (n59[0])) | (16 & (n59[0])) | (32 & (n59[0])) | (64 & (n59[0])) | (128 & (n59[0]));
  n108[1] = (1 & (n59[1])) | (2 & (n59[1])) | (4 & (n59[1])) | (8 & (n59[1])) | (16 & (n59[1])) | (32 & (n59[1])) | (64 & (n59[1])) | (128 & (n59[1]));
  n93[0] = (1 & (n67[0])) | (2 & (n67[0])) | (4 & (n67[0])) | (8 & (n67[0])) | (16 & (n67[0])) | (32 & (n67[0])) | (64 & (n67[0])) | (128 & (n67[0]));
  n93[1] = (1 & (n67[1])) | (2 & (n67[1])) | (4 & (n67[1])) | (8 & (n67[1])) | (16 & (n67[1])) | (32 & (n67[1])) | (64 & (n67[1])) | (128 & (n67[1]));
  n87[0] = 0;
  n79[0] = (1 & (n67[0])) | (2 & (n67[0])) | (4 & (n67[0])) | (8 & (n67[0])) | (16 & (n67[0])) | (32 & (n67[0])) | (64 & (n67[0])) | (128 & (n67[0]));
  n79[1] = (1 & (n67[1])) | (2 & (n67[1])) | (4 & (n67[1])) | (8 & (n67[1])) | (16 & (n67[1])) | (32 & (n67[1])) | (64 & (n67[1]));
  n77[0] = (1 & (n67[1] >> 7));
  n46[0] = 0;
  n46[1] = 0;
  n44[0] = 0;
  n44[1] = 0;
  n38[0] = 0;
  n32[0] = (1 & (n14[0])) | (2 & (n14[0])) | (4 & (n14[0])) | (8 & (n14[0])) | (16 & (n14[0])) | (32 & (n14[0])) | (64 & (n14[0])) | (128 & (n14[0]));
  n32[1] = (1 & (n14[1])) | (2 & (n14[1])) | (4 & (n14[1])) | (8 & (n14[1])) | (16 & (n14[1])) | (32 & (n14[1])) | (64 & (n14[1]));
  n30[0] = (1 & (n14[1] >> 7));
  { unsigned int tmp; (tmp = (unsigned int) n1110[1] - (unsigned int) n1185[1] - (tmp = (unsigned int) n1110[0] - (unsigned int) n1185[0], n1187[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1187[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1110[1] + (unsigned int) n1185[1] + (tmp = (unsigned int) n1110[0] + (unsigned int) n1185[0], n1186[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1186[1] = 255 & (unsigned char) tmp); }
  n1159[0] = 255 & (n1156[0] << 1 | n1156[0]);
  n1129[0] = 255 & (n1126[0] << 1 | n1126[0]);
  n1113[0] = 1 & ~n1112[0];
  { unsigned int tmp; (tmp = (unsigned int) n1027[1] - (unsigned int) n1100[1] - (tmp = (unsigned int) n1027[0] - (unsigned int) n1100[0], n1102[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1102[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1027[1] + (unsigned int) n1100[1] + (tmp = (unsigned int) n1027[0] + (unsigned int) n1100[0], n1101[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1101[1] = 255 & (unsigned char) tmp); }
  n1075[0] = 255 & (n1072[0] << 1 | n1072[0]);
  n1046[0] = 255 & (n1043[0] << 1 | n1043[0]);
  n1030[0] = 1 & ~n1029[0];
  { unsigned int tmp; (tmp = (unsigned int) n946[1] - (unsigned int) n1017[1] - (tmp = (unsigned int) n946[0] - (unsigned int) n1017[0], n1019[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1019[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n946[1] + (unsigned int) n1017[1] + (tmp = (unsigned int) n946[0] + (unsigned int) n1017[0], n1018[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1018[1] = 255 & (unsigned char) tmp); }
  n993[0] = 255 & (n990[0] << 1 | n990[0]);
  n965[0] = 255 & (n962[0] << 1 | n962[0]);
  n949[0] = 1 & ~n948[0];
  { unsigned int tmp; (tmp = (unsigned int) n867[1] - (unsigned int) n936[1] - (tmp = (unsigned int) n867[0] - (unsigned int) n936[0], n938[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n938[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n867[1] + (unsigned int) n936[1] + (tmp = (unsigned int) n867[0] + (unsigned int) n936[0], n937[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n937[1] = 255 & (unsigned char) tmp); }
  n913[0] = 255 & (n910[0] << 1 | n910[0]);
  n886[0] = 255 & (n883[0] << 1 | n883[0]);
  n870[0] = 1 & ~n869[0];
  { unsigned int tmp; (tmp = (unsigned int) n790[1] - (unsigned int) n857[1] - (tmp = (unsigned int) n790[0] - (unsigned int) n857[0], n859[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n859[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n790[1] + (unsigned int) n857[1] + (tmp = (unsigned int) n790[0] + (unsigned int) n857[0], n858[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n858[1] = 255 & (unsigned char) tmp); }
  n835[0] = 255 & (n832[0] << 1 | n832[0]);
  n809[0] = 255 & (n806[0] << 1 | n806[0]);
  n793[0] = 1 & ~n792[0];
  { unsigned int tmp; (tmp = (unsigned int) n715[1] - (unsigned int) n780[1] - (tmp = (unsigned int) n715[0] - (unsigned int) n780[0], n782[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n782[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n715[1] + (unsigned int) n780[1] + (tmp = (unsigned int) n715[0] + (unsigned int) n780[0], n781[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n781[1] = 255 & (unsigned char) tmp); }
  n759[0] = 255 & (n756[0] << 1 | n756[0]);
  n734[0] = 255 & (n731[0] << 1 | n731[0]);
  n718[0] = 1 & ~n717[0];
  { unsigned int tmp; (tmp = (unsigned int) n642[1] - (unsigned int) n705[1] - (tmp = (unsigned int) n642[0] - (unsigned int) n705[0], n707[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n707[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n642[1] + (unsigned int) n705[1] + (tmp = (unsigned int) n642[0] + (unsigned int) n705[0], n706[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n706[1] = 255 & (unsigned char) tmp); }
  n685[0] = 255 & (n682[0] << 1 | n682[0]);
  n661[0] = 255 & (n658[0] << 1 | n658[0]);
  n645[0] = 1 & ~n644[0];
  { unsigned int tmp; (tmp = (unsigned int) n571[1] - (unsigned int) n632[1] - (tmp = (unsigned int) n571[0] - (unsigned int) n632[0], n634[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n634[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n571[1] + (unsigned int) n632[1] + (tmp = (unsigned int) n571[0] + (unsigned int) n632[0], n633[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n633[1] = 255 & (unsigned char) tmp); }
  n613[0] = 255 & (n610[0] << 1 | n610[0]);
  n590[0] = 255 & (n587[0] << 1 | n587[0]);
  n574[0] = 1 & ~n573[0];
  { unsigned int tmp; (tmp = (unsigned int) n502[1] - (unsigned int) n561[1] - (tmp = (unsigned int) n502[0] - (unsigned int) n561[0], n563[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n563[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n502[1] + (unsigned int) n561[1] + (tmp = (unsigned int) n502[0] + (unsigned int) n561[0], n562[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n562[1] = 255 & (unsigned char) tmp); }
  n543[0] = 255 & (n540[0] << 1 | n540[0]);
  n521[0] = 255 & (n518[0] << 1 | n518[0]);
  n505[0] = 1 & ~n504[0];
  { unsigned int tmp; (tmp = (unsigned int) n435[1] - (unsigned int) n492[1] - (tmp = (unsigned int) n435[0] - (unsigned int) n492[0], n494[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n494[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n435[1] + (unsigned int) n492[1] + (tmp = (unsigned int) n435[0] + (unsigned int) n492[0], n493[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n493[1] = 255 & (unsigned char) tmp); }
  n475[0] = 255 & (n472[0] << 1 | n472[0]);
  n454[0] = 255 & (n451[0] << 1 | n451[0]);
  n438[0] = 1 & ~n437[0];
  { unsigned int tmp; (tmp = (unsigned int) n370[1] - (unsigned int) n425[1] - (tmp = (unsigned int) n370[0] - (unsigned int) n425[0], n427[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n427[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n370[1] + (unsigned int) n425[1] + (tmp = (unsigned int) n370[0] + (unsigned int) n425[0], n426[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n426[1] = 255 & (unsigned char) tmp); }
  n409[0] = 255 & (n406[0] << 1 | n406[0]);
  n389[0] = 255 & (n386[0] << 1 | n386[0]);
  n373[0] = 1 & ~n372[0];
  { unsigned int tmp; (tmp = (unsigned int) n307[1] - (unsigned int) n360[1] - (tmp = (unsigned int) n307[0] - (unsigned int) n360[0], n362[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n362[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n307[1] + (unsigned int) n360[1] + (tmp = (unsigned int) n307[0] + (unsigned int) n360[0], n361[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n361[1] = 255 & (unsigned char) tmp); }
  n345[0] = 255 & (n342[0] << 1 | n342[0]);
  n326[0] = 255 & (n323[0] << 1 | n323[0]);
  n310[0] = 1 & ~n309[0];
  { unsigned int tmp; (tmp = (unsigned int) n246[1] - (unsigned int) n297[1] - (tmp = (unsigned int) n246[0] - (unsigned int) n297[0], n299[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n299[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n246[1] + (unsigned int) n297[1] + (tmp = (unsigned int) n246[0] + (unsigned int) n297[0], n298[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n298[1] = 255 & (unsigned char) tmp); }
  n283[0] = 255 & (n280[0] << 1 | n280[0]);
  n265[0] = 255 & (n262[0] << 1 | n262[0]);
  n249[0] = 1 & ~n248[0];
  { unsigned int tmp; (tmp = (unsigned int) n187[1] - (unsigned int) n236[1] - (tmp = (unsigned int) n187[0] - (unsigned int) n236[0], n238[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n238[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n187[1] + (unsigned int) n236[1] + (tmp = (unsigned int) n187[0] + (unsigned int) n236[0], n237[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n237[1] = 255 & (unsigned char) tmp); }
  n223[0] = 255 & (n220[0] << 1 | n220[0]);
  n206[0] = 255 & (n203[0] << 1 | n203[0]);
  n190[0] = 1 & ~n189[0];
  { unsigned int tmp; (tmp = (unsigned int) n130[1] - (unsigned int) n177[1] - (tmp = (unsigned int) n130[0] - (unsigned int) n177[0], n179[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n179[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n130[1] + (unsigned int) n177[1] + (tmp = (unsigned int) n130[0] + (unsigned int) n177[0], n178[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n178[1] = 255 & (unsigned char) tmp); }
  n166[0] = n165[0];
  n166[1] = 255 & (n162[0] << 7 | n165[1]);
  n150[0] = n149[0];
  n150[1] = 255 & (n146[0] << 7 | n149[1]);
  n133[0] = 1 & ~n132[0];
  { unsigned int tmp; (tmp = (unsigned int) n75[1] - (unsigned int) n120[1] - (tmp = (unsigned int) n75[0] - (unsigned int) n120[0], n122[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n122[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n75[1] + (unsigned int) n120[1] + (tmp = (unsigned int) n75[0] + (unsigned int) n120[0], n121[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n121[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n67[1] - (unsigned int) n108[1] - (tmp = (unsigned int) n67[0] - (unsigned int) n108[0], n111[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n111[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n67[1] + (unsigned int) n108[1] + (tmp = (unsigned int) n67[0] + (unsigned int) n108[0], n110[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n110[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n59[1] - (unsigned int) n93[1] - (tmp = (unsigned int) n59[0] - (unsigned int) n93[0], n96[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n96[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n59[1] + (unsigned int) n93[1] + (tmp = (unsigned int) n59[0] + (unsigned int) n93[0], n95[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n95[1] = 255 & (unsigned char) tmp); }
  n78[0] = 1 & ~n77[0];
  { unsigned int tmp; (tmp = (unsigned int) n28[1] - (unsigned int) n1203[1] - (tmp = (unsigned int) n28[0] - (unsigned int) n1203[0], n51[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n51[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n46[1] - (unsigned int) n21[1] - (tmp = (unsigned int) n46[0] - (unsigned int) n21[0], n47[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n47[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n44[1] - (unsigned int) n14[1] - (tmp = (unsigned int) n44[0] - (unsigned int) n14[0], n45[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n45[1] = 255 & (unsigned char) tmp); }
  n31[0] = 1 & ~n30[0];
  n28r[0] = reset_i[0];
  n28e[0] = enable_i[0];
  n28d[0] = ang_i[0];
  n28d[1] = ang_i[1];
  n21r[0] = reset_i[0];
  n21e[0] = enable_i[0];
  n21d[0] = imag_i[0];
  n21d[1] = imag_i[1];
  n14r[0] = reset_i[0];
  n14e[0] = enable_i[0];
  n14d[0] = real_i[0];
  n14d[1] = real_i[1];
  n1160[0] = 255 & (n1156[0] << 2 | n1159[0]);
  n1130[0] = 255 & (n1126[0] << 2 | n1129[0]);
  n1115[0] = n1114[0];
  n1115[1] = 255 & (n1113[0] << 7 | n1114[1]);
  n1076[0] = 255 & (n1072[0] << 2 | n1075[0]);
  n1047[0] = 255 & (n1043[0] << 2 | n1046[0]);
  n1032[0] = n1031[0];
  n1032[1] = 255 & (n1030[0] << 7 | n1031[1]);
  n994[0] = 255 & (n990[0] << 2 | n993[0]);
  n966[0] = 255 & (n962[0] << 2 | n965[0]);
  n951[0] = n950[0];
  n951[1] = 255 & (n949[0] << 7 | n950[1]);
  n914[0] = 255 & (n910[0] << 2 | n913[0]);
  n887[0] = 255 & (n883[0] << 2 | n886[0]);
  n872[0] = n871[0];
  n872[1] = 255 & (n870[0] << 7 | n871[1]);
  n836[0] = 255 & (n832[0] << 2 | n835[0]);
  n810[0] = 255 & (n806[0] << 2 | n809[0]);
  n795[0] = n794[0];
  n795[1] = 255 & (n793[0] << 7 | n794[1]);
  n760[0] = 255 & (n756[0] << 2 | n759[0]);
  n735[0] = 255 & (n731[0] << 2 | n734[0]);
  n720[0] = n719[0];
  n720[1] = 255 & (n718[0] << 7 | n719[1]);
  n686[0] = 255 & (n682[0] << 2 | n685[0]);
  n662[0] = 255 & (n658[0] << 2 | n661[0]);
  n647[0] = n646[0];
  n647[1] = 255 & (n645[0] << 7 | n646[1]);
  n614[0] = 255 & (n610[0] << 2 | n613[0]);
  n591[0] = 255 & (n587[0] << 2 | n590[0]);
  n576[0] = n575[0];
  n576[1] = 255 & (n574[0] << 7 | n575[1]);
  n544[0] = 255 & (n540[0] << 2 | n543[0]);
  n522[0] = 255 & (n518[0] << 2 | n521[0]);
  n507[0] = n506[0];
  n507[1] = 255 & (n505[0] << 7 | n506[1]);
  n476[0] = 255 & (n472[0] << 2 | n475[0]);
  n455[0] = 255 & (n451[0] << 2 | n454[0]);
  n440[0] = n439[0];
  n440[1] = 255 & (n438[0] << 7 | n439[1]);
  n410[0] = 255 & (n406[0] << 2 | n409[0]);
  n390[0] = 255 & (n386[0] << 2 | n389[0]);
  n375[0] = n374[0];
  n375[1] = 255 & (n373[0] << 7 | n374[1]);
  n346[0] = 255 & (n342[0] << 2 | n345[0]);
  n327[0] = 255 & (n323[0] << 2 | n326[0]);
  n312[0] = n311[0];
  n312[1] = 255 & (n310[0] << 7 | n311[1]);
  n284[0] = 255 & (n280[0] << 2 | n283[0]);
  n266[0] = 255 & (n262[0] << 2 | n265[0]);
  n251[0] = n250[0];
  n251[1] = 255 & (n249[0] << 7 | n250[1]);
  n225[0] = n224[0];
  n225[1] = 255 & (n223[0] << 6 | n224[1]);
  n208[0] = n207[0];
  n208[1] = 255 & (n206[0] << 6 | n207[1]);
  n192[0] = n191[0];
  n192[1] = 255 & (n190[0] << 7 | n191[1]);
  { unsigned int tmp; (tmp = (unsigned int) n119[1] - (unsigned int) n166[1] - (tmp = (unsigned int) n119[0] - (unsigned int) n166[0], n168[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n168[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n119[1] + (unsigned int) n166[1] + (tmp = (unsigned int) n119[0] + (unsigned int) n166[0], n167[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n167[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n104[1] - (unsigned int) n150[1] - (tmp = (unsigned int) n104[0] - (unsigned int) n150[0], n152[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n152[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n104[1] + (unsigned int) n150[1] + (tmp = (unsigned int) n104[0] + (unsigned int) n150[0], n151[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n151[1] = 255 & (unsigned char) tmp); }
  n135[0] = n134[0];
  n135[1] = 255 & (n133[0] << 7 | n134[1]);
  n80[0] = n79[0];
  n80[1] = 255 & (n78[0] << 7 | n79[1]);
  n33[0] = n32[0];
  n33[1] = 255 & (n31[0] << 7 | n32[1]);
  n1161[0] = 255 & (n1156[0] << 3 | n1160[0]);
  n1131[0] = 255 & (n1126[0] << 3 | n1130[0]);
  n1123[0] = n1115[0];
  n1123[1] = n1115[1];
  n1123[2] = n1122[0];
  n1077[0] = 255 & (n1072[0] << 3 | n1076[0]);
  n1048[0] = 255 & (n1043[0] << 3 | n1047[0]);
  n1040[0] = n1032[0];
  n1040[1] = n1032[1];
  n1040[2] = n1039[0];
  n995[0] = 255 & (n990[0] << 3 | n994[0]);
  n967[0] = 255 & (n962[0] << 3 | n966[0]);
  n959[0] = n951[0];
  n959[1] = n951[1];
  n959[2] = n958[0];
  n915[0] = 255 & (n910[0] << 3 | n914[0]);
  n888[0] = 255 & (n883[0] << 3 | n887[0]);
  n880[0] = n872[0];
  n880[1] = n872[1];
  n880[2] = n879[0];
  n837[0] = 255 & (n832[0] << 3 | n836[0]);
  n811[0] = 255 & (n806[0] << 3 | n810[0]);
  n803[0] = n795[0];
  n803[1] = n795[1];
  n803[2] = n802[0];
  n761[0] = 255 & (n756[0] << 3 | n760[0]);
  n736[0] = 255 & (n731[0] << 3 | n735[0]);
  n728[0] = n720[0];
  n728[1] = n720[1];
  n728[2] = n727[0];
  n687[0] = 255 & (n682[0] << 3 | n686[0]);
  n663[0] = 255 & (n658[0] << 3 | n662[0]);
  n655[0] = n647[0];
  n655[1] = n647[1];
  n655[2] = n654[0];
  n615[0] = 255 & (n610[0] << 3 | n614[0]);
  n592[0] = 255 & (n587[0] << 3 | n591[0]);
  n584[0] = n576[0];
  n584[1] = n576[1];
  n584[2] = n583[0];
  n545[0] = 255 & (n540[0] << 3 | n544[0]);
  n523[0] = 255 & (n518[0] << 3 | n522[0]);
  n515[0] = n507[0];
  n515[1] = n507[1];
  n515[2] = n514[0];
  n477[0] = 255 & (n472[0] << 3 | n476[0]);
  n456[0] = 255 & (n451[0] << 3 | n455[0]);
  n448[0] = n440[0];
  n448[1] = n440[1];
  n448[2] = n447[0];
  n411[0] = 255 & (n406[0] << 3 | n410[0]);
  n391[0] = 255 & (n386[0] << 3 | n390[0]);
  n383[0] = n375[0];
  n383[1] = n375[1];
  n383[2] = n382[0];
  n347[0] = 255 & (n342[0] << 3 | n346[0]);
  n328[0] = 255 & (n323[0] << 3 | n327[0]);
  n320[0] = n312[0];
  n320[1] = n312[1];
  n320[2] = n319[0];
  n286[0] = n285[0];
  n286[1] = 255 & (n284[0] << 5 | n285[1]);
  n268[0] = n267[0];
  n268[1] = 255 & (n266[0] << 5 | n267[1]);
  n259[0] = n251[0];
  n259[1] = n251[1];
  n259[2] = n258[0];
  { unsigned int tmp; (tmp = (unsigned int) n176[1] - (unsigned int) n225[1] - (tmp = (unsigned int) n176[0] - (unsigned int) n225[0], n227[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n227[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n176[1] + (unsigned int) n225[1] + (tmp = (unsigned int) n176[0] + (unsigned int) n225[0], n226[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n226[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n160[1] - (unsigned int) n208[1] - (tmp = (unsigned int) n160[0] - (unsigned int) n208[0], n210[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n210[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n160[1] + (unsigned int) n208[1] + (tmp = (unsigned int) n160[0] + (unsigned int) n208[0], n209[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n209[1] = 255 & (unsigned char) tmp); }
  n200[0] = n192[0];
  n200[1] = n192[1];
  n200[2] = n199[0];
  n143[0] = n135[0];
  n143[1] = n135[1];
  n143[2] = n142[0];
  n88[0] = n80[0];
  n88[1] = n80[1];
  n88[2] = n87[0];
  n39[0] = n33[0];
  n39[1] = n33[1];
  n39[2] = n38[0];
  n1162[0] = 255 & (n1156[0] << 4 | n1161[0]);
  n1132[0] = 255 & (n1126[0] << 4 | n1131[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1304[2] - (unsigned int) n1123[2] - (tmp = (unsigned int) n1304[1] - (unsigned int) n1123[1] - (tmp = (unsigned int) n1304[0] - (unsigned int) n1123[0], n1124[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1124[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1124[2] = 1 & (unsigned char) tmp); }
  n1078[0] = 255 & (n1072[0] << 4 | n1077[0]);
  n1049[0] = 255 & (n1043[0] << 4 | n1048[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1302[2] - (unsigned int) n1040[2] - (tmp = (unsigned int) n1302[1] - (unsigned int) n1040[1] - (tmp = (unsigned int) n1302[0] - (unsigned int) n1040[0], n1041[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1041[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1041[2] = 1 & (unsigned char) tmp); }
  n996[0] = 255 & (n990[0] << 4 | n995[0]);
  n968[0] = 255 & (n962[0] << 4 | n967[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1300[2] - (unsigned int) n959[2] - (tmp = (unsigned int) n1300[1] - (unsigned int) n959[1] - (tmp = (unsigned int) n1300[0] - (unsigned int) n959[0], n960[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n960[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n960[2] = 1 & (unsigned char) tmp); }
  n916[0] = 255 & (n910[0] << 4 | n915[0]);
  n889[0] = 255 & (n883[0] << 4 | n888[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1298[2] - (unsigned int) n880[2] - (tmp = (unsigned int) n1298[1] - (unsigned int) n880[1] - (tmp = (unsigned int) n1298[0] - (unsigned int) n880[0], n881[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n881[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n881[2] = 1 & (unsigned char) tmp); }
  n838[0] = 255 & (n832[0] << 4 | n837[0]);
  n812[0] = 255 & (n806[0] << 4 | n811[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1296[2] - (unsigned int) n803[2] - (tmp = (unsigned int) n1296[1] - (unsigned int) n803[1] - (tmp = (unsigned int) n1296[0] - (unsigned int) n803[0], n804[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n804[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n804[2] = 1 & (unsigned char) tmp); }
  n762[0] = 255 & (n756[0] << 4 | n761[0]);
  n737[0] = 255 & (n731[0] << 4 | n736[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1294[2] - (unsigned int) n728[2] - (tmp = (unsigned int) n1294[1] - (unsigned int) n728[1] - (tmp = (unsigned int) n1294[0] - (unsigned int) n728[0], n729[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n729[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n729[2] = 1 & (unsigned char) tmp); }
  n688[0] = 255 & (n682[0] << 4 | n687[0]);
  n664[0] = 255 & (n658[0] << 4 | n663[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1292[2] - (unsigned int) n655[2] - (tmp = (unsigned int) n1292[1] - (unsigned int) n655[1] - (tmp = (unsigned int) n1292[0] - (unsigned int) n655[0], n656[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n656[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n656[2] = 1 & (unsigned char) tmp); }
  n616[0] = 255 & (n610[0] << 4 | n615[0]);
  n593[0] = 255 & (n587[0] << 4 | n592[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1290[2] - (unsigned int) n584[2] - (tmp = (unsigned int) n1290[1] - (unsigned int) n584[1] - (tmp = (unsigned int) n1290[0] - (unsigned int) n584[0], n585[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n585[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n585[2] = 1 & (unsigned char) tmp); }
  n546[0] = 255 & (n540[0] << 4 | n545[0]);
  n524[0] = 255 & (n518[0] << 4 | n523[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1288[2] - (unsigned int) n515[2] - (tmp = (unsigned int) n1288[1] - (unsigned int) n515[1] - (tmp = (unsigned int) n1288[0] - (unsigned int) n515[0], n516[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n516[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n516[2] = 1 & (unsigned char) tmp); }
  n478[0] = 255 & (n472[0] << 4 | n477[0]);
  n457[0] = 255 & (n451[0] << 4 | n456[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1286[2] - (unsigned int) n448[2] - (tmp = (unsigned int) n1286[1] - (unsigned int) n448[1] - (tmp = (unsigned int) n1286[0] - (unsigned int) n448[0], n449[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n449[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n449[2] = 1 & (unsigned char) tmp); }
  n412[0] = 255 & (n406[0] << 4 | n411[0]);
  n392[0] = 255 & (n386[0] << 4 | n391[0]);
  { unsigned int tmp; (tmp = (unsigned int) n1284[2] - (unsigned int) n383[2] - (tmp = (unsigned int) n1284[1] - (unsigned int) n383[1] - (tmp = (unsigned int) n1284[0] - (unsigned int) n383[0], n384[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n384[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n384[2] = 1 & (unsigned char) tmp); }
  n349[0] = n348[0];
  n349[1] = 255 & (n347[0] << 4 | n348[1]);
  n330[0] = n329[0];
  n330[1] = 255 & (n328[0] << 4 | n329[1]);
  { unsigned int tmp; (tmp = (unsigned int) n1282[2] - (unsigned int) n320[2] - (tmp = (unsigned int) n1282[1] - (unsigned int) n320[1] - (tmp = (unsigned int) n1282[0] - (unsigned int) n320[0], n321[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n321[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n321[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n235[1] - (unsigned int) n286[1] - (tmp = (unsigned int) n235[0] - (unsigned int) n286[0], n288[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n288[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n235[1] + (unsigned int) n286[1] + (tmp = (unsigned int) n235[0] + (unsigned int) n286[0], n287[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n287[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n218[1] - (unsigned int) n268[1] - (tmp = (unsigned int) n218[0] - (unsigned int) n268[0], n270[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n270[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n218[1] + (unsigned int) n268[1] + (tmp = (unsigned int) n218[0] + (unsigned int) n268[0], n269[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n269[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1280[2] - (unsigned int) n259[2] - (tmp = (unsigned int) n1280[1] - (unsigned int) n259[1] - (tmp = (unsigned int) n1280[0] - (unsigned int) n259[0], n260[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n260[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n260[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1278[2] - (unsigned int) n200[2] - (tmp = (unsigned int) n1278[1] - (unsigned int) n200[1] - (tmp = (unsigned int) n1278[0] - (unsigned int) n200[0], n201[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n201[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n201[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1276[2] - (unsigned int) n143[2] - (tmp = (unsigned int) n1276[1] - (unsigned int) n143[1] - (tmp = (unsigned int) n1276[0] - (unsigned int) n143[0], n144[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n144[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n144[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1274[2] - (unsigned int) n88[2] - (tmp = (unsigned int) n1274[1] - (unsigned int) n88[1] - (tmp = (unsigned int) n1274[0] - (unsigned int) n88[0], n89[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n89[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n89[2] = 1 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n39[2] - (unsigned int) n1272[2] - (tmp = (unsigned int) n39[1] - (unsigned int) n1272[1] - (tmp = (unsigned int) n39[0] - (unsigned int) n1272[0], n42[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n42[1] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n42[2] = 1 & (unsigned char) tmp); }
  n1163[0] = 255 & (n1156[0] << 5 | n1162[0]);
  n1133[0] = 255 & (n1126[0] << 5 | n1132[0]);
  n1125[0] = (1 & (n1124[2]));
  n1079[0] = 255 & (n1072[0] << 5 | n1078[0]);
  n1050[0] = 255 & (n1043[0] << 5 | n1049[0]);
  n1042[0] = (1 & (n1041[2]));
  n997[0] = 255 & (n990[0] << 5 | n996[0]);
  n969[0] = 255 & (n962[0] << 5 | n968[0]);
  n961[0] = (1 & (n960[2]));
  n917[0] = 255 & (n910[0] << 5 | n916[0]);
  n890[0] = 255 & (n883[0] << 5 | n889[0]);
  n882[0] = (1 & (n881[2]));
  n839[0] = 255 & (n832[0] << 5 | n838[0]);
  n813[0] = 255 & (n806[0] << 5 | n812[0]);
  n805[0] = (1 & (n804[2]));
  n763[0] = 255 & (n756[0] << 5 | n762[0]);
  n738[0] = 255 & (n731[0] << 5 | n737[0]);
  n730[0] = (1 & (n729[2]));
  n689[0] = 255 & (n682[0] << 5 | n688[0]);
  n665[0] = 255 & (n658[0] << 5 | n664[0]);
  n657[0] = (1 & (n656[2]));
  n617[0] = 255 & (n610[0] << 5 | n616[0]);
  n594[0] = 255 & (n587[0] << 5 | n593[0]);
  n586[0] = (1 & (n585[2]));
  n547[0] = 255 & (n540[0] << 5 | n546[0]);
  n525[0] = 255 & (n518[0] << 5 | n524[0]);
  n517[0] = (1 & (n516[2]));
  n479[0] = 255 & (n472[0] << 5 | n478[0]);
  n458[0] = 255 & (n451[0] << 5 | n457[0]);
  n450[0] = (1 & (n449[2]));
  n414[0] = n413[0];
  n414[1] = 255 & (n412[0] << 3 | n413[1]);
  n394[0] = n393[0];
  n394[1] = 255 & (n392[0] << 3 | n393[1]);
  n385[0] = (1 & (n384[2]));
  { unsigned int tmp; (tmp = (unsigned int) n296[1] - (unsigned int) n349[1] - (tmp = (unsigned int) n296[0] - (unsigned int) n349[0], n351[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n351[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n296[1] + (unsigned int) n349[1] + (tmp = (unsigned int) n296[0] + (unsigned int) n349[0], n350[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n350[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n278[1] - (unsigned int) n330[1] - (tmp = (unsigned int) n278[0] - (unsigned int) n330[0], n332[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n332[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n278[1] + (unsigned int) n330[1] + (tmp = (unsigned int) n278[0] + (unsigned int) n330[0], n331[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n331[1] = 255 & (unsigned char) tmp); }
  n322[0] = (1 & (n321[2]));
  n261[0] = (1 & (n260[2]));
  n202[0] = (1 & (n201[2]));
  n145[0] = (1 & (n144[2]));
  n90[0] = (1 & (n89[2]));
  n43[0] = (1 & (n42[2]));
  if (n1125[0]) {
    n1188[0] = n1186[0];
    n1188[1] = n1186[1];
  }
  else {
    n1188[0] = n1187[0];
    n1188[1] = n1187[1];
  }
  n1164[0] = 255 & (n1156[0] << 6 | n1163[0]);
  n1155[0] = 1 & ~n1125[0];
  n1134[0] = 255 & (n1126[0] << 6 | n1133[0]);
  if (n1042[0]) {
    n1103[0] = n1101[0];
    n1103[1] = n1101[1];
  }
  else {
    n1103[0] = n1102[0];
    n1103[1] = n1102[1];
  }
  n1080[0] = 255 & (n1072[0] << 6 | n1079[0]);
  n1071[0] = 1 & ~n1042[0];
  n1051[0] = 255 & (n1043[0] << 6 | n1050[0]);
  if (n961[0]) {
    n1020[0] = n1018[0];
    n1020[1] = n1018[1];
  }
  else {
    n1020[0] = n1019[0];
    n1020[1] = n1019[1];
  }
  n998[0] = 255 & (n990[0] << 6 | n997[0]);
  n989[0] = 1 & ~n961[0];
  n970[0] = 255 & (n962[0] << 6 | n969[0]);
  if (n882[0]) {
    n939[0] = n937[0];
    n939[1] = n937[1];
  }
  else {
    n939[0] = n938[0];
    n939[1] = n938[1];
  }
  n918[0] = 255 & (n910[0] << 6 | n917[0]);
  n909[0] = 1 & ~n882[0];
  n891[0] = 255 & (n883[0] << 6 | n890[0]);
  if (n805[0]) {
    n860[0] = n858[0];
    n860[1] = n858[1];
  }
  else {
    n860[0] = n859[0];
    n860[1] = n859[1];
  }
  n840[0] = 255 & (n832[0] << 6 | n839[0]);
  n831[0] = 1 & ~n805[0];
  n814[0] = 255 & (n806[0] << 6 | n813[0]);
  if (n730[0]) {
    n783[0] = n781[0];
    n783[1] = n781[1];
  }
  else {
    n783[0] = n782[0];
    n783[1] = n782[1];
  }
  n764[0] = 255 & (n756[0] << 6 | n763[0]);
  n755[0] = 1 & ~n730[0];
  n739[0] = 255 & (n731[0] << 6 | n738[0]);
  if (n657[0]) {
    n708[0] = n706[0];
    n708[1] = n706[1];
  }
  else {
    n708[0] = n707[0];
    n708[1] = n707[1];
  }
  n690[0] = 255 & (n682[0] << 6 | n689[0]);
  n681[0] = 1 & ~n657[0];
  n666[0] = 255 & (n658[0] << 6 | n665[0]);
  if (n586[0]) {
    n635[0] = n633[0];
    n635[1] = n633[1];
  }
  else {
    n635[0] = n634[0];
    n635[1] = n634[1];
  }
  n618[0] = 255 & (n610[0] << 6 | n617[0]);
  n609[0] = 1 & ~n586[0];
  n595[0] = 255 & (n587[0] << 6 | n594[0]);
  if (n517[0]) {
    n564[0] = n562[0];
    n564[1] = n562[1];
  }
  else {
    n564[0] = n563[0];
    n564[1] = n563[1];
  }
  n548[0] = 255 & (n540[0] << 6 | n547[0]);
  n539[0] = 1 & ~n517[0];
  n526[0] = 255 & (n518[0] << 6 | n525[0]);
  if (n450[0]) {
    n495[0] = n493[0];
    n495[1] = n493[1];
  }
  else {
    n495[0] = n494[0];
    n495[1] = n494[1];
  }
  n481[0] = n480[0];
  n481[1] = 255 & (n479[0] << 2 | n480[1]);
  n471[0] = 1 & ~n450[0];
  n460[0] = n459[0];
  n460[1] = 255 & (n458[0] << 2 | n459[1]);
  if (n385[0]) {
    n428[0] = n426[0];
    n428[1] = n426[1];
  }
  else {
    n428[0] = n427[0];
    n428[1] = n427[1];
  }
  { unsigned int tmp; (tmp = (unsigned int) n359[1] - (unsigned int) n414[1] - (tmp = (unsigned int) n359[0] - (unsigned int) n414[0], n416[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n416[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n359[1] + (unsigned int) n414[1] + (tmp = (unsigned int) n359[0] + (unsigned int) n414[0], n415[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n415[1] = 255 & (unsigned char) tmp); }
  n405[0] = 1 & ~n385[0];
  { unsigned int tmp; (tmp = (unsigned int) n340[1] - (unsigned int) n394[1] - (tmp = (unsigned int) n340[0] - (unsigned int) n394[0], n396[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n396[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n340[1] + (unsigned int) n394[1] + (tmp = (unsigned int) n340[0] + (unsigned int) n394[0], n395[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n395[1] = 255 & (unsigned char) tmp); }
  if (n322[0]) {
    n363[0] = n361[0];
    n363[1] = n361[1];
  }
  else {
    n363[0] = n362[0];
    n363[1] = n362[1];
  }
  n341[0] = 1 & ~n322[0];
  if (n322[0]) {
    n333[0] = n331[0];
    n333[1] = n331[1];
  }
  else {
    n333[0] = n332[0];
    n333[1] = n332[1];
  }
  if (n261[0]) {
    n300[0] = n298[0];
    n300[1] = n298[1];
  }
  else {
    n300[0] = n299[0];
    n300[1] = n299[1];
  }
  n279[0] = 1 & ~n261[0];
  if (n261[0]) {
    n271[0] = n269[0];
    n271[1] = n269[1];
  }
  else {
    n271[0] = n270[0];
    n271[1] = n270[1];
  }
  if (n202[0]) {
    n239[0] = n237[0];
    n239[1] = n237[1];
  }
  else {
    n239[0] = n238[0];
    n239[1] = n238[1];
  }
  n219[0] = 1 & ~n202[0];
  if (n202[0]) {
    n211[0] = n209[0];
    n211[1] = n209[1];
  }
  else {
    n211[0] = n210[0];
    n211[1] = n210[1];
  }
  if (n145[0]) {
    n180[0] = n178[0];
    n180[1] = n178[1];
  }
  else {
    n180[0] = n179[0];
    n180[1] = n179[1];
  }
  n161[0] = 1 & ~n145[0];
  if (n145[0]) {
    n153[0] = n151[0];
    n153[1] = n151[1];
  }
  else {
    n153[0] = n152[0];
    n153[1] = n152[1];
  }
  if (n90[0]) {
    n123[0] = n121[0];
    n123[1] = n121[1];
  }
  else {
    n123[0] = n122[0];
    n123[1] = n122[1];
  }
  n105[0] = 1 & ~n90[0];
  if (n90[0]) {
    n97[0] = n95[0];
    n97[1] = n95[1];
  }
  else {
    n97[0] = n96[0];
    n97[1] = n96[1];
  }
  if (n43[0]) {
    n68[0] = n51[0];
    n68[1] = n51[1];
  }
  else {
    n68[0] = n28[0];
    n68[1] = n28[1];
  }
  if (n43[0]) {
    n60[0] = n47[0];
    n60[1] = n47[1];
  }
  else {
    n60[0] = n21[0];
    n60[1] = n21[1];
  }
  if (n43[0]) {
    n52[0] = n45[0];
    n52[1] = n45[1];
  }
  else {
    n52[0] = n14[0];
    n52[1] = n14[1];
  }
  n1195r[0] = reset_i[0];
  n1195e[0] = enable_i[0];
  n1195d[0] = n1188[0];
  n1195d[1] = n1188[1];
  n1165[0] = 255 & (n1156[0] << 7 | n1164[0]);
  n1135[0] = 255 & (n1126[0] << 7 | n1134[0]);
  n1110r[0] = reset_i[0];
  n1110e[0] = enable_i[0];
  n1110d[0] = n1103[0];
  n1110d[1] = n1103[1];
  n1081[0] = 255 & (n1072[0] << 7 | n1080[0]);
  n1052[0] = 255 & (n1043[0] << 7 | n1051[0]);
  n1027r[0] = reset_i[0];
  n1027e[0] = enable_i[0];
  n1027d[0] = n1020[0];
  n1027d[1] = n1020[1];
  n999[0] = 255 & (n990[0] << 7 | n998[0]);
  n971[0] = 255 & (n962[0] << 7 | n970[0]);
  n946r[0] = reset_i[0];
  n946e[0] = enable_i[0];
  n946d[0] = n939[0];
  n946d[1] = n939[1];
  n919[0] = 255 & (n910[0] << 7 | n918[0]);
  n892[0] = 255 & (n883[0] << 7 | n891[0]);
  n867r[0] = reset_i[0];
  n867e[0] = enable_i[0];
  n867d[0] = n860[0];
  n867d[1] = n860[1];
  n841[0] = 255 & (n832[0] << 7 | n840[0]);
  n815[0] = 255 & (n806[0] << 7 | n814[0]);
  n790r[0] = reset_i[0];
  n790e[0] = enable_i[0];
  n790d[0] = n783[0];
  n790d[1] = n783[1];
  n765[0] = 255 & (n756[0] << 7 | n764[0]);
  n740[0] = 255 & (n731[0] << 7 | n739[0]);
  n715r[0] = reset_i[0];
  n715e[0] = enable_i[0];
  n715d[0] = n708[0];
  n715d[1] = n708[1];
  n691[0] = 255 & (n682[0] << 7 | n690[0]);
  n667[0] = 255 & (n658[0] << 7 | n666[0]);
  n642r[0] = reset_i[0];
  n642e[0] = enable_i[0];
  n642d[0] = n635[0];
  n642d[1] = n635[1];
  n619[0] = 255 & (n610[0] << 7 | n618[0]);
  n596[0] = 255 & (n587[0] << 7 | n595[0]);
  n571r[0] = reset_i[0];
  n571e[0] = enable_i[0];
  n571d[0] = n564[0];
  n571d[1] = n564[1];
  n550[0] = n549[0];
  n550[1] = 255 & (n548[0] << 1 | n549[1]);
  n528[0] = n527[0];
  n528[1] = 255 & (n526[0] << 1 | n527[1]);
  n502r[0] = reset_i[0];
  n502e[0] = enable_i[0];
  n502d[0] = n495[0];
  n502d[1] = n495[1];
  { unsigned int tmp; (tmp = (unsigned int) n424[1] - (unsigned int) n481[1] - (tmp = (unsigned int) n424[0] - (unsigned int) n481[0], n483[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n483[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n424[1] + (unsigned int) n481[1] + (tmp = (unsigned int) n424[0] + (unsigned int) n481[0], n482[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n482[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n404[1] - (unsigned int) n460[1] - (tmp = (unsigned int) n404[0] - (unsigned int) n460[0], n462[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n462[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n404[1] + (unsigned int) n460[1] + (tmp = (unsigned int) n404[0] + (unsigned int) n460[0], n461[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n461[1] = 255 & (unsigned char) tmp); }
  n435r[0] = reset_i[0];
  n435e[0] = enable_i[0];
  n435d[0] = n428[0];
  n435d[1] = n428[1];
  if (n405[0]) {
    n417[0] = n415[0];
    n417[1] = n415[1];
  }
  else {
    n417[0] = n416[0];
    n417[1] = n416[1];
  }
  if (n385[0]) {
    n397[0] = n395[0];
    n397[1] = n395[1];
  }
  else {
    n397[0] = n396[0];
    n397[1] = n396[1];
  }
  n370r[0] = reset_i[0];
  n370e[0] = enable_i[0];
  n370d[0] = n363[0];
  n370d[1] = n363[1];
  if (n341[0]) {
    n352[0] = n350[0];
    n352[1] = n350[1];
  }
  else {
    n352[0] = n351[0];
    n352[1] = n351[1];
  }
  n340r[0] = reset_i[0];
  n340e[0] = enable_i[0];
  n340d[0] = n333[0];
  n340d[1] = n333[1];
  n307r[0] = reset_i[0];
  n307e[0] = enable_i[0];
  n307d[0] = n300[0];
  n307d[1] = n300[1];
  if (n279[0]) {
    n289[0] = n287[0];
    n289[1] = n287[1];
  }
  else {
    n289[0] = n288[0];
    n289[1] = n288[1];
  }
  n278r[0] = reset_i[0];
  n278e[0] = enable_i[0];
  n278d[0] = n271[0];
  n278d[1] = n271[1];
  n246r[0] = reset_i[0];
  n246e[0] = enable_i[0];
  n246d[0] = n239[0];
  n246d[1] = n239[1];
  if (n219[0]) {
    n228[0] = n226[0];
    n228[1] = n226[1];
  }
  else {
    n228[0] = n227[0];
    n228[1] = n227[1];
  }
  n218r[0] = reset_i[0];
  n218e[0] = enable_i[0];
  n218d[0] = n211[0];
  n218d[1] = n211[1];
  n187r[0] = reset_i[0];
  n187e[0] = enable_i[0];
  n187d[0] = n180[0];
  n187d[1] = n180[1];
  if (n161[0]) {
    n169[0] = n167[0];
    n169[1] = n167[1];
  }
  else {
    n169[0] = n168[0];
    n169[1] = n168[1];
  }
  n160r[0] = reset_i[0];
  n160e[0] = enable_i[0];
  n160d[0] = n153[0];
  n160d[1] = n153[1];
  n130r[0] = reset_i[0];
  n130e[0] = enable_i[0];
  n130d[0] = n123[0];
  n130d[1] = n123[1];
  if (n105[0]) {
    n112[0] = n110[0];
    n112[1] = n110[1];
  }
  else {
    n112[0] = n111[0];
    n112[1] = n111[1];
  }
  n104r[0] = reset_i[0];
  n104e[0] = enable_i[0];
  n104d[0] = n97[0];
  n104d[1] = n97[1];
  n75r[0] = reset_i[0];
  n75e[0] = enable_i[0];
  n75d[0] = n68[0];
  n75d[1] = n68[1];
  n67r[0] = reset_i[0];
  n67e[0] = enable_i[0];
  n67d[0] = n60[0];
  n67d[1] = n60[1];
  n59r[0] = reset_i[0];
  n59e[0] = enable_i[0];
  n59d[0] = n52[0];
  n59d[1] = n52[1];
  n1166[0] = n1165[0];
  n1166[1] = n1156[0];
  n1136[0] = n1135[0];
  n1136[1] = n1126[0];
  n1082[0] = n1081[0];
  n1082[1] = n1072[0];
  n1053[0] = n1052[0];
  n1053[1] = n1043[0];
  n1000[0] = n999[0];
  n1000[1] = n990[0];
  n972[0] = n971[0];
  n972[1] = n962[0];
  n920[0] = n919[0];
  n920[1] = n910[0];
  n893[0] = n892[0];
  n893[1] = n883[0];
  n842[0] = n841[0];
  n842[1] = n832[0];
  n816[0] = n815[0];
  n816[1] = n806[0];
  n766[0] = n765[0];
  n766[1] = n756[0];
  n741[0] = n740[0];
  n741[1] = n731[0];
  n692[0] = n691[0];
  n692[1] = n682[0];
  n668[0] = n667[0];
  n668[1] = n658[0];
  n621[0] = n620[0];
  n621[1] = n619[0];
  n598[0] = n597[0];
  n598[1] = n596[0];
  { unsigned int tmp; (tmp = (unsigned int) n491[1] - (unsigned int) n550[1] - (tmp = (unsigned int) n491[0] - (unsigned int) n550[0], n552[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n552[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n491[1] + (unsigned int) n550[1] + (tmp = (unsigned int) n491[0] + (unsigned int) n550[0], n551[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n551[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n470[1] - (unsigned int) n528[1] - (tmp = (unsigned int) n470[0] - (unsigned int) n528[0], n530[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n530[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n470[1] + (unsigned int) n528[1] + (tmp = (unsigned int) n470[0] + (unsigned int) n528[0], n529[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n529[1] = 255 & (unsigned char) tmp); }
  if (n471[0]) {
    n484[0] = n482[0];
    n484[1] = n482[1];
  }
  else {
    n484[0] = n483[0];
    n484[1] = n483[1];
  }
  if (n450[0]) {
    n463[0] = n461[0];
    n463[1] = n461[1];
  }
  else {
    n463[0] = n462[0];
    n463[1] = n462[1];
  }
  n424r[0] = reset_i[0];
  n424e[0] = enable_i[0];
  n424d[0] = n417[0];
  n424d[1] = n417[1];
  n404r[0] = reset_i[0];
  n404e[0] = enable_i[0];
  n404d[0] = n397[0];
  n404d[1] = n397[1];
  n359r[0] = reset_i[0];
  n359e[0] = enable_i[0];
  n359d[0] = n352[0];
  n359d[1] = n352[1];
  n296r[0] = reset_i[0];
  n296e[0] = enable_i[0];
  n296d[0] = n289[0];
  n296d[1] = n289[1];
  n235r[0] = reset_i[0];
  n235e[0] = enable_i[0];
  n235d[0] = n228[0];
  n235d[1] = n228[1];
  n176r[0] = reset_i[0];
  n176e[0] = enable_i[0];
  n176d[0] = n169[0];
  n176d[1] = n169[1];
  n119r[0] = reset_i[0];
  n119e[0] = enable_i[0];
  n119d[0] = n112[0];
  n119d[1] = n112[1];
  n1167[0] = n1166[0];
  n1167[1] = 255 & (n1156[0] << 1 | n1166[1]);
  n1137[0] = n1136[0];
  n1137[1] = 255 & (n1126[0] << 1 | n1136[1]);
  n1083[0] = n1082[0];
  n1083[1] = 255 & (n1072[0] << 1 | n1082[1]);
  n1054[0] = n1053[0];
  n1054[1] = 255 & (n1043[0] << 1 | n1053[1]);
  n1001[0] = n1000[0];
  n1001[1] = 255 & (n990[0] << 1 | n1000[1]);
  n973[0] = n972[0];
  n973[1] = 255 & (n962[0] << 1 | n972[1]);
  n921[0] = n920[0];
  n921[1] = 255 & (n910[0] << 1 | n920[1]);
  n894[0] = n893[0];
  n894[1] = 255 & (n883[0] << 1 | n893[1]);
  n843[0] = n842[0];
  n843[1] = 255 & (n832[0] << 1 | n842[1]);
  n817[0] = n816[0];
  n817[1] = 255 & (n806[0] << 1 | n816[1]);
  n767[0] = n766[0];
  n767[1] = 255 & (n756[0] << 1 | n766[1]);
  n742[0] = n741[0];
  n742[1] = 255 & (n731[0] << 1 | n741[1]);
  n694[0] = 255 & (n692[0] << 7 | n693[0]);
  n694[1] = 255 & (n692[1] << 7 | n692[0] >> 1);
  n670[0] = 255 & (n668[0] << 7 | n669[0]);
  n670[1] = 255 & (n668[1] << 7 | n668[0] >> 1);
  { unsigned int tmp; (tmp = (unsigned int) n560[1] - (unsigned int) n621[1] - (tmp = (unsigned int) n560[0] - (unsigned int) n621[0], n623[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n623[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n560[1] + (unsigned int) n621[1] + (tmp = (unsigned int) n560[0] + (unsigned int) n621[0], n622[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n622[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n538[1] - (unsigned int) n598[1] - (tmp = (unsigned int) n538[0] - (unsigned int) n598[0], n600[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n600[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n538[1] + (unsigned int) n598[1] + (tmp = (unsigned int) n538[0] + (unsigned int) n598[0], n599[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n599[1] = 255 & (unsigned char) tmp); }
  if (n539[0]) {
    n553[0] = n551[0];
    n553[1] = n551[1];
  }
  else {
    n553[0] = n552[0];
    n553[1] = n552[1];
  }
  if (n517[0]) {
    n531[0] = n529[0];
    n531[1] = n529[1];
  }
  else {
    n531[0] = n530[0];
    n531[1] = n530[1];
  }
  n491r[0] = reset_i[0];
  n491e[0] = enable_i[0];
  n491d[0] = n484[0];
  n491d[1] = n484[1];
  n470r[0] = reset_i[0];
  n470e[0] = enable_i[0];
  n470d[0] = n463[0];
  n470d[1] = n463[1];
  n1168[0] = n1167[0];
  n1168[1] = 255 & (n1156[0] << 2 | n1167[1]);
  n1138[0] = n1137[0];
  n1138[1] = 255 & (n1126[0] << 2 | n1137[1]);
  n1084[0] = n1083[0];
  n1084[1] = 255 & (n1072[0] << 2 | n1083[1]);
  n1055[0] = n1054[0];
  n1055[1] = 255 & (n1043[0] << 2 | n1054[1]);
  n1002[0] = n1001[0];
  n1002[1] = 255 & (n990[0] << 2 | n1001[1]);
  n974[0] = n973[0];
  n974[1] = 255 & (n962[0] << 2 | n973[1]);
  n922[0] = n921[0];
  n922[1] = 255 & (n910[0] << 2 | n921[1]);
  n895[0] = n894[0];
  n895[1] = 255 & (n883[0] << 2 | n894[1]);
  n844[0] = n843[0];
  n844[1] = 255 & (n832[0] << 2 | n843[1]);
  n818[0] = n817[0];
  n818[1] = 255 & (n806[0] << 2 | n817[1]);
  n769[0] = 255 & (n767[0] << 6 | n768[0]);
  n769[1] = 255 & (n767[1] << 6 | n767[0] >> 2);
  n744[0] = 255 & (n742[0] << 6 | n743[0]);
  n744[1] = 255 & (n742[1] << 6 | n742[0] >> 2);
  { unsigned int tmp; (tmp = (unsigned int) n631[1] - (unsigned int) n694[1] - (tmp = (unsigned int) n631[0] - (unsigned int) n694[0], n696[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n696[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n631[1] + (unsigned int) n694[1] + (tmp = (unsigned int) n631[0] + (unsigned int) n694[0], n695[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n695[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n608[1] - (unsigned int) n670[1] - (tmp = (unsigned int) n608[0] - (unsigned int) n670[0], n672[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n672[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n608[1] + (unsigned int) n670[1] + (tmp = (unsigned int) n608[0] + (unsigned int) n670[0], n671[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n671[1] = 255 & (unsigned char) tmp); }
  if (n609[0]) {
    n624[0] = n622[0];
    n624[1] = n622[1];
  }
  else {
    n624[0] = n623[0];
    n624[1] = n623[1];
  }
  if (n586[0]) {
    n601[0] = n599[0];
    n601[1] = n599[1];
  }
  else {
    n601[0] = n600[0];
    n601[1] = n600[1];
  }
  n560r[0] = reset_i[0];
  n560e[0] = enable_i[0];
  n560d[0] = n553[0];
  n560d[1] = n553[1];
  n538r[0] = reset_i[0];
  n538e[0] = enable_i[0];
  n538d[0] = n531[0];
  n538d[1] = n531[1];
  n1169[0] = n1168[0];
  n1169[1] = 255 & (n1156[0] << 3 | n1168[1]);
  n1139[0] = n1138[0];
  n1139[1] = 255 & (n1126[0] << 3 | n1138[1]);
  n1085[0] = n1084[0];
  n1085[1] = 255 & (n1072[0] << 3 | n1084[1]);
  n1056[0] = n1055[0];
  n1056[1] = 255 & (n1043[0] << 3 | n1055[1]);
  n1003[0] = n1002[0];
  n1003[1] = 255 & (n990[0] << 3 | n1002[1]);
  n975[0] = n974[0];
  n975[1] = 255 & (n962[0] << 3 | n974[1]);
  n923[0] = n922[0];
  n923[1] = 255 & (n910[0] << 3 | n922[1]);
  n896[0] = n895[0];
  n896[1] = 255 & (n883[0] << 3 | n895[1]);
  n846[0] = 255 & (n844[0] << 5 | n845[0]);
  n846[1] = 255 & (n844[1] << 5 | n844[0] >> 3);
  n820[0] = 255 & (n818[0] << 5 | n819[0]);
  n820[1] = 255 & (n818[1] << 5 | n818[0] >> 3);
  { unsigned int tmp; (tmp = (unsigned int) n704[1] - (unsigned int) n769[1] - (tmp = (unsigned int) n704[0] - (unsigned int) n769[0], n771[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n771[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n704[1] + (unsigned int) n769[1] + (tmp = (unsigned int) n704[0] + (unsigned int) n769[0], n770[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n770[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n680[1] - (unsigned int) n744[1] - (tmp = (unsigned int) n680[0] - (unsigned int) n744[0], n746[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n746[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n680[1] + (unsigned int) n744[1] + (tmp = (unsigned int) n680[0] + (unsigned int) n744[0], n745[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n745[1] = 255 & (unsigned char) tmp); }
  if (n681[0]) {
    n697[0] = n695[0];
    n697[1] = n695[1];
  }
  else {
    n697[0] = n696[0];
    n697[1] = n696[1];
  }
  if (n657[0]) {
    n673[0] = n671[0];
    n673[1] = n671[1];
  }
  else {
    n673[0] = n672[0];
    n673[1] = n672[1];
  }
  n631r[0] = reset_i[0];
  n631e[0] = enable_i[0];
  n631d[0] = n624[0];
  n631d[1] = n624[1];
  n608r[0] = reset_i[0];
  n608e[0] = enable_i[0];
  n608d[0] = n601[0];
  n608d[1] = n601[1];
  n1170[0] = n1169[0];
  n1170[1] = 255 & (n1156[0] << 4 | n1169[1]);
  n1140[0] = n1139[0];
  n1140[1] = 255 & (n1126[0] << 4 | n1139[1]);
  n1086[0] = n1085[0];
  n1086[1] = 255 & (n1072[0] << 4 | n1085[1]);
  n1057[0] = n1056[0];
  n1057[1] = 255 & (n1043[0] << 4 | n1056[1]);
  n1004[0] = n1003[0];
  n1004[1] = 255 & (n990[0] << 4 | n1003[1]);
  n976[0] = n975[0];
  n976[1] = 255 & (n962[0] << 4 | n975[1]);
  n925[0] = 255 & (n923[0] << 4 | n924[0]);
  n925[1] = 255 & (n923[1] << 4 | n923[0] >> 4);
  n898[0] = 255 & (n896[0] << 4 | n897[0]);
  n898[1] = 255 & (n896[1] << 4 | n896[0] >> 4);
  { unsigned int tmp; (tmp = (unsigned int) n779[1] - (unsigned int) n846[1] - (tmp = (unsigned int) n779[0] - (unsigned int) n846[0], n848[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n848[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n779[1] + (unsigned int) n846[1] + (tmp = (unsigned int) n779[0] + (unsigned int) n846[0], n847[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n847[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n754[1] - (unsigned int) n820[1] - (tmp = (unsigned int) n754[0] - (unsigned int) n820[0], n822[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n822[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n754[1] + (unsigned int) n820[1] + (tmp = (unsigned int) n754[0] + (unsigned int) n820[0], n821[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n821[1] = 255 & (unsigned char) tmp); }
  if (n755[0]) {
    n772[0] = n770[0];
    n772[1] = n770[1];
  }
  else {
    n772[0] = n771[0];
    n772[1] = n771[1];
  }
  if (n730[0]) {
    n747[0] = n745[0];
    n747[1] = n745[1];
  }
  else {
    n747[0] = n746[0];
    n747[1] = n746[1];
  }
  n704r[0] = reset_i[0];
  n704e[0] = enable_i[0];
  n704d[0] = n697[0];
  n704d[1] = n697[1];
  n680r[0] = reset_i[0];
  n680e[0] = enable_i[0];
  n680d[0] = n673[0];
  n680d[1] = n673[1];
  n1171[0] = n1170[0];
  n1171[1] = 255 & (n1156[0] << 5 | n1170[1]);
  n1141[0] = n1140[0];
  n1141[1] = 255 & (n1126[0] << 5 | n1140[1]);
  n1087[0] = n1086[0];
  n1087[1] = 255 & (n1072[0] << 5 | n1086[1]);
  n1058[0] = n1057[0];
  n1058[1] = 255 & (n1043[0] << 5 | n1057[1]);
  n1006[0] = 255 & (n1004[0] << 3 | n1005[0]);
  n1006[1] = 255 & (n1004[1] << 3 | n1004[0] >> 5);
  n978[0] = 255 & (n976[0] << 3 | n977[0]);
  n978[1] = 255 & (n976[1] << 3 | n976[0] >> 5);
  { unsigned int tmp; (tmp = (unsigned int) n856[1] - (unsigned int) n925[1] - (tmp = (unsigned int) n856[0] - (unsigned int) n925[0], n927[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n927[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n856[1] + (unsigned int) n925[1] + (tmp = (unsigned int) n856[0] + (unsigned int) n925[0], n926[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n926[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n830[1] - (unsigned int) n898[1] - (tmp = (unsigned int) n830[0] - (unsigned int) n898[0], n900[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n900[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n830[1] + (unsigned int) n898[1] + (tmp = (unsigned int) n830[0] + (unsigned int) n898[0], n899[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n899[1] = 255 & (unsigned char) tmp); }
  if (n831[0]) {
    n849[0] = n847[0];
    n849[1] = n847[1];
  }
  else {
    n849[0] = n848[0];
    n849[1] = n848[1];
  }
  if (n805[0]) {
    n823[0] = n821[0];
    n823[1] = n821[1];
  }
  else {
    n823[0] = n822[0];
    n823[1] = n822[1];
  }
  n779r[0] = reset_i[0];
  n779e[0] = enable_i[0];
  n779d[0] = n772[0];
  n779d[1] = n772[1];
  n754r[0] = reset_i[0];
  n754e[0] = enable_i[0];
  n754d[0] = n747[0];
  n754d[1] = n747[1];
  n1172[0] = n1171[0];
  n1172[1] = 255 & (n1156[0] << 6 | n1171[1]);
  n1142[0] = n1141[0];
  n1142[1] = 255 & (n1126[0] << 6 | n1141[1]);
  n1089[0] = 255 & (n1087[0] << 2 | n1088[0]);
  n1089[1] = 255 & (n1087[1] << 2 | n1087[0] >> 6);
  n1060[0] = 255 & (n1058[0] << 2 | n1059[0]);
  n1060[1] = 255 & (n1058[1] << 2 | n1058[0] >> 6);
  { unsigned int tmp; (tmp = (unsigned int) n935[1] - (unsigned int) n1006[1] - (tmp = (unsigned int) n935[0] - (unsigned int) n1006[0], n1008[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1008[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n935[1] + (unsigned int) n1006[1] + (tmp = (unsigned int) n935[0] + (unsigned int) n1006[0], n1007[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1007[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n908[1] - (unsigned int) n978[1] - (tmp = (unsigned int) n908[0] - (unsigned int) n978[0], n980[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n980[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n908[1] + (unsigned int) n978[1] + (tmp = (unsigned int) n908[0] + (unsigned int) n978[0], n979[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n979[1] = 255 & (unsigned char) tmp); }
  if (n909[0]) {
    n928[0] = n926[0];
    n928[1] = n926[1];
  }
  else {
    n928[0] = n927[0];
    n928[1] = n927[1];
  }
  if (n882[0]) {
    n901[0] = n899[0];
    n901[1] = n899[1];
  }
  else {
    n901[0] = n900[0];
    n901[1] = n900[1];
  }
  n856r[0] = reset_i[0];
  n856e[0] = enable_i[0];
  n856d[0] = n849[0];
  n856d[1] = n849[1];
  n830r[0] = reset_i[0];
  n830e[0] = enable_i[0];
  n830d[0] = n823[0];
  n830d[1] = n823[1];
  n1174[0] = 255 & (n1172[0] << 1 | n1173[0]);
  n1174[1] = 255 & (n1172[1] << 1 | n1172[0] >> 7);
  n1144[0] = 255 & (n1142[0] << 1 | n1143[0]);
  n1144[1] = 255 & (n1142[1] << 1 | n1142[0] >> 7);
  { unsigned int tmp; (tmp = (unsigned int) n1016[1] - (unsigned int) n1089[1] - (tmp = (unsigned int) n1016[0] - (unsigned int) n1089[0], n1091[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1091[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1016[1] + (unsigned int) n1089[1] + (tmp = (unsigned int) n1016[0] + (unsigned int) n1089[0], n1090[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1090[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n988[1] - (unsigned int) n1060[1] - (tmp = (unsigned int) n988[0] - (unsigned int) n1060[0], n1062[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1062[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n988[1] + (unsigned int) n1060[1] + (tmp = (unsigned int) n988[0] + (unsigned int) n1060[0], n1061[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1061[1] = 255 & (unsigned char) tmp); }
  if (n989[0]) {
    n1009[0] = n1007[0];
    n1009[1] = n1007[1];
  }
  else {
    n1009[0] = n1008[0];
    n1009[1] = n1008[1];
  }
  if (n961[0]) {
    n981[0] = n979[0];
    n981[1] = n979[1];
  }
  else {
    n981[0] = n980[0];
    n981[1] = n980[1];
  }
  n935r[0] = reset_i[0];
  n935e[0] = enable_i[0];
  n935d[0] = n928[0];
  n935d[1] = n928[1];
  n908r[0] = reset_i[0];
  n908e[0] = enable_i[0];
  n908d[0] = n901[0];
  n908d[1] = n901[1];
  { unsigned int tmp; (tmp = (unsigned int) n1099[1] - (unsigned int) n1174[1] - (tmp = (unsigned int) n1099[0] - (unsigned int) n1174[0], n1176[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1176[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1099[1] + (unsigned int) n1174[1] + (tmp = (unsigned int) n1099[0] + (unsigned int) n1174[0], n1175[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1175[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1070[1] - (unsigned int) n1144[1] - (tmp = (unsigned int) n1070[0] - (unsigned int) n1144[0], n1146[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1146[1] = 255 & (unsigned char) tmp); }
  { unsigned int tmp; (tmp = (unsigned int) n1070[1] + (unsigned int) n1144[1] + (tmp = (unsigned int) n1070[0] + (unsigned int) n1144[0], n1145[0] = 255 & (unsigned char) tmp, 1 & (tmp >> 8)), n1145[1] = 255 & (unsigned char) tmp); }
  if (n1071[0]) {
    n1092[0] = n1090[0];
    n1092[1] = n1090[1];
  }
  else {
    n1092[0] = n1091[0];
    n1092[1] = n1091[1];
  }
  if (n1042[0]) {
    n1063[0] = n1061[0];
    n1063[1] = n1061[1];
  }
  else {
    n1063[0] = n1062[0];
    n1063[1] = n1062[1];
  }
  n1016r[0] = reset_i[0];
  n1016e[0] = enable_i[0];
  n1016d[0] = n1009[0];
  n1016d[1] = n1009[1];
  n988r[0] = reset_i[0];
  n988e[0] = enable_i[0];
  n988d[0] = n981[0];
  n988d[1] = n981[1];
  if (n1155[0]) {
    n1177[0] = n1175[0];
    n1177[1] = n1175[1];
  }
  else {
    n1177[0] = n1176[0];
    n1177[1] = n1176[1];
  }
  if (n1125[0]) {
    n1147[0] = n1145[0];
    n1147[1] = n1145[1];
  }
  else {
    n1147[0] = n1146[0];
    n1147[1] = n1146[1];
  }
  n1099r[0] = reset_i[0];
  n1099e[0] = enable_i[0];
  n1099d[0] = n1092[0];
  n1099d[1] = n1092[1];
  n1070r[0] = reset_i[0];
  n1070e[0] = enable_i[0];
  n1070d[0] = n1063[0];
  n1070d[1] = n1063[1];
  n1184r[0] = reset_i[0];
  n1184e[0] = enable_i[0];
  n1184d[0] = n1177[0];
  n1184d[1] = n1177[1];
  n1154r[0] = reset_i[0];
  n1154e[0] = enable_i[0];
  n1154d[0] = n1147[0];
  n1154d[1] = n1147[1];
}

void cf_cordic_v_16_16_16_init() {
  { int index; for (index = 3; index > 0;) n1304[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1302[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1300[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1298[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1296[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1294[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1292[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1290[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1288[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1286[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1284[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1282[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1280[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1278[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1276[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1274[--index] = 0; }
  { int index; for (index = 3; index > 0;) n1272[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1203[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1185[--index] = 0; }
  n1173[0] = 0;
  n1156[0] = 0;
  n1143[0] = 0;
  n1126[0] = 0;
  n1122[0] = 0;
  { int index; for (index = 2; index > 0;) n1114[--index] = 0; }
  n1112[0] = 0;
  { int index; for (index = 2; index > 0;) n1100[--index] = 0; }
  n1088[0] = 0;
  n1072[0] = 0;
  n1059[0] = 0;
  n1043[0] = 0;
  n1039[0] = 0;
  { int index; for (index = 2; index > 0;) n1031[--index] = 0; }
  n1029[0] = 0;
  { int index; for (index = 2; index > 0;) n1017[--index] = 0; }
  n1005[0] = 0;
  n990[0] = 0;
  n977[0] = 0;
  n962[0] = 0;
  n958[0] = 0;
  { int index; for (index = 2; index > 0;) n950[--index] = 0; }
  n948[0] = 0;
  { int index; for (index = 2; index > 0;) n936[--index] = 0; }
  n924[0] = 0;
  n910[0] = 0;
  n897[0] = 0;
  n883[0] = 0;
  n879[0] = 0;
  { int index; for (index = 2; index > 0;) n871[--index] = 0; }
  n869[0] = 0;
  { int index; for (index = 2; index > 0;) n857[--index] = 0; }
  n845[0] = 0;
  n832[0] = 0;
  n819[0] = 0;
  n806[0] = 0;
  n802[0] = 0;
  { int index; for (index = 2; index > 0;) n794[--index] = 0; }
  n792[0] = 0;
  { int index; for (index = 2; index > 0;) n780[--index] = 0; }
  n768[0] = 0;
  n756[0] = 0;
  n743[0] = 0;
  n731[0] = 0;
  n727[0] = 0;
  { int index; for (index = 2; index > 0;) n719[--index] = 0; }
  n717[0] = 0;
  { int index; for (index = 2; index > 0;) n705[--index] = 0; }
  n693[0] = 0;
  n682[0] = 0;
  n669[0] = 0;
  n658[0] = 0;
  n654[0] = 0;
  { int index; for (index = 2; index > 0;) n646[--index] = 0; }
  n644[0] = 0;
  { int index; for (index = 2; index > 0;) n632[--index] = 0; }
  n620[0] = 0;
  n610[0] = 0;
  n597[0] = 0;
  n587[0] = 0;
  n583[0] = 0;
  { int index; for (index = 2; index > 0;) n575[--index] = 0; }
  n573[0] = 0;
  { int index; for (index = 2; index > 0;) n561[--index] = 0; }
  { int index; for (index = 2; index > 0;) n549[--index] = 0; }
  n540[0] = 0;
  { int index; for (index = 2; index > 0;) n527[--index] = 0; }
  n518[0] = 0;
  n514[0] = 0;
  { int index; for (index = 2; index > 0;) n506[--index] = 0; }
  n504[0] = 0;
  { int index; for (index = 2; index > 0;) n492[--index] = 0; }
  { int index; for (index = 2; index > 0;) n480[--index] = 0; }
  n472[0] = 0;
  { int index; for (index = 2; index > 0;) n459[--index] = 0; }
  n451[0] = 0;
  n447[0] = 0;
  { int index; for (index = 2; index > 0;) n439[--index] = 0; }
  n437[0] = 0;
  { int index; for (index = 2; index > 0;) n425[--index] = 0; }
  { int index; for (index = 2; index > 0;) n413[--index] = 0; }
  n406[0] = 0;
  { int index; for (index = 2; index > 0;) n393[--index] = 0; }
  n386[0] = 0;
  n382[0] = 0;
  { int index; for (index = 2; index > 0;) n374[--index] = 0; }
  n372[0] = 0;
  { int index; for (index = 2; index > 0;) n360[--index] = 0; }
  { int index; for (index = 2; index > 0;) n348[--index] = 0; }
  n342[0] = 0;
  { int index; for (index = 2; index > 0;) n329[--index] = 0; }
  n323[0] = 0;
  n319[0] = 0;
  { int index; for (index = 2; index > 0;) n311[--index] = 0; }
  n309[0] = 0;
  { int index; for (index = 2; index > 0;) n297[--index] = 0; }
  { int index; for (index = 2; index > 0;) n285[--index] = 0; }
  n280[0] = 0;
  { int index; for (index = 2; index > 0;) n267[--index] = 0; }
  n262[0] = 0;
  n258[0] = 0;
  { int index; for (index = 2; index > 0;) n250[--index] = 0; }
  n248[0] = 0;
  { int index; for (index = 2; index > 0;) n236[--index] = 0; }
  { int index; for (index = 2; index > 0;) n224[--index] = 0; }
  n220[0] = 0;
  { int index; for (index = 2; index > 0;) n207[--index] = 0; }
  n203[0] = 0;
  n199[0] = 0;
  { int index; for (index = 2; index > 0;) n191[--index] = 0; }
  n189[0] = 0;
  { int index; for (index = 2; index > 0;) n177[--index] = 0; }
  { int index; for (index = 2; index > 0;) n165[--index] = 0; }
  n162[0] = 0;
  { int index; for (index = 2; index > 0;) n149[--index] = 0; }
  n146[0] = 0;
  n142[0] = 0;
  { int index; for (index = 2; index > 0;) n134[--index] = 0; }
  n132[0] = 0;
  { int index; for (index = 2; index > 0;) n120[--index] = 0; }
  { int index; for (index = 2; index > 0;) n108[--index] = 0; }
  { int index; for (index = 2; index > 0;) n93[--index] = 0; }
  n87[0] = 0;
  { int index; for (index = 2; index > 0;) n79[--index] = 0; }
  n77[0] = 0;
  { int index; for (index = 2; index > 0;) n46[--index] = 0; }
  { int index; for (index = 2; index > 0;) n44[--index] = 0; }
  n38[0] = 0;
  { int index; for (index = 2; index > 0;) n32[--index] = 0; }
  n30[0] = 0;
  { int index; for (index = 2; index > 0;) n1187[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1186[--index] = 0; }
  n1159[0] = 0;
  n1129[0] = 0;
  n1113[0] = 0;
  { int index; for (index = 2; index > 0;) n1102[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1101[--index] = 0; }
  n1075[0] = 0;
  n1046[0] = 0;
  n1030[0] = 0;
  { int index; for (index = 2; index > 0;) n1019[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1018[--index] = 0; }
  n993[0] = 0;
  n965[0] = 0;
  n949[0] = 0;
  { int index; for (index = 2; index > 0;) n938[--index] = 0; }
  { int index; for (index = 2; index > 0;) n937[--index] = 0; }
  n913[0] = 0;
  n886[0] = 0;
  n870[0] = 0;
  { int index; for (index = 2; index > 0;) n859[--index] = 0; }
  { int index; for (index = 2; index > 0;) n858[--index] = 0; }
  n835[0] = 0;
  n809[0] = 0;
  n793[0] = 0;
  { int index; for (index = 2; index > 0;) n782[--index] = 0; }
  { int index; for (index = 2; index > 0;) n781[--index] = 0; }
  n759[0] = 0;
  n734[0] = 0;
  n718[0] = 0;
  { int index; for (index = 2; index > 0;) n707[--index] = 0; }
  { int index; for (index = 2; index > 0;) n706[--index] = 0; }
  n685[0] = 0;
  n661[0] = 0;
  n645[0] = 0;
  { int index; for (index = 2; index > 0;) n634[--index] = 0; }
  { int index; for (index = 2; index > 0;) n633[--index] = 0; }
  n613[0] = 0;
  n590[0] = 0;
  n574[0] = 0;
  { int index; for (index = 2; index > 0;) n563[--index] = 0; }
  { int index; for (index = 2; index > 0;) n562[--index] = 0; }
  n543[0] = 0;
  n521[0] = 0;
  n505[0] = 0;
  { int index; for (index = 2; index > 0;) n494[--index] = 0; }
  { int index; for (index = 2; index > 0;) n493[--index] = 0; }
  n475[0] = 0;
  n454[0] = 0;
  n438[0] = 0;
  { int index; for (index = 2; index > 0;) n427[--index] = 0; }
  { int index; for (index = 2; index > 0;) n426[--index] = 0; }
  n409[0] = 0;
  n389[0] = 0;
  n373[0] = 0;
  { int index; for (index = 2; index > 0;) n362[--index] = 0; }
  { int index; for (index = 2; index > 0;) n361[--index] = 0; }
  n345[0] = 0;
  n326[0] = 0;
  n310[0] = 0;
  { int index; for (index = 2; index > 0;) n299[--index] = 0; }
  { int index; for (index = 2; index > 0;) n298[--index] = 0; }
  n283[0] = 0;
  n265[0] = 0;
  n249[0] = 0;
  { int index; for (index = 2; index > 0;) n238[--index] = 0; }
  { int index; for (index = 2; index > 0;) n237[--index] = 0; }
  n223[0] = 0;
  n206[0] = 0;
  n190[0] = 0;
  { int index; for (index = 2; index > 0;) n179[--index] = 0; }
  { int index; for (index = 2; index > 0;) n178[--index] = 0; }
  { int index; for (index = 2; index > 0;) n166[--index] = 0; }
  { int index; for (index = 2; index > 0;) n150[--index] = 0; }
  n133[0] = 0;
  { int index; for (index = 2; index > 0;) n122[--index] = 0; }
  { int index; for (index = 2; index > 0;) n121[--index] = 0; }
  { int index; for (index = 2; index > 0;) n111[--index] = 0; }
  { int index; for (index = 2; index > 0;) n110[--index] = 0; }
  { int index; for (index = 2; index > 0;) n96[--index] = 0; }
  { int index; for (index = 2; index > 0;) n95[--index] = 0; }
  n78[0] = 0;
  { int index; for (index = 2; index > 0;) n51[--index] = 0; }
  { int index; for (index = 2; index > 0;) n47[--index] = 0; }
  { int index; for (index = 2; index > 0;) n45[--index] = 0; }
  n31[0] = 0;
  { int index; for (index = 2; index > 0;) n28[--index] = 0; }
  n28r[0] = 0;
  n28e[0] = 0;
  { int index; for (index = 2; index > 0;) n28d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n21[--index] = 0; }
  n21r[0] = 0;
  n21e[0] = 0;
  { int index; for (index = 2; index > 0;) n21d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n14[--index] = 0; }
  n14r[0] = 0;
  n14e[0] = 0;
  { int index; for (index = 2; index > 0;) n14d[--index] = 0; }
  n1160[0] = 0;
  n1130[0] = 0;
  { int index; for (index = 2; index > 0;) n1115[--index] = 0; }
  n1076[0] = 0;
  n1047[0] = 0;
  { int index; for (index = 2; index > 0;) n1032[--index] = 0; }
  n994[0] = 0;
  n966[0] = 0;
  { int index; for (index = 2; index > 0;) n951[--index] = 0; }
  n914[0] = 0;
  n887[0] = 0;
  { int index; for (index = 2; index > 0;) n872[--index] = 0; }
  n836[0] = 0;
  n810[0] = 0;
  { int index; for (index = 2; index > 0;) n795[--index] = 0; }
  n760[0] = 0;
  n735[0] = 0;
  { int index; for (index = 2; index > 0;) n720[--index] = 0; }
  n686[0] = 0;
  n662[0] = 0;
  { int index; for (index = 2; index > 0;) n647[--index] = 0; }
  n614[0] = 0;
  n591[0] = 0;
  { int index; for (index = 2; index > 0;) n576[--index] = 0; }
  n544[0] = 0;
  n522[0] = 0;
  { int index; for (index = 2; index > 0;) n507[--index] = 0; }
  n476[0] = 0;
  n455[0] = 0;
  { int index; for (index = 2; index > 0;) n440[--index] = 0; }
  n410[0] = 0;
  n390[0] = 0;
  { int index; for (index = 2; index > 0;) n375[--index] = 0; }
  n346[0] = 0;
  n327[0] = 0;
  { int index; for (index = 2; index > 0;) n312[--index] = 0; }
  n284[0] = 0;
  n266[0] = 0;
  { int index; for (index = 2; index > 0;) n251[--index] = 0; }
  { int index; for (index = 2; index > 0;) n225[--index] = 0; }
  { int index; for (index = 2; index > 0;) n208[--index] = 0; }
  { int index; for (index = 2; index > 0;) n192[--index] = 0; }
  { int index; for (index = 2; index > 0;) n168[--index] = 0; }
  { int index; for (index = 2; index > 0;) n167[--index] = 0; }
  { int index; for (index = 2; index > 0;) n152[--index] = 0; }
  { int index; for (index = 2; index > 0;) n151[--index] = 0; }
  { int index; for (index = 2; index > 0;) n135[--index] = 0; }
  { int index; for (index = 2; index > 0;) n80[--index] = 0; }
  { int index; for (index = 2; index > 0;) n33[--index] = 0; }
  n1161[0] = 0;
  n1131[0] = 0;
  { int index; for (index = 3; index > 0;) n1123[--index] = 0; }
  n1077[0] = 0;
  n1048[0] = 0;
  { int index; for (index = 3; index > 0;) n1040[--index] = 0; }
  n995[0] = 0;
  n967[0] = 0;
  { int index; for (index = 3; index > 0;) n959[--index] = 0; }
  n915[0] = 0;
  n888[0] = 0;
  { int index; for (index = 3; index > 0;) n880[--index] = 0; }
  n837[0] = 0;
  n811[0] = 0;
  { int index; for (index = 3; index > 0;) n803[--index] = 0; }
  n761[0] = 0;
  n736[0] = 0;
  { int index; for (index = 3; index > 0;) n728[--index] = 0; }
  n687[0] = 0;
  n663[0] = 0;
  { int index; for (index = 3; index > 0;) n655[--index] = 0; }
  n615[0] = 0;
  n592[0] = 0;
  { int index; for (index = 3; index > 0;) n584[--index] = 0; }
  n545[0] = 0;
  n523[0] = 0;
  { int index; for (index = 3; index > 0;) n515[--index] = 0; }
  n477[0] = 0;
  n456[0] = 0;
  { int index; for (index = 3; index > 0;) n448[--index] = 0; }
  n411[0] = 0;
  n391[0] = 0;
  { int index; for (index = 3; index > 0;) n383[--index] = 0; }
  n347[0] = 0;
  n328[0] = 0;
  { int index; for (index = 3; index > 0;) n320[--index] = 0; }
  { int index; for (index = 2; index > 0;) n286[--index] = 0; }
  { int index; for (index = 2; index > 0;) n268[--index] = 0; }
  { int index; for (index = 3; index > 0;) n259[--index] = 0; }
  { int index; for (index = 2; index > 0;) n227[--index] = 0; }
  { int index; for (index = 2; index > 0;) n226[--index] = 0; }
  { int index; for (index = 2; index > 0;) n210[--index] = 0; }
  { int index; for (index = 2; index > 0;) n209[--index] = 0; }
  { int index; for (index = 3; index > 0;) n200[--index] = 0; }
  { int index; for (index = 3; index > 0;) n143[--index] = 0; }
  { int index; for (index = 3; index > 0;) n88[--index] = 0; }
  { int index; for (index = 3; index > 0;) n39[--index] = 0; }
  n1162[0] = 0;
  n1132[0] = 0;
  { int index; for (index = 3; index > 0;) n1124[--index] = 0; }
  n1078[0] = 0;
  n1049[0] = 0;
  { int index; for (index = 3; index > 0;) n1041[--index] = 0; }
  n996[0] = 0;
  n968[0] = 0;
  { int index; for (index = 3; index > 0;) n960[--index] = 0; }
  n916[0] = 0;
  n889[0] = 0;
  { int index; for (index = 3; index > 0;) n881[--index] = 0; }
  n838[0] = 0;
  n812[0] = 0;
  { int index; for (index = 3; index > 0;) n804[--index] = 0; }
  n762[0] = 0;
  n737[0] = 0;
  { int index; for (index = 3; index > 0;) n729[--index] = 0; }
  n688[0] = 0;
  n664[0] = 0;
  { int index; for (index = 3; index > 0;) n656[--index] = 0; }
  n616[0] = 0;
  n593[0] = 0;
  { int index; for (index = 3; index > 0;) n585[--index] = 0; }
  n546[0] = 0;
  n524[0] = 0;
  { int index; for (index = 3; index > 0;) n516[--index] = 0; }
  n478[0] = 0;
  n457[0] = 0;
  { int index; for (index = 3; index > 0;) n449[--index] = 0; }
  n412[0] = 0;
  n392[0] = 0;
  { int index; for (index = 3; index > 0;) n384[--index] = 0; }
  { int index; for (index = 2; index > 0;) n349[--index] = 0; }
  { int index; for (index = 2; index > 0;) n330[--index] = 0; }
  { int index; for (index = 3; index > 0;) n321[--index] = 0; }
  { int index; for (index = 2; index > 0;) n288[--index] = 0; }
  { int index; for (index = 2; index > 0;) n287[--index] = 0; }
  { int index; for (index = 2; index > 0;) n270[--index] = 0; }
  { int index; for (index = 2; index > 0;) n269[--index] = 0; }
  { int index; for (index = 3; index > 0;) n260[--index] = 0; }
  { int index; for (index = 3; index > 0;) n201[--index] = 0; }
  { int index; for (index = 3; index > 0;) n144[--index] = 0; }
  { int index; for (index = 3; index > 0;) n89[--index] = 0; }
  { int index; for (index = 3; index > 0;) n42[--index] = 0; }
  n1163[0] = 0;
  n1133[0] = 0;
  n1125[0] = 0;
  n1079[0] = 0;
  n1050[0] = 0;
  n1042[0] = 0;
  n997[0] = 0;
  n969[0] = 0;
  n961[0] = 0;
  n917[0] = 0;
  n890[0] = 0;
  n882[0] = 0;
  n839[0] = 0;
  n813[0] = 0;
  n805[0] = 0;
  n763[0] = 0;
  n738[0] = 0;
  n730[0] = 0;
  n689[0] = 0;
  n665[0] = 0;
  n657[0] = 0;
  n617[0] = 0;
  n594[0] = 0;
  n586[0] = 0;
  n547[0] = 0;
  n525[0] = 0;
  n517[0] = 0;
  n479[0] = 0;
  n458[0] = 0;
  n450[0] = 0;
  { int index; for (index = 2; index > 0;) n414[--index] = 0; }
  { int index; for (index = 2; index > 0;) n394[--index] = 0; }
  n385[0] = 0;
  { int index; for (index = 2; index > 0;) n351[--index] = 0; }
  { int index; for (index = 2; index > 0;) n350[--index] = 0; }
  { int index; for (index = 2; index > 0;) n332[--index] = 0; }
  { int index; for (index = 2; index > 0;) n331[--index] = 0; }
  n322[0] = 0;
  n261[0] = 0;
  n202[0] = 0;
  n145[0] = 0;
  n90[0] = 0;
  n43[0] = 0;
  { int index; for (index = 2; index > 0;) n1188[--index] = 0; }
  n1164[0] = 0;
  n1155[0] = 0;
  n1134[0] = 0;
  { int index; for (index = 2; index > 0;) n1103[--index] = 0; }
  n1080[0] = 0;
  n1071[0] = 0;
  n1051[0] = 0;
  { int index; for (index = 2; index > 0;) n1020[--index] = 0; }
  n998[0] = 0;
  n989[0] = 0;
  n970[0] = 0;
  { int index; for (index = 2; index > 0;) n939[--index] = 0; }
  n918[0] = 0;
  n909[0] = 0;
  n891[0] = 0;
  { int index; for (index = 2; index > 0;) n860[--index] = 0; }
  n840[0] = 0;
  n831[0] = 0;
  n814[0] = 0;
  { int index; for (index = 2; index > 0;) n783[--index] = 0; }
  n764[0] = 0;
  n755[0] = 0;
  n739[0] = 0;
  { int index; for (index = 2; index > 0;) n708[--index] = 0; }
  n690[0] = 0;
  n681[0] = 0;
  n666[0] = 0;
  { int index; for (index = 2; index > 0;) n635[--index] = 0; }
  n618[0] = 0;
  n609[0] = 0;
  n595[0] = 0;
  { int index; for (index = 2; index > 0;) n564[--index] = 0; }
  n548[0] = 0;
  n539[0] = 0;
  n526[0] = 0;
  { int index; for (index = 2; index > 0;) n495[--index] = 0; }
  { int index; for (index = 2; index > 0;) n481[--index] = 0; }
  n471[0] = 0;
  { int index; for (index = 2; index > 0;) n460[--index] = 0; }
  { int index; for (index = 2; index > 0;) n428[--index] = 0; }
  { int index; for (index = 2; index > 0;) n416[--index] = 0; }
  { int index; for (index = 2; index > 0;) n415[--index] = 0; }
  n405[0] = 0;
  { int index; for (index = 2; index > 0;) n396[--index] = 0; }
  { int index; for (index = 2; index > 0;) n395[--index] = 0; }
  { int index; for (index = 2; index > 0;) n363[--index] = 0; }
  n341[0] = 0;
  { int index; for (index = 2; index > 0;) n333[--index] = 0; }
  { int index; for (index = 2; index > 0;) n300[--index] = 0; }
  n279[0] = 0;
  { int index; for (index = 2; index > 0;) n271[--index] = 0; }
  { int index; for (index = 2; index > 0;) n239[--index] = 0; }
  n219[0] = 0;
  { int index; for (index = 2; index > 0;) n211[--index] = 0; }
  { int index; for (index = 2; index > 0;) n180[--index] = 0; }
  n161[0] = 0;
  { int index; for (index = 2; index > 0;) n153[--index] = 0; }
  { int index; for (index = 2; index > 0;) n123[--index] = 0; }
  n105[0] = 0;
  { int index; for (index = 2; index > 0;) n97[--index] = 0; }
  { int index; for (index = 2; index > 0;) n68[--index] = 0; }
  { int index; for (index = 2; index > 0;) n60[--index] = 0; }
  { int index; for (index = 2; index > 0;) n52[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1195[--index] = 0; }
  n1195r[0] = 0;
  n1195e[0] = 0;
  { int index; for (index = 2; index > 0;) n1195d[--index] = 0; }
  n1165[0] = 0;
  n1135[0] = 0;
  { int index; for (index = 2; index > 0;) n1110[--index] = 0; }
  n1110r[0] = 0;
  n1110e[0] = 0;
  { int index; for (index = 2; index > 0;) n1110d[--index] = 0; }
  n1081[0] = 0;
  n1052[0] = 0;
  { int index; for (index = 2; index > 0;) n1027[--index] = 0; }
  n1027r[0] = 0;
  n1027e[0] = 0;
  { int index; for (index = 2; index > 0;) n1027d[--index] = 0; }
  n999[0] = 0;
  n971[0] = 0;
  { int index; for (index = 2; index > 0;) n946[--index] = 0; }
  n946r[0] = 0;
  n946e[0] = 0;
  { int index; for (index = 2; index > 0;) n946d[--index] = 0; }
  n919[0] = 0;
  n892[0] = 0;
  { int index; for (index = 2; index > 0;) n867[--index] = 0; }
  n867r[0] = 0;
  n867e[0] = 0;
  { int index; for (index = 2; index > 0;) n867d[--index] = 0; }
  n841[0] = 0;
  n815[0] = 0;
  { int index; for (index = 2; index > 0;) n790[--index] = 0; }
  n790r[0] = 0;
  n790e[0] = 0;
  { int index; for (index = 2; index > 0;) n790d[--index] = 0; }
  n765[0] = 0;
  n740[0] = 0;
  { int index; for (index = 2; index > 0;) n715[--index] = 0; }
  n715r[0] = 0;
  n715e[0] = 0;
  { int index; for (index = 2; index > 0;) n715d[--index] = 0; }
  n691[0] = 0;
  n667[0] = 0;
  { int index; for (index = 2; index > 0;) n642[--index] = 0; }
  n642r[0] = 0;
  n642e[0] = 0;
  { int index; for (index = 2; index > 0;) n642d[--index] = 0; }
  n619[0] = 0;
  n596[0] = 0;
  { int index; for (index = 2; index > 0;) n571[--index] = 0; }
  n571r[0] = 0;
  n571e[0] = 0;
  { int index; for (index = 2; index > 0;) n571d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n550[--index] = 0; }
  { int index; for (index = 2; index > 0;) n528[--index] = 0; }
  { int index; for (index = 2; index > 0;) n502[--index] = 0; }
  n502r[0] = 0;
  n502e[0] = 0;
  { int index; for (index = 2; index > 0;) n502d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n483[--index] = 0; }
  { int index; for (index = 2; index > 0;) n482[--index] = 0; }
  { int index; for (index = 2; index > 0;) n462[--index] = 0; }
  { int index; for (index = 2; index > 0;) n461[--index] = 0; }
  { int index; for (index = 2; index > 0;) n435[--index] = 0; }
  n435r[0] = 0;
  n435e[0] = 0;
  { int index; for (index = 2; index > 0;) n435d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n417[--index] = 0; }
  { int index; for (index = 2; index > 0;) n397[--index] = 0; }
  { int index; for (index = 2; index > 0;) n370[--index] = 0; }
  n370r[0] = 0;
  n370e[0] = 0;
  { int index; for (index = 2; index > 0;) n370d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n352[--index] = 0; }
  { int index; for (index = 2; index > 0;) n340[--index] = 0; }
  n340r[0] = 0;
  n340e[0] = 0;
  { int index; for (index = 2; index > 0;) n340d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n307[--index] = 0; }
  n307r[0] = 0;
  n307e[0] = 0;
  { int index; for (index = 2; index > 0;) n307d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n289[--index] = 0; }
  { int index; for (index = 2; index > 0;) n278[--index] = 0; }
  n278r[0] = 0;
  n278e[0] = 0;
  { int index; for (index = 2; index > 0;) n278d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n246[--index] = 0; }
  n246r[0] = 0;
  n246e[0] = 0;
  { int index; for (index = 2; index > 0;) n246d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n228[--index] = 0; }
  { int index; for (index = 2; index > 0;) n218[--index] = 0; }
  n218r[0] = 0;
  n218e[0] = 0;
  { int index; for (index = 2; index > 0;) n218d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n187[--index] = 0; }
  n187r[0] = 0;
  n187e[0] = 0;
  { int index; for (index = 2; index > 0;) n187d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n169[--index] = 0; }
  { int index; for (index = 2; index > 0;) n160[--index] = 0; }
  n160r[0] = 0;
  n160e[0] = 0;
  { int index; for (index = 2; index > 0;) n160d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n130[--index] = 0; }
  n130r[0] = 0;
  n130e[0] = 0;
  { int index; for (index = 2; index > 0;) n130d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n112[--index] = 0; }
  { int index; for (index = 2; index > 0;) n104[--index] = 0; }
  n104r[0] = 0;
  n104e[0] = 0;
  { int index; for (index = 2; index > 0;) n104d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n75[--index] = 0; }
  n75r[0] = 0;
  n75e[0] = 0;
  { int index; for (index = 2; index > 0;) n75d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n67[--index] = 0; }
  n67r[0] = 0;
  n67e[0] = 0;
  { int index; for (index = 2; index > 0;) n67d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n59[--index] = 0; }
  n59r[0] = 0;
  n59e[0] = 0;
  { int index; for (index = 2; index > 0;) n59d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1166[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1136[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1082[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1053[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1000[--index] = 0; }
  { int index; for (index = 2; index > 0;) n972[--index] = 0; }
  { int index; for (index = 2; index > 0;) n920[--index] = 0; }
  { int index; for (index = 2; index > 0;) n893[--index] = 0; }
  { int index; for (index = 2; index > 0;) n842[--index] = 0; }
  { int index; for (index = 2; index > 0;) n816[--index] = 0; }
  { int index; for (index = 2; index > 0;) n766[--index] = 0; }
  { int index; for (index = 2; index > 0;) n741[--index] = 0; }
  { int index; for (index = 2; index > 0;) n692[--index] = 0; }
  { int index; for (index = 2; index > 0;) n668[--index] = 0; }
  { int index; for (index = 2; index > 0;) n621[--index] = 0; }
  { int index; for (index = 2; index > 0;) n598[--index] = 0; }
  { int index; for (index = 2; index > 0;) n552[--index] = 0; }
  { int index; for (index = 2; index > 0;) n551[--index] = 0; }
  { int index; for (index = 2; index > 0;) n530[--index] = 0; }
  { int index; for (index = 2; index > 0;) n529[--index] = 0; }
  { int index; for (index = 2; index > 0;) n484[--index] = 0; }
  { int index; for (index = 2; index > 0;) n463[--index] = 0; }
  { int index; for (index = 2; index > 0;) n424[--index] = 0; }
  n424r[0] = 0;
  n424e[0] = 0;
  { int index; for (index = 2; index > 0;) n424d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n404[--index] = 0; }
  n404r[0] = 0;
  n404e[0] = 0;
  { int index; for (index = 2; index > 0;) n404d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n359[--index] = 0; }
  n359r[0] = 0;
  n359e[0] = 0;
  { int index; for (index = 2; index > 0;) n359d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n296[--index] = 0; }
  n296r[0] = 0;
  n296e[0] = 0;
  { int index; for (index = 2; index > 0;) n296d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n235[--index] = 0; }
  n235r[0] = 0;
  n235e[0] = 0;
  { int index; for (index = 2; index > 0;) n235d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n176[--index] = 0; }
  n176r[0] = 0;
  n176e[0] = 0;
  { int index; for (index = 2; index > 0;) n176d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n119[--index] = 0; }
  n119r[0] = 0;
  n119e[0] = 0;
  { int index; for (index = 2; index > 0;) n119d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1167[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1137[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1083[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1054[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1001[--index] = 0; }
  { int index; for (index = 2; index > 0;) n973[--index] = 0; }
  { int index; for (index = 2; index > 0;) n921[--index] = 0; }
  { int index; for (index = 2; index > 0;) n894[--index] = 0; }
  { int index; for (index = 2; index > 0;) n843[--index] = 0; }
  { int index; for (index = 2; index > 0;) n817[--index] = 0; }
  { int index; for (index = 2; index > 0;) n767[--index] = 0; }
  { int index; for (index = 2; index > 0;) n742[--index] = 0; }
  { int index; for (index = 2; index > 0;) n694[--index] = 0; }
  { int index; for (index = 2; index > 0;) n670[--index] = 0; }
  { int index; for (index = 2; index > 0;) n623[--index] = 0; }
  { int index; for (index = 2; index > 0;) n622[--index] = 0; }
  { int index; for (index = 2; index > 0;) n600[--index] = 0; }
  { int index; for (index = 2; index > 0;) n599[--index] = 0; }
  { int index; for (index = 2; index > 0;) n553[--index] = 0; }
  { int index; for (index = 2; index > 0;) n531[--index] = 0; }
  { int index; for (index = 2; index > 0;) n491[--index] = 0; }
  n491r[0] = 0;
  n491e[0] = 0;
  { int index; for (index = 2; index > 0;) n491d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n470[--index] = 0; }
  n470r[0] = 0;
  n470e[0] = 0;
  { int index; for (index = 2; index > 0;) n470d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1168[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1138[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1084[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1055[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1002[--index] = 0; }
  { int index; for (index = 2; index > 0;) n974[--index] = 0; }
  { int index; for (index = 2; index > 0;) n922[--index] = 0; }
  { int index; for (index = 2; index > 0;) n895[--index] = 0; }
  { int index; for (index = 2; index > 0;) n844[--index] = 0; }
  { int index; for (index = 2; index > 0;) n818[--index] = 0; }
  { int index; for (index = 2; index > 0;) n769[--index] = 0; }
  { int index; for (index = 2; index > 0;) n744[--index] = 0; }
  { int index; for (index = 2; index > 0;) n696[--index] = 0; }
  { int index; for (index = 2; index > 0;) n695[--index] = 0; }
  { int index; for (index = 2; index > 0;) n672[--index] = 0; }
  { int index; for (index = 2; index > 0;) n671[--index] = 0; }
  { int index; for (index = 2; index > 0;) n624[--index] = 0; }
  { int index; for (index = 2; index > 0;) n601[--index] = 0; }
  { int index; for (index = 2; index > 0;) n560[--index] = 0; }
  n560r[0] = 0;
  n560e[0] = 0;
  { int index; for (index = 2; index > 0;) n560d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n538[--index] = 0; }
  n538r[0] = 0;
  n538e[0] = 0;
  { int index; for (index = 2; index > 0;) n538d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1169[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1139[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1085[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1056[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1003[--index] = 0; }
  { int index; for (index = 2; index > 0;) n975[--index] = 0; }
  { int index; for (index = 2; index > 0;) n923[--index] = 0; }
  { int index; for (index = 2; index > 0;) n896[--index] = 0; }
  { int index; for (index = 2; index > 0;) n846[--index] = 0; }
  { int index; for (index = 2; index > 0;) n820[--index] = 0; }
  { int index; for (index = 2; index > 0;) n771[--index] = 0; }
  { int index; for (index = 2; index > 0;) n770[--index] = 0; }
  { int index; for (index = 2; index > 0;) n746[--index] = 0; }
  { int index; for (index = 2; index > 0;) n745[--index] = 0; }
  { int index; for (index = 2; index > 0;) n697[--index] = 0; }
  { int index; for (index = 2; index > 0;) n673[--index] = 0; }
  { int index; for (index = 2; index > 0;) n631[--index] = 0; }
  n631r[0] = 0;
  n631e[0] = 0;
  { int index; for (index = 2; index > 0;) n631d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n608[--index] = 0; }
  n608r[0] = 0;
  n608e[0] = 0;
  { int index; for (index = 2; index > 0;) n608d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1170[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1140[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1086[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1057[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1004[--index] = 0; }
  { int index; for (index = 2; index > 0;) n976[--index] = 0; }
  { int index; for (index = 2; index > 0;) n925[--index] = 0; }
  { int index; for (index = 2; index > 0;) n898[--index] = 0; }
  { int index; for (index = 2; index > 0;) n848[--index] = 0; }
  { int index; for (index = 2; index > 0;) n847[--index] = 0; }
  { int index; for (index = 2; index > 0;) n822[--index] = 0; }
  { int index; for (index = 2; index > 0;) n821[--index] = 0; }
  { int index; for (index = 2; index > 0;) n772[--index] = 0; }
  { int index; for (index = 2; index > 0;) n747[--index] = 0; }
  { int index; for (index = 2; index > 0;) n704[--index] = 0; }
  n704r[0] = 0;
  n704e[0] = 0;
  { int index; for (index = 2; index > 0;) n704d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n680[--index] = 0; }
  n680r[0] = 0;
  n680e[0] = 0;
  { int index; for (index = 2; index > 0;) n680d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1171[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1141[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1087[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1058[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1006[--index] = 0; }
  { int index; for (index = 2; index > 0;) n978[--index] = 0; }
  { int index; for (index = 2; index > 0;) n927[--index] = 0; }
  { int index; for (index = 2; index > 0;) n926[--index] = 0; }
  { int index; for (index = 2; index > 0;) n900[--index] = 0; }
  { int index; for (index = 2; index > 0;) n899[--index] = 0; }
  { int index; for (index = 2; index > 0;) n849[--index] = 0; }
  { int index; for (index = 2; index > 0;) n823[--index] = 0; }
  { int index; for (index = 2; index > 0;) n779[--index] = 0; }
  n779r[0] = 0;
  n779e[0] = 0;
  { int index; for (index = 2; index > 0;) n779d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n754[--index] = 0; }
  n754r[0] = 0;
  n754e[0] = 0;
  { int index; for (index = 2; index > 0;) n754d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1172[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1142[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1089[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1060[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1008[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1007[--index] = 0; }
  { int index; for (index = 2; index > 0;) n980[--index] = 0; }
  { int index; for (index = 2; index > 0;) n979[--index] = 0; }
  { int index; for (index = 2; index > 0;) n928[--index] = 0; }
  { int index; for (index = 2; index > 0;) n901[--index] = 0; }
  { int index; for (index = 2; index > 0;) n856[--index] = 0; }
  n856r[0] = 0;
  n856e[0] = 0;
  { int index; for (index = 2; index > 0;) n856d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n830[--index] = 0; }
  n830r[0] = 0;
  n830e[0] = 0;
  { int index; for (index = 2; index > 0;) n830d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1174[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1144[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1091[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1090[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1062[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1061[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1009[--index] = 0; }
  { int index; for (index = 2; index > 0;) n981[--index] = 0; }
  { int index; for (index = 2; index > 0;) n935[--index] = 0; }
  n935r[0] = 0;
  n935e[0] = 0;
  { int index; for (index = 2; index > 0;) n935d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n908[--index] = 0; }
  n908r[0] = 0;
  n908e[0] = 0;
  { int index; for (index = 2; index > 0;) n908d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1176[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1175[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1146[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1145[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1092[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1063[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1016[--index] = 0; }
  n1016r[0] = 0;
  n1016e[0] = 0;
  { int index; for (index = 2; index > 0;) n1016d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n988[--index] = 0; }
  n988r[0] = 0;
  n988e[0] = 0;
  { int index; for (index = 2; index > 0;) n988d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1177[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1147[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1099[--index] = 0; }
  n1099r[0] = 0;
  n1099e[0] = 0;
  { int index; for (index = 2; index > 0;) n1099d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1070[--index] = 0; }
  n1070r[0] = 0;
  n1070e[0] = 0;
  { int index; for (index = 2; index > 0;) n1070d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1184[--index] = 0; }
  n1184r[0] = 0;
  n1184e[0] = 0;
  { int index; for (index = 2; index > 0;) n1184d[--index] = 0; }
  { int index; for (index = 2; index > 0;) n1154[--index] = 0; }
  n1154r[0] = 0;
  n1154e[0] = 0;
  { int index; for (index = 2; index > 0;) n1154d[--index] = 0; }
  cf_cordic_v_16_16_16_calc();
}

void cf_cordic_v_16_16_16_cycle_clock()
{
  if (n14r[0]) {
    n14[0] = 0;
    n14[1] = 0;
  }
  else if (n14e[0]) {
    n14[0] = n14d[0];
    n14[1] = n14d[1];
  }
  if (n21r[0]) {
    n21[0] = 0;
    n21[1] = 0;
  }
  else if (n21e[0]) {
    n21[0] = n21d[0];
    n21[1] = n21d[1];
  }
  if (n28r[0]) {
    n28[0] = 0;
    n28[1] = 0;
  }
  else if (n28e[0]) {
    n28[0] = n28d[0];
    n28[1] = n28d[1];
  }
  if (n59r[0]) {
    n59[0] = 0;
    n59[1] = 0;
  }
  else if (n59e[0]) {
    n59[0] = n59d[0];
    n59[1] = n59d[1];
  }
  if (n67r[0]) {
    n67[0] = 0;
    n67[1] = 0;
  }
  else if (n67e[0]) {
    n67[0] = n67d[0];
    n67[1] = n67d[1];
  }
  if (n75r[0]) {
    n75[0] = 0;
    n75[1] = 0;
  }
  else if (n75e[0]) {
    n75[0] = n75d[0];
    n75[1] = n75d[1];
  }
  if (n104r[0]) {
    n104[0] = 0;
    n104[1] = 0;
  }
  else if (n104e[0]) {
    n104[0] = n104d[0];
    n104[1] = n104d[1];
  }
  if (n119r[0]) {
    n119[0] = 0;
    n119[1] = 0;
  }
  else if (n119e[0]) {
    n119[0] = n119d[0];
    n119[1] = n119d[1];
  }
  if (n130r[0]) {
    n130[0] = 0;
    n130[1] = 0;
  }
  else if (n130e[0]) {
    n130[0] = n130d[0];
    n130[1] = n130d[1];
  }
  if (n160r[0]) {
    n160[0] = 0;
    n160[1] = 0;
  }
  else if (n160e[0]) {
    n160[0] = n160d[0];
    n160[1] = n160d[1];
  }
  if (n176r[0]) {
    n176[0] = 0;
    n176[1] = 0;
  }
  else if (n176e[0]) {
    n176[0] = n176d[0];
    n176[1] = n176d[1];
  }
  if (n187r[0]) {
    n187[0] = 0;
    n187[1] = 0;
  }
  else if (n187e[0]) {
    n187[0] = n187d[0];
    n187[1] = n187d[1];
  }
  if (n218r[0]) {
    n218[0] = 0;
    n218[1] = 0;
  }
  else if (n218e[0]) {
    n218[0] = n218d[0];
    n218[1] = n218d[1];
  }
  if (n235r[0]) {
    n235[0] = 0;
    n235[1] = 0;
  }
  else if (n235e[0]) {
    n235[0] = n235d[0];
    n235[1] = n235d[1];
  }
  if (n246r[0]) {
    n246[0] = 0;
    n246[1] = 0;
  }
  else if (n246e[0]) {
    n246[0] = n246d[0];
    n246[1] = n246d[1];
  }
  if (n278r[0]) {
    n278[0] = 0;
    n278[1] = 0;
  }
  else if (n278e[0]) {
    n278[0] = n278d[0];
    n278[1] = n278d[1];
  }
  if (n296r[0]) {
    n296[0] = 0;
    n296[1] = 0;
  }
  else if (n296e[0]) {
    n296[0] = n296d[0];
    n296[1] = n296d[1];
  }
  if (n307r[0]) {
    n307[0] = 0;
    n307[1] = 0;
  }
  else if (n307e[0]) {
    n307[0] = n307d[0];
    n307[1] = n307d[1];
  }
  if (n340r[0]) {
    n340[0] = 0;
    n340[1] = 0;
  }
  else if (n340e[0]) {
    n340[0] = n340d[0];
    n340[1] = n340d[1];
  }
  if (n359r[0]) {
    n359[0] = 0;
    n359[1] = 0;
  }
  else if (n359e[0]) {
    n359[0] = n359d[0];
    n359[1] = n359d[1];
  }
  if (n370r[0]) {
    n370[0] = 0;
    n370[1] = 0;
  }
  else if (n370e[0]) {
    n370[0] = n370d[0];
    n370[1] = n370d[1];
  }
  if (n404r[0]) {
    n404[0] = 0;
    n404[1] = 0;
  }
  else if (n404e[0]) {
    n404[0] = n404d[0];
    n404[1] = n404d[1];
  }
  if (n424r[0]) {
    n424[0] = 0;
    n424[1] = 0;
  }
  else if (n424e[0]) {
    n424[0] = n424d[0];
    n424[1] = n424d[1];
  }
  if (n435r[0]) {
    n435[0] = 0;
    n435[1] = 0;
  }
  else if (n435e[0]) {
    n435[0] = n435d[0];
    n435[1] = n435d[1];
  }
  if (n470r[0]) {
    n470[0] = 0;
    n470[1] = 0;
  }
  else if (n470e[0]) {
    n470[0] = n470d[0];
    n470[1] = n470d[1];
  }
  if (n491r[0]) {
    n491[0] = 0;
    n491[1] = 0;
  }
  else if (n491e[0]) {
    n491[0] = n491d[0];
    n491[1] = n491d[1];
  }
  if (n502r[0]) {
    n502[0] = 0;
    n502[1] = 0;
  }
  else if (n502e[0]) {
    n502[0] = n502d[0];
    n502[1] = n502d[1];
  }
  if (n538r[0]) {
    n538[0] = 0;
    n538[1] = 0;
  }
  else if (n538e[0]) {
    n538[0] = n538d[0];
    n538[1] = n538d[1];
  }
  if (n560r[0]) {
    n560[0] = 0;
    n560[1] = 0;
  }
  else if (n560e[0]) {
    n560[0] = n560d[0];
    n560[1] = n560d[1];
  }
  if (n571r[0]) {
    n571[0] = 0;
    n571[1] = 0;
  }
  else if (n571e[0]) {
    n571[0] = n571d[0];
    n571[1] = n571d[1];
  }
  if (n608r[0]) {
    n608[0] = 0;
    n608[1] = 0;
  }
  else if (n608e[0]) {
    n608[0] = n608d[0];
    n608[1] = n608d[1];
  }
  if (n631r[0]) {
    n631[0] = 0;
    n631[1] = 0;
  }
  else if (n631e[0]) {
    n631[0] = n631d[0];
    n631[1] = n631d[1];
  }
  if (n642r[0]) {
    n642[0] = 0;
    n642[1] = 0;
  }
  else if (n642e[0]) {
    n642[0] = n642d[0];
    n642[1] = n642d[1];
  }
  if (n680r[0]) {
    n680[0] = 0;
    n680[1] = 0;
  }
  else if (n680e[0]) {
    n680[0] = n680d[0];
    n680[1] = n680d[1];
  }
  if (n704r[0]) {
    n704[0] = 0;
    n704[1] = 0;
  }
  else if (n704e[0]) {
    n704[0] = n704d[0];
    n704[1] = n704d[1];
  }
  if (n715r[0]) {
    n715[0] = 0;
    n715[1] = 0;
  }
  else if (n715e[0]) {
    n715[0] = n715d[0];
    n715[1] = n715d[1];
  }
  if (n754r[0]) {
    n754[0] = 0;
    n754[1] = 0;
  }
  else if (n754e[0]) {
    n754[0] = n754d[0];
    n754[1] = n754d[1];
  }
  if (n779r[0]) {
    n779[0] = 0;
    n779[1] = 0;
  }
  else if (n779e[0]) {
    n779[0] = n779d[0];
    n779[1] = n779d[1];
  }
  if (n790r[0]) {
    n790[0] = 0;
    n790[1] = 0;
  }
  else if (n790e[0]) {
    n790[0] = n790d[0];
    n790[1] = n790d[1];
  }
  if (n830r[0]) {
    n830[0] = 0;
    n830[1] = 0;
  }
  else if (n830e[0]) {
    n830[0] = n830d[0];
    n830[1] = n830d[1];
  }
  if (n856r[0]) {
    n856[0] = 0;
    n856[1] = 0;
  }
  else if (n856e[0]) {
    n856[0] = n856d[0];
    n856[1] = n856d[1];
  }
  if (n867r[0]) {
    n867[0] = 0;
    n867[1] = 0;
  }
  else if (n867e[0]) {
    n867[0] = n867d[0];
    n867[1] = n867d[1];
  }
  if (n908r[0]) {
    n908[0] = 0;
    n908[1] = 0;
  }
  else if (n908e[0]) {
    n908[0] = n908d[0];
    n908[1] = n908d[1];
  }
  if (n935r[0]) {
    n935[0] = 0;
    n935[1] = 0;
  }
  else if (n935e[0]) {
    n935[0] = n935d[0];
    n935[1] = n935d[1];
  }
  if (n946r[0]) {
    n946[0] = 0;
    n946[1] = 0;
  }
  else if (n946e[0]) {
    n946[0] = n946d[0];
    n946[1] = n946d[1];
  }
  if (n988r[0]) {
    n988[0] = 0;
    n988[1] = 0;
  }
  else if (n988e[0]) {
    n988[0] = n988d[0];
    n988[1] = n988d[1];
  }
  if (n1016r[0]) {
    n1016[0] = 0;
    n1016[1] = 0;
  }
  else if (n1016e[0]) {
    n1016[0] = n1016d[0];
    n1016[1] = n1016d[1];
  }
  if (n1027r[0]) {
    n1027[0] = 0;
    n1027[1] = 0;
  }
  else if (n1027e[0]) {
    n1027[0] = n1027d[0];
    n1027[1] = n1027d[1];
  }
  if (n1070r[0]) {
    n1070[0] = 0;
    n1070[1] = 0;
  }
  else if (n1070e[0]) {
    n1070[0] = n1070d[0];
    n1070[1] = n1070d[1];
  }
  if (n1099r[0]) {
    n1099[0] = 0;
    n1099[1] = 0;
  }
  else if (n1099e[0]) {
    n1099[0] = n1099d[0];
    n1099[1] = n1099d[1];
  }
  if (n1110r[0]) {
    n1110[0] = 0;
    n1110[1] = 0;
  }
  else if (n1110e[0]) {
    n1110[0] = n1110d[0];
    n1110[1] = n1110d[1];
  }
  if (n1154r[0]) {
    n1154[0] = 0;
    n1154[1] = 0;
  }
  else if (n1154e[0]) {
    n1154[0] = n1154d[0];
    n1154[1] = n1154d[1];
  }
  if (n1184r[0]) {
    n1184[0] = 0;
    n1184[1] = 0;
  }
  else if (n1184e[0]) {
    n1184[0] = n1184d[0];
    n1184[1] = n1184d[1];
  }
  if (n1195r[0]) {
    n1195[0] = 0;
    n1195[1] = 0;
  }
  else if (n1195e[0]) {
    n1195[0] = n1195d[0];
    n1195[1] = n1195d[1];
  }
}

static FILE* sim_file;
static int sim_count;
static unsigned char sim_enable_i[1];
static unsigned char sim_reset_i[1];
static unsigned char sim_real_i[2];
static unsigned char sim_imag_i[2];
static unsigned char sim_ang_i[2];
static unsigned char sim_real_o[2];
static unsigned char sim_imag_o[2];
static unsigned char sim_ang_o[2];

void cf_cordic_v_16_16_16_sim_init(const char* file) {
  time_t date = time(NULL);
  sim_count = 1;
  cf_cordic_v_16_16_16_init();
  sim_enable_i[0] = enable_i[0];
  sim_reset_i[0] = reset_i[0];
  sim_real_i[0] = real_i[0];
  sim_real_i[1] = real_i[1];
  sim_imag_i[0] = imag_i[0];
  sim_imag_i[1] = imag_i[1];
  sim_ang_i[0] = ang_i[0];
  sim_ang_i[1] = ang_i[1];
  sim_real_o[0] = real_o[0];
  sim_real_o[1] = real_o[1];
  sim_imag_o[0] = imag_o[0];
  sim_imag_o[1] = imag_o[1];
  sim_ang_o[0] = ang_o[0];
  sim_ang_o[1] = ang_o[1];
  sim_file = fopen(file, "w");
  fprintf(sim_file,
    "$date\n  %s$end\n"
    "$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n"
    "$timescale\n  1 ns\n$end\n"
    "$scope module cf_cordic_v_16_16_16 $end\n"
    "$var wire 1 ! enable_i $end\n"
    "$var wire 1 \" reset_i $end\n"
    "$var wire 16 # real_i $end\n"
    "$var wire 16 $ imag_i $end\n"
    "$var wire 16 %% ang_i $end\n"
    "$var wire 16 & real_o $end\n"
    "$var wire 16 ' imag_o $end\n"
    "$var wire 16 ( ang_o $end\n"
    "$upscope $end\n"
    "$enddefinitions $end\n"
    "#0\n"
    "$dumpvars\n", asctime(localtime(&date)));
  fprintf(sim_file, enable_i[0] ? "1!\n" : "0!\n");
  fprintf(sim_file, reset_i[0] ? "1\"\n" : "0\"\n");
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & real_i[byte]) ? "1" : "0");
        else if (bit & real_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " #\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & imag_i[byte]) ? "1" : "0");
        else if (bit & imag_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " $\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & ang_i[byte]) ? "1" : "0");
        else if (bit & ang_i[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " %%\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & real_o[byte]) ? "1" : "0");
        else if (bit & real_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " &\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & imag_o[byte]) ? "1" : "0");
        else if (bit & imag_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " '\n");
  }
  {
    int bit;
    int byte;
    int found = 0;
    for (byte = 1; byte >= 0; byte--) {
      for (bit = 128; bit >= 1; bit /= 2) {
        if (found)
          fprintf(sim_file, (bit & ang_o[byte]) ? "1" : "0");
        else if (bit & ang_o[byte]) {
          found = 1;
          fprintf(sim_file, "b1");
        }
      }
    }
    if (!found)
      fprintf(sim_file, "b0");
    fprintf(sim_file, " (\n");
  }
  fprintf(sim_file, "$end\n");
}

void cf_cordic_v_16_16_16_sim_end() {
  fprintf(sim_file, "#%d\n", sim_count);
  fclose(sim_file);
}

void cf_cordic_v_16_16_16_sim_sample() {
  int changed = 0;
  if (sim_enable_i[0] != enable_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, enable_i[0] ? "1!\n" : "0!\n");
    sim_enable_i[0] = enable_i[0];
  }
  if (sim_reset_i[0] != reset_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    fprintf(sim_file, reset_i[0] ? "1\"\n" : "0\"\n");
    sim_reset_i[0] = reset_i[0];
  }
  if (sim_real_i[1] != real_i[1] || sim_real_i[0] != real_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & real_i[byte]) ? "1" : "0");
          else if (bit & real_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " #\n");
    }
    sim_real_i[0] = real_i[0];
    sim_real_i[1] = real_i[1];
  }
  if (sim_imag_i[1] != imag_i[1] || sim_imag_i[0] != imag_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & imag_i[byte]) ? "1" : "0");
          else if (bit & imag_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " $\n");
    }
    sim_imag_i[0] = imag_i[0];
    sim_imag_i[1] = imag_i[1];
  }
  if (sim_ang_i[1] != ang_i[1] || sim_ang_i[0] != ang_i[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & ang_i[byte]) ? "1" : "0");
          else if (bit & ang_i[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " %%\n");
    }
    sim_ang_i[0] = ang_i[0];
    sim_ang_i[1] = ang_i[1];
  }
  if (sim_real_o[1] != real_o[1] || sim_real_o[0] != real_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & real_o[byte]) ? "1" : "0");
          else if (bit & real_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " &\n");
    }
    sim_real_o[0] = real_o[0];
    sim_real_o[1] = real_o[1];
  }
  if (sim_imag_o[1] != imag_o[1] || sim_imag_o[0] != imag_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & imag_o[byte]) ? "1" : "0");
          else if (bit & imag_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " '\n");
    }
    sim_imag_o[0] = imag_o[0];
    sim_imag_o[1] = imag_o[1];
  }
  if (sim_ang_o[1] != ang_o[1] || sim_ang_o[0] != ang_o[0]) {
    if (!changed) { changed = 1; fprintf(sim_file, "#%d\n", sim_count); }
    {
      int bit;
      int byte;
      int found = 0;
      for (byte = 1; byte >= 0; byte--) {
        for (bit = 128; bit >= 1; bit /= 2) {
          if (found)
            fprintf(sim_file, (bit & ang_o[byte]) ? "1" : "0");
          else if (bit & ang_o[byte]) {
            found = 1;
            fprintf(sim_file, "b1");
          }
        }
      }
      if (!found)
        fprintf(sim_file, "b0");
      fprintf(sim_file, " (\n");
    }
    sim_ang_o[0] = ang_o[0];
    sim_ang_o[1] = ang_o[1];
  }
  sim_count++;
}

